#line 1 "scan.c"
/*-------------------------------------------------------------------------
 *
 * scan.l
 *	  lexical scanner for PostgreSQL
 *
 * NOTE NOTE NOTE:
 *
 * The rules in this file must be kept in sync with src/fe_utils/psqlscan.l
 * and src/interfaces/ecpg/preproc/pgc.l!
 *
 * The rules are designed so that the scanner never has to backtrack,
 * in the sense that there is always a rule that can match the input
 * consumed so far (the rule action may internally throw back some input
 * with yyless(), however).  As explained in the flex manual, this makes
 * for a useful speed increase --- several percent faster when measuring
 * raw parsing (Flex + Bison).  The extra complexity is mostly in the rules
 * for handling float numbers and continued string literals.  If you change
 * the lexical rules, verify that you haven't broken the no-backtrack
 * property by running flex with the "-b" option and checking that the
 * resulting "lex.backup" file says that no backing up is needed.  (As of
 * Postgres 9.2, this check is made automatically by the Makefile.)
 *
 *
 * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * IDENTIFICATION
 *	  src/backend/parser/scan.l
 *
 *-------------------------------------------------------------------------
 */
#include "postgres.h"

#include <ctype.h>
#include <unistd.h>

#include "common/string.h"
#include "gramparse.h"
#include "nodes/miscnodes.h"
#include "parser/parser.h"		/* only needed for GUC variables */
#include "parser/scansup.h"
#include "port/pg_bitutils.h"
#include "mb/pg_wchar.h"
#include "utils/builtins.h"

#line 47 "scan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define core_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer core_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define core_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer core_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define core_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer core_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define core_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string core_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define core_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes core_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define core_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer core_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define core_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer core_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define core_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state core_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define core_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer core_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define core_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state core_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define core_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state core_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define core_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack core_yyensure_buffer_stack
#endif

#ifdef yylex
#define core_yylex_ALREADY_DEFINED
#else
#define yylex core_yylex
#endif

#ifdef yyrestart
#define core_yyrestart_ALREADY_DEFINED
#else
#define yyrestart core_yyrestart
#endif

#ifdef yylex_init
#define core_yylex_init_ALREADY_DEFINED
#else
#define yylex_init core_yylex_init
#endif

#ifdef yylex_init_extra
#define core_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra core_yylex_init_extra
#endif

#ifdef yylex_destroy
#define core_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy core_yylex_destroy
#endif

#ifdef yyget_debug
#define core_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug core_yyget_debug
#endif

#ifdef yyset_debug
#define core_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug core_yyset_debug
#endif

#ifdef yyget_extra
#define core_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra core_yyget_extra
#endif

#ifdef yyset_extra
#define core_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra core_yyset_extra
#endif

#ifdef yyget_in
#define core_yyget_in_ALREADY_DEFINED
#else
#define yyget_in core_yyget_in
#endif

#ifdef yyset_in
#define core_yyset_in_ALREADY_DEFINED
#else
#define yyset_in core_yyset_in
#endif

#ifdef yyget_out
#define core_yyget_out_ALREADY_DEFINED
#else
#define yyget_out core_yyget_out
#endif

#ifdef yyset_out
#define core_yyset_out_ALREADY_DEFINED
#else
#define yyset_out core_yyset_out
#endif

#ifdef yyget_leng
#define core_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng core_yyget_leng
#endif

#ifdef yyget_text
#define core_yyget_text_ALREADY_DEFINED
#else
#define yyget_text core_yyget_text
#endif

#ifdef yyget_lineno
#define core_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno core_yyget_lineno
#endif

#ifdef yyset_lineno
#define core_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno core_yyset_lineno
#endif

#ifdef yyget_column
#define core_yyget_column_ALREADY_DEFINED
#else
#define yyget_column core_yyget_column
#endif

#ifdef yyset_column
#define core_yyset_column_ALREADY_DEFINED
#else
#define yyset_column core_yyset_column
#endif

#ifdef yywrap
#define core_yywrap_ALREADY_DEFINED
#else
#define yywrap core_yywrap
#endif

#ifdef yyget_lval
#define core_yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval core_yyget_lval
#endif

#ifdef yyset_lval
#define core_yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval core_yyset_lval
#endif

#ifdef yyget_lloc
#define core_yyget_lloc_ALREADY_DEFINED
#else
#define yyget_lloc core_yyget_lloc
#endif

#ifdef yyset_lloc
#define core_yyset_lloc_ALREADY_DEFINED
#else
#define yyset_lloc core_yyset_lloc
#endif

#ifdef yyalloc
#define core_yyalloc_ALREADY_DEFINED
#else
#define yyalloc core_yyalloc
#endif

#ifdef yyrealloc
#define core_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc core_yyrealloc
#endif

#ifdef yyfree
#define core_yyfree_ALREADY_DEFINED
#else
#define yyfree core_yyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define core_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef const struct yy_trans_info *yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 76
#define YY_END_OF_BUFFER 77
struct yy_trans_info
	{
	flex_int16_t yy_verify;
	flex_int16_t yy_nxt;
	};
static const struct yy_trans_info yy_transition[24855] =
    {
 {   0,   0 }, {   0,24599 }, {   0,   0 }, {   0,24597 }, {   1,6192 },
 {   2,6192 }, {   3,6192 }, {   4,6192 }, {   5,6192 }, {   6,6192 },
 {   7,6192 }, {   8,6192 }, {   9,6194 }, {  10,6199 }, {  11,6194 },
 {  12,6194 }, {  13,6194 }, {  14,6192 }, {  15,6192 }, {  16,6192 },
 {  17,6192 }, {  18,6192 }, {  19,6192 }, {  20,6192 }, {  21,6192 },
 {  22,6192 }, {  23,6192 }, {  24,6192 }, {  25,6192 }, {  26,6192 },
 {  27,6192 }, {  28,6192 }, {  29,6192 }, {  30,6192 }, {  31,6192 },
 {  32,6194 }, {  33,6201 }, {  34,6196 }, {  35,6241 }, {  36,6307 },
 {  37,6564 }, {  38,6241 }, {  39,6214 }, {  40,6216 }, {  41,6216 },
 {  42,6564 }, {  43,6564 }, {  44,6216 }, {  45,6575 }, {  46,6594 },

 {  47,6665 }, {  48,6697 }, {  49,6954 }, {  50,6954 }, {  51,6954 },
 {  52,6954 }, {  53,6954 }, {  54,6954 }, {  55,6954 }, {  56,6954 },
 {  57,6954 }, {  58,6219 }, {  59,6216 }, {  60,7211 }, {  61,7222 },
 {  62,7289 }, {  63,6241 }, {  64,6241 }, {  65,7321 }, {  66,7578 },
 {  67,7321 }, {  68,7321 }, {  69,7835 }, {  70,7321 }, {  71,7321 },
 {  72,7321 }, {  73,7321 }, {  74,7321 }, {  75,7321 }, {  76,7321 },
 {  77,7321 }, {  78,8092 }, {  79,7321 }, {  80,7321 }, {  81,7321 },
 {  82,7321 }, {  83,7321 }, {  84,7321 }, {  85,8349 }, {  86,7321 },
 {  87,7321 }, {  88,8606 }, {  89,7321 }, {  90,7321 }, {  91,6216 },
 {  92,6192 }, {  93,6216 }, {  94,6564 }, {  95,7321 }, {  96,6241 },

 {  97,7321 }, {  98,7578 }, {  99,7321 }, { 100,7321 }, { 101,7835 },
 { 102,7321 }, { 103,7321 }, { 104,7321 }, { 105,7321 }, { 106,7321 },
 { 107,7321 }, { 108,7321 }, { 109,7321 }, { 110,8092 }, { 111,7321 },
 { 112,7321 }, { 113,7321 }, { 114,7321 }, { 115,7321 }, { 116,7321 },
 { 117,8349 }, { 118,7321 }, { 119,7321 }, { 120,8606 }, { 121,7321 },
 { 122,7321 }, { 123,6192 }, { 124,6241 }, { 125,6192 }, { 126,6241 },
 { 127,6192 }, { 128,7321 }, { 129,7321 }, { 130,7321 }, { 131,7321 },
 { 132,7321 }, { 133,7321 }, { 134,7321 }, { 135,7321 }, { 136,7321 },
 { 137,7321 }, { 138,7321 }, { 139,7321 }, { 140,7321 }, { 141,7321 },
 { 142,7321 }, { 143,7321 }, { 144,7321 }, { 145,7321 }, { 146,7321 },

 { 147,7321 }, { 148,7321 }, { 149,7321 }, { 150,7321 }, { 151,7321 },
 { 152,7321 }, { 153,7321 }, { 154,7321 }, { 155,7321 }, { 156,7321 },
 { 157,7321 }, { 158,7321 }, { 159,7321 }, { 160,7321 }, { 161,7321 },
 { 162,7321 }, { 163,7321 }, { 164,7321 }, { 165,7321 }, { 166,7321 },
 { 167,7321 }, { 168,7321 }, { 169,7321 }, { 170,7321 }, { 171,7321 },
 { 172,7321 }, { 173,7321 }, { 174,7321 }, { 175,7321 }, { 176,7321 },
 { 177,7321 }, { 178,7321 }, { 179,7321 }, { 180,7321 }, { 181,7321 },
 { 182,7321 }, { 183,7321 }, { 184,7321 }, { 185,7321 }, { 186,7321 },
 { 187,7321 }, { 188,7321 }, { 189,7321 }, { 190,7321 }, { 191,7321 },
 { 192,7321 }, { 193,7321 }, { 194,7321 }, { 195,7321 }, { 196,7321 },

 { 197,7321 }, { 198,7321 }, { 199,7321 }, { 200,7321 }, { 201,7321 },
 { 202,7321 }, { 203,7321 }, { 204,7321 }, { 205,7321 }, { 206,7321 },
 { 207,7321 }, { 208,7321 }, { 209,7321 }, { 210,7321 }, { 211,7321 },
 { 212,7321 }, { 213,7321 }, { 214,7321 }, { 215,7321 }, { 216,7321 },
 { 217,7321 }, { 218,7321 }, { 219,7321 }, { 220,7321 }, { 221,7321 },
 { 222,7321 }, { 223,7321 }, { 224,7321 }, { 225,7321 }, { 226,7321 },
 { 227,7321 }, { 228,7321 }, { 229,7321 }, { 230,7321 }, { 231,7321 },
 { 232,7321 }, { 233,7321 }, { 234,7321 }, { 235,7321 }, { 236,7321 },
 { 237,7321 }, { 238,7321 }, { 239,7321 }, { 240,7321 }, { 241,7321 },
 { 242,7321 }, { 243,7321 }, { 244,7321 }, { 245,7321 }, { 246,7321 },

 { 247,7321 }, { 248,7321 }, { 249,7321 }, { 250,7321 }, { 251,7321 },
 { 252,7321 }, { 253,7321 }, { 254,7321 }, { 255,7321 }, { 256,6192 },
 {   0,   0 }, {   0,24339 }, {   1,5934 }, {   2,5934 }, {   3,5934 },
 {   4,5934 }, {   5,5934 }, {   6,5934 }, {   7,5934 }, {   8,5934 },
 {   9,5936 }, {  10,5941 }, {  11,5936 }, {  12,5936 }, {  13,5936 },
 {  14,5934 }, {  15,5934 }, {  16,5934 }, {  17,5934 }, {  18,5934 },
 {  19,5934 }, {  20,5934 }, {  21,5934 }, {  22,5934 }, {  23,5934 },
 {  24,5934 }, {  25,5934 }, {  26,5934 }, {  27,5934 }, {  28,5934 },
 {  29,5934 }, {  30,5934 }, {  31,5934 }, {  32,5936 }, {  33,5943 },
 {  34,5938 }, {  35,5983 }, {  36,6049 }, {  37,6306 }, {  38,5983 },

 {  39,5956 }, {  40,5958 }, {  41,5958 }, {  42,6306 }, {  43,6306 },
 {  44,5958 }, {  45,6317 }, {  46,6336 }, {  47,6407 }, {  48,6439 },
 {  49,6696 }, {  50,6696 }, {  51,6696 }, {  52,6696 }, {  53,6696 },
 {  54,6696 }, {  55,6696 }, {  56,6696 }, {  57,6696 }, {  58,5961 },
 {  59,5958 }, {  60,6953 }, {  61,6964 }, {  62,7031 }, {  63,5983 },
 {  64,5983 }, {  65,7063 }, {  66,7320 }, {  67,7063 }, {  68,7063 },
 {  69,7577 }, {  70,7063 }, {  71,7063 }, {  72,7063 }, {  73,7063 },
 {  74,7063 }, {  75,7063 }, {  76,7063 }, {  77,7063 }, {  78,7834 },
 {  79,7063 }, {  80,7063 }, {  81,7063 }, {  82,7063 }, {  83,7063 },
 {  84,7063 }, {  85,8091 }, {  86,7063 }, {  87,7063 }, {  88,8348 },

 {  89,7063 }, {  90,7063 }, {  91,5958 }, {  92,5934 }, {  93,5958 },
 {  94,6306 }, {  95,7063 }, {  96,5983 }, {  97,7063 }, {  98,7320 },
 {  99,7063 }, { 100,7063 }, { 101,7577 }, { 102,7063 }, { 103,7063 },
 { 104,7063 }, { 105,7063 }, { 106,7063 }, { 107,7063 }, { 108,7063 },
 { 109,7063 }, { 110,7834 }, { 111,7063 }, { 112,7063 }, { 113,7063 },
 { 114,7063 }, { 115,7063 }, { 116,7063 }, { 117,8091 }, { 118,7063 },
 { 119,7063 }, { 120,8348 }, { 121,7063 }, { 122,7063 }, { 123,5934 },
 { 124,5983 }, { 125,5934 }, { 126,5983 }, { 127,5934 }, { 128,7063 },
 { 129,7063 }, { 130,7063 }, { 131,7063 }, { 132,7063 }, { 133,7063 },
 { 134,7063 }, { 135,7063 }, { 136,7063 }, { 137,7063 }, { 138,7063 },

 { 139,7063 }, { 140,7063 }, { 141,7063 }, { 142,7063 }, { 143,7063 },
 { 144,7063 }, { 145,7063 }, { 146,7063 }, { 147,7063 }, { 148,7063 },
 { 149,7063 }, { 150,7063 }, { 151,7063 }, { 152,7063 }, { 153,7063 },
 { 154,7063 }, { 155,7063 }, { 156,7063 }, { 157,7063 }, { 158,7063 },
 { 159,7063 }, { 160,7063 }, { 161,7063 }, { 162,7063 }, { 163,7063 },
 { 164,7063 }, { 165,7063 }, { 166,7063 }, { 167,7063 }, { 168,7063 },
 { 169,7063 }, { 170,7063 }, { 171,7063 }, { 172,7063 }, { 173,7063 },
 { 174,7063 }, { 175,7063 }, { 176,7063 }, { 177,7063 }, { 178,7063 },
 { 179,7063 }, { 180,7063 }, { 181,7063 }, { 182,7063 }, { 183,7063 },
 { 184,7063 }, { 185,7063 }, { 186,7063 }, { 187,7063 }, { 188,7063 },

 { 189,7063 }, { 190,7063 }, { 191,7063 }, { 192,7063 }, { 193,7063 },
 { 194,7063 }, { 195,7063 }, { 196,7063 }, { 197,7063 }, { 198,7063 },
 { 199,7063 }, { 200,7063 }, { 201,7063 }, { 202,7063 }, { 203,7063 },
 { 204,7063 }, { 205,7063 }, { 206,7063 }, { 207,7063 }, { 208,7063 },
 { 209,7063 }, { 210,7063 }, { 211,7063 }, { 212,7063 }, { 213,7063 },
 { 214,7063 }, { 215,7063 }, { 216,7063 }, { 217,7063 }, { 218,7063 },
 { 219,7063 }, { 220,7063 }, { 221,7063 }, { 222,7063 }, { 223,7063 },
 { 224,7063 }, { 225,7063 }, { 226,7063 }, { 227,7063 }, { 228,7063 },
 { 229,7063 }, { 230,7063 }, { 231,7063 }, { 232,7063 }, { 233,7063 },
 { 234,7063 }, { 235,7063 }, { 236,7063 }, { 237,7063 }, { 238,7063 },

 { 239,7063 }, { 240,7063 }, { 241,7063 }, { 242,7063 }, { 243,7063 },
 { 244,7063 }, { 245,7063 }, { 246,7063 }, { 247,7063 }, { 248,7063 },
 { 249,7063 }, { 250,7063 }, { 251,7063 }, { 252,7063 }, { 253,7063 },
 { 254,7063 }, { 255,7063 }, { 256,5934 }, {   0,  10 }, {   0,24081 },
 {   1,8347 }, {   2,8347 }, {   3,8347 }, {   4,8347 }, {   5,8347 },
 {   6,8347 }, {   7,8347 }, {   8,8347 }, {   9,8347 }, {  10,8347 },
 {  11,8347 }, {  12,8347 }, {  13,8347 }, {  14,8347 }, {  15,8347 },
 {  16,8347 }, {  17,8347 }, {  18,8347 }, {  19,8347 }, {  20,8347 },
 {  21,8347 }, {  22,8347 }, {  23,8347 }, {  24,8347 }, {  25,8347 },
 {  26,8347 }, {  27,8347 }, {  28,8347 }, {  29,8347 }, {  30,8347 },

 {  31,8347 }, {  32,8347 }, {  33,8347 }, {  34,8347 }, {  35,8347 },
 {  36,8347 }, {  37,8347 }, {  38,8347 }, {  39,5705 }, {  40,8347 },
 {  41,8347 }, {  42,8347 }, {  43,8347 }, {  44,8347 }, {  45,8347 },
 {  46,8347 }, {  47,8347 }, {  48,8347 }, {  49,8347 }, {  50,8347 },
 {  51,8347 }, {  52,8347 }, {  53,8347 }, {  54,8347 }, {  55,8347 },
 {  56,8347 }, {  57,8347 }, {  58,8347 }, {  59,8347 }, {  60,8347 },
 {  61,8347 }, {  62,8347 }, {  63,8347 }, {  64,8347 }, {  65,8347 },
 {  66,8347 }, {  67,8347 }, {  68,8347 }, {  69,8347 }, {  70,8347 },
 {  71,8347 }, {  72,8347 }, {  73,8347 }, {  74,8347 }, {  75,8347 },
 {  76,8347 }, {  77,8347 }, {  78,8347 }, {  79,8347 }, {  80,8347 },

 {  81,8347 }, {  82,8347 }, {  83,8347 }, {  84,8347 }, {  85,8347 },
 {  86,8347 }, {  87,8347 }, {  88,8347 }, {  89,8347 }, {  90,8347 },
 {  91,8347 }, {  92,8347 }, {  93,8347 }, {  94,8347 }, {  95,8347 },
 {  96,8347 }, {  97,8347 }, {  98,8347 }, {  99,8347 }, { 100,8347 },
 { 101,8347 }, { 102,8347 }, { 103,8347 }, { 104,8347 }, { 105,8347 },
 { 106,8347 }, { 107,8347 }, { 108,8347 }, { 109,8347 }, { 110,8347 },
 { 111,8347 }, { 112,8347 }, { 113,8347 }, { 114,8347 }, { 115,8347 },
 { 116,8347 }, { 117,8347 }, { 118,8347 }, { 119,8347 }, { 120,8347 },
 { 121,8347 }, { 122,8347 }, { 123,8347 }, { 124,8347 }, { 125,8347 },
 { 126,8347 }, { 127,8347 }, { 128,8347 }, { 129,8347 }, { 130,8347 },

 { 131,8347 }, { 132,8347 }, { 133,8347 }, { 134,8347 }, { 135,8347 },
 { 136,8347 }, { 137,8347 }, { 138,8347 }, { 139,8347 }, { 140,8347 },
 { 141,8347 }, { 142,8347 }, { 143,8347 }, { 144,8347 }, { 145,8347 },
 { 146,8347 }, { 147,8347 }, { 148,8347 }, { 149,8347 }, { 150,8347 },
 { 151,8347 }, { 152,8347 }, { 153,8347 }, { 154,8347 }, { 155,8347 },
 { 156,8347 }, { 157,8347 }, { 158,8347 }, { 159,8347 }, { 160,8347 },
 { 161,8347 }, { 162,8347 }, { 163,8347 }, { 164,8347 }, { 165,8347 },
 { 166,8347 }, { 167,8347 }, { 168,8347 }, { 169,8347 }, { 170,8347 },
 { 171,8347 }, { 172,8347 }, { 173,8347 }, { 174,8347 }, { 175,8347 },
 { 176,8347 }, { 177,8347 }, { 178,8347 }, { 179,8347 }, { 180,8347 },

 { 181,8347 }, { 182,8347 }, { 183,8347 }, { 184,8347 }, { 185,8347 },
 { 186,8347 }, { 187,8347 }, { 188,8347 }, { 189,8347 }, { 190,8347 },
 { 191,8347 }, { 192,8347 }, { 193,8347 }, { 194,8347 }, { 195,8347 },
 { 196,8347 }, { 197,8347 }, { 198,8347 }, { 199,8347 }, { 200,8347 },
 { 201,8347 }, { 202,8347 }, { 203,8347 }, { 204,8347 }, { 205,8347 },
 { 206,8347 }, { 207,8347 }, { 208,8347 }, { 209,8347 }, { 210,8347 },
 { 211,8347 }, { 212,8347 }, { 213,8347 }, { 214,8347 }, { 215,8347 },
 { 216,8347 }, { 217,8347 }, { 218,8347 }, { 219,8347 }, { 220,8347 },
 { 221,8347 }, { 222,8347 }, { 223,8347 }, { 224,8347 }, { 225,8347 },
 { 226,8347 }, { 227,8347 }, { 228,8347 }, { 229,8347 }, { 230,8347 },

 { 231,8347 }, { 232,8347 }, { 233,8347 }, { 234,8347 }, { 235,8347 },
 { 236,8347 }, { 237,8347 }, { 238,8347 }, { 239,8347 }, { 240,8347 },
 { 241,8347 }, { 242,8347 }, { 243,8347 }, { 244,8347 }, { 245,8347 },
 { 246,8347 }, { 247,8347 }, { 248,8347 }, { 249,8347 }, { 250,8347 },
 { 251,8347 }, { 252,8347 }, { 253,8347 }, { 254,8347 }, { 255,8347 },
 { 256,8347 }, {   0,  10 }, {   0,23823 }, {   1,8089 }, {   2,8089 },
 {   3,8089 }, {   4,8089 }, {   5,8089 }, {   6,8089 }, {   7,8089 },
 {   8,8089 }, {   9,8089 }, {  10,8089 }, {  11,8089 }, {  12,8089 },
 {  13,8089 }, {  14,8089 }, {  15,8089 }, {  16,8089 }, {  17,8089 },
 {  18,8089 }, {  19,8089 }, {  20,8089 }, {  21,8089 }, {  22,8089 },

 {  23,8089 }, {  24,8089 }, {  25,8089 }, {  26,8089 }, {  27,8089 },
 {  28,8089 }, {  29,8089 }, {  30,8089 }, {  31,8089 }, {  32,8089 },
 {  33,8089 }, {  34,8089 }, {  35,8089 }, {  36,8089 }, {  37,8089 },
 {  38,8089 }, {  39,5447 }, {  40,8089 }, {  41,8089 }, {  42,8089 },
 {  43,8089 }, {  44,8089 }, {  45,8089 }, {  46,8089 }, {  47,8089 },
 {  48,8089 }, {  49,8089 }, {  50,8089 }, {  51,8089 }, {  52,8089 },
 {  53,8089 }, {  54,8089 }, {  55,8089 }, {  56,8089 }, {  57,8089 },
 {  58,8089 }, {  59,8089 }, {  60,8089 }, {  61,8089 }, {  62,8089 },
 {  63,8089 }, {  64,8089 }, {  65,8089 }, {  66,8089 }, {  67,8089 },
 {  68,8089 }, {  69,8089 }, {  70,8089 }, {  71,8089 }, {  72,8089 },

 {  73,8089 }, {  74,8089 }, {  75,8089 }, {  76,8089 }, {  77,8089 },
 {  78,8089 }, {  79,8089 }, {  80,8089 }, {  81,8089 }, {  82,8089 },
 {  83,8089 }, {  84,8089 }, {  85,8089 }, {  86,8089 }, {  87,8089 },
 {  88,8089 }, {  89,8089 }, {  90,8089 }, {  91,8089 }, {  92,8089 },
 {  93,8089 }, {  94,8089 }, {  95,8089 }, {  96,8089 }, {  97,8089 },
 {  98,8089 }, {  99,8089 }, { 100,8089 }, { 101,8089 }, { 102,8089 },
 { 103,8089 }, { 104,8089 }, { 105,8089 }, { 106,8089 }, { 107,8089 },
 { 108,8089 }, { 109,8089 }, { 110,8089 }, { 111,8089 }, { 112,8089 },
 { 113,8089 }, { 114,8089 }, { 115,8089 }, { 116,8089 }, { 117,8089 },
 { 118,8089 }, { 119,8089 }, { 120,8089 }, { 121,8089 }, { 122,8089 },

 { 123,8089 }, { 124,8089 }, { 125,8089 }, { 126,8089 }, { 127,8089 },
 { 128,8089 }, { 129,8089 }, { 130,8089 }, { 131,8089 }, { 132,8089 },
 { 133,8089 }, { 134,8089 }, { 135,8089 }, { 136,8089 }, { 137,8089 },
 { 138,8089 }, { 139,8089 }, { 140,8089 }, { 141,8089 }, { 142,8089 },
 { 143,8089 }, { 144,8089 }, { 145,8089 }, { 146,8089 }, { 147,8089 },
 { 148,8089 }, { 149,8089 }, { 150,8089 }, { 151,8089 }, { 152,8089 },
 { 153,8089 }, { 154,8089 }, { 155,8089 }, { 156,8089 }, { 157,8089 },
 { 158,8089 }, { 159,8089 }, { 160,8089 }, { 161,8089 }, { 162,8089 },
 { 163,8089 }, { 164,8089 }, { 165,8089 }, { 166,8089 }, { 167,8089 },
 { 168,8089 }, { 169,8089 }, { 170,8089 }, { 171,8089 }, { 172,8089 },

 { 173,8089 }, { 174,8089 }, { 175,8089 }, { 176,8089 }, { 177,8089 },
 { 178,8089 }, { 179,8089 }, { 180,8089 }, { 181,8089 }, { 182,8089 },
 { 183,8089 }, { 184,8089 }, { 185,8089 }, { 186,8089 }, { 187,8089 },
 { 188,8089 }, { 189,8089 }, { 190,8089 }, { 191,8089 }, { 192,8089 },
 { 193,8089 }, { 194,8089 }, { 195,8089 }, { 196,8089 }, { 197,8089 },
 { 198,8089 }, { 199,8089 }, { 200,8089 }, { 201,8089 }, { 202,8089 },
 { 203,8089 }, { 204,8089 }, { 205,8089 }, { 206,8089 }, { 207,8089 },
 { 208,8089 }, { 209,8089 }, { 210,8089 }, { 211,8089 }, { 212,8089 },
 { 213,8089 }, { 214,8089 }, { 215,8089 }, { 216,8089 }, { 217,8089 },
 { 218,8089 }, { 219,8089 }, { 220,8089 }, { 221,8089 }, { 222,8089 },

 { 223,8089 }, { 224,8089 }, { 225,8089 }, { 226,8089 }, { 227,8089 },
 { 228,8089 }, { 229,8089 }, { 230,8089 }, { 231,8089 }, { 232,8089 },
 { 233,8089 }, { 234,8089 }, { 235,8089 }, { 236,8089 }, { 237,8089 },
 { 238,8089 }, { 239,8089 }, { 240,8089 }, { 241,8089 }, { 242,8089 },
 { 243,8089 }, { 244,8089 }, { 245,8089 }, { 246,8089 }, { 247,8089 },
 { 248,8089 }, { 249,8089 }, { 250,8089 }, { 251,8089 }, { 252,8089 },
 { 253,8089 }, { 254,8089 }, { 255,8089 }, { 256,8089 }, {   0,   0 },
 {   0,23565 }, {   1,8089 }, {   2,8089 }, {   3,8089 }, {   4,8089 },
 {   5,8089 }, {   6,8089 }, {   7,8089 }, {   8,8089 }, {   9,8089 },
 {  10,8089 }, {  11,8089 }, {  12,8089 }, {  13,8089 }, {  14,8089 },

 {  15,8089 }, {  16,8089 }, {  17,8089 }, {  18,8089 }, {  19,8089 },
 {  20,8089 }, {  21,8089 }, {  22,8089 }, {  23,8089 }, {  24,8089 },
 {  25,8089 }, {  26,8089 }, {  27,8089 }, {  28,8089 }, {  29,8089 },
 {  30,8089 }, {  31,8089 }, {  32,8089 }, {  33,8347 }, {  34,8089 },
 {  35,8347 }, {  36,8089 }, {  37,8347 }, {  38,8347 }, {  39,8089 },
 {  40,8089 }, {  41,8089 }, {  42,5192 }, {  43,8347 }, {  44,8089 },
 {  45,8347 }, {  46,8089 }, {  47,5196 }, {  48,8089 }, {  49,8089 },
 {  50,8089 }, {  51,8089 }, {  52,8089 }, {  53,8089 }, {  54,8089 },
 {  55,8089 }, {  56,8089 }, {  57,8089 }, {  58,8089 }, {  59,8089 },
 {  60,8347 }, {  61,8347 }, {  62,8347 }, {  63,8347 }, {  64,8347 },

 {  65,8089 }, {  66,8089 }, {  67,8089 }, {  68,8089 }, {  69,8089 },
 {  70,8089 }, {  71,8089 }, {  72,8089 }, {  73,8089 }, {  74,8089 },
 {  75,8089 }, {  76,8089 }, {  77,8089 }, {  78,8089 }, {  79,8089 },
 {  80,8089 }, {  81,8089 }, {  82,8089 }, {  83,8089 }, {  84,8089 },
 {  85,8089 }, {  86,8089 }, {  87,8089 }, {  88,8089 }, {  89,8089 },
 {  90,8089 }, {  91,8089 }, {  92,8089 }, {  93,8089 }, {  94,8347 },
 {  95,8089 }, {  96,8347 }, {  97,8089 }, {  98,8089 }, {  99,8089 },
 { 100,8089 }, { 101,8089 }, { 102,8089 }, { 103,8089 }, { 104,8089 },
 { 105,8089 }, { 106,8089 }, { 107,8089 }, { 108,8089 }, { 109,8089 },
 { 110,8089 }, { 111,8089 }, { 112,8089 }, { 113,8089 }, { 114,8089 },

 { 115,8089 }, { 116,8089 }, { 117,8089 }, { 118,8089 }, { 119,8089 },
 { 120,8089 }, { 121,8089 }, { 122,8089 }, { 123,8089 }, { 124,8347 },
 { 125,8089 }, { 126,8347 }, { 127,8089 }, { 128,8089 }, { 129,8089 },
 { 130,8089 }, { 131,8089 }, { 132,8089 }, { 133,8089 }, { 134,8089 },
 { 135,8089 }, { 136,8089 }, { 137,8089 }, { 138,8089 }, { 139,8089 },
 { 140,8089 }, { 141,8089 }, { 142,8089 }, { 143,8089 }, { 144,8089 },
 { 145,8089 }, { 146,8089 }, { 147,8089 }, { 148,8089 }, { 149,8089 },
 { 150,8089 }, { 151,8089 }, { 152,8089 }, { 153,8089 }, { 154,8089 },
 { 155,8089 }, { 156,8089 }, { 157,8089 }, { 158,8089 }, { 159,8089 },
 { 160,8089 }, { 161,8089 }, { 162,8089 }, { 163,8089 }, { 164,8089 },

 { 165,8089 }, { 166,8089 }, { 167,8089 }, { 168,8089 }, { 169,8089 },
 { 170,8089 }, { 171,8089 }, { 172,8089 }, { 173,8089 }, { 174,8089 },
 { 175,8089 }, { 176,8089 }, { 177,8089 }, { 178,8089 }, { 179,8089 },
 { 180,8089 }, { 181,8089 }, { 182,8089 }, { 183,8089 }, { 184,8089 },
 { 185,8089 }, { 186,8089 }, { 187,8089 }, { 188,8089 }, { 189,8089 },
 { 190,8089 }, { 191,8089 }, { 192,8089 }, { 193,8089 }, { 194,8089 },
 { 195,8089 }, { 196,8089 }, { 197,8089 }, { 198,8089 }, { 199,8089 },
 { 200,8089 }, { 201,8089 }, { 202,8089 }, { 203,8089 }, { 204,8089 },
 { 205,8089 }, { 206,8089 }, { 207,8089 }, { 208,8089 }, { 209,8089 },
 { 210,8089 }, { 211,8089 }, { 212,8089 }, { 213,8089 }, { 214,8089 },

 { 215,8089 }, { 216,8089 }, { 217,8089 }, { 218,8089 }, { 219,8089 },
 { 220,8089 }, { 221,8089 }, { 222,8089 }, { 223,8089 }, { 224,8089 },
 { 225,8089 }, { 226,8089 }, { 227,8089 }, { 228,8089 }, { 229,8089 },
 { 230,8089 }, { 231,8089 }, { 232,8089 }, { 233,8089 }, { 234,8089 },
 { 235,8089 }, { 236,8089 }, { 237,8089 }, { 238,8089 }, { 239,8089 },
 { 240,8089 }, { 241,8089 }, { 242,8089 }, { 243,8089 }, { 244,8089 },
 { 245,8089 }, { 246,8089 }, { 247,8089 }, { 248,8089 }, { 249,8089 },
 { 250,8089 }, { 251,8089 }, { 252,8089 }, { 253,8089 }, { 254,8089 },
 { 255,8089 }, { 256,8089 }, {   0,   0 }, {   0,23307 }, {   1,7831 },
 {   2,7831 }, {   3,7831 }, {   4,7831 }, {   5,7831 }, {   6,7831 },

 {   7,7831 }, {   8,7831 }, {   9,7831 }, {  10,7831 }, {  11,7831 },
 {  12,7831 }, {  13,7831 }, {  14,7831 }, {  15,7831 }, {  16,7831 },
 {  17,7831 }, {  18,7831 }, {  19,7831 }, {  20,7831 }, {  21,7831 },
 {  22,7831 }, {  23,7831 }, {  24,7831 }, {  25,7831 }, {  26,7831 },
 {  27,7831 }, {  28,7831 }, {  29,7831 }, {  30,7831 }, {  31,7831 },
 {  32,7831 }, {  33,8089 }, {  34,7831 }, {  35,8089 }, {  36,7831 },
 {  37,8089 }, {  38,8089 }, {  39,7831 }, {  40,7831 }, {  41,7831 },
 {  42,4934 }, {  43,8089 }, {  44,7831 }, {  45,8089 }, {  46,7831 },
 {  47,4938 }, {  48,7831 }, {  49,7831 }, {  50,7831 }, {  51,7831 },
 {  52,7831 }, {  53,7831 }, {  54,7831 }, {  55,7831 }, {  56,7831 },

 {  57,7831 }, {  58,7831 }, {  59,7831 }, {  60,8089 }, {  61,8089 },
 {  62,8089 }, {  63,8089 }, {  64,8089 }, {  65,7831 }, {  66,7831 },
 {  67,7831 }, {  68,7831 }, {  69,7831 }, {  70,7831 }, {  71,7831 },
 {  72,7831 }, {  73,7831 }, {  74,7831 }, {  75,7831 }, {  76,7831 },
 {  77,7831 }, {  78,7831 }, {  79,7831 }, {  80,7831 }, {  81,7831 },
 {  82,7831 }, {  83,7831 }, {  84,7831 }, {  85,7831 }, {  86,7831 },
 {  87,7831 }, {  88,7831 }, {  89,7831 }, {  90,7831 }, {  91,7831 },
 {  92,7831 }, {  93,7831 }, {  94,8089 }, {  95,7831 }, {  96,8089 },
 {  97,7831 }, {  98,7831 }, {  99,7831 }, { 100,7831 }, { 101,7831 },
 { 102,7831 }, { 103,7831 }, { 104,7831 }, { 105,7831 }, { 106,7831 },

 { 107,7831 }, { 108,7831 }, { 109,7831 }, { 110,7831 }, { 111,7831 },
 { 112,7831 }, { 113,7831 }, { 114,7831 }, { 115,7831 }, { 116,7831 },
 { 117,7831 }, { 118,7831 }, { 119,7831 }, { 120,7831 }, { 121,7831 },
 { 122,7831 }, { 123,7831 }, { 124,8089 }, { 125,7831 }, { 126,8089 },
 { 127,7831 }, { 128,7831 }, { 129,7831 }, { 130,7831 }, { 131,7831 },
 { 132,7831 }, { 133,7831 }, { 134,7831 }, { 135,7831 }, { 136,7831 },
 { 137,7831 }, { 138,7831 }, { 139,7831 }, { 140,7831 }, { 141,7831 },
 { 142,7831 }, { 143,7831 }, { 144,7831 }, { 145,7831 }, { 146,7831 },
 { 147,7831 }, { 148,7831 }, { 149,7831 }, { 150,7831 }, { 151,7831 },
 { 152,7831 }, { 153,7831 }, { 154,7831 }, { 155,7831 }, { 156,7831 },

 { 157,7831 }, { 158,7831 }, { 159,7831 }, { 160,7831 }, { 161,7831 },
 { 162,7831 }, { 163,7831 }, { 164,7831 }, { 165,7831 }, { 166,7831 },
 { 167,7831 }, { 168,7831 }, { 169,7831 }, { 170,7831 }, { 171,7831 },
 { 172,7831 }, { 173,7831 }, { 174,7831 }, { 175,7831 }, { 176,7831 },
 { 177,7831 }, { 178,7831 }, { 179,7831 }, { 180,7831 }, { 181,7831 },
 { 182,7831 }, { 183,7831 }, { 184,7831 }, { 185,7831 }, { 186,7831 },
 { 187,7831 }, { 188,7831 }, { 189,7831 }, { 190,7831 }, { 191,7831 },
 { 192,7831 }, { 193,7831 }, { 194,7831 }, { 195,7831 }, { 196,7831 },
 { 197,7831 }, { 198,7831 }, { 199,7831 }, { 200,7831 }, { 201,7831 },
 { 202,7831 }, { 203,7831 }, { 204,7831 }, { 205,7831 }, { 206,7831 },

 { 207,7831 }, { 208,7831 }, { 209,7831 }, { 210,7831 }, { 211,7831 },
 { 212,7831 }, { 213,7831 }, { 214,7831 }, { 215,7831 }, { 216,7831 },
 { 217,7831 }, { 218,7831 }, { 219,7831 }, { 220,7831 }, { 221,7831 },
 { 222,7831 }, { 223,7831 }, { 224,7831 }, { 225,7831 }, { 226,7831 },
 { 227,7831 }, { 228,7831 }, { 229,7831 }, { 230,7831 }, { 231,7831 },
 { 232,7831 }, { 233,7831 }, { 234,7831 }, { 235,7831 }, { 236,7831 },
 { 237,7831 }, { 238,7831 }, { 239,7831 }, { 240,7831 }, { 241,7831 },
 { 242,7831 }, { 243,7831 }, { 244,7831 }, { 245,7831 }, { 246,7831 },
 { 247,7831 }, { 248,7831 }, { 249,7831 }, { 250,7831 }, { 251,7831 },
 { 252,7831 }, { 253,7831 }, { 254,7831 }, { 255,7831 }, { 256,7831 },

 {   0,   0 }, {   0,23049 }, {   1,8089 }, {   2,8089 }, {   3,8089 },
 {   4,8089 }, {   5,8089 }, {   6,8089 }, {   7,8089 }, {   8,8089 },
 {   9,8089 }, {  10,8089 }, {  11,8089 }, {  12,8089 }, {  13,8089 },
 {  14,8089 }, {  15,8089 }, {  16,8089 }, {  17,8089 }, {  18,8089 },
 {  19,8089 }, {  20,8089 }, {  21,8089 }, {  22,8089 }, {  23,8089 },
 {  24,8089 }, {  25,8089 }, {  26,8089 }, {  27,8089 }, {  28,8089 },
 {  29,8089 }, {  30,8089 }, {  31,8089 }, {  32,8089 }, {  33,8089 },
 {  34,4685 }, {  35,8089 }, {  36,8089 }, {  37,8089 }, {  38,8089 },
 {  39,8089 }, {  40,8089 }, {  41,8089 }, {  42,8089 }, {  43,8089 },
 {  44,8089 }, {  45,8089 }, {  46,8089 }, {  47,8089 }, {  48,8089 },

 {  49,8089 }, {  50,8089 }, {  51,8089 }, {  52,8089 }, {  53,8089 },
 {  54,8089 }, {  55,8089 }, {  56,8089 }, {  57,8089 }, {  58,8089 },
 {  59,8089 }, {  60,8089 }, {  61,8089 }, {  62,8089 }, {  63,8089 },
 {  64,8089 }, {  65,8089 }, {  66,8089 }, {  67,8089 }, {  68,8089 },
 {  69,8089 }, {  70,8089 }, {  71,8089 }, {  72,8089 }, {  73,8089 },
 {  74,8089 }, {  75,8089 }, {  76,8089 }, {  77,8089 }, {  78,8089 },
 {  79,8089 }, {  80,8089 }, {  81,8089 }, {  82,8089 }, {  83,8089 },
 {  84,8089 }, {  85,8089 }, {  86,8089 }, {  87,8089 }, {  88,8089 },
 {  89,8089 }, {  90,8089 }, {  91,8089 }, {  92,8089 }, {  93,8089 },
 {  94,8089 }, {  95,8089 }, {  96,8089 }, {  97,8089 }, {  98,8089 },

 {  99,8089 }, { 100,8089 }, { 101,8089 }, { 102,8089 }, { 103,8089 },
 { 104,8089 }, { 105,8089 }, { 106,8089 }, { 107,8089 }, { 108,8089 },
 { 109,8089 }, { 110,8089 }, { 111,8089 }, { 112,8089 }, { 113,8089 },
 { 114,8089 }, { 115,8089 }, { 116,8089 }, { 117,8089 }, { 118,8089 },
 { 119,8089 }, { 120,8089 }, { 121,8089 }, { 122,8089 }, { 123,8089 },
 { 124,8089 }, { 125,8089 }, { 126,8089 }, { 127,8089 }, { 128,8089 },
 { 129,8089 }, { 130,8089 }, { 131,8089 }, { 132,8089 }, { 133,8089 },
 { 134,8089 }, { 135,8089 }, { 136,8089 }, { 137,8089 }, { 138,8089 },
 { 139,8089 }, { 140,8089 }, { 141,8089 }, { 142,8089 }, { 143,8089 },
 { 144,8089 }, { 145,8089 }, { 146,8089 }, { 147,8089 }, { 148,8089 },

 { 149,8089 }, { 150,8089 }, { 151,8089 }, { 152,8089 }, { 153,8089 },
 { 154,8089 }, { 155,8089 }, { 156,8089 }, { 157,8089 }, { 158,8089 },
 { 159,8089 }, { 160,8089 }, { 161,8089 }, { 162,8089 }, { 163,8089 },
 { 164,8089 }, { 165,8089 }, { 166,8089 }, { 167,8089 }, { 168,8089 },
 { 169,8089 }, { 170,8089 }, { 171,8089 }, { 172,8089 }, { 173,8089 },
 { 174,8089 }, { 175,8089 }, { 176,8089 }, { 177,8089 }, { 178,8089 },
 { 179,8089 }, { 180,8089 }, { 181,8089 }, { 182,8089 }, { 183,8089 },
 { 184,8089 }, { 185,8089 }, { 186,8089 }, { 187,8089 }, { 188,8089 },
 { 189,8089 }, { 190,8089 }, { 191,8089 }, { 192,8089 }, { 193,8089 },
 { 194,8089 }, { 195,8089 }, { 196,8089 }, { 197,8089 }, { 198,8089 },

 { 199,8089 }, { 200,8089 }, { 201,8089 }, { 202,8089 }, { 203,8089 },
 { 204,8089 }, { 205,8089 }, { 206,8089 }, { 207,8089 }, { 208,8089 },
 { 209,8089 }, { 210,8089 }, { 211,8089 }, { 212,8089 }, { 213,8089 },
 { 214,8089 }, { 215,8089 }, { 216,8089 }, { 217,8089 }, { 218,8089 },
 { 219,8089 }, { 220,8089 }, { 221,8089 }, { 222,8089 }, { 223,8089 },
 { 224,8089 }, { 225,8089 }, { 226,8089 }, { 227,8089 }, { 228,8089 },
 { 229,8089 }, { 230,8089 }, { 231,8089 }, { 232,8089 }, { 233,8089 },
 { 234,8089 }, { 235,8089 }, { 236,8089 }, { 237,8089 }, { 238,8089 },
 { 239,8089 }, { 240,8089 }, { 241,8089 }, { 242,8089 }, { 243,8089 },
 { 244,8089 }, { 245,8089 }, { 246,8089 }, { 247,8089 }, { 248,8089 },

 { 249,8089 }, { 250,8089 }, { 251,8089 }, { 252,8089 }, { 253,8089 },
 { 254,8089 }, { 255,8089 }, { 256,8089 }, {   0,   0 }, {   0,22791 },
 {   1,7831 }, {   2,7831 }, {   3,7831 }, {   4,7831 }, {   5,7831 },
 {   6,7831 }, {   7,7831 }, {   8,7831 }, {   9,7831 }, {  10,7831 },
 {  11,7831 }, {  12,7831 }, {  13,7831 }, {  14,7831 }, {  15,7831 },
 {  16,7831 }, {  17,7831 }, {  18,7831 }, {  19,7831 }, {  20,7831 },
 {  21,7831 }, {  22,7831 }, {  23,7831 }, {  24,7831 }, {  25,7831 },
 {  26,7831 }, {  27,7831 }, {  28,7831 }, {  29,7831 }, {  30,7831 },
 {  31,7831 }, {  32,7831 }, {  33,7831 }, {  34,4427 }, {  35,7831 },
 {  36,7831 }, {  37,7831 }, {  38,7831 }, {  39,7831 }, {  40,7831 },

 {  41,7831 }, {  42,7831 }, {  43,7831 }, {  44,7831 }, {  45,7831 },
 {  46,7831 }, {  47,7831 }, {  48,7831 }, {  49,7831 }, {  50,7831 },
 {  51,7831 }, {  52,7831 }, {  53,7831 }, {  54,7831 }, {  55,7831 },
 {  56,7831 }, {  57,7831 }, {  58,7831 }, {  59,7831 }, {  60,7831 },
 {  61,7831 }, {  62,7831 }, {  63,7831 }, {  64,7831 }, {  65,7831 },
 {  66,7831 }, {  67,7831 }, {  68,7831 }, {  69,7831 }, {  70,7831 },
 {  71,7831 }, {  72,7831 }, {  73,7831 }, {  74,7831 }, {  75,7831 },
 {  76,7831 }, {  77,7831 }, {  78,7831 }, {  79,7831 }, {  80,7831 },
 {  81,7831 }, {  82,7831 }, {  83,7831 }, {  84,7831 }, {  85,7831 },
 {  86,7831 }, {  87,7831 }, {  88,7831 }, {  89,7831 }, {  90,7831 },

 {  91,7831 }, {  92,7831 }, {  93,7831 }, {  94,7831 }, {  95,7831 },
 {  96,7831 }, {  97,7831 }, {  98,7831 }, {  99,7831 }, { 100,7831 },
 { 101,7831 }, { 102,7831 }, { 103,7831 }, { 104,7831 }, { 105,7831 },
 { 106,7831 }, { 107,7831 }, { 108,7831 }, { 109,7831 }, { 110,7831 },
 { 111,7831 }, { 112,7831 }, { 113,7831 }, { 114,7831 }, { 115,7831 },
 { 116,7831 }, { 117,7831 }, { 118,7831 }, { 119,7831 }, { 120,7831 },
 { 121,7831 }, { 122,7831 }, { 123,7831 }, { 124,7831 }, { 125,7831 },
 { 126,7831 }, { 127,7831 }, { 128,7831 }, { 129,7831 }, { 130,7831 },
 { 131,7831 }, { 132,7831 }, { 133,7831 }, { 134,7831 }, { 135,7831 },
 { 136,7831 }, { 137,7831 }, { 138,7831 }, { 139,7831 }, { 140,7831 },

 { 141,7831 }, { 142,7831 }, { 143,7831 }, { 144,7831 }, { 145,7831 },
 { 146,7831 }, { 147,7831 }, { 148,7831 }, { 149,7831 }, { 150,7831 },
 { 151,7831 }, { 152,7831 }, { 153,7831 }, { 154,7831 }, { 155,7831 },
 { 156,7831 }, { 157,7831 }, { 158,7831 }, { 159,7831 }, { 160,7831 },
 { 161,7831 }, { 162,7831 }, { 163,7831 }, { 164,7831 }, { 165,7831 },
 { 166,7831 }, { 167,7831 }, { 168,7831 }, { 169,7831 }, { 170,7831 },
 { 171,7831 }, { 172,7831 }, { 173,7831 }, { 174,7831 }, { 175,7831 },
 { 176,7831 }, { 177,7831 }, { 178,7831 }, { 179,7831 }, { 180,7831 },
 { 181,7831 }, { 182,7831 }, { 183,7831 }, { 184,7831 }, { 185,7831 },
 { 186,7831 }, { 187,7831 }, { 188,7831 }, { 189,7831 }, { 190,7831 },

 { 191,7831 }, { 192,7831 }, { 193,7831 }, { 194,7831 }, { 195,7831 },
 { 196,7831 }, { 197,7831 }, { 198,7831 }, { 199,7831 }, { 200,7831 },
 { 201,7831 }, { 202,7831 }, { 203,7831 }, { 204,7831 }, { 205,7831 },
 { 206,7831 }, { 207,7831 }, { 208,7831 }, { 209,7831 }, { 210,7831 },
 { 211,7831 }, { 212,7831 }, { 213,7831 }, { 214,7831 }, { 215,7831 },
 { 216,7831 }, { 217,7831 }, { 218,7831 }, { 219,7831 }, { 220,7831 },
 { 221,7831 }, { 222,7831 }, { 223,7831 }, { 224,7831 }, { 225,7831 },
 { 226,7831 }, { 227,7831 }, { 228,7831 }, { 229,7831 }, { 230,7831 },
 { 231,7831 }, { 232,7831 }, { 233,7831 }, { 234,7831 }, { 235,7831 },
 { 236,7831 }, { 237,7831 }, { 238,7831 }, { 239,7831 }, { 240,7831 },

 { 241,7831 }, { 242,7831 }, { 243,7831 }, { 244,7831 }, { 245,7831 },
 { 246,7831 }, { 247,7831 }, { 248,7831 }, { 249,7831 }, { 250,7831 },
 { 251,7831 }, { 252,7831 }, { 253,7831 }, { 254,7831 }, { 255,7831 },
 { 256,7831 }, {   0,   9 }, {   0,22533 }, {   1,7831 }, {   2,7831 },
 {   3,7831 }, {   4,7831 }, {   5,7831 }, {   6,7831 }, {   7,7831 },
 {   8,7831 }, {   9,7831 }, {  10,7831 }, {  11,7831 }, {  12,7831 },
 {  13,7831 }, {  14,7831 }, {  15,7831 }, {  16,7831 }, {  17,7831 },
 {  18,7831 }, {  19,7831 }, {  20,7831 }, {  21,7831 }, {  22,7831 },
 {  23,7831 }, {  24,7831 }, {  25,7831 }, {  26,7831 }, {  27,7831 },
 {  28,7831 }, {  29,7831 }, {  30,7831 }, {  31,7831 }, {  32,7831 },

 {  33,7831 }, {  34,7831 }, {  35,7831 }, {  36,7831 }, {  37,7831 },
 {  38,7831 }, {  39,4157 }, {  40,7831 }, {  41,7831 }, {  42,7831 },
 {  43,7831 }, {  44,7831 }, {  45,7831 }, {  46,7831 }, {  47,7831 },
 {  48,7831 }, {  49,7831 }, {  50,7831 }, {  51,7831 }, {  52,7831 },
 {  53,7831 }, {  54,7831 }, {  55,7831 }, {  56,7831 }, {  57,7831 },
 {  58,7831 }, {  59,7831 }, {  60,7831 }, {  61,7831 }, {  62,7831 },
 {  63,7831 }, {  64,7831 }, {  65,7831 }, {  66,7831 }, {  67,7831 },
 {  68,7831 }, {  69,7831 }, {  70,7831 }, {  71,7831 }, {  72,7831 },
 {  73,7831 }, {  74,7831 }, {  75,7831 }, {  76,7831 }, {  77,7831 },
 {  78,7831 }, {  79,7831 }, {  80,7831 }, {  81,7831 }, {  82,7831 },

 {  83,7831 }, {  84,7831 }, {  85,7831 }, {  86,7831 }, {  87,7831 },
 {  88,7831 }, {  89,7831 }, {  90,7831 }, {  91,7831 }, {  92,7831 },
 {  93,7831 }, {  94,7831 }, {  95,7831 }, {  96,7831 }, {  97,7831 },
 {  98,7831 }, {  99,7831 }, { 100,7831 }, { 101,7831 }, { 102,7831 },
 { 103,7831 }, { 104,7831 }, { 105,7831 }, { 106,7831 }, { 107,7831 },
 { 108,7831 }, { 109,7831 }, { 110,7831 }, { 111,7831 }, { 112,7831 },
 { 113,7831 }, { 114,7831 }, { 115,7831 }, { 116,7831 }, { 117,7831 },
 { 118,7831 }, { 119,7831 }, { 120,7831 }, { 121,7831 }, { 122,7831 },
 { 123,7831 }, { 124,7831 }, { 125,7831 }, { 126,7831 }, { 127,7831 },
 { 128,7831 }, { 129,7831 }, { 130,7831 }, { 131,7831 }, { 132,7831 },

 { 133,7831 }, { 134,7831 }, { 135,7831 }, { 136,7831 }, { 137,7831 },
 { 138,7831 }, { 139,7831 }, { 140,7831 }, { 141,7831 }, { 142,7831 },
 { 143,7831 }, { 144,7831 }, { 145,7831 }, { 146,7831 }, { 147,7831 },
 { 148,7831 }, { 149,7831 }, { 150,7831 }, { 151,7831 }, { 152,7831 },
 { 153,7831 }, { 154,7831 }, { 155,7831 }, { 156,7831 }, { 157,7831 },
 { 158,7831 }, { 159,7831 }, { 160,7831 }, { 161,7831 }, { 162,7831 },
 { 163,7831 }, { 164,7831 }, { 165,7831 }, { 166,7831 }, { 167,7831 },
 { 168,7831 }, { 169,7831 }, { 170,7831 }, { 171,7831 }, { 172,7831 },
 { 173,7831 }, { 174,7831 }, { 175,7831 }, { 176,7831 }, { 177,7831 },
 { 178,7831 }, { 179,7831 }, { 180,7831 }, { 181,7831 }, { 182,7831 },

 { 183,7831 }, { 184,7831 }, { 185,7831 }, { 186,7831 }, { 187,7831 },
 { 188,7831 }, { 189,7831 }, { 190,7831 }, { 191,7831 }, { 192,7831 },
 { 193,7831 }, { 194,7831 }, { 195,7831 }, { 196,7831 }, { 197,7831 },
 { 198,7831 }, { 199,7831 }, { 200,7831 }, { 201,7831 }, { 202,7831 },
 { 203,7831 }, { 204,7831 }, { 205,7831 }, { 206,7831 }, { 207,7831 },
 { 208,7831 }, { 209,7831 }, { 210,7831 }, { 211,7831 }, { 212,7831 },
 { 213,7831 }, { 214,7831 }, { 215,7831 }, { 216,7831 }, { 217,7831 },
 { 218,7831 }, { 219,7831 }, { 220,7831 }, { 221,7831 }, { 222,7831 },
 { 223,7831 }, { 224,7831 }, { 225,7831 }, { 226,7831 }, { 227,7831 },
 { 228,7831 }, { 229,7831 }, { 230,7831 }, { 231,7831 }, { 232,7831 },

 { 233,7831 }, { 234,7831 }, { 235,7831 }, { 236,7831 }, { 237,7831 },
 { 238,7831 }, { 239,7831 }, { 240,7831 }, { 241,7831 }, { 242,7831 },
 { 243,7831 }, { 244,7831 }, { 245,7831 }, { 246,7831 }, { 247,7831 },
 { 248,7831 }, { 249,7831 }, { 250,7831 }, { 251,7831 }, { 252,7831 },
 { 253,7831 }, { 254,7831 }, { 255,7831 }, { 256,7831 }, {   0,   9 },
 {   0,22275 }, {   1,7573 }, {   2,7573 }, {   3,7573 }, {   4,7573 },
 {   5,7573 }, {   6,7573 }, {   7,7573 }, {   8,7573 }, {   9,7573 },
 {  10,7573 }, {  11,7573 }, {  12,7573 }, {  13,7573 }, {  14,7573 },
 {  15,7573 }, {  16,7573 }, {  17,7573 }, {  18,7573 }, {  19,7573 },
 {  20,7573 }, {  21,7573 }, {  22,7573 }, {  23,7573 }, {  24,7573 },

 {  25,7573 }, {  26,7573 }, {  27,7573 }, {  28,7573 }, {  29,7573 },
 {  30,7573 }, {  31,7573 }, {  32,7573 }, {  33,7573 }, {  34,7573 },
 {  35,7573 }, {  36,7573 }, {  37,7573 }, {  38,7573 }, {  39,3899 },
 {  40,7573 }, {  41,7573 }, {  42,7573 }, {  43,7573 }, {  44,7573 },
 {  45,7573 }, {  46,7573 }, {  47,7573 }, {  48,7573 }, {  49,7573 },
 {  50,7573 }, {  51,7573 }, {  52,7573 }, {  53,7573 }, {  54,7573 },
 {  55,7573 }, {  56,7573 }, {  57,7573 }, {  58,7573 }, {  59,7573 },
 {  60,7573 }, {  61,7573 }, {  62,7573 }, {  63,7573 }, {  64,7573 },
 {  65,7573 }, {  66,7573 }, {  67,7573 }, {  68,7573 }, {  69,7573 },
 {  70,7573 }, {  71,7573 }, {  72,7573 }, {  73,7573 }, {  74,7573 },

 {  75,7573 }, {  76,7573 }, {  77,7573 }, {  78,7573 }, {  79,7573 },
 {  80,7573 }, {  81,7573 }, {  82,7573 }, {  83,7573 }, {  84,7573 },
 {  85,7573 }, {  86,7573 }, {  87,7573 }, {  88,7573 }, {  89,7573 },
 {  90,7573 }, {  91,7573 }, {  92,7573 }, {  93,7573 }, {  94,7573 },
 {  95,7573 }, {  96,7573 }, {  97,7573 }, {  98,7573 }, {  99,7573 },
 { 100,7573 }, { 101,7573 }, { 102,7573 }, { 103,7573 }, { 104,7573 },
 { 105,7573 }, { 106,7573 }, { 107,7573 }, { 108,7573 }, { 109,7573 },
 { 110,7573 }, { 111,7573 }, { 112,7573 }, { 113,7573 }, { 114,7573 },
 { 115,7573 }, { 116,7573 }, { 117,7573 }, { 118,7573 }, { 119,7573 },
 { 120,7573 }, { 121,7573 }, { 122,7573 }, { 123,7573 }, { 124,7573 },

 { 125,7573 }, { 126,7573 }, { 127,7573 }, { 128,7573 }, { 129,7573 },
 { 130,7573 }, { 131,7573 }, { 132,7573 }, { 133,7573 }, { 134,7573 },
 { 135,7573 }, { 136,7573 }, { 137,7573 }, { 138,7573 }, { 139,7573 },
 { 140,7573 }, { 141,7573 }, { 142,7573 }, { 143,7573 }, { 144,7573 },
 { 145,7573 }, { 146,7573 }, { 147,7573 }, { 148,7573 }, { 149,7573 },
 { 150,7573 }, { 151,7573 }, { 152,7573 }, { 153,7573 }, { 154,7573 },
 { 155,7573 }, { 156,7573 }, { 157,7573 }, { 158,7573 }, { 159,7573 },
 { 160,7573 }, { 161,7573 }, { 162,7573 }, { 163,7573 }, { 164,7573 },
 { 165,7573 }, { 166,7573 }, { 167,7573 }, { 168,7573 }, { 169,7573 },
 { 170,7573 }, { 171,7573 }, { 172,7573 }, { 173,7573 }, { 174,7573 },

 { 175,7573 }, { 176,7573 }, { 177,7573 }, { 178,7573 }, { 179,7573 },
 { 180,7573 }, { 181,7573 }, { 182,7573 }, { 183,7573 }, { 184,7573 },
 { 185,7573 }, { 186,7573 }, { 187,7573 }, { 188,7573 }, { 189,7573 },
 { 190,7573 }, { 191,7573 }, { 192,7573 }, { 193,7573 }, { 194,7573 },
 { 195,7573 }, { 196,7573 }, { 197,7573 }, { 198,7573 }, { 199,7573 },
 { 200,7573 }, { 201,7573 }, { 202,7573 }, { 203,7573 }, { 204,7573 },
 { 205,7573 }, { 206,7573 }, { 207,7573 }, { 208,7573 }, { 209,7573 },
 { 210,7573 }, { 211,7573 }, { 212,7573 }, { 213,7573 }, { 214,7573 },
 { 215,7573 }, { 216,7573 }, { 217,7573 }, { 218,7573 }, { 219,7573 },
 { 220,7573 }, { 221,7573 }, { 222,7573 }, { 223,7573 }, { 224,7573 },

 { 225,7573 }, { 226,7573 }, { 227,7573 }, { 228,7573 }, { 229,7573 },
 { 230,7573 }, { 231,7573 }, { 232,7573 }, { 233,7573 }, { 234,7573 },
 { 235,7573 }, { 236,7573 }, { 237,7573 }, { 238,7573 }, { 239,7573 },
 { 240,7573 }, { 241,7573 }, { 242,7573 }, { 243,7573 }, { 244,7573 },
 { 245,7573 }, { 246,7573 }, { 247,7573 }, { 248,7573 }, { 249,7573 },
 { 250,7573 }, { 251,7573 }, { 252,7573 }, { 253,7573 }, { 254,7573 },
 { 255,7573 }, { 256,7573 }, {   0,   0 }, {   0,22017 }, {   1,7573 },
 {   2,7573 }, {   3,7573 }, {   4,7573 }, {   5,7573 }, {   6,7573 },
 {   7,7573 }, {   8,7573 }, {   9,7573 }, {  10,7573 }, {  11,7573 },
 {  12,7573 }, {  13,7573 }, {  14,7573 }, {  15,7573 }, {  16,7573 },

 {  17,7573 }, {  18,7573 }, {  19,7573 }, {  20,7573 }, {  21,7573 },
 {  22,7573 }, {  23,7573 }, {  24,7573 }, {  25,7573 }, {  26,7573 },
 {  27,7573 }, {  28,7573 }, {  29,7573 }, {  30,7573 }, {  31,7573 },
 {  32,7573 }, {  33,7573 }, {  34,7573 }, {  35,7573 }, {  36,7573 },
 {  37,7573 }, {  38,7573 }, {  39,3670 }, {  40,7573 }, {  41,7573 },
 {  42,7573 }, {  43,7573 }, {  44,7573 }, {  45,7573 }, {  46,7573 },
 {  47,7573 }, {  48,7573 }, {  49,7573 }, {  50,7573 }, {  51,7573 },
 {  52,7573 }, {  53,7573 }, {  54,7573 }, {  55,7573 }, {  56,7573 },
 {  57,7573 }, {  58,7573 }, {  59,7573 }, {  60,7573 }, {  61,7573 },
 {  62,7573 }, {  63,7573 }, {  64,7573 }, {  65,7573 }, {  66,7573 },

 {  67,7573 }, {  68,7573 }, {  69,7573 }, {  70,7573 }, {  71,7573 },
 {  72,7573 }, {  73,7573 }, {  74,7573 }, {  75,7573 }, {  76,7573 },
 {  77,7573 }, {  78,7573 }, {  79,7573 }, {  80,7573 }, {  81,7573 },
 {  82,7573 }, {  83,7573 }, {  84,7573 }, {  85,7573 }, {  86,7573 },
 {  87,7573 }, {  88,7573 }, {  89,7573 }, {  90,7573 }, {  91,7573 },
 {  92,7573 }, {  93,7573 }, {  94,7573 }, {  95,7573 }, {  96,7573 },
 {  97,7573 }, {  98,7573 }, {  99,7573 }, { 100,7573 }, { 101,7573 },
 { 102,7573 }, { 103,7573 }, { 104,7573 }, { 105,7573 }, { 106,7573 },
 { 107,7573 }, { 108,7573 }, { 109,7573 }, { 110,7573 }, { 111,7573 },
 { 112,7573 }, { 113,7573 }, { 114,7573 }, { 115,7573 }, { 116,7573 },

 { 117,7573 }, { 118,7573 }, { 119,7573 }, { 120,7573 }, { 121,7573 },
 { 122,7573 }, { 123,7573 }, { 124,7573 }, { 125,7573 }, { 126,7573 },
 { 127,7573 }, { 128,7573 }, { 129,7573 }, { 130,7573 }, { 131,7573 },
 { 132,7573 }, { 133,7573 }, { 134,7573 }, { 135,7573 }, { 136,7573 },
 { 137,7573 }, { 138,7573 }, { 139,7573 }, { 140,7573 }, { 141,7573 },
 { 142,7573 }, { 143,7573 }, { 144,7573 }, { 145,7573 }, { 146,7573 },
 { 147,7573 }, { 148,7573 }, { 149,7573 }, { 150,7573 }, { 151,7573 },
 { 152,7573 }, { 153,7573 }, { 154,7573 }, { 155,7573 }, { 156,7573 },
 { 157,7573 }, { 158,7573 }, { 159,7573 }, { 160,7573 }, { 161,7573 },
 { 162,7573 }, { 163,7573 }, { 164,7573 }, { 165,7573 }, { 166,7573 },

 { 167,7573 }, { 168,7573 }, { 169,7573 }, { 170,7573 }, { 171,7573 },
 { 172,7573 }, { 173,7573 }, { 174,7573 }, { 175,7573 }, { 176,7573 },
 { 177,7573 }, { 178,7573 }, { 179,7573 }, { 180,7573 }, { 181,7573 },
 { 182,7573 }, { 183,7573 }, { 184,7573 }, { 185,7573 }, { 186,7573 },
 { 187,7573 }, { 188,7573 }, { 189,7573 }, { 190,7573 }, { 191,7573 },
 { 192,7573 }, { 193,7573 }, { 194,7573 }, { 195,7573 }, { 196,7573 },
 { 197,7573 }, { 198,7573 }, { 199,7573 }, { 200,7573 }, { 201,7573 },
 { 202,7573 }, { 203,7573 }, { 204,7573 }, { 205,7573 }, { 206,7573 },
 { 207,7573 }, { 208,7573 }, { 209,7573 }, { 210,7573 }, { 211,7573 },
 { 212,7573 }, { 213,7573 }, { 214,7573 }, { 215,7573 }, { 216,7573 },

 { 217,7573 }, { 218,7573 }, { 219,7573 }, { 220,7573 }, { 221,7573 },
 { 222,7573 }, { 223,7573 }, { 224,7573 }, { 225,7573 }, { 226,7573 },
 { 227,7573 }, { 228,7573 }, { 229,7573 }, { 230,7573 }, { 231,7573 },
 { 232,7573 }, { 233,7573 }, { 234,7573 }, { 235,7573 }, { 236,7573 },
 { 237,7573 }, { 238,7573 }, { 239,7573 }, { 240,7573 }, { 241,7573 },
 { 242,7573 }, { 243,7573 }, { 244,7573 }, { 245,7573 }, { 246,7573 },
 { 247,7573 }, { 248,7573 }, { 249,7573 }, { 250,7573 }, { 251,7573 },
 { 252,7573 }, { 253,7573 }, { 254,7573 }, { 255,7573 }, { 256,7573 },
 {   0,   0 }, {   0,21759 }, {   1,7315 }, {   2,7315 }, {   3,7315 },
 {   4,7315 }, {   5,7315 }, {   6,7315 }, {   7,7315 }, {   8,7315 },

 {   9,7315 }, {  10,7315 }, {  11,7315 }, {  12,7315 }, {  13,7315 },
 {  14,7315 }, {  15,7315 }, {  16,7315 }, {  17,7315 }, {  18,7315 },
 {  19,7315 }, {  20,7315 }, {  21,7315 }, {  22,7315 }, {  23,7315 },
 {  24,7315 }, {  25,7315 }, {  26,7315 }, {  27,7315 }, {  28,7315 },
 {  29,7315 }, {  30,7315 }, {  31,7315 }, {  32,7315 }, {  33,7315 },
 {  34,7315 }, {  35,7315 }, {  36,7315 }, {  37,7315 }, {  38,7315 },
 {  39,3412 }, {  40,7315 }, {  41,7315 }, {  42,7315 }, {  43,7315 },
 {  44,7315 }, {  45,7315 }, {  46,7315 }, {  47,7315 }, {  48,7315 },
 {  49,7315 }, {  50,7315 }, {  51,7315 }, {  52,7315 }, {  53,7315 },
 {  54,7315 }, {  55,7315 }, {  56,7315 }, {  57,7315 }, {  58,7315 },

 {  59,7315 }, {  60,7315 }, {  61,7315 }, {  62,7315 }, {  63,7315 },
 {  64,7315 }, {  65,7315 }, {  66,7315 }, {  67,7315 }, {  68,7315 },
 {  69,7315 }, {  70,7315 }, {  71,7315 }, {  72,7315 }, {  73,7315 },
 {  74,7315 }, {  75,7315 }, {  76,7315 }, {  77,7315 }, {  78,7315 },
 {  79,7315 }, {  80,7315 }, {  81,7315 }, {  82,7315 }, {  83,7315 },
 {  84,7315 }, {  85,7315 }, {  86,7315 }, {  87,7315 }, {  88,7315 },
 {  89,7315 }, {  90,7315 }, {  91,7315 }, {  92,7315 }, {  93,7315 },
 {  94,7315 }, {  95,7315 }, {  96,7315 }, {  97,7315 }, {  98,7315 },
 {  99,7315 }, { 100,7315 }, { 101,7315 }, { 102,7315 }, { 103,7315 },
 { 104,7315 }, { 105,7315 }, { 106,7315 }, { 107,7315 }, { 108,7315 },

 { 109,7315 }, { 110,7315 }, { 111,7315 }, { 112,7315 }, { 113,7315 },
 { 114,7315 }, { 115,7315 }, { 116,7315 }, { 117,7315 }, { 118,7315 },
 { 119,7315 }, { 120,7315 }, { 121,7315 }, { 122,7315 }, { 123,7315 },
 { 124,7315 }, { 125,7315 }, { 126,7315 }, { 127,7315 }, { 128,7315 },
 { 129,7315 }, { 130,7315 }, { 131,7315 }, { 132,7315 }, { 133,7315 },
 { 134,7315 }, { 135,7315 }, { 136,7315 }, { 137,7315 }, { 138,7315 },
 { 139,7315 }, { 140,7315 }, { 141,7315 }, { 142,7315 }, { 143,7315 },
 { 144,7315 }, { 145,7315 }, { 146,7315 }, { 147,7315 }, { 148,7315 },
 { 149,7315 }, { 150,7315 }, { 151,7315 }, { 152,7315 }, { 153,7315 },
 { 154,7315 }, { 155,7315 }, { 156,7315 }, { 157,7315 }, { 158,7315 },

 { 159,7315 }, { 160,7315 }, { 161,7315 }, { 162,7315 }, { 163,7315 },
 { 164,7315 }, { 165,7315 }, { 166,7315 }, { 167,7315 }, { 168,7315 },
 { 169,7315 }, { 170,7315 }, { 171,7315 }, { 172,7315 }, { 173,7315 },
 { 174,7315 }, { 175,7315 }, { 176,7315 }, { 177,7315 }, { 178,7315 },
 { 179,7315 }, { 180,7315 }, { 181,7315 }, { 182,7315 }, { 183,7315 },
 { 184,7315 }, { 185,7315 }, { 186,7315 }, { 187,7315 }, { 188,7315 },
 { 189,7315 }, { 190,7315 }, { 191,7315 }, { 192,7315 }, { 193,7315 },
 { 194,7315 }, { 195,7315 }, { 196,7315 }, { 197,7315 }, { 198,7315 },
 { 199,7315 }, { 200,7315 }, { 201,7315 }, { 202,7315 }, { 203,7315 },
 { 204,7315 }, { 205,7315 }, { 206,7315 }, { 207,7315 }, { 208,7315 },

 { 209,7315 }, { 210,7315 }, { 211,7315 }, { 212,7315 }, { 213,7315 },
 { 214,7315 }, { 215,7315 }, { 216,7315 }, { 217,7315 }, { 218,7315 },
 { 219,7315 }, { 220,7315 }, { 221,7315 }, { 222,7315 }, { 223,7315 },
 { 224,7315 }, { 225,7315 }, { 226,7315 }, { 227,7315 }, { 228,7315 },
 { 229,7315 }, { 230,7315 }, { 231,7315 }, { 232,7315 }, { 233,7315 },
 { 234,7315 }, { 235,7315 }, { 236,7315 }, { 237,7315 }, { 238,7315 },
 { 239,7315 }, { 240,7315 }, { 241,7315 }, { 242,7315 }, { 243,7315 },
 { 244,7315 }, { 245,7315 }, { 246,7315 }, { 247,7315 }, { 248,7315 },
 { 249,7315 }, { 250,7315 }, { 251,7315 }, { 252,7315 }, { 253,7315 },
 { 254,7315 }, { 255,7315 }, { 256,7315 }, {   0,  18 }, {   0,21501 },

 {   1,3156 }, {   2,3156 }, {   3,3156 }, {   4,3156 }, {   5,3156 },
 {   6,3156 }, {   7,3156 }, {   8,3156 }, {   9,7315 }, {  10,7320 },
 {  11,7315 }, {  12,7315 }, {  13,7344 }, {  14,3156 }, {  15,3156 },
 {  16,3156 }, {  17,3156 }, {  18,3156 }, {  19,3156 }, {  20,3156 },
 {  21,3156 }, {  22,3156 }, {  23,3156 }, {  24,3156 }, {  25,3156 },
 {  26,3156 }, {  27,3156 }, {  28,3156 }, {  29,3156 }, {  30,3156 },
 {  31,3156 }, {  32,7315 }, {  33,3156 }, {  34,3156 }, {  35,3156 },
 {  36,3156 }, {  37,3156 }, {  38,3156 }, {  39,3156 }, {  40,3156 },
 {  41,3156 }, {  42,3156 }, {  43,3156 }, {  44,3156 }, {  45,3158 },
 {  46,3156 }, {  47,3156 }, {  48,3156 }, {  49,3156 }, {  50,3156 },

 {  51,3156 }, {  52,3156 }, {  53,3156 }, {  54,3156 }, {  55,3156 },
 {  56,3156 }, {  57,3156 }, {  58,3156 }, {  59,3156 }, {  60,3156 },
 {  61,3156 }, {  62,3156 }, {  63,3156 }, {  64,3156 }, {  65,3156 },
 {  66,3156 }, {  67,3156 }, {  68,3156 }, {  69,3156 }, {  70,3156 },
 {  71,3156 }, {  72,3156 }, {  73,3156 }, {  74,3156 }, {  75,3156 },
 {  76,3156 }, {  77,3156 }, {  78,3156 }, {  79,3156 }, {  80,3156 },
 {  81,3156 }, {  82,3156 }, {  83,3156 }, {  84,3156 }, {  85,3156 },
 {  86,3156 }, {  87,3156 }, {  88,3156 }, {  89,3156 }, {  90,3156 },
 {  91,3156 }, {  92,3156 }, {  93,3156 }, {  94,3156 }, {  95,3156 },
 {  96,3156 }, {  97,3156 }, {  98,3156 }, {  99,3156 }, { 100,3156 },

 { 101,3156 }, { 102,3156 }, { 103,3156 }, { 104,3156 }, { 105,3156 },
 { 106,3156 }, { 107,3156 }, { 108,3156 }, { 109,3156 }, { 110,3156 },
 { 111,3156 }, { 112,3156 }, { 113,3156 }, { 114,3156 }, { 115,3156 },
 { 116,3156 }, { 117,3156 }, { 118,3156 }, { 119,3156 }, { 120,3156 },
 { 121,3156 }, { 122,3156 }, { 123,3156 }, { 124,3156 }, { 125,3156 },
 { 126,3156 }, { 127,3156 }, { 128,3156 }, { 129,3156 }, { 130,3156 },
 { 131,3156 }, { 132,3156 }, { 133,3156 }, { 134,3156 }, { 135,3156 },
 { 136,3156 }, { 137,3156 }, { 138,3156 }, { 139,3156 }, { 140,3156 },
 { 141,3156 }, { 142,3156 }, { 143,3156 }, { 144,3156 }, { 145,3156 },
 { 146,3156 }, { 147,3156 }, { 148,3156 }, { 149,3156 }, { 150,3156 },

 { 151,3156 }, { 152,3156 }, { 153,3156 }, { 154,3156 }, { 155,3156 },
 { 156,3156 }, { 157,3156 }, { 158,3156 }, { 159,3156 }, { 160,3156 },
 { 161,3156 }, { 162,3156 }, { 163,3156 }, { 164,3156 }, { 165,3156 },
 { 166,3156 }, { 167,3156 }, { 168,3156 }, { 169,3156 }, { 170,3156 },
 { 171,3156 }, { 172,3156 }, { 173,3156 }, { 174,3156 }, { 175,3156 },
 { 176,3156 }, { 177,3156 }, { 178,3156 }, { 179,3156 }, { 180,3156 },
 { 181,3156 }, { 182,3156 }, { 183,3156 }, { 184,3156 }, { 185,3156 },
 { 186,3156 }, { 187,3156 }, { 188,3156 }, { 189,3156 }, { 190,3156 },
 { 191,3156 }, { 192,3156 }, { 193,3156 }, { 194,3156 }, { 195,3156 },
 { 196,3156 }, { 197,3156 }, { 198,3156 }, { 199,3156 }, { 200,3156 },

 { 201,3156 }, { 202,3156 }, { 203,3156 }, { 204,3156 }, { 205,3156 },
 { 206,3156 }, { 207,3156 }, { 208,3156 }, { 209,3156 }, { 210,3156 },
 { 211,3156 }, { 212,3156 }, { 213,3156 }, { 214,3156 }, { 215,3156 },
 { 216,3156 }, { 217,3156 }, { 218,3156 }, { 219,3156 }, { 220,3156 },
 { 221,3156 }, { 222,3156 }, { 223,3156 }, { 224,3156 }, { 225,3156 },
 { 226,3156 }, { 227,3156 }, { 228,3156 }, { 229,3156 }, { 230,3156 },
 { 231,3156 }, { 232,3156 }, { 233,3156 }, { 234,3156 }, { 235,3156 },
 { 236,3156 }, { 237,3156 }, { 238,3156 }, { 239,3156 }, { 240,3156 },
 { 241,3156 }, { 242,3156 }, { 243,3156 }, { 244,3156 }, { 245,3156 },
 { 246,3156 }, { 247,3156 }, { 248,3156 }, { 249,3156 }, { 250,3156 },

 { 251,3156 }, { 252,3156 }, { 253,3156 }, { 254,3156 }, { 255,3156 },
 { 256,3156 }, {   0,  18 }, {   0,21243 }, {   1,2898 }, {   2,2898 },
 {   3,2898 }, {   4,2898 }, {   5,2898 }, {   6,2898 }, {   7,2898 },
 {   8,2898 }, {   9,7057 }, {  10,7062 }, {  11,7057 }, {  12,7057 },
 {  13,7086 }, {  14,2898 }, {  15,2898 }, {  16,2898 }, {  17,2898 },
 {  18,2898 }, {  19,2898 }, {  20,2898 }, {  21,2898 }, {  22,2898 },
 {  23,2898 }, {  24,2898 }, {  25,2898 }, {  26,2898 }, {  27,2898 },
 {  28,2898 }, {  29,2898 }, {  30,2898 }, {  31,2898 }, {  32,7057 },
 {  33,2898 }, {  34,2898 }, {  35,2898 }, {  36,2898 }, {  37,2898 },
 {  38,2898 }, {  39,2898 }, {  40,2898 }, {  41,2898 }, {  42,2898 },

 {  43,2898 }, {  44,2898 }, {  45,2900 }, {  46,2898 }, {  47,2898 },
 {  48,2898 }, {  49,2898 }, {  50,2898 }, {  51,2898 }, {  52,2898 },
 {  53,2898 }, {  54,2898 }, {  55,2898 }, {  56,2898 }, {  57,2898 },
 {  58,2898 }, {  59,2898 }, {  60,2898 }, {  61,2898 }, {  62,2898 },
 {  63,2898 }, {  64,2898 }, {  65,2898 }, {  66,2898 }, {  67,2898 },
 {  68,2898 }, {  69,2898 }, {  70,2898 }, {  71,2898 }, {  72,2898 },
 {  73,2898 }, {  74,2898 }, {  75,2898 }, {  76,2898 }, {  77,2898 },
 {  78,2898 }, {  79,2898 }, {  80,2898 }, {  81,2898 }, {  82,2898 },
 {  83,2898 }, {  84,2898 }, {  85,2898 }, {  86,2898 }, {  87,2898 },
 {  88,2898 }, {  89,2898 }, {  90,2898 }, {  91,2898 }, {  92,2898 },

 {  93,2898 }, {  94,2898 }, {  95,2898 }, {  96,2898 }, {  97,2898 },
 {  98,2898 }, {  99,2898 }, { 100,2898 }, { 101,2898 }, { 102,2898 },
 { 103,2898 }, { 104,2898 }, { 105,2898 }, { 106,2898 }, { 107,2898 },
 { 108,2898 }, { 109,2898 }, { 110,2898 }, { 111,2898 }, { 112,2898 },
 { 113,2898 }, { 114,2898 }, { 115,2898 }, { 116,2898 }, { 117,2898 },
 { 118,2898 }, { 119,2898 }, { 120,2898 }, { 121,2898 }, { 122,2898 },
 { 123,2898 }, { 124,2898 }, { 125,2898 }, { 126,2898 }, { 127,2898 },
 { 128,2898 }, { 129,2898 }, { 130,2898 }, { 131,2898 }, { 132,2898 },
 { 133,2898 }, { 134,2898 }, { 135,2898 }, { 136,2898 }, { 137,2898 },
 { 138,2898 }, { 139,2898 }, { 140,2898 }, { 141,2898 }, { 142,2898 },

 { 143,2898 }, { 144,2898 }, { 145,2898 }, { 146,2898 }, { 147,2898 },
 { 148,2898 }, { 149,2898 }, { 150,2898 }, { 151,2898 }, { 152,2898 },
 { 153,2898 }, { 154,2898 }, { 155,2898 }, { 156,2898 }, { 157,2898 },
 { 158,2898 }, { 159,2898 }, { 160,2898 }, { 161,2898 }, { 162,2898 },
 { 163,2898 }, { 164,2898 }, { 165,2898 }, { 166,2898 }, { 167,2898 },
 { 168,2898 }, { 169,2898 }, { 170,2898 }, { 171,2898 }, { 172,2898 },
 { 173,2898 }, { 174,2898 }, { 175,2898 }, { 176,2898 }, { 177,2898 },
 { 178,2898 }, { 179,2898 }, { 180,2898 }, { 181,2898 }, { 182,2898 },
 { 183,2898 }, { 184,2898 }, { 185,2898 }, { 186,2898 }, { 187,2898 },
 { 188,2898 }, { 189,2898 }, { 190,2898 }, { 191,2898 }, { 192,2898 },

 { 193,2898 }, { 194,2898 }, { 195,2898 }, { 196,2898 }, { 197,2898 },
 { 198,2898 }, { 199,2898 }, { 200,2898 }, { 201,2898 }, { 202,2898 },
 { 203,2898 }, { 204,2898 }, { 205,2898 }, { 206,2898 }, { 207,2898 },
 { 208,2898 }, { 209,2898 }, { 210,2898 }, { 211,2898 }, { 212,2898 },
 { 213,2898 }, { 214,2898 }, { 215,2898 }, { 216,2898 }, { 217,2898 },
 { 218,2898 }, { 219,2898 }, { 220,2898 }, { 221,2898 }, { 222,2898 },
 { 223,2898 }, { 224,2898 }, { 225,2898 }, { 226,2898 }, { 227,2898 },
 { 228,2898 }, { 229,2898 }, { 230,2898 }, { 231,2898 }, { 232,2898 },
 { 233,2898 }, { 234,2898 }, { 235,2898 }, { 236,2898 }, { 237,2898 },
 { 238,2898 }, { 239,2898 }, { 240,2898 }, { 241,2898 }, { 242,2898 },

 { 243,2898 }, { 244,2898 }, { 245,2898 }, { 246,2898 }, { 247,2898 },
 { 248,2898 }, { 249,2898 }, { 250,2898 }, { 251,2898 }, { 252,2898 },
 { 253,2898 }, { 254,2898 }, { 255,2898 }, { 256,2898 }, {   0,   0 },
 {   0,20985 }, {   1,6875 }, {   2,6875 }, {   3,6875 }, {   4,6875 },
 {   5,6875 }, {   6,6875 }, {   7,6875 }, {   8,6875 }, {   9,6875 },
 {  10,7133 }, {  11,6875 }, {  12,6875 }, {  13,6875 }, {  14,6875 },
 {  15,6875 }, {  16,6875 }, {  17,6875 }, {  18,6875 }, {  19,6875 },
 {  20,6875 }, {  21,6875 }, {  22,6875 }, {  23,6875 }, {  24,6875 },
 {  25,6875 }, {  26,6875 }, {  27,6875 }, {  28,6875 }, {  29,6875 },
 {  30,6875 }, {  31,6875 }, {  32,6875 }, {  33,6875 }, {  34,6875 },

 {  35,6875 }, {  36,6875 }, {  37,6875 }, {  38,6875 }, {  39,2645 },
 {  40,6875 }, {  41,6875 }, {  42,6875 }, {  43,6875 }, {  44,6875 },
 {  45,6875 }, {  46,6875 }, {  47,6875 }, {  48,6875 }, {  49,6875 },
 {  50,6875 }, {  51,6875 }, {  52,6875 }, {  53,6875 }, {  54,6875 },
 {  55,6875 }, {  56,6875 }, {  57,6875 }, {  58,6875 }, {  59,6875 },
 {  60,6875 }, {  61,6875 }, {  62,6875 }, {  63,6875 }, {  64,6875 },
 {  65,6875 }, {  66,6875 }, {  67,6875 }, {  68,6875 }, {  69,6875 },
 {  70,6875 }, {  71,6875 }, {  72,6875 }, {  73,6875 }, {  74,6875 },
 {  75,6875 }, {  76,6875 }, {  77,6875 }, {  78,6875 }, {  79,6875 },
 {  80,6875 }, {  81,6875 }, {  82,6875 }, {  83,6875 }, {  84,6875 },

 {  85,6875 }, {  86,6875 }, {  87,6875 }, {  88,6875 }, {  89,6875 },
 {  90,6875 }, {  91,6875 }, {  92,7391 }, {  93,6875 }, {  94,6875 },
 {  95,6875 }, {  96,6875 }, {  97,6875 }, {  98,6875 }, {  99,6875 },
 { 100,6875 }, { 101,6875 }, { 102,6875 }, { 103,6875 }, { 104,6875 },
 { 105,6875 }, { 106,6875 }, { 107,6875 }, { 108,6875 }, { 109,6875 },
 { 110,6875 }, { 111,6875 }, { 112,6875 }, { 113,6875 }, { 114,6875 },
 { 115,6875 }, { 116,6875 }, { 117,6875 }, { 118,6875 }, { 119,6875 },
 { 120,6875 }, { 121,6875 }, { 122,6875 }, { 123,6875 }, { 124,6875 },
 { 125,6875 }, { 126,6875 }, { 127,6875 }, { 128,6875 }, { 129,6875 },
 { 130,6875 }, { 131,6875 }, { 132,6875 }, { 133,6875 }, { 134,6875 },

 { 135,6875 }, { 136,6875 }, { 137,6875 }, { 138,6875 }, { 139,6875 },
 { 140,6875 }, { 141,6875 }, { 142,6875 }, { 143,6875 }, { 144,6875 },
 { 145,6875 }, { 146,6875 }, { 147,6875 }, { 148,6875 }, { 149,6875 },
 { 150,6875 }, { 151,6875 }, { 152,6875 }, { 153,6875 }, { 154,6875 },
 { 155,6875 }, { 156,6875 }, { 157,6875 }, { 158,6875 }, { 159,6875 },
 { 160,6875 }, { 161,6875 }, { 162,6875 }, { 163,6875 }, { 164,6875 },
 { 165,6875 }, { 166,6875 }, { 167,6875 }, { 168,6875 }, { 169,6875 },
 { 170,6875 }, { 171,6875 }, { 172,6875 }, { 173,6875 }, { 174,6875 },
 { 175,6875 }, { 176,6875 }, { 177,6875 }, { 178,6875 }, { 179,6875 },
 { 180,6875 }, { 181,6875 }, { 182,6875 }, { 183,6875 }, { 184,6875 },

 { 185,6875 }, { 186,6875 }, { 187,6875 }, { 188,6875 }, { 189,6875 },
 { 190,6875 }, { 191,6875 }, { 192,6875 }, { 193,6875 }, { 194,6875 },
 { 195,6875 }, { 196,6875 }, { 197,6875 }, { 198,6875 }, { 199,6875 },
 { 200,6875 }, { 201,6875 }, { 202,6875 }, { 203,6875 }, { 204,6875 },
 { 205,6875 }, { 206,6875 }, { 207,6875 }, { 208,6875 }, { 209,6875 },
 { 210,6875 }, { 211,6875 }, { 212,6875 }, { 213,6875 }, { 214,6875 },
 { 215,6875 }, { 216,6875 }, { 217,6875 }, { 218,6875 }, { 219,6875 },
 { 220,6875 }, { 221,6875 }, { 222,6875 }, { 223,6875 }, { 224,6875 },
 { 225,6875 }, { 226,6875 }, { 227,6875 }, { 228,6875 }, { 229,6875 },
 { 230,6875 }, { 231,6875 }, { 232,6875 }, { 233,6875 }, { 234,6875 },

 { 235,6875 }, { 236,6875 }, { 237,6875 }, { 238,6875 }, { 239,6875 },
 { 240,6875 }, { 241,6875 }, { 242,6875 }, { 243,6875 }, { 244,6875 },
 { 245,6875 }, { 246,6875 }, { 247,6875 }, { 248,6875 }, { 249,6875 },
 { 250,6875 }, { 251,6875 }, { 252,6875 }, { 253,6875 }, { 254,6875 },
 { 255,6875 }, { 256,6875 }, {   0,   0 }, {   0,20727 }, {   1,6617 },
 {   2,6617 }, {   3,6617 }, {   4,6617 }, {   5,6617 }, {   6,6617 },
 {   7,6617 }, {   8,6617 }, {   9,6617 }, {  10,6875 }, {  11,6617 },
 {  12,6617 }, {  13,6617 }, {  14,6617 }, {  15,6617 }, {  16,6617 },
 {  17,6617 }, {  18,6617 }, {  19,6617 }, {  20,6617 }, {  21,6617 },
 {  22,6617 }, {  23,6617 }, {  24,6617 }, {  25,6617 }, {  26,6617 },

 {  27,6617 }, {  28,6617 }, {  29,6617 }, {  30,6617 }, {  31,6617 },
 {  32,6617 }, {  33,6617 }, {  34,6617 }, {  35,6617 }, {  36,6617 },
 {  37,6617 }, {  38,6617 }, {  39,2387 }, {  40,6617 }, {  41,6617 },
 {  42,6617 }, {  43,6617 }, {  44,6617 }, {  45,6617 }, {  46,6617 },
 {  47,6617 }, {  48,6617 }, {  49,6617 }, {  50,6617 }, {  51,6617 },
 {  52,6617 }, {  53,6617 }, {  54,6617 }, {  55,6617 }, {  56,6617 },
 {  57,6617 }, {  58,6617 }, {  59,6617 }, {  60,6617 }, {  61,6617 },
 {  62,6617 }, {  63,6617 }, {  64,6617 }, {  65,6617 }, {  66,6617 },
 {  67,6617 }, {  68,6617 }, {  69,6617 }, {  70,6617 }, {  71,6617 },
 {  72,6617 }, {  73,6617 }, {  74,6617 }, {  75,6617 }, {  76,6617 },

 {  77,6617 }, {  78,6617 }, {  79,6617 }, {  80,6617 }, {  81,6617 },
 {  82,6617 }, {  83,6617 }, {  84,6617 }, {  85,6617 }, {  86,6617 },
 {  87,6617 }, {  88,6617 }, {  89,6617 }, {  90,6617 }, {  91,6617 },
 {  92,7133 }, {  93,6617 }, {  94,6617 }, {  95,6617 }, {  96,6617 },
 {  97,6617 }, {  98,6617 }, {  99,6617 }, { 100,6617 }, { 101,6617 },
 { 102,6617 }, { 103,6617 }, { 104,6617 }, { 105,6617 }, { 106,6617 },
 { 107,6617 }, { 108,6617 }, { 109,6617 }, { 110,6617 }, { 111,6617 },
 { 112,6617 }, { 113,6617 }, { 114,6617 }, { 115,6617 }, { 116,6617 },
 { 117,6617 }, { 118,6617 }, { 119,6617 }, { 120,6617 }, { 121,6617 },
 { 122,6617 }, { 123,6617 }, { 124,6617 }, { 125,6617 }, { 126,6617 },

 { 127,6617 }, { 128,6617 }, { 129,6617 }, { 130,6617 }, { 131,6617 },
 { 132,6617 }, { 133,6617 }, { 134,6617 }, { 135,6617 }, { 136,6617 },
 { 137,6617 }, { 138,6617 }, { 139,6617 }, { 140,6617 }, { 141,6617 },
 { 142,6617 }, { 143,6617 }, { 144,6617 }, { 145,6617 }, { 146,6617 },
 { 147,6617 }, { 148,6617 }, { 149,6617 }, { 150,6617 }, { 151,6617 },
 { 152,6617 }, { 153,6617 }, { 154,6617 }, { 155,6617 }, { 156,6617 },
 { 157,6617 }, { 158,6617 }, { 159,6617 }, { 160,6617 }, { 161,6617 },
 { 162,6617 }, { 163,6617 }, { 164,6617 }, { 165,6617 }, { 166,6617 },
 { 167,6617 }, { 168,6617 }, { 169,6617 }, { 170,6617 }, { 171,6617 },
 { 172,6617 }, { 173,6617 }, { 174,6617 }, { 175,6617 }, { 176,6617 },

 { 177,6617 }, { 178,6617 }, { 179,6617 }, { 180,6617 }, { 181,6617 },
 { 182,6617 }, { 183,6617 }, { 184,6617 }, { 185,6617 }, { 186,6617 },
 { 187,6617 }, { 188,6617 }, { 189,6617 }, { 190,6617 }, { 191,6617 },
 { 192,6617 }, { 193,6617 }, { 194,6617 }, { 195,6617 }, { 196,6617 },
 { 197,6617 }, { 198,6617 }, { 199,6617 }, { 200,6617 }, { 201,6617 },
 { 202,6617 }, { 203,6617 }, { 204,6617 }, { 205,6617 }, { 206,6617 },
 { 207,6617 }, { 208,6617 }, { 209,6617 }, { 210,6617 }, { 211,6617 },
 { 212,6617 }, { 213,6617 }, { 214,6617 }, { 215,6617 }, { 216,6617 },
 { 217,6617 }, { 218,6617 }, { 219,6617 }, { 220,6617 }, { 221,6617 },
 { 222,6617 }, { 223,6617 }, { 224,6617 }, { 225,6617 }, { 226,6617 },

 { 227,6617 }, { 228,6617 }, { 229,6617 }, { 230,6617 }, { 231,6617 },
 { 232,6617 }, { 233,6617 }, { 234,6617 }, { 235,6617 }, { 236,6617 },
 { 237,6617 }, { 238,6617 }, { 239,6617 }, { 240,6617 }, { 241,6617 },
 { 242,6617 }, { 243,6617 }, { 244,6617 }, { 245,6617 }, { 246,6617 },
 { 247,6617 }, { 248,6617 }, { 249,6617 }, { 250,6617 }, { 251,6617 },
 { 252,6617 }, { 253,6617 }, { 254,6617 }, { 255,6617 }, { 256,6617 },
 {   0,   0 }, {   0,20469 }, {   1,7133 }, {   2,7133 }, {   3,7133 },
 {   4,7133 }, {   5,7133 }, {   6,7133 }, {   7,7133 }, {   8,7133 },
 {   9,7133 }, {  10,7391 }, {  11,7133 }, {  12,7133 }, {  13,7133 },
 {  14,7133 }, {  15,7133 }, {  16,7133 }, {  17,7133 }, {  18,7133 },

 {  19,7133 }, {  20,7133 }, {  21,7133 }, {  22,7133 }, {  23,7133 },
 {  24,7133 }, {  25,7133 }, {  26,7133 }, {  27,7133 }, {  28,7133 },
 {  29,7133 }, {  30,7133 }, {  31,7133 }, {  32,7133 }, {  33,7133 },
 {  34,7133 }, {  35,7133 }, {  36,7649 }, {  37,7133 }, {  38,7133 },
 {  39,7133 }, {  40,7133 }, {  41,7133 }, {  42,7133 }, {  43,7133 },
 {  44,7133 }, {  45,7133 }, {  46,7133 }, {  47,7133 }, {  48,7133 },
 {  49,7133 }, {  50,7133 }, {  51,7133 }, {  52,7133 }, {  53,7133 },
 {  54,7133 }, {  55,7133 }, {  56,7133 }, {  57,7133 }, {  58,7133 },
 {  59,7133 }, {  60,7133 }, {  61,7133 }, {  62,7133 }, {  63,7133 },
 {  64,7133 }, {  65,7133 }, {  66,7133 }, {  67,7133 }, {  68,7133 },

 {  69,7133 }, {  70,7133 }, {  71,7133 }, {  72,7133 }, {  73,7133 },
 {  74,7133 }, {  75,7133 }, {  76,7133 }, {  77,7133 }, {  78,7133 },
 {  79,7133 }, {  80,7133 }, {  81,7133 }, {  82,7133 }, {  83,7133 },
 {  84,7133 }, {  85,7133 }, {  86,7133 }, {  87,7133 }, {  88,7133 },
 {  89,7133 }, {  90,7133 }, {  91,7133 }, {  92,7133 }, {  93,7133 },
 {  94,7133 }, {  95,7133 }, {  96,7133 }, {  97,7133 }, {  98,7133 },
 {  99,7133 }, { 100,7133 }, { 101,7133 }, { 102,7133 }, { 103,7133 },
 { 104,7133 }, { 105,7133 }, { 106,7133 }, { 107,7133 }, { 108,7133 },
 { 109,7133 }, { 110,7133 }, { 111,7133 }, { 112,7133 }, { 113,7133 },
 { 114,7133 }, { 115,7133 }, { 116,7133 }, { 117,7133 }, { 118,7133 },

 { 119,7133 }, { 120,7133 }, { 121,7133 }, { 122,7133 }, { 123,7133 },
 { 124,7133 }, { 125,7133 }, { 126,7133 }, { 127,7133 }, { 128,7133 },
 { 129,7133 }, { 130,7133 }, { 131,7133 }, { 132,7133 }, { 133,7133 },
 { 134,7133 }, { 135,7133 }, { 136,7133 }, { 137,7133 }, { 138,7133 },
 { 139,7133 }, { 140,7133 }, { 141,7133 }, { 142,7133 }, { 143,7133 },
 { 144,7133 }, { 145,7133 }, { 146,7133 }, { 147,7133 }, { 148,7133 },
 { 149,7133 }, { 150,7133 }, { 151,7133 }, { 152,7133 }, { 153,7133 },
 { 154,7133 }, { 155,7133 }, { 156,7133 }, { 157,7133 }, { 158,7133 },
 { 159,7133 }, { 160,7133 }, { 161,7133 }, { 162,7133 }, { 163,7133 },
 { 164,7133 }, { 165,7133 }, { 166,7133 }, { 167,7133 }, { 168,7133 },

 { 169,7133 }, { 170,7133 }, { 171,7133 }, { 172,7133 }, { 173,7133 },
 { 174,7133 }, { 175,7133 }, { 176,7133 }, { 177,7133 }, { 178,7133 },
 { 179,7133 }, { 180,7133 }, { 181,7133 }, { 182,7133 }, { 183,7133 },
 { 184,7133 }, { 185,7133 }, { 186,7133 }, { 187,7133 }, { 188,7133 },
 { 189,7133 }, { 190,7133 }, { 191,7133 }, { 192,7133 }, { 193,7133 },
 { 194,7133 }, { 195,7133 }, { 196,7133 }, { 197,7133 }, { 198,7133 },
 { 199,7133 }, { 200,7133 }, { 201,7133 }, { 202,7133 }, { 203,7133 },
 { 204,7133 }, { 205,7133 }, { 206,7133 }, { 207,7133 }, { 208,7133 },
 { 209,7133 }, { 210,7133 }, { 211,7133 }, { 212,7133 }, { 213,7133 },
 { 214,7133 }, { 215,7133 }, { 216,7133 }, { 217,7133 }, { 218,7133 },

 { 219,7133 }, { 220,7133 }, { 221,7133 }, { 222,7133 }, { 223,7133 },
 { 224,7133 }, { 225,7133 }, { 226,7133 }, { 227,7133 }, { 228,7133 },
 { 229,7133 }, { 230,7133 }, { 231,7133 }, { 232,7133 }, { 233,7133 },
 { 234,7133 }, { 235,7133 }, { 236,7133 }, { 237,7133 }, { 238,7133 },
 { 239,7133 }, { 240,7133 }, { 241,7133 }, { 242,7133 }, { 243,7133 },
 { 244,7133 }, { 245,7133 }, { 246,7133 }, { 247,7133 }, { 248,7133 },
 { 249,7133 }, { 250,7133 }, { 251,7133 }, { 252,7133 }, { 253,7133 },
 { 254,7133 }, { 255,7133 }, { 256,7133 }, {   0,   0 }, {   0,20211 },
 {   1,6875 }, {   2,6875 }, {   3,6875 }, {   4,6875 }, {   5,6875 },
 {   6,6875 }, {   7,6875 }, {   8,6875 }, {   9,6875 }, {  10,7133 },

 {  11,6875 }, {  12,6875 }, {  13,6875 }, {  14,6875 }, {  15,6875 },
 {  16,6875 }, {  17,6875 }, {  18,6875 }, {  19,6875 }, {  20,6875 },
 {  21,6875 }, {  22,6875 }, {  23,6875 }, {  24,6875 }, {  25,6875 },
 {  26,6875 }, {  27,6875 }, {  28,6875 }, {  29,6875 }, {  30,6875 },
 {  31,6875 }, {  32,6875 }, {  33,6875 }, {  34,6875 }, {  35,6875 },
 {  36,7391 }, {  37,6875 }, {  38,6875 }, {  39,6875 }, {  40,6875 },
 {  41,6875 }, {  42,6875 }, {  43,6875 }, {  44,6875 }, {  45,6875 },
 {  46,6875 }, {  47,6875 }, {  48,6875 }, {  49,6875 }, {  50,6875 },
 {  51,6875 }, {  52,6875 }, {  53,6875 }, {  54,6875 }, {  55,6875 },
 {  56,6875 }, {  57,6875 }, {  58,6875 }, {  59,6875 }, {  60,6875 },

 {  61,6875 }, {  62,6875 }, {  63,6875 }, {  64,6875 }, {  65,6875 },
 {  66,6875 }, {  67,6875 }, {  68,6875 }, {  69,6875 }, {  70,6875 },
 {  71,6875 }, {  72,6875 }, {  73,6875 }, {  74,6875 }, {  75,6875 },
 {  76,6875 }, {  77,6875 }, {  78,6875 }, {  79,6875 }, {  80,6875 },
 {  81,6875 }, {  82,6875 }, {  83,6875 }, {  84,6875 }, {  85,6875 },
 {  86,6875 }, {  87,6875 }, {  88,6875 }, {  89,6875 }, {  90,6875 },
 {  91,6875 }, {  92,6875 }, {  93,6875 }, {  94,6875 }, {  95,6875 },
 {  96,6875 }, {  97,6875 }, {  98,6875 }, {  99,6875 }, { 100,6875 },
 { 101,6875 }, { 102,6875 }, { 103,6875 }, { 104,6875 }, { 105,6875 },
 { 106,6875 }, { 107,6875 }, { 108,6875 }, { 109,6875 }, { 110,6875 },

 { 111,6875 }, { 112,6875 }, { 113,6875 }, { 114,6875 }, { 115,6875 },
 { 116,6875 }, { 117,6875 }, { 118,6875 }, { 119,6875 }, { 120,6875 },
 { 121,6875 }, { 122,6875 }, { 123,6875 }, { 124,6875 }, { 125,6875 },
 { 126,6875 }, { 127,6875 }, { 128,6875 }, { 129,6875 }, { 130,6875 },
 { 131,6875 }, { 132,6875 }, { 133,6875 }, { 134,6875 }, { 135,6875 },
 { 136,6875 }, { 137,6875 }, { 138,6875 }, { 139,6875 }, { 140,6875 },
 { 141,6875 }, { 142,6875 }, { 143,6875 }, { 144,6875 }, { 145,6875 },
 { 146,6875 }, { 147,6875 }, { 148,6875 }, { 149,6875 }, { 150,6875 },
 { 151,6875 }, { 152,6875 }, { 153,6875 }, { 154,6875 }, { 155,6875 },
 { 156,6875 }, { 157,6875 }, { 158,6875 }, { 159,6875 }, { 160,6875 },

 { 161,6875 }, { 162,6875 }, { 163,6875 }, { 164,6875 }, { 165,6875 },
 { 166,6875 }, { 167,6875 }, { 168,6875 }, { 169,6875 }, { 170,6875 },
 { 171,6875 }, { 172,6875 }, { 173,6875 }, { 174,6875 }, { 175,6875 },
 { 176,6875 }, { 177,6875 }, { 178,6875 }, { 179,6875 }, { 180,6875 },
 { 181,6875 }, { 182,6875 }, { 183,6875 }, { 184,6875 }, { 185,6875 },
 { 186,6875 }, { 187,6875 }, { 188,6875 }, { 189,6875 }, { 190,6875 },
 { 191,6875 }, { 192,6875 }, { 193,6875 }, { 194,6875 }, { 195,6875 },
 { 196,6875 }, { 197,6875 }, { 198,6875 }, { 199,6875 }, { 200,6875 },
 { 201,6875 }, { 202,6875 }, { 203,6875 }, { 204,6875 }, { 205,6875 },
 { 206,6875 }, { 207,6875 }, { 208,6875 }, { 209,6875 }, { 210,6875 },

 { 211,6875 }, { 212,6875 }, { 213,6875 }, { 214,6875 }, { 215,6875 },
 { 216,6875 }, { 217,6875 }, { 218,6875 }, { 219,6875 }, { 220,6875 },
 { 221,6875 }, { 222,6875 }, { 223,6875 }, { 224,6875 }, { 225,6875 },
 { 226,6875 }, { 227,6875 }, { 228,6875 }, { 229,6875 }, { 230,6875 },
 { 231,6875 }, { 232,6875 }, { 233,6875 }, { 234,6875 }, { 235,6875 },
 { 236,6875 }, { 237,6875 }, { 238,6875 }, { 239,6875 }, { 240,6875 },
 { 241,6875 }, { 242,6875 }, { 243,6875 }, { 244,6875 }, { 245,6875 },
 { 246,6875 }, { 247,6875 }, { 248,6875 }, { 249,6875 }, { 250,6875 },
 { 251,6875 }, { 252,6875 }, { 253,6875 }, { 254,6875 }, { 255,6875 },
 { 256,6875 }, {   0,   0 }, {   0,19953 }, {   1,4993 }, {   2,4993 },

 {   3,4993 }, {   4,4993 }, {   5,4993 }, {   6,4993 }, {   7,4993 },
 {   8,4993 }, {   9,4993 }, {  10,4993 }, {  11,4993 }, {  12,4993 },
 {  13,4993 }, {  14,4993 }, {  15,4993 }, {  16,4993 }, {  17,4993 },
 {  18,4993 }, {  19,4993 }, {  20,4993 }, {  21,4993 }, {  22,4993 },
 {  23,4993 }, {  24,4993 }, {  25,4993 }, {  26,4993 }, {  27,4993 },
 {  28,4993 }, {  29,4993 }, {  30,4993 }, {  31,4993 }, {  32,4993 },
 {  33,4993 }, {  34,1615 }, {  35,4993 }, {  36,4993 }, {  37,4993 },
 {  38,4993 }, {  39,4993 }, {  40,4993 }, {  41,4993 }, {  42,4993 },
 {  43,4993 }, {  44,4993 }, {  45,4993 }, {  46,4993 }, {  47,4993 },
 {  48,4993 }, {  49,4993 }, {  50,4993 }, {  51,4993 }, {  52,4993 },

 {  53,4993 }, {  54,4993 }, {  55,4993 }, {  56,4993 }, {  57,4993 },
 {  58,4993 }, {  59,4993 }, {  60,4993 }, {  61,4993 }, {  62,4993 },
 {  63,4993 }, {  64,4993 }, {  65,4993 }, {  66,4993 }, {  67,4993 },
 {  68,4993 }, {  69,4993 }, {  70,4993 }, {  71,4993 }, {  72,4993 },
 {  73,4993 }, {  74,4993 }, {  75,4993 }, {  76,4993 }, {  77,4993 },
 {  78,4993 }, {  79,4993 }, {  80,4993 }, {  81,4993 }, {  82,4993 },
 {  83,4993 }, {  84,4993 }, {  85,4993 }, {  86,4993 }, {  87,4993 },
 {  88,4993 }, {  89,4993 }, {  90,4993 }, {  91,4993 }, {  92,4993 },
 {  93,4993 }, {  94,4993 }, {  95,4993 }, {  96,4993 }, {  97,4993 },
 {  98,4993 }, {  99,4993 }, { 100,4993 }, { 101,4993 }, { 102,4993 },

 { 103,4993 }, { 104,4993 }, { 105,4993 }, { 106,4993 }, { 107,4993 },
 { 108,4993 }, { 109,4993 }, { 110,4993 }, { 111,4993 }, { 112,4993 },
 { 113,4993 }, { 114,4993 }, { 115,4993 }, { 116,4993 }, { 117,4993 },
 { 118,4993 }, { 119,4993 }, { 120,4993 }, { 121,4993 }, { 122,4993 },
 { 123,4993 }, { 124,4993 }, { 125,4993 }, { 126,4993 }, { 127,4993 },
 { 128,4993 }, { 129,4993 }, { 130,4993 }, { 131,4993 }, { 132,4993 },
 { 133,4993 }, { 134,4993 }, { 135,4993 }, { 136,4993 }, { 137,4993 },
 { 138,4993 }, { 139,4993 }, { 140,4993 }, { 141,4993 }, { 142,4993 },
 { 143,4993 }, { 144,4993 }, { 145,4993 }, { 146,4993 }, { 147,4993 },
 { 148,4993 }, { 149,4993 }, { 150,4993 }, { 151,4993 }, { 152,4993 },

 { 153,4993 }, { 154,4993 }, { 155,4993 }, { 156,4993 }, { 157,4993 },
 { 158,4993 }, { 159,4993 }, { 160,4993 }, { 161,4993 }, { 162,4993 },
 { 163,4993 }, { 164,4993 }, { 165,4993 }, { 166,4993 }, { 167,4993 },
 { 168,4993 }, { 169,4993 }, { 170,4993 }, { 171,4993 }, { 172,4993 },
 { 173,4993 }, { 174,4993 }, { 175,4993 }, { 176,4993 }, { 177,4993 },
 { 178,4993 }, { 179,4993 }, { 180,4993 }, { 181,4993 }, { 182,4993 },
 { 183,4993 }, { 184,4993 }, { 185,4993 }, { 186,4993 }, { 187,4993 },
 { 188,4993 }, { 189,4993 }, { 190,4993 }, { 191,4993 }, { 192,4993 },
 { 193,4993 }, { 194,4993 }, { 195,4993 }, { 196,4993 }, { 197,4993 },
 { 198,4993 }, { 199,4993 }, { 200,4993 }, { 201,4993 }, { 202,4993 },

 { 203,4993 }, { 204,4993 }, { 205,4993 }, { 206,4993 }, { 207,4993 },
 { 208,4993 }, { 209,4993 }, { 210,4993 }, { 211,4993 }, { 212,4993 },
 { 213,4993 }, { 214,4993 }, { 215,4993 }, { 216,4993 }, { 217,4993 },
 { 218,4993 }, { 219,4993 }, { 220,4993 }, { 221,4993 }, { 222,4993 },
 { 223,4993 }, { 224,4993 }, { 225,4993 }, { 226,4993 }, { 227,4993 },
 { 228,4993 }, { 229,4993 }, { 230,4993 }, { 231,4993 }, { 232,4993 },
 { 233,4993 }, { 234,4993 }, { 235,4993 }, { 236,4993 }, { 237,4993 },
 { 238,4993 }, { 239,4993 }, { 240,4993 }, { 241,4993 }, { 242,4993 },
 { 243,4993 }, { 244,4993 }, { 245,4993 }, { 246,4993 }, { 247,4993 },
 { 248,4993 }, { 249,4993 }, { 250,4993 }, { 251,4993 }, { 252,4993 },

 { 253,4993 }, { 254,4993 }, { 255,4993 }, { 256,4993 }, {   0,   0 },
 {   0,19695 }, {   1,4735 }, {   2,4735 }, {   3,4735 }, {   4,4735 },
 {   5,4735 }, {   6,4735 }, {   7,4735 }, {   8,4735 }, {   9,4735 },
 {  10,4735 }, {  11,4735 }, {  12,4735 }, {  13,4735 }, {  14,4735 },
 {  15,4735 }, {  16,4735 }, {  17,4735 }, {  18,4735 }, {  19,4735 },
 {  20,4735 }, {  21,4735 }, {  22,4735 }, {  23,4735 }, {  24,4735 },
 {  25,4735 }, {  26,4735 }, {  27,4735 }, {  28,4735 }, {  29,4735 },
 {  30,4735 }, {  31,4735 }, {  32,4735 }, {  33,4735 }, {  34,1357 },
 {  35,4735 }, {  36,4735 }, {  37,4735 }, {  38,4735 }, {  39,4735 },
 {  40,4735 }, {  41,4735 }, {  42,4735 }, {  43,4735 }, {  44,4735 },

 {  45,4735 }, {  46,4735 }, {  47,4735 }, {  48,4735 }, {  49,4735 },
 {  50,4735 }, {  51,4735 }, {  52,4735 }, {  53,4735 }, {  54,4735 },
 {  55,4735 }, {  56,4735 }, {  57,4735 }, {  58,4735 }, {  59,4735 },
 {  60,4735 }, {  61,4735 }, {  62,4735 }, {  63,4735 }, {  64,4735 },
 {  65,4735 }, {  66,4735 }, {  67,4735 }, {  68,4735 }, {  69,4735 },
 {  70,4735 }, {  71,4735 }, {  72,4735 }, {  73,4735 }, {  74,4735 },
 {  75,4735 }, {  76,4735 }, {  77,4735 }, {  78,4735 }, {  79,4735 },
 {  80,4735 }, {  81,4735 }, {  82,4735 }, {  83,4735 }, {  84,4735 },
 {  85,4735 }, {  86,4735 }, {  87,4735 }, {  88,4735 }, {  89,4735 },
 {  90,4735 }, {  91,4735 }, {  92,4735 }, {  93,4735 }, {  94,4735 },

 {  95,4735 }, {  96,4735 }, {  97,4735 }, {  98,4735 }, {  99,4735 },
 { 100,4735 }, { 101,4735 }, { 102,4735 }, { 103,4735 }, { 104,4735 },
 { 105,4735 }, { 106,4735 }, { 107,4735 }, { 108,4735 }, { 109,4735 },
 { 110,4735 }, { 111,4735 }, { 112,4735 }, { 113,4735 }, { 114,4735 },
 { 115,4735 }, { 116,4735 }, { 117,4735 }, { 118,4735 }, { 119,4735 },
 { 120,4735 }, { 121,4735 }, { 122,4735 }, { 123,4735 }, { 124,4735 },
 { 125,4735 }, { 126,4735 }, { 127,4735 }, { 128,4735 }, { 129,4735 },
 { 130,4735 }, { 131,4735 }, { 132,4735 }, { 133,4735 }, { 134,4735 },
 { 135,4735 }, { 136,4735 }, { 137,4735 }, { 138,4735 }, { 139,4735 },
 { 140,4735 }, { 141,4735 }, { 142,4735 }, { 143,4735 }, { 144,4735 },

 { 145,4735 }, { 146,4735 }, { 147,4735 }, { 148,4735 }, { 149,4735 },
 { 150,4735 }, { 151,4735 }, { 152,4735 }, { 153,4735 }, { 154,4735 },
 { 155,4735 }, { 156,4735 }, { 157,4735 }, { 158,4735 }, { 159,4735 },
 { 160,4735 }, { 161,4735 }, { 162,4735 }, { 163,4735 }, { 164,4735 },
 { 165,4735 }, { 166,4735 }, { 167,4735 }, { 168,4735 }, { 169,4735 },
 { 170,4735 }, { 171,4735 }, { 172,4735 }, { 173,4735 }, { 174,4735 },
 { 175,4735 }, { 176,4735 }, { 177,4735 }, { 178,4735 }, { 179,4735 },
 { 180,4735 }, { 181,4735 }, { 182,4735 }, { 183,4735 }, { 184,4735 },
 { 185,4735 }, { 186,4735 }, { 187,4735 }, { 188,4735 }, { 189,4735 },
 { 190,4735 }, { 191,4735 }, { 192,4735 }, { 193,4735 }, { 194,4735 },

 { 195,4735 }, { 196,4735 }, { 197,4735 }, { 198,4735 }, { 199,4735 },
 { 200,4735 }, { 201,4735 }, { 202,4735 }, { 203,4735 }, { 204,4735 },
 { 205,4735 }, { 206,4735 }, { 207,4735 }, { 208,4735 }, { 209,4735 },
 { 210,4735 }, { 211,4735 }, { 212,4735 }, { 213,4735 }, { 214,4735 },
 { 215,4735 }, { 216,4735 }, { 217,4735 }, { 218,4735 }, { 219,4735 },
 { 220,4735 }, { 221,4735 }, { 222,4735 }, { 223,4735 }, { 224,4735 },
 { 225,4735 }, { 226,4735 }, { 227,4735 }, { 228,4735 }, { 229,4735 },
 { 230,4735 }, { 231,4735 }, { 232,4735 }, { 233,4735 }, { 234,4735 },
 { 235,4735 }, { 236,4735 }, { 237,4735 }, { 238,4735 }, { 239,4735 },
 { 240,4735 }, { 241,4735 }, { 242,4735 }, { 243,4735 }, { 244,4735 },

 { 245,4735 }, { 246,4735 }, { 247,4735 }, { 248,4735 }, { 249,4735 },
 { 250,4735 }, { 251,4735 }, { 252,4735 }, { 253,4735 }, { 254,4735 },
 { 255,4735 }, { 256,4735 }, {   0,   0 }, {   0,19437 }, {   1,4993 },
 {   2,4993 }, {   3,4993 }, {   4,4993 }, {   5,4993 }, {   6,4993 },
 {   7,4993 }, {   8,4993 }, {   9,4993 }, {  10,4993 }, {  11,4993 },
 {  12,4993 }, {  13,4993 }, {  14,4993 }, {  15,4993 }, {  16,4993 },
 {  17,4993 }, {  18,4993 }, {  19,4993 }, {  20,4993 }, {  21,4993 },
 {  22,4993 }, {  23,4993 }, {  24,4993 }, {  25,4993 }, {  26,4993 },
 {  27,4993 }, {  28,4993 }, {  29,4993 }, {  30,4993 }, {  31,4993 },
 {  32,4993 }, {  33,4993 }, {  34,4993 }, {  35,4993 }, {  36,4993 },

 {  37,4993 }, {  38,4993 }, {  39,1090 }, {  40,4993 }, {  41,4993 },
 {  42,4993 }, {  43,4993 }, {  44,4993 }, {  45,4993 }, {  46,4993 },
 {  47,4993 }, {  48,4993 }, {  49,4993 }, {  50,4993 }, {  51,4993 },
 {  52,4993 }, {  53,4993 }, {  54,4993 }, {  55,4993 }, {  56,4993 },
 {  57,4993 }, {  58,4993 }, {  59,4993 }, {  60,4993 }, {  61,4993 },
 {  62,4993 }, {  63,4993 }, {  64,4993 }, {  65,4993 }, {  66,4993 },
 {  67,4993 }, {  68,4993 }, {  69,4993 }, {  70,4993 }, {  71,4993 },
 {  72,4993 }, {  73,4993 }, {  74,4993 }, {  75,4993 }, {  76,4993 },
 {  77,4993 }, {  78,4993 }, {  79,4993 }, {  80,4993 }, {  81,4993 },
 {  82,4993 }, {  83,4993 }, {  84,4993 }, {  85,4993 }, {  86,4993 },

 {  87,4993 }, {  88,4993 }, {  89,4993 }, {  90,4993 }, {  91,4993 },
 {  92,4993 }, {  93,4993 }, {  94,4993 }, {  95,4993 }, {  96,4993 },
 {  97,4993 }, {  98,4993 }, {  99,4993 }, { 100,4993 }, { 101,4993 },
 { 102,4993 }, { 103,4993 }, { 104,4993 }, { 105,4993 }, { 106,4993 },
 { 107,4993 }, { 108,4993 }, { 109,4993 }, { 110,4993 }, { 111,4993 },
 { 112,4993 }, { 113,4993 }, { 114,4993 }, { 115,4993 }, { 116,4993 },
 { 117,4993 }, { 118,4993 }, { 119,4993 }, { 120,4993 }, { 121,4993 },
 { 122,4993 }, { 123,4993 }, { 124,4993 }, { 125,4993 }, { 126,4993 },
 { 127,4993 }, { 128,4993 }, { 129,4993 }, { 130,4993 }, { 131,4993 },
 { 132,4993 }, { 133,4993 }, { 134,4993 }, { 135,4993 }, { 136,4993 },

 { 137,4993 }, { 138,4993 }, { 139,4993 }, { 140,4993 }, { 141,4993 },
 { 142,4993 }, { 143,4993 }, { 144,4993 }, { 145,4993 }, { 146,4993 },
 { 147,4993 }, { 148,4993 }, { 149,4993 }, { 150,4993 }, { 151,4993 },
 { 152,4993 }, { 153,4993 }, { 154,4993 }, { 155,4993 }, { 156,4993 },
 { 157,4993 }, { 158,4993 }, { 159,4993 }, { 160,4993 }, { 161,4993 },
 { 162,4993 }, { 163,4993 }, { 164,4993 }, { 165,4993 }, { 166,4993 },
 { 167,4993 }, { 168,4993 }, { 169,4993 }, { 170,4993 }, { 171,4993 },
 { 172,4993 }, { 173,4993 }, { 174,4993 }, { 175,4993 }, { 176,4993 },
 { 177,4993 }, { 178,4993 }, { 179,4993 }, { 180,4993 }, { 181,4993 },
 { 182,4993 }, { 183,4993 }, { 184,4993 }, { 185,4993 }, { 186,4993 },

 { 187,4993 }, { 188,4993 }, { 189,4993 }, { 190,4993 }, { 191,4993 },
 { 192,4993 }, { 193,4993 }, { 194,4993 }, { 195,4993 }, { 196,4993 },
 { 197,4993 }, { 198,4993 }, { 199,4993 }, { 200,4993 }, { 201,4993 },
 { 202,4993 }, { 203,4993 }, { 204,4993 }, { 205,4993 }, { 206,4993 },
 { 207,4993 }, { 208,4993 }, { 209,4993 }, { 210,4993 }, { 211,4993 },
 { 212,4993 }, { 213,4993 }, { 214,4993 }, { 215,4993 }, { 216,4993 },
 { 217,4993 }, { 218,4993 }, { 219,4993 }, { 220,4993 }, { 221,4993 },
 { 222,4993 }, { 223,4993 }, { 224,4993 }, { 225,4993 }, { 226,4993 },
 { 227,4993 }, { 228,4993 }, { 229,4993 }, { 230,4993 }, { 231,4993 },
 { 232,4993 }, { 233,4993 }, { 234,4993 }, { 235,4993 }, { 236,4993 },

 { 237,4993 }, { 238,4993 }, { 239,4993 }, { 240,4993 }, { 241,4993 },
 { 242,4993 }, { 243,4993 }, { 244,4993 }, { 245,4993 }, { 246,4993 },
 { 247,4993 }, { 248,4993 }, { 249,4993 }, { 250,4993 }, { 251,4993 },
 { 252,4993 }, { 253,4993 }, { 254,4993 }, { 255,4993 }, { 256,4993 },
 {   0,   0 }, {   0,19179 }, {   1,4735 }, {   2,4735 }, {   3,4735 },
 {   4,4735 }, {   5,4735 }, {   6,4735 }, {   7,4735 }, {   8,4735 },
 {   9,4735 }, {  10,4735 }, {  11,4735 }, {  12,4735 }, {  13,4735 },
 {  14,4735 }, {  15,4735 }, {  16,4735 }, {  17,4735 }, {  18,4735 },
 {  19,4735 }, {  20,4735 }, {  21,4735 }, {  22,4735 }, {  23,4735 },
 {  24,4735 }, {  25,4735 }, {  26,4735 }, {  27,4735 }, {  28,4735 },

 {  29,4735 }, {  30,4735 }, {  31,4735 }, {  32,4735 }, {  33,4735 },
 {  34,4735 }, {  35,4735 }, {  36,4735 }, {  37,4735 }, {  38,4735 },
 {  39, 832 }, {  40,4735 }, {  41,4735 }, {  42,4735 }, {  43,4735 },
 {  44,4735 }, {  45,4735 }, {  46,4735 }, {  47,4735 }, {  48,4735 },
 {  49,4735 }, {  50,4735 }, {  51,4735 }, {  52,4735 }, {  53,4735 },
 {  54,4735 }, {  55,4735 }, {  56,4735 }, {  57,4735 }, {  58,4735 },
 {  59,4735 }, {  60,4735 }, {  61,4735 }, {  62,4735 }, {  63,4735 },
 {  64,4735 }, {  65,4735 }, {  66,4735 }, {  67,4735 }, {  68,4735 },
 {  69,4735 }, {  70,4735 }, {  71,4735 }, {  72,4735 }, {  73,4735 },
 {  74,4735 }, {  75,4735 }, {  76,4735 }, {  77,4735 }, {  78,4735 },

 {  79,4735 }, {  80,4735 }, {  81,4735 }, {  82,4735 }, {  83,4735 },
 {  84,4735 }, {  85,4735 }, {  86,4735 }, {  87,4735 }, {  88,4735 },
 {  89,4735 }, {  90,4735 }, {  91,4735 }, {  92,4735 }, {  93,4735 },
 {  94,4735 }, {  95,4735 }, {  96,4735 }, {  97,4735 }, {  98,4735 },
 {  99,4735 }, { 100,4735 }, { 101,4735 }, { 102,4735 }, { 103,4735 },
 { 104,4735 }, { 105,4735 }, { 106,4735 }, { 107,4735 }, { 108,4735 },
 { 109,4735 }, { 110,4735 }, { 111,4735 }, { 112,4735 }, { 113,4735 },
 { 114,4735 }, { 115,4735 }, { 116,4735 }, { 117,4735 }, { 118,4735 },
 { 119,4735 }, { 120,4735 }, { 121,4735 }, { 122,4735 }, { 123,4735 },
 { 124,4735 }, { 125,4735 }, { 126,4735 }, { 127,4735 }, { 128,4735 },

 { 129,4735 }, { 130,4735 }, { 131,4735 }, { 132,4735 }, { 133,4735 },
 { 134,4735 }, { 135,4735 }, { 136,4735 }, { 137,4735 }, { 138,4735 },
 { 139,4735 }, { 140,4735 }, { 141,4735 }, { 142,4735 }, { 143,4735 },
 { 144,4735 }, { 145,4735 }, { 146,4735 }, { 147,4735 }, { 148,4735 },
 { 149,4735 }, { 150,4735 }, { 151,4735 }, { 152,4735 }, { 153,4735 },
 { 154,4735 }, { 155,4735 }, { 156,4735 }, { 157,4735 }, { 158,4735 },
 { 159,4735 }, { 160,4735 }, { 161,4735 }, { 162,4735 }, { 163,4735 },
 { 164,4735 }, { 165,4735 }, { 166,4735 }, { 167,4735 }, { 168,4735 },
 { 169,4735 }, { 170,4735 }, { 171,4735 }, { 172,4735 }, { 173,4735 },
 { 174,4735 }, { 175,4735 }, { 176,4735 }, { 177,4735 }, { 178,4735 },

 { 179,4735 }, { 180,4735 }, { 181,4735 }, { 182,4735 }, { 183,4735 },
 { 184,4735 }, { 185,4735 }, { 186,4735 }, { 187,4735 }, { 188,4735 },
 { 189,4735 }, { 190,4735 }, { 191,4735 }, { 192,4735 }, { 193,4735 },
 { 194,4735 }, { 195,4735 }, { 196,4735 }, { 197,4735 }, { 198,4735 },
 { 199,4735 }, { 200,4735 }, { 201,4735 }, { 202,4735 }, { 203,4735 },
 { 204,4735 }, { 205,4735 }, { 206,4735 }, { 207,4735 }, { 208,4735 },
 { 209,4735 }, { 210,4735 }, { 211,4735 }, { 212,4735 }, { 213,4735 },
 { 214,4735 }, { 215,4735 }, { 216,4735 }, { 217,4735 }, { 218,4735 },
 { 219,4735 }, { 220,4735 }, { 221,4735 }, { 222,4735 }, { 223,4735 },
 { 224,4735 }, { 225,4735 }, { 226,4735 }, { 227,4735 }, { 228,4735 },

 { 229,4735 }, { 230,4735 }, { 231,4735 }, { 232,4735 }, { 233,4735 },
 { 234,4735 }, { 235,4735 }, { 236,4735 }, { 237,4735 }, { 238,4735 },
 { 239,4735 }, { 240,4735 }, { 241,4735 }, { 242,4735 }, { 243,4735 },
 { 244,4735 }, { 245,4735 }, { 246,4735 }, { 247,4735 }, { 248,4735 },
 { 249,4735 }, { 250,4735 }, { 251,4735 }, { 252,4735 }, { 253,4735 },
 { 254,4735 }, { 255,4735 }, { 256,4735 }, {   0,   0 }, {   0,18921 },
 {   1, 593 }, {   2, 593 }, {   3, 593 }, {   4, 593 }, {   5, 593 },
 {   6, 593 }, {   7, 593 }, {   8, 593 }, {   9, 593 }, {  10, 597 },
 {  11, 593 }, {  12, 593 }, {  13, 593 }, {  14, 593 }, {  15, 593 },
 {  16, 593 }, {  17, 593 }, {  18, 593 }, {  19, 593 }, {  20, 593 },

 {  21, 593 }, {  22, 593 }, {  23, 593 }, {  24, 593 }, {  25, 593 },
 {  26, 593 }, {  27, 593 }, {  28, 593 }, {  29, 593 }, {  30, 593 },
 {  31, 593 }, {  32, 593 }, {  33, 593 }, {  34, 593 }, {  35, 593 },
 {  36, 593 }, {  37, 593 }, {  38, 593 }, {  39, 593 }, {  40, 593 },
 {  41, 593 }, {  42, 593 }, {  43, 593 }, {  44, 593 }, {  45, 593 },
 {  46, 593 }, {  47, 593 }, {  48, 593 }, {  49, 593 }, {  50, 593 },
 {  51, 593 }, {  52, 593 }, {  53, 593 }, {  54, 593 }, {  55, 593 },
 {  56, 593 }, {  57, 593 }, {  58, 593 }, {  59, 593 }, {  60, 593 },
 {  61, 593 }, {  62, 593 }, {  63, 593 }, {  64, 593 }, {  65, 593 },
 {  66, 593 }, {  67, 593 }, {  68, 593 }, {  69, 593 }, {  70, 593 },

 {  71, 593 }, {  72, 593 }, {  73, 593 }, {  74, 593 }, {  75, 593 },
 {  76, 593 }, {  77, 593 }, {  78, 593 }, {  79, 593 }, {  80, 593 },
 {  81, 593 }, {  82, 593 }, {  83, 593 }, {  84, 593 }, {  85, 593 },
 {  86, 593 }, {  87, 593 }, {  88, 593 }, {  89, 593 }, {  90, 593 },
 {  91, 593 }, {  92, 637 }, {  93, 593 }, {  94, 593 }, {  95, 593 },
 {  96, 593 }, {  97, 593 }, {  98, 593 }, {  99, 593 }, { 100, 593 },
 { 101, 593 }, { 102, 593 }, { 103, 593 }, { 104, 593 }, { 105, 593 },
 { 106, 593 }, { 107, 593 }, { 108, 593 }, { 109, 593 }, { 110, 593 },
 { 111, 593 }, { 112, 593 }, { 113, 593 }, { 114, 593 }, { 115, 593 },
 { 116, 593 }, { 117, 593 }, { 118, 593 }, { 119, 593 }, { 120, 593 },

 { 121, 593 }, { 122, 593 }, { 123, 593 }, { 124, 593 }, { 125, 593 },
 { 126, 593 }, { 127, 593 }, { 128, 593 }, { 129, 593 }, { 130, 593 },
 { 131, 593 }, { 132, 593 }, { 133, 593 }, { 134, 593 }, { 135, 593 },
 { 136, 593 }, { 137, 593 }, { 138, 593 }, { 139, 593 }, { 140, 593 },
 { 141, 593 }, { 142, 593 }, { 143, 593 }, { 144, 593 }, { 145, 593 },
 { 146, 593 }, { 147, 593 }, { 148, 593 }, { 149, 593 }, { 150, 593 },
 { 151, 593 }, { 152, 593 }, { 153, 593 }, { 154, 593 }, { 155, 593 },
 { 156, 593 }, { 157, 593 }, { 158, 593 }, { 159, 593 }, { 160, 593 },
 { 161, 593 }, { 162, 593 }, { 163, 593 }, { 164, 593 }, { 165, 593 },
 { 166, 593 }, { 167, 593 }, { 168, 593 }, { 169, 593 }, { 170, 593 },

 { 171, 593 }, { 172, 593 }, { 173, 593 }, { 174, 593 }, { 175, 593 },
 { 176, 593 }, { 177, 593 }, { 178, 593 }, { 179, 593 }, { 180, 593 },
 { 181, 593 }, { 182, 593 }, { 183, 593 }, { 184, 593 }, { 185, 593 },
 { 186, 593 }, { 187, 593 }, { 188, 593 }, { 189, 593 }, { 190, 593 },
 { 191, 593 }, { 192, 593 }, { 193, 593 }, { 194, 593 }, { 195, 593 },
 { 196, 593 }, { 197, 593 }, { 198, 593 }, { 199, 593 }, { 200, 593 },
 { 201, 593 }, { 202, 593 }, { 203, 593 }, { 204, 593 }, { 205, 593 },
 { 206, 593 }, { 207, 593 }, { 208, 593 }, { 209, 593 }, { 210, 593 },
 { 211, 593 }, { 212, 593 }, { 213, 593 }, { 214, 593 }, { 215, 593 },
 { 216, 593 }, { 217, 593 }, { 218, 593 }, { 219, 593 }, { 220, 593 },

 { 221, 593 }, { 222, 593 }, { 223, 593 }, { 224, 593 }, { 225, 593 },
 { 226, 593 }, { 227, 593 }, { 228, 593 }, { 229, 593 }, { 230, 593 },
 { 231, 593 }, { 232, 593 }, { 233, 593 }, { 234, 593 }, { 235, 593 },
 { 236, 593 }, { 237, 593 }, { 238, 593 }, { 239, 593 }, { 240, 593 },
 { 241, 593 }, { 242, 593 }, { 243, 593 }, { 244, 593 }, { 245, 593 },
 { 246, 593 }, { 247, 593 }, { 248, 593 }, { 249, 593 }, { 250, 593 },
 { 251, 593 }, { 252, 593 }, { 253, 593 }, { 254, 593 }, { 255, 593 },
 { 256, 593 }, {   0,   0 }, {   0,18663 }, {   1, 335 }, {   2, 335 },
 {   3, 335 }, {   4, 335 }, {   5, 335 }, {   6, 335 }, {   7, 335 },
 {   8, 335 }, {   9, 335 }, {  10, 339 }, {  11, 335 }, {  12, 335 },

 {  13, 335 }, {  14, 335 }, {  15, 335 }, {  16, 335 }, {  17, 335 },
 {  18, 335 }, {  19, 335 }, {  20, 335 }, {  21, 335 }, {  22, 335 },
 {  23, 335 }, {  24, 335 }, {  25, 335 }, {  26, 335 }, {  27, 335 },
 {  28, 335 }, {  29, 335 }, {  30, 335 }, {  31, 335 }, {  32, 335 },
 {  33, 335 }, {  34, 335 }, {  35, 335 }, {  36, 335 }, {  37, 335 },
 {  38, 335 }, {  39, 335 }, {  40, 335 }, {  41, 335 }, {  42, 335 },
 {  43, 335 }, {  44, 335 }, {  45, 335 }, {  46, 335 }, {  47, 335 },
 {  48, 335 }, {  49, 335 }, {  50, 335 }, {  51, 335 }, {  52, 335 },
 {  53, 335 }, {  54, 335 }, {  55, 335 }, {  56, 335 }, {  57, 335 },
 {  58, 335 }, {  59, 335 }, {  60, 335 }, {  61, 335 }, {  62, 335 },

 {  63, 335 }, {  64, 335 }, {  65, 335 }, {  66, 335 }, {  67, 335 },
 {  68, 335 }, {  69, 335 }, {  70, 335 }, {  71, 335 }, {  72, 335 },
 {  73, 335 }, {  74, 335 }, {  75, 335 }, {  76, 335 }, {  77, 335 },
 {  78, 335 }, {  79, 335 }, {  80, 335 }, {  81, 335 }, {  82, 335 },
 {  83, 335 }, {  84, 335 }, {  85, 335 }, {  86, 335 }, {  87, 335 },
 {  88, 335 }, {  89, 335 }, {  90, 335 }, {  91, 335 }, {  92, 379 },
 {  93, 335 }, {  94, 335 }, {  95, 335 }, {  96, 335 }, {  97, 335 },
 {  98, 335 }, {  99, 335 }, { 100, 335 }, { 101, 335 }, { 102, 335 },
 { 103, 335 }, { 104, 335 }, { 105, 335 }, { 106, 335 }, { 107, 335 },
 { 108, 335 }, { 109, 335 }, { 110, 335 }, { 111, 335 }, { 112, 335 },

 { 113, 335 }, { 114, 335 }, { 115, 335 }, { 116, 335 }, { 117, 335 },
 { 118, 335 }, { 119, 335 }, { 120, 335 }, { 121, 335 }, { 122, 335 },
 { 123, 335 }, { 124, 335 }, { 125, 335 }, { 126, 335 }, { 127, 335 },
 { 128, 335 }, { 129, 335 }, { 130, 335 }, { 131, 335 }, { 132, 335 },
 { 133, 335 }, { 134, 335 }, { 135, 335 }, { 136, 335 }, { 137, 335 },
 { 138, 335 }, { 139, 335 }, { 140, 335 }, { 141, 335 }, { 142, 335 },
 { 143, 335 }, { 144, 335 }, { 145, 335 }, { 146, 335 }, { 147, 335 },
 { 148, 335 }, { 149, 335 }, { 150, 335 }, { 151, 335 }, { 152, 335 },
 { 153, 335 }, { 154, 335 }, { 155, 335 }, { 156, 335 }, { 157, 335 },
 { 158, 335 }, { 159, 335 }, { 160, 335 }, { 161, 335 }, { 162, 335 },

 { 163, 335 }, { 164, 335 }, { 165, 335 }, { 166, 335 }, { 167, 335 },
 { 168, 335 }, { 169, 335 }, { 170, 335 }, { 171, 335 }, { 172, 335 },
 { 173, 335 }, { 174, 335 }, { 175, 335 }, { 176, 335 }, { 177, 335 },
 { 178, 335 }, { 179, 335 }, { 180, 335 }, { 181, 335 }, { 182, 335 },
 { 183, 335 }, { 184, 335 }, { 185, 335 }, { 186, 335 }, { 187, 335 },
 { 188, 335 }, { 189, 335 }, { 190, 335 }, { 191, 335 }, { 192, 335 },
 { 193, 335 }, { 194, 335 }, { 195, 335 }, { 196, 335 }, { 197, 335 },
 { 198, 335 }, { 199, 335 }, { 200, 335 }, { 201, 335 }, { 202, 335 },
 { 203, 335 }, { 204, 335 }, { 205, 335 }, { 206, 335 }, { 207, 335 },
 { 208, 335 }, { 209, 335 }, { 210, 335 }, { 211, 335 }, { 212, 335 },

 { 213, 335 }, { 214, 335 }, { 215, 335 }, { 216, 335 }, { 217, 335 },
 { 218, 335 }, { 219, 335 }, { 220, 335 }, { 221, 335 }, { 222, 335 },
 { 223, 335 }, { 224, 335 }, { 225, 335 }, { 226, 335 }, { 227, 335 },
 { 228, 335 }, { 229, 335 }, { 230, 335 }, { 231, 335 }, { 232, 335 },
 { 233, 335 }, { 234, 335 }, { 235, 335 }, { 236, 335 }, { 237, 335 },
 { 238, 335 }, { 239, 335 }, { 240, 335 }, { 241, 335 }, { 242, 335 },
 { 243, 335 }, { 244, 335 }, { 245, 335 }, { 246, 335 }, { 247, 335 },
 { 248, 335 }, { 249, 335 }, { 250, 335 }, { 251, 335 }, { 252, 335 },
 { 253, 335 }, { 254, 335 }, { 255, 335 }, { 256, 335 }, {   0,  75 },
 {   0,18405 }, {   0,   1 }, {   0,18403 }, {   0,  38 }, {   0,18401 },

 {   0,   0 }, {   0,   1 }, {   0,18398 }, {   0,  54 }, {   0,18396 },
 {   0,   0 }, {   9,5585 }, {  10,5585 }, {  11,5585 }, {  12,5585 },
 {  13,5585 }, {   9,5580 }, {  10,5580 }, {  11,5580 }, {  12,5580 },
 {  13,5580 }, {   0,  13 }, {   0,18383 }, {   0,  53 }, {   0,18381 },
 {   0,   0 }, {   0,  53 }, {   0,18378 }, {   0,  16 }, {   0,18376 },
 {   0,   0 }, {   0,   6 }, {   0,18373 }, {   0,   0 }, {  32,5585 },
 {   0,   6 }, {   0,18369 }, {   0,   0 }, {   0,   0 }, {  32,5580 },
 {   0,  40 }, {   0,18364 }, {  33,5833 }, {   0,   0 }, {  35,5833 },
 {   0,   0 }, {  37,5833 }, {  38,5833 }, {   0,  54 }, {   0,18356 },
 {   0,   0 }, {  42,5833 }, {  43,5833 }, {   0,   0 }, {  45,5833 },

 {   0,   0 }, {  47,5833 }, {   0,  16 }, {   0,18347 }, {   0,  19 },
 {   0,18345 }, {   0,  18 }, {   0,18343 }, {   0,   0 }, {   0,  16 },
 {   0,18340 }, {   0,  41 }, {   0,18338 }, {   0,   0 }, {  60,5833 },
 {  61,5844 }, {  62,5833 }, {  63,5833 }, {  64,5833 }, {  42, 363 },
 {  34, 358 }, {   0,  25 }, {   0,18328 }, {  42,8528 }, {  47, 365 },
 {   0,  26 }, {   0,18324 }, {  33,5793 }, {   0,   0 }, {  35,5793 },
 {  58, 349 }, {  37,5793 }, {  38,5793 }, {  61, 351 }, {   0,   0 },
 {   0,   0 }, {  42,5793 }, {  43,5793 }, {   0,   0 }, {  45,5793 },
 {   0,   0 }, {  47,5793 }, {  39, 346 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  34, 332 }, {   0,   0 }, {  94,5833 }, {  39, 339 },

 {  96,5833 }, {   0,   0 }, {  45,9480 }, {   0,   0 }, {  60,5793 },
 {  61,5793 }, {  62,5793 }, {  63,5793 }, {  64,5793 }, {   0,  75 },
 {   0,18290 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  25 }, {   0,18284 }, {   0,  32 }, {   0,18282 }, {   0,  46 },
 {   0,18280 }, {   0,  68 }, {   0,18278 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,5833 }, {   0,   0 },
 { 126,5833 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,5793 }, {   0,   0 },
 {  96,5793 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  36,   8 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,5817 }, {  49,5817 },
 {  50,5817 }, {  51,5817 }, {  52,5817 }, {  53,5817 }, {  54,5817 },
 {  55,5817 }, {  56,5817 }, {  57,5817 }, { 124,5793 }, {   0,   0 },
 { 126,5793 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,6074 }, {  66,6074 }, {  67,6074 }, {  68,6074 }, {  69,6074 },
 {  70,6074 }, {  71,6074 }, {  72,6074 }, {  73,6074 }, {  74,6074 },
 {  75,6074 }, {  76,6074 }, {  77,6074 }, {  78,6074 }, {  79,6074 },
 {  80,6074 }, {  81,6074 }, {  82,6074 }, {  83,6074 }, {  84,6074 },
 {  85,6074 }, {  86,6074 }, {  87,6074 }, {  88,6074 }, {  89,6074 },

 {  90,6074 }, {  85,10625 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,6074 }, {   0,   0 }, {  97,6074 }, {  98,6074 }, {  99,6074 },
 { 100,6074 }, { 101,6074 }, { 102,6074 }, { 103,6074 }, { 104,6074 },
 { 105,6074 }, { 106,6074 }, { 107,6074 }, { 108,6074 }, { 109,6074 },
 { 110,6074 }, { 111,6074 }, { 112,6074 }, { 113,6074 }, { 114,6074 },
 { 115,6074 }, { 116,6074 }, { 117,6074 }, { 118,6074 }, { 119,6074 },
 { 120,6074 }, { 121,6074 }, { 122,6074 }, { 117,10648 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,6074 }, { 129,6074 },
 { 130,6074 }, { 131,6074 }, { 132,6074 }, { 133,6074 }, { 134,6074 },
 { 135,6074 }, { 136,6074 }, { 137,6074 }, { 138,6074 }, { 139,6074 },

 { 140,6074 }, { 141,6074 }, { 142,6074 }, { 143,6074 }, { 144,6074 },
 { 145,6074 }, { 146,6074 }, { 147,6074 }, { 148,6074 }, { 149,6074 },
 { 150,6074 }, { 151,6074 }, { 152,6074 }, { 153,6074 }, { 154,6074 },
 { 155,6074 }, { 156,6074 }, { 157,6074 }, { 158,6074 }, { 159,6074 },
 { 160,6074 }, { 161,6074 }, { 162,6074 }, { 163,6074 }, { 164,6074 },
 { 165,6074 }, { 166,6074 }, { 167,6074 }, { 168,6074 }, { 169,6074 },
 { 170,6074 }, { 171,6074 }, { 172,6074 }, { 173,6074 }, { 174,6074 },
 { 175,6074 }, { 176,6074 }, { 177,6074 }, { 178,6074 }, { 179,6074 },
 { 180,6074 }, { 181,6074 }, { 182,6074 }, { 183,6074 }, { 184,6074 },
 { 185,6074 }, { 186,6074 }, { 187,6074 }, { 188,6074 }, { 189,6074 },

 { 190,6074 }, { 191,6074 }, { 192,6074 }, { 193,6074 }, { 194,6074 },
 { 195,6074 }, { 196,6074 }, { 197,6074 }, { 198,6074 }, { 199,6074 },
 { 200,6074 }, { 201,6074 }, { 202,6074 }, { 203,6074 }, { 204,6074 },
 { 205,6074 }, { 206,6074 }, { 207,6074 }, { 208,6074 }, { 209,6074 },
 { 210,6074 }, { 211,6074 }, { 212,6074 }, { 213,6074 }, { 214,6074 },
 { 215,6074 }, { 216,6074 }, { 217,6074 }, { 218,6074 }, { 219,6074 },
 { 220,6074 }, { 221,6074 }, { 222,6074 }, { 223,6074 }, { 224,6074 },
 { 225,6074 }, { 226,6074 }, { 227,6074 }, { 228,6074 }, { 229,6074 },
 { 230,6074 }, { 231,6074 }, { 232,6074 }, { 233,6074 }, { 234,6074 },
 { 235,6074 }, { 236,6074 }, { 237,6074 }, { 238,6074 }, { 239,6074 },

 { 240,6074 }, { 241,6074 }, { 242,6074 }, { 243,6074 }, { 244,6074 },
 { 245,6074 }, { 246,6074 }, { 247,6074 }, { 248,6074 }, { 249,6074 },
 { 250,6074 }, { 251,6074 }, { 252,6074 }, { 253,6074 }, { 254,6074 },
 { 255,6074 }, {   0,  53 }, {   0,18033 }, {   0,  63 }, {   0,18031 },
 {   0,  45 }, {   0,18029 }, {   0,  47 }, {   0,18027 }, {   0,   8 },
 {   0,18025 }, {   0,   0 }, {   0,  53 }, {   0,18022 }, {   0,  14 },
 {   0,18020 }, {   0,  12 }, {   0,18018 }, {   0,   0 }, {   0,  44 },
 {   0,18015 }, {   0,  11 }, {   0,18013 }, {   0,   0 }, {   0,   7 },
 {   0,18010 }, {   0,   4 }, {   0,18008 }, {   0,  42 }, {   0,18006 },
 {   0,   0 }, {   0,  53 }, {   0,18003 }, {   0,  20 }, {   0,18001 },

 {  33,5470 }, {   0,   0 }, {  35,5470 }, {   0,   0 }, {  37,5470 },
 {  38,5470 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,5470 },
 {  43,5470 }, {  33,5459 }, {  45,5470 }, {  35,5459 }, {  47,5470 },
 {  37,5459 }, {  38,5459 }, {  48,11842 }, {  49,11842 }, {  34, 104 },
 {  42,5459 }, {  43,5459 }, {   0,   0 }, {  45,6063 }, {  39, 110 },
 {  47,5459 }, {   0,   0 }, {  60,5470 }, {  61,5470 }, {  62,5470 },
 {  63,5470 }, {  64,5470 }, {  42,   0 }, {   0,  18 }, {   0,17966 },
 {   0,  17 }, {   0,17964 }, {  47,   2 }, {  60,5459 }, {  61,5459 },
 {  62,5459 }, {  63,5459 }, {  64,5459 }, {  46,-277 }, {   0,   0 },
 {  48,6302 }, {  49,6302 }, {  50,6302 }, {  51,6302 }, {  52,6302 },

 {  53,6302 }, {  54,6302 }, {  55,6302 }, {  56,6302 }, {  57,6302 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,5470 }, {   0,   0 }, {  96,5470 }, {  95, 118 },
 {   0,   0 }, {   0,   0 }, {   0,  53 }, {   0,17932 }, {   0,   0 },
 {   0,  18 }, {   0,17929 }, {  94,5459 }, {   0,   0 }, {  96,5459 },
 {   0,  28 }, {   0,17924 }, {   0,  34 }, {   0,17922 }, {  45,9103 },
 {   0,  56 }, {   0,17919 }, {   0,  72 }, {   0,17917 }, {   0,  65 },
 {   0,17915 }, {   0,  63 }, {   0,17913 }, {   0,  39 }, {   0,17911 },
 {   0,   0 }, { 124,5470 }, {   0,   0 }, { 126,5470 }, {   0,  15 },
 {   0,17905 }, {   0,  71 }, {   0,17903 }, {   0,   0 }, {   0,  57 },

 {   0,17900 }, {  33,5369 }, { 124,5459 }, {  35,5369 }, { 126,5459 },
 {  37,5369 }, {  38,5369 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42,6488 }, {  43,5369 }, {   0,   0 }, {  45,5369 }, {   0,   0 },
 {  47,5369 }, {  45,13191 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,5369 }, {  61,5369 },
 {  62,5369 }, {  63,5369 }, {  64,5369 }, {   0,   0 }, {   0,   0 },
 {  48,11724 }, {  49,11724 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  46,6488 }, {   0,   0 }, {  48,6745 }, {  49,6745 },

 {  50,6745 }, {  51,6745 }, {  52,6745 }, {  53,6745 }, {  54,6745 },
 {  55,6745 }, {  56,6745 }, {  57,6745 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94,5369 }, {   0,   0 }, {  96,5369 },
 {  65,-378 }, {  66,-131 }, {  67,-378 }, {  68,-378 }, {  69,7002 },
 {  70,-378 }, {  71,-378 }, {  72,-378 }, {  73,-378 }, {  74,-378 },
 {  75,-378 }, {  76,-378 }, {  77,-378 }, {  78,-378 }, {  79,7012 },
 {  80,-378 }, {  81,-378 }, {  82,-378 }, {  83,-378 }, {  84,-378 },
 {  85,-378 }, {  86,-378 }, {  87,-378 }, {  88,7020 }, {  89,-378 },
 {  90,-378 }, {   0,   0 }, { 124,5369 }, {   0,   0 }, { 126,5369 },
 {  95,7043 }, {   0,   0 }, {  97,-378 }, {  98,-131 }, {  99,-378 },

 { 100,-378 }, { 101,7002 }, { 102,-378 }, { 103,-378 }, { 104,-378 },
 { 105,-378 }, { 106,-378 }, { 107,-378 }, { 108,-378 }, { 109,-378 },
 { 110,-378 }, { 111,7012 }, { 112,-378 }, { 113,-378 }, { 114,-378 },
 { 115,-378 }, { 116,-378 }, { 117,-378 }, { 118,-378 }, { 119,-378 },
 { 120,7020 }, { 121,-378 }, { 122,-378 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-378 }, { 129,-378 },
 { 130,-378 }, { 131,-378 }, { 132,-378 }, { 133,-378 }, { 134,-378 },
 { 135,-378 }, { 136,-378 }, { 137,-378 }, { 138,-378 }, { 139,-378 },
 { 140,-378 }, { 141,-378 }, { 142,-378 }, { 143,-378 }, { 144,-378 },
 { 145,-378 }, { 146,-378 }, { 147,-378 }, { 148,-378 }, { 149,-378 },

 { 150,-378 }, { 151,-378 }, { 152,-378 }, { 153,-378 }, { 154,-378 },
 { 155,-378 }, { 156,-378 }, { 157,-378 }, { 158,-378 }, { 159,-378 },
 { 160,-378 }, { 161,-378 }, { 162,-378 }, { 163,-378 }, { 164,-378 },
 { 165,-378 }, { 166,-378 }, { 167,-378 }, { 168,-378 }, { 169,-378 },
 { 170,-378 }, { 171,-378 }, { 172,-378 }, { 173,-378 }, { 174,-378 },
 { 175,-378 }, { 176,-378 }, { 177,-378 }, { 178,-378 }, { 179,-378 },
 { 180,-378 }, { 181,-378 }, { 182,-378 }, { 183,-378 }, { 184,-378 },
 { 185,-378 }, { 186,-378 }, { 187,-378 }, { 188,-378 }, { 189,-378 },
 { 190,-378 }, { 191,-378 }, { 192,-378 }, { 193,-378 }, { 194,-378 },
 { 195,-378 }, { 196,-378 }, { 197,-378 }, { 198,-378 }, { 199,-378 },

 { 200,-378 }, { 201,-378 }, { 202,-378 }, { 203,-378 }, { 204,-378 },
 { 205,-378 }, { 206,-378 }, { 207,-378 }, { 208,-378 }, { 209,-378 },
 { 210,-378 }, { 211,-378 }, { 212,-378 }, { 213,-378 }, { 214,-378 },
 { 215,-378 }, { 216,-378 }, { 217,-378 }, { 218,-378 }, { 219,-378 },
 { 220,-378 }, { 221,-378 }, { 222,-378 }, { 223,-378 }, { 224,-378 },
 { 225,-378 }, { 226,-378 }, { 227,-378 }, { 228,-378 }, { 229,-378 },
 { 230,-378 }, { 231,-378 }, { 232,-378 }, { 233,-378 }, { 234,-378 },
 { 235,-378 }, { 236,-378 }, { 237,-378 }, { 238,-378 }, { 239,-378 },
 { 240,-378 }, { 241,-378 }, { 242,-378 }, { 243,-378 }, { 244,-378 },
 { 245,-378 }, { 246,-378 }, { 247,-378 }, { 248,-378 }, { 249,-378 },

 { 250,-378 }, { 251,-378 }, { 252,-378 }, { 253,-378 }, { 254,-378 },
 { 255,-378 }, {   0,  57 }, {   0,17643 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  71 }, {   0,17633 }, {   0,  73 }, {   0,17631 },
 {   0,  70 }, {   0,17629 }, {   0,  69 }, {   0,17627 }, {   0,  29 },
 {   0,17625 }, {   0,  30 }, {   0,17623 }, {   0,  23 }, {   0,17621 },
 {   0,  24 }, {   0,17619 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,6231 }, {   0,   0 },
 {  48,6488 }, {  49,6488 }, {  50,6488 }, {  51,6488 }, {  52,6488 },
 {  53,6488 }, {  54,6488 }, {  55,6488 }, {  56,6488 }, {  57,6488 },
 {  48,11444 }, {  49,11444 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-635 }, {  66,-635 }, {  67,-635 },
 {  68,-635 }, {  69,6745 }, {  70,-635 }, {  71,-635 }, {  72,-635 },
 {  73,-635 }, {  74,-635 }, {  75,-635 }, {  76,-635 }, {  77,-635 },
 {  78,-635 }, {  79,-635 }, {  80,-635 }, {  81,-635 }, {  82,-635 },
 {  83,-635 }, {  84,-635 }, {  85,-635 }, {  86,-635 }, {  87,-635 },
 {  88,-635 }, {  89,-635 }, {  90,-635 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  95,6786 }, {   0,   0 }, {  97,-635 },
 {  98,-635 }, {  99,-635 }, { 100,-635 }, { 101,6745 }, { 102,-635 },
 { 103,-635 }, { 104,-635 }, { 105,-635 }, { 106,-635 }, { 107,-635 },
 { 108,-635 }, { 109,-635 }, { 110,-635 }, { 111,-635 }, { 112,-635 },
 { 113,-635 }, { 114,-635 }, { 115,-635 }, { 116,-635 }, { 117,-635 },
 { 118,-635 }, { 119,-635 }, { 120,-635 }, { 121,-635 }, { 122,-635 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-635 }, { 129,-635 }, { 130,-635 }, { 131,-635 }, { 132,-635 },
 { 133,-635 }, { 134,-635 }, { 135,-635 }, { 136,-635 }, { 137,-635 },
 { 138,-635 }, { 139,-635 }, { 140,-635 }, { 141,-635 }, { 142,-635 },

 { 143,-635 }, { 144,-635 }, { 145,-635 }, { 146,-635 }, { 147,-635 },
 { 148,-635 }, { 149,-635 }, { 150,-635 }, { 151,-635 }, { 152,-635 },
 { 153,-635 }, { 154,-635 }, { 155,-635 }, { 156,-635 }, { 157,-635 },
 { 158,-635 }, { 159,-635 }, { 160,-635 }, { 161,-635 }, { 162,-635 },
 { 163,-635 }, { 164,-635 }, { 165,-635 }, { 166,-635 }, { 167,-635 },
 { 168,-635 }, { 169,-635 }, { 170,-635 }, { 171,-635 }, { 172,-635 },
 { 173,-635 }, { 174,-635 }, { 175,-635 }, { 176,-635 }, { 177,-635 },
 { 178,-635 }, { 179,-635 }, { 180,-635 }, { 181,-635 }, { 182,-635 },
 { 183,-635 }, { 184,-635 }, { 185,-635 }, { 186,-635 }, { 187,-635 },
 { 188,-635 }, { 189,-635 }, { 190,-635 }, { 191,-635 }, { 192,-635 },

 { 193,-635 }, { 194,-635 }, { 195,-635 }, { 196,-635 }, { 197,-635 },
 { 198,-635 }, { 199,-635 }, { 200,-635 }, { 201,-635 }, { 202,-635 },
 { 203,-635 }, { 204,-635 }, { 205,-635 }, { 206,-635 }, { 207,-635 },
 { 208,-635 }, { 209,-635 }, { 210,-635 }, { 211,-635 }, { 212,-635 },
 { 213,-635 }, { 214,-635 }, { 215,-635 }, { 216,-635 }, { 217,-635 },
 { 218,-635 }, { 219,-635 }, { 220,-635 }, { 221,-635 }, { 222,-635 },
 { 223,-635 }, { 224,-635 }, { 225,-635 }, { 226,-635 }, { 227,-635 },
 { 228,-635 }, { 229,-635 }, { 230,-635 }, { 231,-635 }, { 232,-635 },
 { 233,-635 }, { 234,-635 }, { 235,-635 }, { 236,-635 }, { 237,-635 },
 { 238,-635 }, { 239,-635 }, { 240,-635 }, { 241,-635 }, { 242,-635 },

 { 243,-635 }, { 244,-635 }, { 245,-635 }, { 246,-635 }, { 247,-635 },
 { 248,-635 }, { 249,-635 }, { 250,-635 }, { 251,-635 }, { 252,-635 },
 { 253,-635 }, { 254,-635 }, { 255,-635 }, {   0,  53 }, {   0,17386 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  53 },
 {   0,17375 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  33,4823 }, {   0,   0 }, {  35,4823 },

 {   0,   0 }, {  37,4823 }, {  38,4823 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  42,4823 }, {  43,4823 }, {  33,4812 }, {  45,4823 },
 {  35,4812 }, {  47,4823 }, {  37,4812 }, {  38,4812 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  42,4812 }, {  43,4812 }, {   0,   0 },
 {  45,4812 }, {   0,   0 }, {  47,4812 }, {   0,   0 }, {  60,4823 },
 {  61,6588 }, {  62,6599 }, {  63,4823 }, {  64,4823 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  60,4812 }, {  61,4812 }, {  62,6655 }, {  63,4812 }, {  64,4812 },
 {   0,   0 }, {   0,  53 }, {   0,17308 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,4823 }, {   0,   0 },
 {  96,4823 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,4812 },
 {   0,   0 }, {  96,4812 }, {   0,   0 }, {   0,  74 }, {   0,17276 },
 {  33,4745 }, {   0,   0 }, {  35,4745 }, {   0,   0 }, {  37,4745 },
 {  38,4745 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,4745 },
 {  43,4745 }, {   0,   0 }, {  45,4745 }, { 124,4823 }, {  47,4745 },
 { 126,4823 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,4812 },

 {   0,   0 }, { 126,4812 }, {  60,4745 }, {  61,6628 }, {  62,4745 },
 {  63,4745 }, {  64,4745 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,6662 }, {  49,6662 }, {  50,6662 },
 {  51,6662 }, {  52,6662 }, {  53,6662 }, {  54,6662 }, {  55,6662 },
 {  56,6662 }, {  57,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,4745 }, {   0,   0 }, {  96,4745 }, {  65,6662 },
 {  66,6662 }, {  67,6662 }, {  68,6662 }, {  69,6662 }, {  70,6662 },
 {  71,6662 }, {  72,6662 }, {  73,6662 }, {  74,6662 }, {  75,6662 },

 {  76,6662 }, {  77,6662 }, {  78,6662 }, {  79,6662 }, {  80,6662 },
 {  81,6662 }, {  82,6662 }, {  83,6662 }, {  84,6662 }, {  85,6662 },
 {  86,6662 }, {  87,6662 }, {  88,6662 }, {  89,6662 }, {  90,6662 },
 {   0,   0 }, { 124,4745 }, {   0,   0 }, { 126,4745 }, {  95,6662 },
 {   0,   0 }, {  97,6662 }, {  98,6662 }, {  99,6662 }, { 100,6662 },
 { 101,6662 }, { 102,6662 }, { 103,6662 }, { 104,6662 }, { 105,6662 },
 { 106,6662 }, { 107,6662 }, { 108,6662 }, { 109,6662 }, { 110,6662 },
 { 111,6662 }, { 112,6662 }, { 113,6662 }, { 114,6662 }, { 115,6662 },
 { 116,6662 }, { 117,6662 }, { 118,6662 }, { 119,6662 }, { 120,6662 },
 { 121,6662 }, { 122,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, { 128,6662 }, { 129,6662 }, { 130,6662 },
 { 131,6662 }, { 132,6662 }, { 133,6662 }, { 134,6662 }, { 135,6662 },
 { 136,6662 }, { 137,6662 }, { 138,6662 }, { 139,6662 }, { 140,6662 },
 { 141,6662 }, { 142,6662 }, { 143,6662 }, { 144,6662 }, { 145,6662 },
 { 146,6662 }, { 147,6662 }, { 148,6662 }, { 149,6662 }, { 150,6662 },
 { 151,6662 }, { 152,6662 }, { 153,6662 }, { 154,6662 }, { 155,6662 },
 { 156,6662 }, { 157,6662 }, { 158,6662 }, { 159,6662 }, { 160,6662 },
 { 161,6662 }, { 162,6662 }, { 163,6662 }, { 164,6662 }, { 165,6662 },
 { 166,6662 }, { 167,6662 }, { 168,6662 }, { 169,6662 }, { 170,6662 },
 { 171,6662 }, { 172,6662 }, { 173,6662 }, { 174,6662 }, { 175,6662 },

 { 176,6662 }, { 177,6662 }, { 178,6662 }, { 179,6662 }, { 180,6662 },
 { 181,6662 }, { 182,6662 }, { 183,6662 }, { 184,6662 }, { 185,6662 },
 { 186,6662 }, { 187,6662 }, { 188,6662 }, { 189,6662 }, { 190,6662 },
 { 191,6662 }, { 192,6662 }, { 193,6662 }, { 194,6662 }, { 195,6662 },
 { 196,6662 }, { 197,6662 }, { 198,6662 }, { 199,6662 }, { 200,6662 },
 { 201,6662 }, { 202,6662 }, { 203,6662 }, { 204,6662 }, { 205,6662 },
 { 206,6662 }, { 207,6662 }, { 208,6662 }, { 209,6662 }, { 210,6662 },
 { 211,6662 }, { 212,6662 }, { 213,6662 }, { 214,6662 }, { 215,6662 },
 { 216,6662 }, { 217,6662 }, { 218,6662 }, { 219,6662 }, { 220,6662 },
 { 221,6662 }, { 222,6662 }, { 223,6662 }, { 224,6662 }, { 225,6662 },

 { 226,6662 }, { 227,6662 }, { 228,6662 }, { 229,6662 }, { 230,6662 },
 { 231,6662 }, { 232,6662 }, { 233,6662 }, { 234,6662 }, { 235,6662 },
 { 236,6662 }, { 237,6662 }, { 238,6662 }, { 239,6662 }, { 240,6662 },
 { 241,6662 }, { 242,6662 }, { 243,6662 }, { 244,6662 }, { 245,6662 },
 { 246,6662 }, { 247,6662 }, { 248,6662 }, { 249,6662 }, { 250,6662 },
 { 251,6662 }, { 252,6662 }, { 253,6662 }, { 254,6662 }, { 255,6662 },
 {   0,  74 }, {   0,17019 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  36,6405 }, {   0,   0 }, {   0,   0 },
 {  39,-1006 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,6405 },
 {  49,6405 }, {  50,6405 }, {  51,6405 }, {  52,6405 }, {  53,6405 },
 {  54,6405 }, {  55,6405 }, {  56,6405 }, {  57,6405 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,6405 }, {  66,6405 }, {  67,6405 }, {  68,6405 },

 {  69,6405 }, {  70,6405 }, {  71,6405 }, {  72,6405 }, {  73,6405 },
 {  74,6405 }, {  75,6405 }, {  76,6405 }, {  77,6405 }, {  78,6405 },
 {  79,6405 }, {  80,6405 }, {  81,6405 }, {  82,6405 }, {  83,6405 },
 {  84,6405 }, {  85,6405 }, {  86,6405 }, {  87,6405 }, {  88,6405 },
 {  89,6405 }, {  90,6405 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,6405 }, {   0,   0 }, {  97,6405 }, {  98,6405 },
 {  99,6405 }, { 100,6405 }, { 101,6405 }, { 102,6405 }, { 103,6405 },
 { 104,6405 }, { 105,6405 }, { 106,6405 }, { 107,6405 }, { 108,6405 },
 { 109,6405 }, { 110,6405 }, { 111,6405 }, { 112,6405 }, { 113,6405 },
 { 114,6405 }, { 115,6405 }, { 116,6405 }, { 117,6405 }, { 118,6405 },

 { 119,6405 }, { 120,6405 }, { 121,6405 }, { 122,6405 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,6405 },
 { 129,6405 }, { 130,6405 }, { 131,6405 }, { 132,6405 }, { 133,6405 },
 { 134,6405 }, { 135,6405 }, { 136,6405 }, { 137,6405 }, { 138,6405 },
 { 139,6405 }, { 140,6405 }, { 141,6405 }, { 142,6405 }, { 143,6405 },
 { 144,6405 }, { 145,6405 }, { 146,6405 }, { 147,6405 }, { 148,6405 },
 { 149,6405 }, { 150,6405 }, { 151,6405 }, { 152,6405 }, { 153,6405 },
 { 154,6405 }, { 155,6405 }, { 156,6405 }, { 157,6405 }, { 158,6405 },
 { 159,6405 }, { 160,6405 }, { 161,6405 }, { 162,6405 }, { 163,6405 },
 { 164,6405 }, { 165,6405 }, { 166,6405 }, { 167,6405 }, { 168,6405 },

 { 169,6405 }, { 170,6405 }, { 171,6405 }, { 172,6405 }, { 173,6405 },
 { 174,6405 }, { 175,6405 }, { 176,6405 }, { 177,6405 }, { 178,6405 },
 { 179,6405 }, { 180,6405 }, { 181,6405 }, { 182,6405 }, { 183,6405 },
 { 184,6405 }, { 185,6405 }, { 186,6405 }, { 187,6405 }, { 188,6405 },
 { 189,6405 }, { 190,6405 }, { 191,6405 }, { 192,6405 }, { 193,6405 },
 { 194,6405 }, { 195,6405 }, { 196,6405 }, { 197,6405 }, { 198,6405 },
 { 199,6405 }, { 200,6405 }, { 201,6405 }, { 202,6405 }, { 203,6405 },
 { 204,6405 }, { 205,6405 }, { 206,6405 }, { 207,6405 }, { 208,6405 },
 { 209,6405 }, { 210,6405 }, { 211,6405 }, { 212,6405 }, { 213,6405 },
 { 214,6405 }, { 215,6405 }, { 216,6405 }, { 217,6405 }, { 218,6405 },

 { 219,6405 }, { 220,6405 }, { 221,6405 }, { 222,6405 }, { 223,6405 },
 { 224,6405 }, { 225,6405 }, { 226,6405 }, { 227,6405 }, { 228,6405 },
 { 229,6405 }, { 230,6405 }, { 231,6405 }, { 232,6405 }, { 233,6405 },
 { 234,6405 }, { 235,6405 }, { 236,6405 }, { 237,6405 }, { 238,6405 },
 { 239,6405 }, { 240,6405 }, { 241,6405 }, { 242,6405 }, { 243,6405 },
 { 244,6405 }, { 245,6405 }, { 246,6405 }, { 247,6405 }, { 248,6405 },
 { 249,6405 }, { 250,6405 }, { 251,6405 }, { 252,6405 }, { 253,6405 },
 { 254,6405 }, { 255,6405 }, {   0,  74 }, {   0,16762 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36,6148 },
 {   0,   0 }, {   0,   0 }, {  39,-1258 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,6148 }, {  49,6148 }, {  50,6148 }, {  51,6148 },
 {  52,6148 }, {  53,6148 }, {  54,6148 }, {  55,6148 }, {  56,6148 },
 {  57,6148 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,6148 }, {  66,6148 },
 {  67,6148 }, {  68,6148 }, {  69,6148 }, {  70,6148 }, {  71,6148 },
 {  72,6148 }, {  73,6148 }, {  74,6148 }, {  75,6148 }, {  76,6148 },
 {  77,6148 }, {  78,6148 }, {  79,6148 }, {  80,6148 }, {  81,6148 },
 {  82,6148 }, {  83,6148 }, {  84,6148 }, {  85,6148 }, {  86,6148 },
 {  87,6148 }, {  88,6148 }, {  89,6148 }, {  90,6148 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,6148 }, {   0,   0 },
 {  97,6148 }, {  98,6148 }, {  99,6148 }, { 100,6148 }, { 101,6148 },
 { 102,6148 }, { 103,6148 }, { 104,6148 }, { 105,6148 }, { 106,6148 },
 { 107,6148 }, { 108,6148 }, { 109,6148 }, { 110,6148 }, { 111,6148 },

 { 112,6148 }, { 113,6148 }, { 114,6148 }, { 115,6148 }, { 116,6148 },
 { 117,6148 }, { 118,6148 }, { 119,6148 }, { 120,6148 }, { 121,6148 },
 { 122,6148 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,6148 }, { 129,6148 }, { 130,6148 }, { 131,6148 },
 { 132,6148 }, { 133,6148 }, { 134,6148 }, { 135,6148 }, { 136,6148 },
 { 137,6148 }, { 138,6148 }, { 139,6148 }, { 140,6148 }, { 141,6148 },
 { 142,6148 }, { 143,6148 }, { 144,6148 }, { 145,6148 }, { 146,6148 },
 { 147,6148 }, { 148,6148 }, { 149,6148 }, { 150,6148 }, { 151,6148 },
 { 152,6148 }, { 153,6148 }, { 154,6148 }, { 155,6148 }, { 156,6148 },
 { 157,6148 }, { 158,6148 }, { 159,6148 }, { 160,6148 }, { 161,6148 },

 { 162,6148 }, { 163,6148 }, { 164,6148 }, { 165,6148 }, { 166,6148 },
 { 167,6148 }, { 168,6148 }, { 169,6148 }, { 170,6148 }, { 171,6148 },
 { 172,6148 }, { 173,6148 }, { 174,6148 }, { 175,6148 }, { 176,6148 },
 { 177,6148 }, { 178,6148 }, { 179,6148 }, { 180,6148 }, { 181,6148 },
 { 182,6148 }, { 183,6148 }, { 184,6148 }, { 185,6148 }, { 186,6148 },
 { 187,6148 }, { 188,6148 }, { 189,6148 }, { 190,6148 }, { 191,6148 },
 { 192,6148 }, { 193,6148 }, { 194,6148 }, { 195,6148 }, { 196,6148 },
 { 197,6148 }, { 198,6148 }, { 199,6148 }, { 200,6148 }, { 201,6148 },
 { 202,6148 }, { 203,6148 }, { 204,6148 }, { 205,6148 }, { 206,6148 },
 { 207,6148 }, { 208,6148 }, { 209,6148 }, { 210,6148 }, { 211,6148 },

 { 212,6148 }, { 213,6148 }, { 214,6148 }, { 215,6148 }, { 216,6148 },
 { 217,6148 }, { 218,6148 }, { 219,6148 }, { 220,6148 }, { 221,6148 },
 { 222,6148 }, { 223,6148 }, { 224,6148 }, { 225,6148 }, { 226,6148 },
 { 227,6148 }, { 228,6148 }, { 229,6148 }, { 230,6148 }, { 231,6148 },
 { 232,6148 }, { 233,6148 }, { 234,6148 }, { 235,6148 }, { 236,6148 },
 { 237,6148 }, { 238,6148 }, { 239,6148 }, { 240,6148 }, { 241,6148 },
 { 242,6148 }, { 243,6148 }, { 244,6148 }, { 245,6148 }, { 246,6148 },
 { 247,6148 }, { 248,6148 }, { 249,6148 }, { 250,6148 }, { 251,6148 },
 { 252,6148 }, { 253,6148 }, { 254,6148 }, { 255,6148 }, {   0,  74 },
 {   0,16505 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  36,5891 }, {   0,   0 }, {   0,   0 }, {  39,-1513 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,5891 }, {  49,5891 },
 {  50,5891 }, {  51,5891 }, {  52,5891 }, {  53,5891 }, {  54,5891 },

 {  55,5891 }, {  56,5891 }, {  57,5891 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,5891 }, {  66,5891 }, {  67,5891 }, {  68,5891 }, {  69,5891 },
 {  70,5891 }, {  71,5891 }, {  72,5891 }, {  73,5891 }, {  74,5891 },
 {  75,5891 }, {  76,5891 }, {  77,5891 }, {  78,5891 }, {  79,5891 },
 {  80,5891 }, {  81,5891 }, {  82,5891 }, {  83,5891 }, {  84,5891 },
 {  85,5891 }, {  86,5891 }, {  87,5891 }, {  88,5891 }, {  89,5891 },
 {  90,5891 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,5891 }, {   0,   0 }, {  97,5891 }, {  98,5891 }, {  99,5891 },
 { 100,5891 }, { 101,5891 }, { 102,5891 }, { 103,5891 }, { 104,5891 },

 { 105,5891 }, { 106,5891 }, { 107,5891 }, { 108,5891 }, { 109,5891 },
 { 110,5891 }, { 111,5891 }, { 112,5891 }, { 113,5891 }, { 114,5891 },
 { 115,5891 }, { 116,5891 }, { 117,5891 }, { 118,5891 }, { 119,5891 },
 { 120,5891 }, { 121,5891 }, { 122,5891 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,5891 }, { 129,5891 },
 { 130,5891 }, { 131,5891 }, { 132,5891 }, { 133,5891 }, { 134,5891 },
 { 135,5891 }, { 136,5891 }, { 137,5891 }, { 138,5891 }, { 139,5891 },
 { 140,5891 }, { 141,5891 }, { 142,5891 }, { 143,5891 }, { 144,5891 },
 { 145,5891 }, { 146,5891 }, { 147,5891 }, { 148,5891 }, { 149,5891 },
 { 150,5891 }, { 151,5891 }, { 152,5891 }, { 153,5891 }, { 154,5891 },

 { 155,5891 }, { 156,5891 }, { 157,5891 }, { 158,5891 }, { 159,5891 },
 { 160,5891 }, { 161,5891 }, { 162,5891 }, { 163,5891 }, { 164,5891 },
 { 165,5891 }, { 166,5891 }, { 167,5891 }, { 168,5891 }, { 169,5891 },
 { 170,5891 }, { 171,5891 }, { 172,5891 }, { 173,5891 }, { 174,5891 },
 { 175,5891 }, { 176,5891 }, { 177,5891 }, { 178,5891 }, { 179,5891 },
 { 180,5891 }, { 181,5891 }, { 182,5891 }, { 183,5891 }, { 184,5891 },
 { 185,5891 }, { 186,5891 }, { 187,5891 }, { 188,5891 }, { 189,5891 },
 { 190,5891 }, { 191,5891 }, { 192,5891 }, { 193,5891 }, { 194,5891 },
 { 195,5891 }, { 196,5891 }, { 197,5891 }, { 198,5891 }, { 199,5891 },
 { 200,5891 }, { 201,5891 }, { 202,5891 }, { 203,5891 }, { 204,5891 },

 { 205,5891 }, { 206,5891 }, { 207,5891 }, { 208,5891 }, { 209,5891 },
 { 210,5891 }, { 211,5891 }, { 212,5891 }, { 213,5891 }, { 214,5891 },
 { 215,5891 }, { 216,5891 }, { 217,5891 }, { 218,5891 }, { 219,5891 },
 { 220,5891 }, { 221,5891 }, { 222,5891 }, { 223,5891 }, { 224,5891 },
 { 225,5891 }, { 226,5891 }, { 227,5891 }, { 228,5891 }, { 229,5891 },
 { 230,5891 }, { 231,5891 }, { 232,5891 }, { 233,5891 }, { 234,5891 },
 { 235,5891 }, { 236,5891 }, { 237,5891 }, { 238,5891 }, { 239,5891 },
 { 240,5891 }, { 241,5891 }, { 242,5891 }, { 243,5891 }, { 244,5891 },
 { 245,5891 }, { 246,5891 }, { 247,5891 }, { 248,5891 }, { 249,5891 },
 { 250,5891 }, { 251,5891 }, { 252,5891 }, { 253,5891 }, { 254,5891 },

 { 255,5891 }, {   0,  74 }, {   0,16248 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36,5634 }, {   0,   0 },
 {  38,-1767 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  48,5634 }, {  49,5634 }, {  50,5634 }, {  51,5634 }, {  52,5634 },
 {  53,5634 }, {  54,5634 }, {  55,5634 }, {  56,5634 }, {  57,5634 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,5634 }, {  66,5634 }, {  67,5634 },
 {  68,5634 }, {  69,5634 }, {  70,5634 }, {  71,5634 }, {  72,5634 },
 {  73,5634 }, {  74,5634 }, {  75,5634 }, {  76,5634 }, {  77,5634 },
 {  78,5634 }, {  79,5634 }, {  80,5634 }, {  81,5634 }, {  82,5634 },
 {  83,5634 }, {  84,5634 }, {  85,5634 }, {  86,5634 }, {  87,5634 },
 {  88,5634 }, {  89,5634 }, {  90,5634 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,5634 }, {   0,   0 }, {  97,5634 },

 {  98,5634 }, {  99,5634 }, { 100,5634 }, { 101,5634 }, { 102,5634 },
 { 103,5634 }, { 104,5634 }, { 105,5634 }, { 106,5634 }, { 107,5634 },
 { 108,5634 }, { 109,5634 }, { 110,5634 }, { 111,5634 }, { 112,5634 },
 { 113,5634 }, { 114,5634 }, { 115,5634 }, { 116,5634 }, { 117,5634 },
 { 118,5634 }, { 119,5634 }, { 120,5634 }, { 121,5634 }, { 122,5634 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,5634 }, { 129,5634 }, { 130,5634 }, { 131,5634 }, { 132,5634 },
 { 133,5634 }, { 134,5634 }, { 135,5634 }, { 136,5634 }, { 137,5634 },
 { 138,5634 }, { 139,5634 }, { 140,5634 }, { 141,5634 }, { 142,5634 },
 { 143,5634 }, { 144,5634 }, { 145,5634 }, { 146,5634 }, { 147,5634 },

 { 148,5634 }, { 149,5634 }, { 150,5634 }, { 151,5634 }, { 152,5634 },
 { 153,5634 }, { 154,5634 }, { 155,5634 }, { 156,5634 }, { 157,5634 },
 { 158,5634 }, { 159,5634 }, { 160,5634 }, { 161,5634 }, { 162,5634 },
 { 163,5634 }, { 164,5634 }, { 165,5634 }, { 166,5634 }, { 167,5634 },
 { 168,5634 }, { 169,5634 }, { 170,5634 }, { 171,5634 }, { 172,5634 },
 { 173,5634 }, { 174,5634 }, { 175,5634 }, { 176,5634 }, { 177,5634 },
 { 178,5634 }, { 179,5634 }, { 180,5634 }, { 181,5634 }, { 182,5634 },
 { 183,5634 }, { 184,5634 }, { 185,5634 }, { 186,5634 }, { 187,5634 },
 { 188,5634 }, { 189,5634 }, { 190,5634 }, { 191,5634 }, { 192,5634 },
 { 193,5634 }, { 194,5634 }, { 195,5634 }, { 196,5634 }, { 197,5634 },

 { 198,5634 }, { 199,5634 }, { 200,5634 }, { 201,5634 }, { 202,5634 },
 { 203,5634 }, { 204,5634 }, { 205,5634 }, { 206,5634 }, { 207,5634 },
 { 208,5634 }, { 209,5634 }, { 210,5634 }, { 211,5634 }, { 212,5634 },
 { 213,5634 }, { 214,5634 }, { 215,5634 }, { 216,5634 }, { 217,5634 },
 { 218,5634 }, { 219,5634 }, { 220,5634 }, { 221,5634 }, { 222,5634 },
 { 223,5634 }, { 224,5634 }, { 225,5634 }, { 226,5634 }, { 227,5634 },
 { 228,5634 }, { 229,5634 }, { 230,5634 }, { 231,5634 }, { 232,5634 },
 { 233,5634 }, { 234,5634 }, { 235,5634 }, { 236,5634 }, { 237,5634 },
 { 238,5634 }, { 239,5634 }, { 240,5634 }, { 241,5634 }, { 242,5634 },
 { 243,5634 }, { 244,5634 }, { 245,5634 }, { 246,5634 }, { 247,5634 },

 { 248,5634 }, { 249,5634 }, { 250,5634 }, { 251,5634 }, { 252,5634 },
 { 253,5634 }, { 254,5634 }, { 255,5634 }, {   0,  74 }, {   0,15991 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,5377 }, {   0,   0 }, {   0,   0 }, {  39,-2022 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,5377 }, {  49,5377 }, {  50,5377 },
 {  51,5377 }, {  52,5377 }, {  53,5377 }, {  54,5377 }, {  55,5377 },
 {  56,5377 }, {  57,5377 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,5377 },
 {  66,5377 }, {  67,5377 }, {  68,5377 }, {  69,5377 }, {  70,5377 },
 {  71,5377 }, {  72,5377 }, {  73,5377 }, {  74,5377 }, {  75,5377 },
 {  76,5377 }, {  77,5377 }, {  78,5377 }, {  79,5377 }, {  80,5377 },
 {  81,5377 }, {  82,5377 }, {  83,5377 }, {  84,5377 }, {  85,5377 },
 {  86,5377 }, {  87,5377 }, {  88,5377 }, {  89,5377 }, {  90,5377 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,5377 },
 {   0,   0 }, {  97,5377 }, {  98,5377 }, {  99,5377 }, { 100,5377 },
 { 101,5377 }, { 102,5377 }, { 103,5377 }, { 104,5377 }, { 105,5377 },
 { 106,5377 }, { 107,5377 }, { 108,5377 }, { 109,5377 }, { 110,5377 },
 { 111,5377 }, { 112,5377 }, { 113,5377 }, { 114,5377 }, { 115,5377 },
 { 116,5377 }, { 117,5377 }, { 118,5377 }, { 119,5377 }, { 120,5377 },
 { 121,5377 }, { 122,5377 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,5377 }, { 129,5377 }, { 130,5377 },
 { 131,5377 }, { 132,5377 }, { 133,5377 }, { 134,5377 }, { 135,5377 },
 { 136,5377 }, { 137,5377 }, { 138,5377 }, { 139,5377 }, { 140,5377 },

 { 141,5377 }, { 142,5377 }, { 143,5377 }, { 144,5377 }, { 145,5377 },
 { 146,5377 }, { 147,5377 }, { 148,5377 }, { 149,5377 }, { 150,5377 },
 { 151,5377 }, { 152,5377 }, { 153,5377 }, { 154,5377 }, { 155,5377 },
 { 156,5377 }, { 157,5377 }, { 158,5377 }, { 159,5377 }, { 160,5377 },
 { 161,5377 }, { 162,5377 }, { 163,5377 }, { 164,5377 }, { 165,5377 },
 { 166,5377 }, { 167,5377 }, { 168,5377 }, { 169,5377 }, { 170,5377 },
 { 171,5377 }, { 172,5377 }, { 173,5377 }, { 174,5377 }, { 175,5377 },
 { 176,5377 }, { 177,5377 }, { 178,5377 }, { 179,5377 }, { 180,5377 },
 { 181,5377 }, { 182,5377 }, { 183,5377 }, { 184,5377 }, { 185,5377 },
 { 186,5377 }, { 187,5377 }, { 188,5377 }, { 189,5377 }, { 190,5377 },

 { 191,5377 }, { 192,5377 }, { 193,5377 }, { 194,5377 }, { 195,5377 },
 { 196,5377 }, { 197,5377 }, { 198,5377 }, { 199,5377 }, { 200,5377 },
 { 201,5377 }, { 202,5377 }, { 203,5377 }, { 204,5377 }, { 205,5377 },
 { 206,5377 }, { 207,5377 }, { 208,5377 }, { 209,5377 }, { 210,5377 },
 { 211,5377 }, { 212,5377 }, { 213,5377 }, { 214,5377 }, { 215,5377 },
 { 216,5377 }, { 217,5377 }, { 218,5377 }, { 219,5377 }, { 220,5377 },
 { 221,5377 }, { 222,5377 }, { 223,5377 }, { 224,5377 }, { 225,5377 },
 { 226,5377 }, { 227,5377 }, { 228,5377 }, { 229,5377 }, { 230,5377 },
 { 231,5377 }, { 232,5377 }, { 233,5377 }, { 234,5377 }, { 235,5377 },
 { 236,5377 }, { 237,5377 }, { 238,5377 }, { 239,5377 }, { 240,5377 },

 { 241,5377 }, { 242,5377 }, { 243,5377 }, { 244,5377 }, { 245,5377 },
 { 246,5377 }, { 247,5377 }, { 248,5377 }, { 249,5377 }, { 250,5377 },
 { 251,5377 }, { 252,5377 }, { 253,5377 }, { 254,5377 }, { 255,5377 },
 {   0,  10 }, {   0,15734 }, {   1,5377 }, {   2,5377 }, {   3,5377 },
 {   4,5377 }, {   5,5377 }, {   6,5377 }, {   7,5377 }, {   8,5377 },
 {   9,5377 }, {  10,5377 }, {  11,5377 }, {  12,5377 }, {  13,5377 },
 {  14,5377 }, {  15,5377 }, {  16,5377 }, {  17,5377 }, {  18,5377 },
 {  19,5377 }, {  20,5377 }, {  21,5377 }, {  22,5377 }, {  23,5377 },
 {  24,5377 }, {  25,5377 }, {  26,5377 }, {  27,5377 }, {  28,5377 },
 {  29,5377 }, {  30,5377 }, {  31,5377 }, {  32,5377 }, {  33,5377 },

 {  34,5377 }, {  35,5377 }, {  36,5377 }, {  37,5377 }, {  38,5377 },
 {   0,   0 }, {  40,5377 }, {  41,5377 }, {  42,5377 }, {  43,5377 },
 {  44,5377 }, {  45,5377 }, {  46,5377 }, {  47,5377 }, {  48,5377 },
 {  49,5377 }, {  50,5377 }, {  51,5377 }, {  52,5377 }, {  53,5377 },
 {  54,5377 }, {  55,5377 }, {  56,5377 }, {  57,5377 }, {  58,5377 },
 {  59,5377 }, {  60,5377 }, {  61,5377 }, {  62,5377 }, {  63,5377 },
 {  64,5377 }, {  65,5377 }, {  66,5377 }, {  67,5377 }, {  68,5377 },
 {  69,5377 }, {  70,5377 }, {  71,5377 }, {  72,5377 }, {  73,5377 },
 {  74,5377 }, {  75,5377 }, {  76,5377 }, {  77,5377 }, {  78,5377 },
 {  79,5377 }, {  80,5377 }, {  81,5377 }, {  82,5377 }, {  83,5377 },

 {  84,5377 }, {  85,5377 }, {  86,5377 }, {  87,5377 }, {  88,5377 },
 {  89,5377 }, {  90,5377 }, {  91,5377 }, {  92,5377 }, {  93,5377 },
 {  94,5377 }, {  95,5377 }, {  96,5377 }, {  97,5377 }, {  98,5377 },
 {  99,5377 }, { 100,5377 }, { 101,5377 }, { 102,5377 }, { 103,5377 },
 { 104,5377 }, { 105,5377 }, { 106,5377 }, { 107,5377 }, { 108,5377 },
 { 109,5377 }, { 110,5377 }, { 111,5377 }, { 112,5377 }, { 113,5377 },
 { 114,5377 }, { 115,5377 }, { 116,5377 }, { 117,5377 }, { 118,5377 },
 { 119,5377 }, { 120,5377 }, { 121,5377 }, { 122,5377 }, { 123,5377 },
 { 124,5377 }, { 125,5377 }, { 126,5377 }, { 127,5377 }, { 128,5377 },
 { 129,5377 }, { 130,5377 }, { 131,5377 }, { 132,5377 }, { 133,5377 },

 { 134,5377 }, { 135,5377 }, { 136,5377 }, { 137,5377 }, { 138,5377 },
 { 139,5377 }, { 140,5377 }, { 141,5377 }, { 142,5377 }, { 143,5377 },
 { 144,5377 }, { 145,5377 }, { 146,5377 }, { 147,5377 }, { 148,5377 },
 { 149,5377 }, { 150,5377 }, { 151,5377 }, { 152,5377 }, { 153,5377 },
 { 154,5377 }, { 155,5377 }, { 156,5377 }, { 157,5377 }, { 158,5377 },
 { 159,5377 }, { 160,5377 }, { 161,5377 }, { 162,5377 }, { 163,5377 },
 { 164,5377 }, { 165,5377 }, { 166,5377 }, { 167,5377 }, { 168,5377 },
 { 169,5377 }, { 170,5377 }, { 171,5377 }, { 172,5377 }, { 173,5377 },
 { 174,5377 }, { 175,5377 }, { 176,5377 }, { 177,5377 }, { 178,5377 },
 { 179,5377 }, { 180,5377 }, { 181,5377 }, { 182,5377 }, { 183,5377 },

 { 184,5377 }, { 185,5377 }, { 186,5377 }, { 187,5377 }, { 188,5377 },
 { 189,5377 }, { 190,5377 }, { 191,5377 }, { 192,5377 }, { 193,5377 },
 { 194,5377 }, { 195,5377 }, { 196,5377 }, { 197,5377 }, { 198,5377 },
 { 199,5377 }, { 200,5377 }, { 201,5377 }, { 202,5377 }, { 203,5377 },
 { 204,5377 }, { 205,5377 }, { 206,5377 }, { 207,5377 }, { 208,5377 },
 { 209,5377 }, { 210,5377 }, { 211,5377 }, { 212,5377 }, { 213,5377 },
 { 214,5377 }, { 215,5377 }, { 216,5377 }, { 217,5377 }, { 218,5377 },
 { 219,5377 }, { 220,5377 }, { 221,5377 }, { 222,5377 }, { 223,5377 },
 { 224,5377 }, { 225,5377 }, { 226,5377 }, { 227,5377 }, { 228,5377 },
 { 229,5377 }, { 230,5377 }, { 231,5377 }, { 232,5377 }, { 233,5377 },

 { 234,5377 }, { 235,5377 }, { 236,5377 }, { 237,5377 }, { 238,5377 },
 { 239,5377 }, { 240,5377 }, { 241,5377 }, { 242,5377 }, { 243,5377 },
 { 244,5377 }, { 245,5377 }, { 246,5377 }, { 247,5377 }, { 248,5377 },
 { 249,5377 }, { 250,5377 }, { 251,5377 }, { 252,5377 }, { 253,5377 },
 { 254,5377 }, { 255,5377 }, { 256,5377 }, {   0,   5 }, {   0,15476 },
 {   1,5377 }, {   2,5377 }, {   3,5377 }, {   4,5377 }, {   5,5377 },
 {   6,5377 }, {   7,5377 }, {   8,5377 }, {   9,5377 }, {  10,5377 },
 {  11,5377 }, {  12,5377 }, {  13,5377 }, {  14,5377 }, {  15,5377 },
 {  16,5377 }, {  17,5377 }, {  18,5377 }, {  19,5377 }, {  20,5377 },
 {  21,5377 }, {  22,5377 }, {  23,5377 }, {  24,5377 }, {  25,5377 },

 {  26,5377 }, {  27,5377 }, {  28,5377 }, {  29,5377 }, {  30,5377 },
 {  31,5377 }, {  32,5377 }, {  33,5377 }, {  34,5377 }, {  35,5377 },
 {  36,5377 }, {  37,5377 }, {  38,5377 }, {  39,5377 }, {  40,5377 },
 {  41,5377 }, {   0,   0 }, {  43,5377 }, {  44,5377 }, {  45,5377 },
 {  46,5377 }, {   0,   0 }, {  48,5377 }, {  49,5377 }, {  50,5377 },
 {  51,5377 }, {  52,5377 }, {  53,5377 }, {  54,5377 }, {  55,5377 },
 {  56,5377 }, {  57,5377 }, {  58,5377 }, {  59,5377 }, {  60,5377 },
 {  61,5377 }, {  62,5377 }, {  63,5377 }, {  64,5377 }, {  65,5377 },
 {  66,5377 }, {  67,5377 }, {  68,5377 }, {  69,5377 }, {  70,5377 },
 {  71,5377 }, {  72,5377 }, {  73,5377 }, {  74,5377 }, {  75,5377 },

 {  76,5377 }, {  77,5377 }, {  78,5377 }, {  79,5377 }, {  80,5377 },
 {  81,5377 }, {  82,5377 }, {  83,5377 }, {  84,5377 }, {  85,5377 },
 {  86,5377 }, {  87,5377 }, {  88,5377 }, {  89,5377 }, {  90,5377 },
 {  91,5377 }, {  92,5377 }, {  93,5377 }, {  94,5377 }, {  95,5377 },
 {  96,5377 }, {  97,5377 }, {  98,5377 }, {  99,5377 }, { 100,5377 },
 { 101,5377 }, { 102,5377 }, { 103,5377 }, { 104,5377 }, { 105,5377 },
 { 106,5377 }, { 107,5377 }, { 108,5377 }, { 109,5377 }, { 110,5377 },
 { 111,5377 }, { 112,5377 }, { 113,5377 }, { 114,5377 }, { 115,5377 },
 { 116,5377 }, { 117,5377 }, { 118,5377 }, { 119,5377 }, { 120,5377 },
 { 121,5377 }, { 122,5377 }, { 123,5377 }, { 124,5377 }, { 125,5377 },

 { 126,5377 }, { 127,5377 }, { 128,5377 }, { 129,5377 }, { 130,5377 },
 { 131,5377 }, { 132,5377 }, { 133,5377 }, { 134,5377 }, { 135,5377 },
 { 136,5377 }, { 137,5377 }, { 138,5377 }, { 139,5377 }, { 140,5377 },
 { 141,5377 }, { 142,5377 }, { 143,5377 }, { 144,5377 }, { 145,5377 },
 { 146,5377 }, { 147,5377 }, { 148,5377 }, { 149,5377 }, { 150,5377 },
 { 151,5377 }, { 152,5377 }, { 153,5377 }, { 154,5377 }, { 155,5377 },
 { 156,5377 }, { 157,5377 }, { 158,5377 }, { 159,5377 }, { 160,5377 },
 { 161,5377 }, { 162,5377 }, { 163,5377 }, { 164,5377 }, { 165,5377 },
 { 166,5377 }, { 167,5377 }, { 168,5377 }, { 169,5377 }, { 170,5377 },
 { 171,5377 }, { 172,5377 }, { 173,5377 }, { 174,5377 }, { 175,5377 },

 { 176,5377 }, { 177,5377 }, { 178,5377 }, { 179,5377 }, { 180,5377 },
 { 181,5377 }, { 182,5377 }, { 183,5377 }, { 184,5377 }, { 185,5377 },
 { 186,5377 }, { 187,5377 }, { 188,5377 }, { 189,5377 }, { 190,5377 },
 { 191,5377 }, { 192,5377 }, { 193,5377 }, { 194,5377 }, { 195,5377 },
 { 196,5377 }, { 197,5377 }, { 198,5377 }, { 199,5377 }, { 200,5377 },
 { 201,5377 }, { 202,5377 }, { 203,5377 }, { 204,5377 }, { 205,5377 },
 { 206,5377 }, { 207,5377 }, { 208,5377 }, { 209,5377 }, { 210,5377 },
 { 211,5377 }, { 212,5377 }, { 213,5377 }, { 214,5377 }, { 215,5377 },
 { 216,5377 }, { 217,5377 }, { 218,5377 }, { 219,5377 }, { 220,5377 },
 { 221,5377 }, { 222,5377 }, { 223,5377 }, { 224,5377 }, { 225,5377 },

 { 226,5377 }, { 227,5377 }, { 228,5377 }, { 229,5377 }, { 230,5377 },
 { 231,5377 }, { 232,5377 }, { 233,5377 }, { 234,5377 }, { 235,5377 },
 { 236,5377 }, { 237,5377 }, { 238,5377 }, { 239,5377 }, { 240,5377 },
 { 241,5377 }, { 242,5377 }, { 243,5377 }, { 244,5377 }, { 245,5377 },
 { 246,5377 }, { 247,5377 }, { 248,5377 }, { 249,5377 }, { 250,5377 },
 { 251,5377 }, { 252,5377 }, { 253,5377 }, { 254,5377 }, { 255,5377 },
 { 256,5377 }, {   0,   5 }, {   0,15218 }, {   1,5119 }, {   2,5119 },
 {   3,5119 }, {   4,5119 }, {   5,5119 }, {   6,5119 }, {   7,5119 },
 {   8,5119 }, {   9,5119 }, {  10,5119 }, {  11,5119 }, {  12,5119 },
 {  13,5119 }, {  14,5119 }, {  15,5119 }, {  16,5119 }, {  17,5119 },

 {  18,5119 }, {  19,5119 }, {  20,5119 }, {  21,5119 }, {  22,5119 },
 {  23,5119 }, {  24,5119 }, {  25,5119 }, {  26,5119 }, {  27,5119 },
 {  28,5119 }, {  29,5119 }, {  30,5119 }, {  31,5119 }, {  32,5119 },
 {  33,5119 }, {  34,5119 }, {  35,5119 }, {  36,5119 }, {  37,5119 },
 {  38,5119 }, {  39,5119 }, {  40,5119 }, {  41,5119 }, {   0,   0 },
 {  43,5119 }, {  44,5119 }, {  45,5119 }, {  46,5119 }, {   0,   0 },
 {  48,5119 }, {  49,5119 }, {  50,5119 }, {  51,5119 }, {  52,5119 },
 {  53,5119 }, {  54,5119 }, {  55,5119 }, {  56,5119 }, {  57,5119 },
 {  58,5119 }, {  59,5119 }, {  60,5119 }, {  61,5119 }, {  62,5119 },
 {  63,5119 }, {  64,5119 }, {  65,5119 }, {  66,5119 }, {  67,5119 },

 {  68,5119 }, {  69,5119 }, {  70,5119 }, {  71,5119 }, {  72,5119 },
 {  73,5119 }, {  74,5119 }, {  75,5119 }, {  76,5119 }, {  77,5119 },
 {  78,5119 }, {  79,5119 }, {  80,5119 }, {  81,5119 }, {  82,5119 },
 {  83,5119 }, {  84,5119 }, {  85,5119 }, {  86,5119 }, {  87,5119 },
 {  88,5119 }, {  89,5119 }, {  90,5119 }, {  91,5119 }, {  92,5119 },
 {  93,5119 }, {  94,5119 }, {  95,5119 }, {  96,5119 }, {  97,5119 },
 {  98,5119 }, {  99,5119 }, { 100,5119 }, { 101,5119 }, { 102,5119 },
 { 103,5119 }, { 104,5119 }, { 105,5119 }, { 106,5119 }, { 107,5119 },
 { 108,5119 }, { 109,5119 }, { 110,5119 }, { 111,5119 }, { 112,5119 },
 { 113,5119 }, { 114,5119 }, { 115,5119 }, { 116,5119 }, { 117,5119 },

 { 118,5119 }, { 119,5119 }, { 120,5119 }, { 121,5119 }, { 122,5119 },
 { 123,5119 }, { 124,5119 }, { 125,5119 }, { 126,5119 }, { 127,5119 },
 { 128,5119 }, { 129,5119 }, { 130,5119 }, { 131,5119 }, { 132,5119 },
 { 133,5119 }, { 134,5119 }, { 135,5119 }, { 136,5119 }, { 137,5119 },
 { 138,5119 }, { 139,5119 }, { 140,5119 }, { 141,5119 }, { 142,5119 },
 { 143,5119 }, { 144,5119 }, { 145,5119 }, { 146,5119 }, { 147,5119 },
 { 148,5119 }, { 149,5119 }, { 150,5119 }, { 151,5119 }, { 152,5119 },
 { 153,5119 }, { 154,5119 }, { 155,5119 }, { 156,5119 }, { 157,5119 },
 { 158,5119 }, { 159,5119 }, { 160,5119 }, { 161,5119 }, { 162,5119 },
 { 163,5119 }, { 164,5119 }, { 165,5119 }, { 166,5119 }, { 167,5119 },

 { 168,5119 }, { 169,5119 }, { 170,5119 }, { 171,5119 }, { 172,5119 },
 { 173,5119 }, { 174,5119 }, { 175,5119 }, { 176,5119 }, { 177,5119 },
 { 178,5119 }, { 179,5119 }, { 180,5119 }, { 181,5119 }, { 182,5119 },
 { 183,5119 }, { 184,5119 }, { 185,5119 }, { 186,5119 }, { 187,5119 },
 { 188,5119 }, { 189,5119 }, { 190,5119 }, { 191,5119 }, { 192,5119 },
 { 193,5119 }, { 194,5119 }, { 195,5119 }, { 196,5119 }, { 197,5119 },
 { 198,5119 }, { 199,5119 }, { 200,5119 }, { 201,5119 }, { 202,5119 },
 { 203,5119 }, { 204,5119 }, { 205,5119 }, { 206,5119 }, { 207,5119 },
 { 208,5119 }, { 209,5119 }, { 210,5119 }, { 211,5119 }, { 212,5119 },
 { 213,5119 }, { 214,5119 }, { 215,5119 }, { 216,5119 }, { 217,5119 },

 { 218,5119 }, { 219,5119 }, { 220,5119 }, { 221,5119 }, { 222,5119 },
 { 223,5119 }, { 224,5119 }, { 225,5119 }, { 226,5119 }, { 227,5119 },
 { 228,5119 }, { 229,5119 }, { 230,5119 }, { 231,5119 }, { 232,5119 },
 { 233,5119 }, { 234,5119 }, { 235,5119 }, { 236,5119 }, { 237,5119 },
 { 238,5119 }, { 239,5119 }, { 240,5119 }, { 241,5119 }, { 242,5119 },
 { 243,5119 }, { 244,5119 }, { 245,5119 }, { 246,5119 }, { 247,5119 },
 { 248,5119 }, { 249,5119 }, { 250,5119 }, { 251,5119 }, { 252,5119 },
 { 253,5119 }, { 254,5119 }, { 255,5119 }, { 256,5119 }, {   0,  43 },
 {   0,14960 }, {   1,5247 }, {   2,5247 }, {   3,5247 }, {   4,5247 },
 {   5,5247 }, {   6,5247 }, {   7,5247 }, {   8,5247 }, {   9,5247 },

 {  10,5247 }, {  11,5247 }, {  12,5247 }, {  13,5247 }, {  14,5247 },
 {  15,5247 }, {  16,5247 }, {  17,5247 }, {  18,5247 }, {  19,5247 },
 {  20,5247 }, {  21,5247 }, {  22,5247 }, {  23,5247 }, {  24,5247 },
 {  25,5247 }, {  26,5247 }, {  27,5247 }, {  28,5247 }, {  29,5247 },
 {  30,5247 }, {  31,5247 }, {  32,5247 }, {  33,5247 }, {   0,   0 },
 {  35,5247 }, {  36,5247 }, {  37,5247 }, {  38,5247 }, {  39,5247 },
 {  40,5247 }, {  41,5247 }, {  42,5247 }, {  43,5247 }, {  44,5247 },
 {  45,5247 }, {  46,5247 }, {  47,5247 }, {  48,5247 }, {  49,5247 },
 {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 }, {  54,5247 },
 {  55,5247 }, {  56,5247 }, {  57,5247 }, {  58,5247 }, {  59,5247 },

 {  60,5247 }, {  61,5247 }, {  62,5247 }, {  63,5247 }, {  64,5247 },
 {  65,5247 }, {  66,5247 }, {  67,5247 }, {  68,5247 }, {  69,5247 },
 {  70,5247 }, {  71,5247 }, {  72,5247 }, {  73,5247 }, {  74,5247 },
 {  75,5247 }, {  76,5247 }, {  77,5247 }, {  78,5247 }, {  79,5247 },
 {  80,5247 }, {  81,5247 }, {  82,5247 }, {  83,5247 }, {  84,5247 },
 {  85,5247 }, {  86,5247 }, {  87,5247 }, {  88,5247 }, {  89,5247 },
 {  90,5247 }, {  91,5247 }, {  92,5247 }, {  93,5247 }, {  94,5247 },
 {  95,5247 }, {  96,5247 }, {  97,5247 }, {  98,5247 }, {  99,5247 },
 { 100,5247 }, { 101,5247 }, { 102,5247 }, { 103,5247 }, { 104,5247 },
 { 105,5247 }, { 106,5247 }, { 107,5247 }, { 108,5247 }, { 109,5247 },

 { 110,5247 }, { 111,5247 }, { 112,5247 }, { 113,5247 }, { 114,5247 },
 { 115,5247 }, { 116,5247 }, { 117,5247 }, { 118,5247 }, { 119,5247 },
 { 120,5247 }, { 121,5247 }, { 122,5247 }, { 123,5247 }, { 124,5247 },
 { 125,5247 }, { 126,5247 }, { 127,5247 }, { 128,5247 }, { 129,5247 },
 { 130,5247 }, { 131,5247 }, { 132,5247 }, { 133,5247 }, { 134,5247 },
 { 135,5247 }, { 136,5247 }, { 137,5247 }, { 138,5247 }, { 139,5247 },
 { 140,5247 }, { 141,5247 }, { 142,5247 }, { 143,5247 }, { 144,5247 },
 { 145,5247 }, { 146,5247 }, { 147,5247 }, { 148,5247 }, { 149,5247 },
 { 150,5247 }, { 151,5247 }, { 152,5247 }, { 153,5247 }, { 154,5247 },
 { 155,5247 }, { 156,5247 }, { 157,5247 }, { 158,5247 }, { 159,5247 },

 { 160,5247 }, { 161,5247 }, { 162,5247 }, { 163,5247 }, { 164,5247 },
 { 165,5247 }, { 166,5247 }, { 167,5247 }, { 168,5247 }, { 169,5247 },
 { 170,5247 }, { 171,5247 }, { 172,5247 }, { 173,5247 }, { 174,5247 },
 { 175,5247 }, { 176,5247 }, { 177,5247 }, { 178,5247 }, { 179,5247 },
 { 180,5247 }, { 181,5247 }, { 182,5247 }, { 183,5247 }, { 184,5247 },
 { 185,5247 }, { 186,5247 }, { 187,5247 }, { 188,5247 }, { 189,5247 },
 { 190,5247 }, { 191,5247 }, { 192,5247 }, { 193,5247 }, { 194,5247 },
 { 195,5247 }, { 196,5247 }, { 197,5247 }, { 198,5247 }, { 199,5247 },
 { 200,5247 }, { 201,5247 }, { 202,5247 }, { 203,5247 }, { 204,5247 },
 { 205,5247 }, { 206,5247 }, { 207,5247 }, { 208,5247 }, { 209,5247 },

 { 210,5247 }, { 211,5247 }, { 212,5247 }, { 213,5247 }, { 214,5247 },
 { 215,5247 }, { 216,5247 }, { 217,5247 }, { 218,5247 }, { 219,5247 },
 { 220,5247 }, { 221,5247 }, { 222,5247 }, { 223,5247 }, { 224,5247 },
 { 225,5247 }, { 226,5247 }, { 227,5247 }, { 228,5247 }, { 229,5247 },
 { 230,5247 }, { 231,5247 }, { 232,5247 }, { 233,5247 }, { 234,5247 },
 { 235,5247 }, { 236,5247 }, { 237,5247 }, { 238,5247 }, { 239,5247 },
 { 240,5247 }, { 241,5247 }, { 242,5247 }, { 243,5247 }, { 244,5247 },
 { 245,5247 }, { 246,5247 }, { 247,5247 }, { 248,5247 }, { 249,5247 },
 { 250,5247 }, { 251,5247 }, { 252,5247 }, { 253,5247 }, { 254,5247 },
 { 255,5247 }, { 256,5247 }, {   0,   9 }, {   0,14702 }, {   1,5247 },

 {   2,5247 }, {   3,5247 }, {   4,5247 }, {   5,5247 }, {   6,5247 },
 {   7,5247 }, {   8,5247 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {  14,5247 }, {  15,5247 }, {  16,5247 },
 {  17,5247 }, {  18,5247 }, {  19,5247 }, {  20,5247 }, {  21,5247 },
 {  22,5247 }, {  23,5247 }, {  24,5247 }, {  25,5247 }, {  26,5247 },
 {  27,5247 }, {  28,5247 }, {  29,5247 }, {  30,5247 }, {  31,5247 },
 {  32,5247 }, {  33,5247 }, {  34,5247 }, {  35,5247 }, {  36,5247 },
 {  37,5247 }, {  38,5247 }, {   0,   0 }, {  40,5247 }, {  41,5247 },
 {  42,5247 }, {  43,5247 }, {  44,5247 }, {  45,5247 }, {  46,5247 },
 {  47,5247 }, {  48,5247 }, {  49,5247 }, {  50,5247 }, {  51,5247 },

 {  52,5247 }, {  53,5247 }, {  54,5247 }, {  55,5247 }, {  56,5247 },
 {  57,5247 }, {  58,5247 }, {  59,5247 }, {  60,5247 }, {  61,5247 },
 {  62,5247 }, {  63,5247 }, {  64,5247 }, {  65,5247 }, {  66,5247 },
 {  67,5247 }, {  68,5247 }, {  69,5247 }, {  70,5247 }, {  71,5247 },
 {  72,5247 }, {  73,5247 }, {  74,5247 }, {  75,5247 }, {  76,5247 },
 {  77,5247 }, {  78,5247 }, {  79,5247 }, {  80,5247 }, {  81,5247 },
 {  82,5247 }, {  83,5247 }, {  84,5247 }, {  85,5247 }, {  86,5247 },
 {  87,5247 }, {  88,5247 }, {  89,5247 }, {  90,5247 }, {  91,5247 },
 {  92,5247 }, {  93,5247 }, {  94,5247 }, {  95,5247 }, {  96,5247 },
 {  97,5247 }, {  98,5247 }, {  99,5247 }, { 100,5247 }, { 101,5247 },

 { 102,5247 }, { 103,5247 }, { 104,5247 }, { 105,5247 }, { 106,5247 },
 { 107,5247 }, { 108,5247 }, { 109,5247 }, { 110,5247 }, { 111,5247 },
 { 112,5247 }, { 113,5247 }, { 114,5247 }, { 115,5247 }, { 116,5247 },
 { 117,5247 }, { 118,5247 }, { 119,5247 }, { 120,5247 }, { 121,5247 },
 { 122,5247 }, { 123,5247 }, { 124,5247 }, { 125,5247 }, { 126,5247 },
 { 127,5247 }, { 128,5247 }, { 129,5247 }, { 130,5247 }, { 131,5247 },
 { 132,5247 }, { 133,5247 }, { 134,5247 }, { 135,5247 }, { 136,5247 },
 { 137,5247 }, { 138,5247 }, { 139,5247 }, { 140,5247 }, { 141,5247 },
 { 142,5247 }, { 143,5247 }, { 144,5247 }, { 145,5247 }, { 146,5247 },
 { 147,5247 }, { 148,5247 }, { 149,5247 }, { 150,5247 }, { 151,5247 },

 { 152,5247 }, { 153,5247 }, { 154,5247 }, { 155,5247 }, { 156,5247 },
 { 157,5247 }, { 158,5247 }, { 159,5247 }, { 160,5247 }, { 161,5247 },
 { 162,5247 }, { 163,5247 }, { 164,5247 }, { 165,5247 }, { 166,5247 },
 { 167,5247 }, { 168,5247 }, { 169,5247 }, { 170,5247 }, { 171,5247 },
 { 172,5247 }, { 173,5247 }, { 174,5247 }, { 175,5247 }, { 176,5247 },
 { 177,5247 }, { 178,5247 }, { 179,5247 }, { 180,5247 }, { 181,5247 },
 { 182,5247 }, { 183,5247 }, { 184,5247 }, { 185,5247 }, { 186,5247 },
 { 187,5247 }, { 188,5247 }, { 189,5247 }, { 190,5247 }, { 191,5247 },
 { 192,5247 }, { 193,5247 }, { 194,5247 }, { 195,5247 }, { 196,5247 },
 { 197,5247 }, { 198,5247 }, { 199,5247 }, { 200,5247 }, { 201,5247 },

 { 202,5247 }, { 203,5247 }, { 204,5247 }, { 205,5247 }, { 206,5247 },
 { 207,5247 }, { 208,5247 }, { 209,5247 }, { 210,5247 }, { 211,5247 },
 { 212,5247 }, { 213,5247 }, { 214,5247 }, { 215,5247 }, { 216,5247 },
 { 217,5247 }, { 218,5247 }, { 219,5247 }, { 220,5247 }, { 221,5247 },
 { 222,5247 }, { 223,5247 }, { 224,5247 }, { 225,5247 }, { 226,5247 },
 { 227,5247 }, { 228,5247 }, { 229,5247 }, { 230,5247 }, { 231,5247 },
 { 232,5247 }, { 233,5247 }, { 234,5247 }, { 235,5247 }, { 236,5247 },
 { 237,5247 }, { 238,5247 }, { 239,5247 }, { 240,5247 }, { 241,5247 },
 { 242,5247 }, { 243,5247 }, { 244,5247 }, { 245,5247 }, { 246,5247 },
 { 247,5247 }, { 248,5247 }, { 249,5247 }, { 250,5247 }, { 251,5247 },

 { 252,5247 }, { 253,5247 }, { 254,5247 }, { 255,5247 }, { 256,5247 },
 {   0,  21 }, {   0,14444 }, {   1,5247 }, {   2,5247 }, {   3,5247 },
 {   4,5247 }, {   5,5247 }, {   6,5247 }, {   7,5247 }, {   8,5247 },
 {   9,5247 }, {  10,5247 }, {  11,5247 }, {  12,5247 }, {  13,5247 },
 {  14,5247 }, {  15,5247 }, {  16,5247 }, {  17,5247 }, {  18,5247 },
 {  19,5247 }, {  20,5247 }, {  21,5247 }, {  22,5247 }, {  23,5247 },
 {  24,5247 }, {  25,5247 }, {  26,5247 }, {  27,5247 }, {  28,5247 },
 {  29,5247 }, {  30,5247 }, {  31,5247 }, {  32,5247 }, {  33,5247 },
 {  34,5247 }, {  35,5247 }, {  36,5247 }, {  37,5247 }, {  38,5247 },
 {   0,   0 }, {  40,5247 }, {  41,5247 }, {  42,5247 }, {  43,5247 },

 {  44,5247 }, {  45,5247 }, {  46,5247 }, {  47,5247 }, {  48,5247 },
 {  49,5247 }, {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 },
 {  54,5247 }, {  55,5247 }, {  56,5247 }, {  57,5247 }, {  58,5247 },
 {  59,5247 }, {  60,5247 }, {  61,5247 }, {  62,5247 }, {  63,5247 },
 {  64,5247 }, {  65,5247 }, {  66,5247 }, {  67,5247 }, {  68,5247 },
 {  69,5247 }, {  70,5247 }, {  71,5247 }, {  72,5247 }, {  73,5247 },
 {  74,5247 }, {  75,5247 }, {  76,5247 }, {  77,5247 }, {  78,5247 },
 {  79,5247 }, {  80,5247 }, {  81,5247 }, {  82,5247 }, {  83,5247 },
 {  84,5247 }, {  85,5247 }, {  86,5247 }, {  87,5247 }, {  88,5247 },
 {  89,5247 }, {  90,5247 }, {  91,5247 }, {  92,5247 }, {  93,5247 },

 {  94,5247 }, {  95,5247 }, {  96,5247 }, {  97,5247 }, {  98,5247 },
 {  99,5247 }, { 100,5247 }, { 101,5247 }, { 102,5247 }, { 103,5247 },
 { 104,5247 }, { 105,5247 }, { 106,5247 }, { 107,5247 }, { 108,5247 },
 { 109,5247 }, { 110,5247 }, { 111,5247 }, { 112,5247 }, { 113,5247 },
 { 114,5247 }, { 115,5247 }, { 116,5247 }, { 117,5247 }, { 118,5247 },
 { 119,5247 }, { 120,5247 }, { 121,5247 }, { 122,5247 }, { 123,5247 },
 { 124,5247 }, { 125,5247 }, { 126,5247 }, { 127,5247 }, { 128,5247 },
 { 129,5247 }, { 130,5247 }, { 131,5247 }, { 132,5247 }, { 133,5247 },
 { 134,5247 }, { 135,5247 }, { 136,5247 }, { 137,5247 }, { 138,5247 },
 { 139,5247 }, { 140,5247 }, { 141,5247 }, { 142,5247 }, { 143,5247 },

 { 144,5247 }, { 145,5247 }, { 146,5247 }, { 147,5247 }, { 148,5247 },
 { 149,5247 }, { 150,5247 }, { 151,5247 }, { 152,5247 }, { 153,5247 },
 { 154,5247 }, { 155,5247 }, { 156,5247 }, { 157,5247 }, { 158,5247 },
 { 159,5247 }, { 160,5247 }, { 161,5247 }, { 162,5247 }, { 163,5247 },
 { 164,5247 }, { 165,5247 }, { 166,5247 }, { 167,5247 }, { 168,5247 },
 { 169,5247 }, { 170,5247 }, { 171,5247 }, { 172,5247 }, { 173,5247 },
 { 174,5247 }, { 175,5247 }, { 176,5247 }, { 177,5247 }, { 178,5247 },
 { 179,5247 }, { 180,5247 }, { 181,5247 }, { 182,5247 }, { 183,5247 },
 { 184,5247 }, { 185,5247 }, { 186,5247 }, { 187,5247 }, { 188,5247 },
 { 189,5247 }, { 190,5247 }, { 191,5247 }, { 192,5247 }, { 193,5247 },

 { 194,5247 }, { 195,5247 }, { 196,5247 }, { 197,5247 }, { 198,5247 },
 { 199,5247 }, { 200,5247 }, { 201,5247 }, { 202,5247 }, { 203,5247 },
 { 204,5247 }, { 205,5247 }, { 206,5247 }, { 207,5247 }, { 208,5247 },
 { 209,5247 }, { 210,5247 }, { 211,5247 }, { 212,5247 }, { 213,5247 },
 { 214,5247 }, { 215,5247 }, { 216,5247 }, { 217,5247 }, { 218,5247 },
 { 219,5247 }, { 220,5247 }, { 221,5247 }, { 222,5247 }, { 223,5247 },
 { 224,5247 }, { 225,5247 }, { 226,5247 }, { 227,5247 }, { 228,5247 },
 { 229,5247 }, { 230,5247 }, { 231,5247 }, { 232,5247 }, { 233,5247 },
 { 234,5247 }, { 235,5247 }, { 236,5247 }, { 237,5247 }, { 238,5247 },
 { 239,5247 }, { 240,5247 }, { 241,5247 }, { 242,5247 }, { 243,5247 },

 { 244,5247 }, { 245,5247 }, { 246,5247 }, { 247,5247 }, { 248,5247 },
 { 249,5247 }, { 250,5247 }, { 251,5247 }, { 252,5247 }, { 253,5247 },
 { 254,5247 }, { 255,5247 }, { 256,5247 }, {   0,  18 }, {   0,14186 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  18 }, {   0,14181 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   9,5247 }, {  10,5252 },
 {  11,5247 }, {  12,5247 }, {  13,5252 }, {   9,5271 }, {  10,5271 },
 {  11,5271 }, {  12,5271 }, {  13,5271 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  18 }, {   0,14157 }, {   0,   0 },
 {   0,   0 }, {  32,5247 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  32,5271 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {   0,   0 }, {  39,-3783 }, {  45,-3780 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-3748 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  32,5247 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  39,-3807 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-3772 }, {   0,  22 },
 {   0,14110 }, {   1,5505 }, {   2,5505 }, {   3,5505 }, {   4,5505 },
 {   5,5505 }, {   6,5505 }, {   7,5505 }, {   8,5505 }, {   9,5505 },

 {  10,5505 }, {  11,5505 }, {  12,5505 }, {  13,5505 }, {  14,5505 },
 {  15,5505 }, {  16,5505 }, {  17,5505 }, {  18,5505 }, {  19,5505 },
 {  20,5505 }, {  21,5505 }, {  22,5505 }, {  23,5505 }, {  24,5505 },
 {  25,5505 }, {  26,5505 }, {  27,5505 }, {  28,5505 }, {  29,5505 },
 {  30,5505 }, {  31,5505 }, {  32,5505 }, {  33,5505 }, {  34,5505 },
 {  35,5505 }, {  36,5505 }, {  37,5505 }, {  38,5505 }, {   0,   0 },
 {  40,5505 }, {  41,5505 }, {  42,5505 }, {  43,5505 }, {  44,5505 },
 {  45,5505 }, {  46,5505 }, {  47,5505 }, {  48,5505 }, {  49,5505 },
 {  50,5505 }, {  51,5505 }, {  52,5505 }, {  53,5505 }, {  54,5505 },
 {  55,5505 }, {  56,5505 }, {  57,5505 }, {  58,5505 }, {  59,5505 },

 {  60,5505 }, {  61,5505 }, {  62,5505 }, {  63,5505 }, {  64,5505 },
 {  65,5505 }, {  66,5505 }, {  67,5505 }, {  68,5505 }, {  69,5505 },
 {  70,5505 }, {  71,5505 }, {  72,5505 }, {  73,5505 }, {  74,5505 },
 {  75,5505 }, {  76,5505 }, {  77,5505 }, {  78,5505 }, {  79,5505 },
 {  80,5505 }, {  81,5505 }, {  82,5505 }, {  83,5505 }, {  84,5505 },
 {  85,5505 }, {  86,5505 }, {  87,5505 }, {  88,5505 }, {  89,5505 },
 {  90,5505 }, {  91,5505 }, {   0,   0 }, {  93,5505 }, {  94,5505 },
 {  95,5505 }, {  96,5505 }, {  97,5505 }, {  98,5505 }, {  99,5505 },
 { 100,5505 }, { 101,5505 }, { 102,5505 }, { 103,5505 }, { 104,5505 },
 { 105,5505 }, { 106,5505 }, { 107,5505 }, { 108,5505 }, { 109,5505 },

 { 110,5505 }, { 111,5505 }, { 112,5505 }, { 113,5505 }, { 114,5505 },
 { 115,5505 }, { 116,5505 }, { 117,5505 }, { 118,5505 }, { 119,5505 },
 { 120,5505 }, { 121,5505 }, { 122,5505 }, { 123,5505 }, { 124,5505 },
 { 125,5505 }, { 126,5505 }, { 127,5505 }, { 128,5505 }, { 129,5505 },
 { 130,5505 }, { 131,5505 }, { 132,5505 }, { 133,5505 }, { 134,5505 },
 { 135,5505 }, { 136,5505 }, { 137,5505 }, { 138,5505 }, { 139,5505 },
 { 140,5505 }, { 141,5505 }, { 142,5505 }, { 143,5505 }, { 144,5505 },
 { 145,5505 }, { 146,5505 }, { 147,5505 }, { 148,5505 }, { 149,5505 },
 { 150,5505 }, { 151,5505 }, { 152,5505 }, { 153,5505 }, { 154,5505 },
 { 155,5505 }, { 156,5505 }, { 157,5505 }, { 158,5505 }, { 159,5505 },

 { 160,5505 }, { 161,5505 }, { 162,5505 }, { 163,5505 }, { 164,5505 },
 { 165,5505 }, { 166,5505 }, { 167,5505 }, { 168,5505 }, { 169,5505 },
 { 170,5505 }, { 171,5505 }, { 172,5505 }, { 173,5505 }, { 174,5505 },
 { 175,5505 }, { 176,5505 }, { 177,5505 }, { 178,5505 }, { 179,5505 },
 { 180,5505 }, { 181,5505 }, { 182,5505 }, { 183,5505 }, { 184,5505 },
 { 185,5505 }, { 186,5505 }, { 187,5505 }, { 188,5505 }, { 189,5505 },
 { 190,5505 }, { 191,5505 }, { 192,5505 }, { 193,5505 }, { 194,5505 },
 { 195,5505 }, { 196,5505 }, { 197,5505 }, { 198,5505 }, { 199,5505 },
 { 200,5505 }, { 201,5505 }, { 202,5505 }, { 203,5505 }, { 204,5505 },
 { 205,5505 }, { 206,5505 }, { 207,5505 }, { 208,5505 }, { 209,5505 },

 { 210,5505 }, { 211,5505 }, { 212,5505 }, { 213,5505 }, { 214,5505 },
 { 215,5505 }, { 216,5505 }, { 217,5505 }, { 218,5505 }, { 219,5505 },
 { 220,5505 }, { 221,5505 }, { 222,5505 }, { 223,5505 }, { 224,5505 },
 { 225,5505 }, { 226,5505 }, { 227,5505 }, { 228,5505 }, { 229,5505 },
 { 230,5505 }, { 231,5505 }, { 232,5505 }, { 233,5505 }, { 234,5505 },
 { 235,5505 }, { 236,5505 }, { 237,5505 }, { 238,5505 }, { 239,5505 },
 { 240,5505 }, { 241,5505 }, { 242,5505 }, { 243,5505 }, { 244,5505 },
 { 245,5505 }, { 246,5505 }, { 247,5505 }, { 248,5505 }, { 249,5505 },
 { 250,5505 }, { 251,5505 }, { 252,5505 }, { 253,5505 }, { 254,5505 },
 { 255,5505 }, { 256,5505 }, {   0,  22 }, {   0,13852 }, {   1,5247 },

 {   2,5247 }, {   3,5247 }, {   4,5247 }, {   5,5247 }, {   6,5247 },
 {   7,5247 }, {   8,5247 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {  14,5247 }, {  15,5247 }, {  16,5247 },
 {  17,5247 }, {  18,5247 }, {  19,5247 }, {  20,5247 }, {  21,5247 },
 {  22,5247 }, {  23,5247 }, {  24,5247 }, {  25,5247 }, {  26,5247 },
 {  27,5247 }, {  28,5247 }, {  29,5247 }, {  30,5247 }, {  31,5247 },
 {  32,5247 }, {  33,5247 }, {  34,5247 }, {  35,5247 }, {  36,5247 },
 {  37,5247 }, {  38,5247 }, {   0,   0 }, {  40,5247 }, {  41,5247 },
 {  42,5247 }, {  43,5247 }, {  44,5247 }, {  45,5247 }, {  46,5247 },
 {  47,5247 }, {  48,5247 }, {  49,5247 }, {  50,5247 }, {  51,5247 },

 {  52,5247 }, {  53,5247 }, {  54,5247 }, {  55,5247 }, {  56,5247 },
 {  57,5247 }, {  58,5247 }, {  59,5247 }, {  60,5247 }, {  61,5247 },
 {  62,5247 }, {  63,5247 }, {  64,5247 }, {  65,5247 }, {  66,5247 },
 {  67,5247 }, {  68,5247 }, {  69,5247 }, {  70,5247 }, {  71,5247 },
 {  72,5247 }, {  73,5247 }, {  74,5247 }, {  75,5247 }, {  76,5247 },
 {  77,5247 }, {  78,5247 }, {  79,5247 }, {  80,5247 }, {  81,5247 },
 {  82,5247 }, {  83,5247 }, {  84,5247 }, {  85,5247 }, {  86,5247 },
 {  87,5247 }, {  88,5247 }, {  89,5247 }, {  90,5247 }, {  91,5247 },
 {   0,   0 }, {  93,5247 }, {  94,5247 }, {  95,5247 }, {  96,5247 },
 {  97,5247 }, {  98,5247 }, {  99,5247 }, { 100,5247 }, { 101,5247 },

 { 102,5247 }, { 103,5247 }, { 104,5247 }, { 105,5247 }, { 106,5247 },
 { 107,5247 }, { 108,5247 }, { 109,5247 }, { 110,5247 }, { 111,5247 },
 { 112,5247 }, { 113,5247 }, { 114,5247 }, { 115,5247 }, { 116,5247 },
 { 117,5247 }, { 118,5247 }, { 119,5247 }, { 120,5247 }, { 121,5247 },
 { 122,5247 }, { 123,5247 }, { 124,5247 }, { 125,5247 }, { 126,5247 },
 { 127,5247 }, { 128,5247 }, { 129,5247 }, { 130,5247 }, { 131,5247 },
 { 132,5247 }, { 133,5247 }, { 134,5247 }, { 135,5247 }, { 136,5247 },
 { 137,5247 }, { 138,5247 }, { 139,5247 }, { 140,5247 }, { 141,5247 },
 { 142,5247 }, { 143,5247 }, { 144,5247 }, { 145,5247 }, { 146,5247 },
 { 147,5247 }, { 148,5247 }, { 149,5247 }, { 150,5247 }, { 151,5247 },

 { 152,5247 }, { 153,5247 }, { 154,5247 }, { 155,5247 }, { 156,5247 },
 { 157,5247 }, { 158,5247 }, { 159,5247 }, { 160,5247 }, { 161,5247 },
 { 162,5247 }, { 163,5247 }, { 164,5247 }, { 165,5247 }, { 166,5247 },
 { 167,5247 }, { 168,5247 }, { 169,5247 }, { 170,5247 }, { 171,5247 },
 { 172,5247 }, { 173,5247 }, { 174,5247 }, { 175,5247 }, { 176,5247 },
 { 177,5247 }, { 178,5247 }, { 179,5247 }, { 180,5247 }, { 181,5247 },
 { 182,5247 }, { 183,5247 }, { 184,5247 }, { 185,5247 }, { 186,5247 },
 { 187,5247 }, { 188,5247 }, { 189,5247 }, { 190,5247 }, { 191,5247 },
 { 192,5247 }, { 193,5247 }, { 194,5247 }, { 195,5247 }, { 196,5247 },
 { 197,5247 }, { 198,5247 }, { 199,5247 }, { 200,5247 }, { 201,5247 },

 { 202,5247 }, { 203,5247 }, { 204,5247 }, { 205,5247 }, { 206,5247 },
 { 207,5247 }, { 208,5247 }, { 209,5247 }, { 210,5247 }, { 211,5247 },
 { 212,5247 }, { 213,5247 }, { 214,5247 }, { 215,5247 }, { 216,5247 },
 { 217,5247 }, { 218,5247 }, { 219,5247 }, { 220,5247 }, { 221,5247 },
 { 222,5247 }, { 223,5247 }, { 224,5247 }, { 225,5247 }, { 226,5247 },
 { 227,5247 }, { 228,5247 }, { 229,5247 }, { 230,5247 }, { 231,5247 },
 { 232,5247 }, { 233,5247 }, { 234,5247 }, { 235,5247 }, { 236,5247 },
 { 237,5247 }, { 238,5247 }, { 239,5247 }, { 240,5247 }, { 241,5247 },
 { 242,5247 }, { 243,5247 }, { 244,5247 }, { 245,5247 }, { 246,5247 },
 { 247,5247 }, { 248,5247 }, { 249,5247 }, { 250,5247 }, { 251,5247 },

 { 252,5247 }, { 253,5247 }, { 254,5247 }, { 255,5247 }, { 256,5247 },
 {   0,  31 }, {   0,13594 }, {   1,-4330 }, {   2,-4330 }, {   3,-4330 },
 {   4,-4330 }, {   5,-4330 }, {   6,-4330 }, {   7,-4330 }, {   8,-4330 },
 {   9,-4330 }, {  10,-4330 }, {  11,-4330 }, {  12,-4330 }, {  13,-4330 },
 {  14,-4330 }, {  15,-4330 }, {  16,-4330 }, {  17,-4330 }, {  18,-4330 },
 {  19,-4330 }, {  20,-4330 }, {  21,-4330 }, {  22,-4330 }, {  23,-4330 },
 {  24,-4330 }, {  25,-4330 }, {  26,-4330 }, {  27,-4330 }, {  28,-4330 },
 {  29,-4330 }, {  30,-4330 }, {  31,-4330 }, {  32,-4330 }, {  33,-4330 },
 {  34,-4330 }, {  35,-4330 }, {  36,-4330 }, {  37,-4330 }, {  38,-4330 },
 {  39,-4330 }, {  40,-4330 }, {  41,-4330 }, {  42,-4330 }, {  43,-4330 },

 {  44,-4330 }, {  45,-4330 }, {  46,-4330 }, {  47,-4330 }, {  48,5247 },
 {  49,5247 }, {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 },
 {  54,5247 }, {  55,5247 }, {  56,-4330 }, {  57,-4330 }, {  58,-4330 },
 {  59,-4330 }, {  60,-4330 }, {  61,-4330 }, {  62,-4330 }, {  63,-4330 },
 {  64,-4330 }, {  65,-4330 }, {  66,-4330 }, {  67,-4330 }, {  68,-4330 },
 {  69,-4330 }, {  70,-4330 }, {  71,-4330 }, {  72,-4330 }, {  73,-4330 },
 {  74,-4330 }, {  75,-4330 }, {  76,-4330 }, {  77,-4330 }, {  78,-4330 },
 {  79,-4330 }, {  80,-4330 }, {  81,-4330 }, {  82,-4330 }, {  83,-4330 },
 {  84,-4330 }, {  85,5255 }, {  86,-4330 }, {  87,-4330 }, {  88,-4330 },
 {  89,-4330 }, {  90,-4330 }, {  91,-4330 }, {  92,-4330 }, {  93,-4330 },

 {  94,-4330 }, {  95,-4330 }, {  96,-4330 }, {  97,-4330 }, {  98,-4330 },
 {  99,-4330 }, { 100,-4330 }, { 101,-4330 }, { 102,-4330 }, { 103,-4330 },
 { 104,-4330 }, { 105,-4330 }, { 106,-4330 }, { 107,-4330 }, { 108,-4330 },
 { 109,-4330 }, { 110,-4330 }, { 111,-4330 }, { 112,-4330 }, { 113,-4330 },
 { 114,-4330 }, { 115,-4330 }, { 116,-4330 }, { 117,5278 }, { 118,-4330 },
 { 119,-4330 }, { 120,5316 }, { 121,-4330 }, { 122,-4330 }, { 123,-4330 },
 { 124,-4330 }, { 125,-4330 }, { 126,-4330 }, { 127,-4330 }, { 128,-4330 },
 { 129,-4330 }, { 130,-4330 }, { 131,-4330 }, { 132,-4330 }, { 133,-4330 },
 { 134,-4330 }, { 135,-4330 }, { 136,-4330 }, { 137,-4330 }, { 138,-4330 },
 { 139,-4330 }, { 140,-4330 }, { 141,-4330 }, { 142,-4330 }, { 143,-4330 },

 { 144,-4330 }, { 145,-4330 }, { 146,-4330 }, { 147,-4330 }, { 148,-4330 },
 { 149,-4330 }, { 150,-4330 }, { 151,-4330 }, { 152,-4330 }, { 153,-4330 },
 { 154,-4330 }, { 155,-4330 }, { 156,-4330 }, { 157,-4330 }, { 158,-4330 },
 { 159,-4330 }, { 160,-4330 }, { 161,-4330 }, { 162,-4330 }, { 163,-4330 },
 { 164,-4330 }, { 165,-4330 }, { 166,-4330 }, { 167,-4330 }, { 168,-4330 },
 { 169,-4330 }, { 170,-4330 }, { 171,-4330 }, { 172,-4330 }, { 173,-4330 },
 { 174,-4330 }, { 175,-4330 }, { 176,-4330 }, { 177,-4330 }, { 178,-4330 },
 { 179,-4330 }, { 180,-4330 }, { 181,-4330 }, { 182,-4330 }, { 183,-4330 },
 { 184,-4330 }, { 185,-4330 }, { 186,-4330 }, { 187,-4330 }, { 188,-4330 },
 { 189,-4330 }, { 190,-4330 }, { 191,-4330 }, { 192,-4330 }, { 193,-4330 },

 { 194,-4330 }, { 195,-4330 }, { 196,-4330 }, { 197,-4330 }, { 198,-4330 },
 { 199,-4330 }, { 200,-4330 }, { 201,-4330 }, { 202,-4330 }, { 203,-4330 },
 { 204,-4330 }, { 205,-4330 }, { 206,-4330 }, { 207,-4330 }, { 208,-4330 },
 { 209,-4330 }, { 210,-4330 }, { 211,-4330 }, { 212,-4330 }, { 213,-4330 },
 { 214,-4330 }, { 215,-4330 }, { 216,-4330 }, { 217,-4330 }, { 218,-4330 },
 { 219,-4330 }, { 220,-4330 }, { 221,-4330 }, { 222,-4330 }, { 223,-4330 },
 { 224,-4330 }, { 225,-4330 }, { 226,-4330 }, { 227,-4330 }, { 228,-4330 },
 { 229,-4330 }, { 230,-4330 }, { 231,-4330 }, { 232,-4330 }, { 233,-4330 },
 { 234,-4330 }, { 235,-4330 }, { 236,-4330 }, { 237,-4330 }, { 238,-4330 },
 { 239,-4330 }, { 240,-4330 }, { 241,-4330 }, { 242,-4330 }, { 243,-4330 },

 { 244,-4330 }, { 245,-4330 }, { 246,-4330 }, { 247,-4330 }, { 248,-4330 },
 { 249,-4330 }, { 250,-4330 }, { 251,-4330 }, { 252,-4330 }, { 253,-4330 },
 { 254,-4330 }, { 255,-4330 }, { 256,-4330 }, {   0,  35 }, {   0,13336 },
 {   1,5162 }, {   2,5162 }, {   3,5162 }, {   4,5162 }, {   5,5162 },
 {   6,5162 }, {   7,5162 }, {   8,5162 }, {   9,5162 }, {  10,5162 },
 {  11,5162 }, {  12,5162 }, {  13,5162 }, {  14,5162 }, {  15,5162 },
 {  16,5162 }, {  17,5162 }, {  18,5162 }, {  19,5162 }, {  20,5162 },
 {  21,5162 }, {  22,5162 }, {  23,5162 }, {  24,5162 }, {  25,5162 },
 {  26,5162 }, {  27,5162 }, {  28,5162 }, {  29,5162 }, {  30,5162 },
 {  31,5162 }, {  32,5162 }, {  33,5162 }, {  34,5162 }, {  35,5162 },

 {   0,   0 }, {  37,5162 }, {  38,5162 }, {  39,5162 }, {  40,5162 },
 {  41,5162 }, {  42,5162 }, {  43,5162 }, {  44,5162 }, {  45,5162 },
 {  46,5162 }, {  47,5162 }, {  48,5162 }, {  49,5162 }, {  50,5162 },
 {  51,5162 }, {  52,5162 }, {  53,5162 }, {  54,5162 }, {  55,5162 },
 {  56,5162 }, {  57,5162 }, {  58,5162 }, {  59,5162 }, {  60,5162 },
 {  61,5162 }, {  62,5162 }, {  63,5162 }, {  64,5162 }, {  65,5162 },
 {  66,5162 }, {  67,5162 }, {  68,5162 }, {  69,5162 }, {  70,5162 },
 {  71,5162 }, {  72,5162 }, {  73,5162 }, {  74,5162 }, {  75,5162 },
 {  76,5162 }, {  77,5162 }, {  78,5162 }, {  79,5162 }, {  80,5162 },
 {  81,5162 }, {  82,5162 }, {  83,5162 }, {  84,5162 }, {  85,5162 },

 {  86,5162 }, {  87,5162 }, {  88,5162 }, {  89,5162 }, {  90,5162 },
 {  91,5162 }, {  92,5162 }, {  93,5162 }, {  94,5162 }, {  95,5162 },
 {  96,5162 }, {  97,5162 }, {  98,5162 }, {  99,5162 }, { 100,5162 },
 { 101,5162 }, { 102,5162 }, { 103,5162 }, { 104,5162 }, { 105,5162 },
 { 106,5162 }, { 107,5162 }, { 108,5162 }, { 109,5162 }, { 110,5162 },
 { 111,5162 }, { 112,5162 }, { 113,5162 }, { 114,5162 }, { 115,5162 },
 { 116,5162 }, { 117,5162 }, { 118,5162 }, { 119,5162 }, { 120,5162 },
 { 121,5162 }, { 122,5162 }, { 123,5162 }, { 124,5162 }, { 125,5162 },
 { 126,5162 }, { 127,5162 }, { 128,5162 }, { 129,5162 }, { 130,5162 },
 { 131,5162 }, { 132,5162 }, { 133,5162 }, { 134,5162 }, { 135,5162 },

 { 136,5162 }, { 137,5162 }, { 138,5162 }, { 139,5162 }, { 140,5162 },
 { 141,5162 }, { 142,5162 }, { 143,5162 }, { 144,5162 }, { 145,5162 },
 { 146,5162 }, { 147,5162 }, { 148,5162 }, { 149,5162 }, { 150,5162 },
 { 151,5162 }, { 152,5162 }, { 153,5162 }, { 154,5162 }, { 155,5162 },
 { 156,5162 }, { 157,5162 }, { 158,5162 }, { 159,5162 }, { 160,5162 },
 { 161,5162 }, { 162,5162 }, { 163,5162 }, { 164,5162 }, { 165,5162 },
 { 166,5162 }, { 167,5162 }, { 168,5162 }, { 169,5162 }, { 170,5162 },
 { 171,5162 }, { 172,5162 }, { 173,5162 }, { 174,5162 }, { 175,5162 },
 { 176,5162 }, { 177,5162 }, { 178,5162 }, { 179,5162 }, { 180,5162 },
 { 181,5162 }, { 182,5162 }, { 183,5162 }, { 184,5162 }, { 185,5162 },

 { 186,5162 }, { 187,5162 }, { 188,5162 }, { 189,5162 }, { 190,5162 },
 { 191,5162 }, { 192,5162 }, { 193,5162 }, { 194,5162 }, { 195,5162 },
 { 196,5162 }, { 197,5162 }, { 198,5162 }, { 199,5162 }, { 200,5162 },
 { 201,5162 }, { 202,5162 }, { 203,5162 }, { 204,5162 }, { 205,5162 },
 { 206,5162 }, { 207,5162 }, { 208,5162 }, { 209,5162 }, { 210,5162 },
 { 211,5162 }, { 212,5162 }, { 213,5162 }, { 214,5162 }, { 215,5162 },
 { 216,5162 }, { 217,5162 }, { 218,5162 }, { 219,5162 }, { 220,5162 },
 { 221,5162 }, { 222,5162 }, { 223,5162 }, { 224,5162 }, { 225,5162 },
 { 226,5162 }, { 227,5162 }, { 228,5162 }, { 229,5162 }, { 230,5162 },
 { 231,5162 }, { 232,5162 }, { 233,5162 }, { 234,5162 }, { 235,5162 },

 { 236,5162 }, { 237,5162 }, { 238,5162 }, { 239,5162 }, { 240,5162 },
 { 241,5162 }, { 242,5162 }, { 243,5162 }, { 244,5162 }, { 245,5162 },
 { 246,5162 }, { 247,5162 }, { 248,5162 }, { 249,5162 }, { 250,5162 },
 { 251,5162 }, { 252,5162 }, { 253,5162 }, { 254,5162 }, { 255,5162 },
 { 256,5162 }, {   0,  35 }, {   0,13078 }, {   1,4904 }, {   2,4904 },
 {   3,4904 }, {   4,4904 }, {   5,4904 }, {   6,4904 }, {   7,4904 },
 {   8,4904 }, {   9,4904 }, {  10,4904 }, {  11,4904 }, {  12,4904 },
 {  13,4904 }, {  14,4904 }, {  15,4904 }, {  16,4904 }, {  17,4904 },
 {  18,4904 }, {  19,4904 }, {  20,4904 }, {  21,4904 }, {  22,4904 },
 {  23,4904 }, {  24,4904 }, {  25,4904 }, {  26,4904 }, {  27,4904 },

 {  28,4904 }, {  29,4904 }, {  30,4904 }, {  31,4904 }, {  32,4904 },
 {  33,4904 }, {  34,4904 }, {  35,4904 }, {   0,   0 }, {  37,4904 },
 {  38,4904 }, {  39,4904 }, {  40,4904 }, {  41,4904 }, {  42,4904 },
 {  43,4904 }, {  44,4904 }, {  45,4904 }, {  46,4904 }, {  47,4904 },
 {  48,4904 }, {  49,4904 }, {  50,4904 }, {  51,4904 }, {  52,4904 },
 {  53,4904 }, {  54,4904 }, {  55,4904 }, {  56,4904 }, {  57,4904 },
 {  58,4904 }, {  59,4904 }, {  60,4904 }, {  61,4904 }, {  62,4904 },
 {  63,4904 }, {  64,4904 }, {  65,4904 }, {  66,4904 }, {  67,4904 },
 {  68,4904 }, {  69,4904 }, {  70,4904 }, {  71,4904 }, {  72,4904 },
 {  73,4904 }, {  74,4904 }, {  75,4904 }, {  76,4904 }, {  77,4904 },

 {  78,4904 }, {  79,4904 }, {  80,4904 }, {  81,4904 }, {  82,4904 },
 {  83,4904 }, {  84,4904 }, {  85,4904 }, {  86,4904 }, {  87,4904 },
 {  88,4904 }, {  89,4904 }, {  90,4904 }, {  91,4904 }, {  92,4904 },
 {  93,4904 }, {  94,4904 }, {  95,4904 }, {  96,4904 }, {  97,4904 },
 {  98,4904 }, {  99,4904 }, { 100,4904 }, { 101,4904 }, { 102,4904 },
 { 103,4904 }, { 104,4904 }, { 105,4904 }, { 106,4904 }, { 107,4904 },
 { 108,4904 }, { 109,4904 }, { 110,4904 }, { 111,4904 }, { 112,4904 },
 { 113,4904 }, { 114,4904 }, { 115,4904 }, { 116,4904 }, { 117,4904 },
 { 118,4904 }, { 119,4904 }, { 120,4904 }, { 121,4904 }, { 122,4904 },
 { 123,4904 }, { 124,4904 }, { 125,4904 }, { 126,4904 }, { 127,4904 },

 { 128,4904 }, { 129,4904 }, { 130,4904 }, { 131,4904 }, { 132,4904 },
 { 133,4904 }, { 134,4904 }, { 135,4904 }, { 136,4904 }, { 137,4904 },
 { 138,4904 }, { 139,4904 }, { 140,4904 }, { 141,4904 }, { 142,4904 },
 { 143,4904 }, { 144,4904 }, { 145,4904 }, { 146,4904 }, { 147,4904 },
 { 148,4904 }, { 149,4904 }, { 150,4904 }, { 151,4904 }, { 152,4904 },
 { 153,4904 }, { 154,4904 }, { 155,4904 }, { 156,4904 }, { 157,4904 },
 { 158,4904 }, { 159,4904 }, { 160,4904 }, { 161,4904 }, { 162,4904 },
 { 163,4904 }, { 164,4904 }, { 165,4904 }, { 166,4904 }, { 167,4904 },
 { 168,4904 }, { 169,4904 }, { 170,4904 }, { 171,4904 }, { 172,4904 },
 { 173,4904 }, { 174,4904 }, { 175,4904 }, { 176,4904 }, { 177,4904 },

 { 178,4904 }, { 179,4904 }, { 180,4904 }, { 181,4904 }, { 182,4904 },
 { 183,4904 }, { 184,4904 }, { 185,4904 }, { 186,4904 }, { 187,4904 },
 { 188,4904 }, { 189,4904 }, { 190,4904 }, { 191,4904 }, { 192,4904 },
 { 193,4904 }, { 194,4904 }, { 195,4904 }, { 196,4904 }, { 197,4904 },
 { 198,4904 }, { 199,4904 }, { 200,4904 }, { 201,4904 }, { 202,4904 },
 { 203,4904 }, { 204,4904 }, { 205,4904 }, { 206,4904 }, { 207,4904 },
 { 208,4904 }, { 209,4904 }, { 210,4904 }, { 211,4904 }, { 212,4904 },
 { 213,4904 }, { 214,4904 }, { 215,4904 }, { 216,4904 }, { 217,4904 },
 { 218,4904 }, { 219,4904 }, { 220,4904 }, { 221,4904 }, { 222,4904 },
 { 223,4904 }, { 224,4904 }, { 225,4904 }, { 226,4904 }, { 227,4904 },

 { 228,4904 }, { 229,4904 }, { 230,4904 }, { 231,4904 }, { 232,4904 },
 { 233,4904 }, { 234,4904 }, { 235,4904 }, { 236,4904 }, { 237,4904 },
 { 238,4904 }, { 239,4904 }, { 240,4904 }, { 241,4904 }, { 242,4904 },
 { 243,4904 }, { 244,4904 }, { 245,4904 }, { 246,4904 }, { 247,4904 },
 { 248,4904 }, { 249,4904 }, { 250,4904 }, { 251,4904 }, { 252,4904 },
 { 253,4904 }, { 254,4904 }, { 255,4904 }, { 256,4904 }, {   0,  37 },
 {   0,12820 }, {   0,   1 }, {   0,12818 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 },
 {  13,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  32,   0 },
 {   0,   0 }, {  36,-5102 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,4904 }, {  66,4904 }, {  67,4904 }, {  68,4904 }, {  69,4904 },

 {  70,4904 }, {  71,4904 }, {  72,4904 }, {  73,4904 }, {  74,4904 },
 {  75,4904 }, {  76,4904 }, {  77,4904 }, {  78,4904 }, {  79,4904 },
 {  80,4904 }, {  81,4904 }, {  82,4904 }, {  83,4904 }, {  84,4904 },
 {  85,4904 }, {  86,4904 }, {  87,4904 }, {  88,4904 }, {  89,4904 },
 {  90,4904 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,4904 }, {   0,   0 }, {  97,4904 }, {  98,4904 }, {  99,4904 },
 { 100,4904 }, { 101,4904 }, { 102,4904 }, { 103,4904 }, { 104,4904 },
 { 105,4904 }, { 106,4904 }, { 107,4904 }, { 108,4904 }, { 109,4904 },
 { 110,4904 }, { 111,4904 }, { 112,4904 }, { 113,4904 }, { 114,4904 },
 { 115,4904 }, { 116,4904 }, { 117,4904 }, { 118,4904 }, { 119,4904 },

 { 120,4904 }, { 121,4904 }, { 122,4904 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,4904 }, { 129,4904 },
 { 130,4904 }, { 131,4904 }, { 132,4904 }, { 133,4904 }, { 134,4904 },
 { 135,4904 }, { 136,4904 }, { 137,4904 }, { 138,4904 }, { 139,4904 },
 { 140,4904 }, { 141,4904 }, { 142,4904 }, { 143,4904 }, { 144,4904 },
 { 145,4904 }, { 146,4904 }, { 147,4904 }, { 148,4904 }, { 149,4904 },
 { 150,4904 }, { 151,4904 }, { 152,4904 }, { 153,4904 }, { 154,4904 },
 { 155,4904 }, { 156,4904 }, { 157,4904 }, { 158,4904 }, { 159,4904 },
 { 160,4904 }, { 161,4904 }, { 162,4904 }, { 163,4904 }, { 164,4904 },
 { 165,4904 }, { 166,4904 }, { 167,4904 }, { 168,4904 }, { 169,4904 },

 { 170,4904 }, { 171,4904 }, { 172,4904 }, { 173,4904 }, { 174,4904 },
 { 175,4904 }, { 176,4904 }, { 177,4904 }, { 178,4904 }, { 179,4904 },
 { 180,4904 }, { 181,4904 }, { 182,4904 }, { 183,4904 }, { 184,4904 },
 { 185,4904 }, { 186,4904 }, { 187,4904 }, { 188,4904 }, { 189,4904 },
 { 190,4904 }, { 191,4904 }, { 192,4904 }, { 193,4904 }, { 194,4904 },
 { 195,4904 }, { 196,4904 }, { 197,4904 }, { 198,4904 }, { 199,4904 },
 { 200,4904 }, { 201,4904 }, { 202,4904 }, { 203,4904 }, { 204,4904 },
 { 205,4904 }, { 206,4904 }, { 207,4904 }, { 208,4904 }, { 209,4904 },
 { 210,4904 }, { 211,4904 }, { 212,4904 }, { 213,4904 }, { 214,4904 },
 { 215,4904 }, { 216,4904 }, { 217,4904 }, { 218,4904 }, { 219,4904 },

 { 220,4904 }, { 221,4904 }, { 222,4904 }, { 223,4904 }, { 224,4904 },
 { 225,4904 }, { 226,4904 }, { 227,4904 }, { 228,4904 }, { 229,4904 },
 { 230,4904 }, { 231,4904 }, { 232,4904 }, { 233,4904 }, { 234,4904 },
 { 235,4904 }, { 236,4904 }, { 237,4904 }, { 238,4904 }, { 239,4904 },
 { 240,4904 }, { 241,4904 }, { 242,4904 }, { 243,4904 }, { 244,4904 },
 { 245,4904 }, { 246,4904 }, { 247,4904 }, { 248,4904 }, { 249,4904 },
 { 250,4904 }, { 251,4904 }, { 252,4904 }, { 253,4904 }, { 254,4904 },
 { 255,4904 }, {   0,  54 }, {   0,12563 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  52 }, {   0,12552 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  33,   0 }, {   0,   0 }, {  35,   0 }, {   0,   0 }, {  37,   0 },
 {  38,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,   0 },
 {  43,   0 }, {  33, -11 }, {  45,   0 }, {  35, -11 }, {  47,   0 },
 {  37, -11 }, {  38, -11 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42, -11 }, {  43, -11 }, {   0,   0 }, {  45, -11 }, {   0,   0 },
 {  47, -11 }, {   0,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 },

 {  63,   0 }, {  64,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60, -11 }, {  61, -11 },
 {  62, -11 }, {  63, -11 }, {  64, -11 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  55 }, {   0,12473 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,   0 }, {   0,   0 }, {  96,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94, -11 }, {   0,   0 }, {  96, -11 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 124,   0 }, {   0,   0 }, { 126,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 124, -11 }, {   0,   0 }, { 126, -11 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-5446 }, {  66,-5446 }, {  67,-5446 },
 {  68,-5446 }, {  69,-5446 }, {  70,-5446 }, {  71,-5446 }, {  72,-5446 },

 {  73,-5446 }, {  74,-5446 }, {  75,-5446 }, {  76,-5446 }, {  77,-5446 },
 {  78,-5446 }, {  79,-5446 }, {  80,-5446 }, {  81,-5446 }, {  82,-5446 },
 {  83,-5446 }, {  84,-5446 }, {  85,-5446 }, {  86,-5446 }, {  87,-5446 },
 {  88,-5446 }, {  89,-5446 }, {  90,-5446 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,-5446 }, {   0,   0 }, {  97,-5446 },
 {  98,-5446 }, {  99,-5446 }, { 100,-5446 }, { 101,-5446 }, { 102,-5446 },
 { 103,-5446 }, { 104,-5446 }, { 105,-5446 }, { 106,-5446 }, { 107,-5446 },
 { 108,-5446 }, { 109,-5446 }, { 110,-5446 }, { 111,-5446 }, { 112,-5446 },
 { 113,-5446 }, { 114,-5446 }, { 115,-5446 }, { 116,-5446 }, { 117,-5446 },
 { 118,-5446 }, { 119,-5446 }, { 120,-5446 }, { 121,-5446 }, { 122,-5446 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-5446 }, { 129,-5446 }, { 130,-5446 }, { 131,-5446 }, { 132,-5446 },
 { 133,-5446 }, { 134,-5446 }, { 135,-5446 }, { 136,-5446 }, { 137,-5446 },
 { 138,-5446 }, { 139,-5446 }, { 140,-5446 }, { 141,-5446 }, { 142,-5446 },
 { 143,-5446 }, { 144,-5446 }, { 145,-5446 }, { 146,-5446 }, { 147,-5446 },
 { 148,-5446 }, { 149,-5446 }, { 150,-5446 }, { 151,-5446 }, { 152,-5446 },
 { 153,-5446 }, { 154,-5446 }, { 155,-5446 }, { 156,-5446 }, { 157,-5446 },
 { 158,-5446 }, { 159,-5446 }, { 160,-5446 }, { 161,-5446 }, { 162,-5446 },
 { 163,-5446 }, { 164,-5446 }, { 165,-5446 }, { 166,-5446 }, { 167,-5446 },
 { 168,-5446 }, { 169,-5446 }, { 170,-5446 }, { 171,-5446 }, { 172,-5446 },

 { 173,-5446 }, { 174,-5446 }, { 175,-5446 }, { 176,-5446 }, { 177,-5446 },
 { 178,-5446 }, { 179,-5446 }, { 180,-5446 }, { 181,-5446 }, { 182,-5446 },
 { 183,-5446 }, { 184,-5446 }, { 185,-5446 }, { 186,-5446 }, { 187,-5446 },
 { 188,-5446 }, { 189,-5446 }, { 190,-5446 }, { 191,-5446 }, { 192,-5446 },
 { 193,-5446 }, { 194,-5446 }, { 195,-5446 }, { 196,-5446 }, { 197,-5446 },
 { 198,-5446 }, { 199,-5446 }, { 200,-5446 }, { 201,-5446 }, { 202,-5446 },
 { 203,-5446 }, { 204,-5446 }, { 205,-5446 }, { 206,-5446 }, { 207,-5446 },
 { 208,-5446 }, { 209,-5446 }, { 210,-5446 }, { 211,-5446 }, { 212,-5446 },
 { 213,-5446 }, { 214,-5446 }, { 215,-5446 }, { 216,-5446 }, { 217,-5446 },
 { 218,-5446 }, { 219,-5446 }, { 220,-5446 }, { 221,-5446 }, { 222,-5446 },

 { 223,-5446 }, { 224,-5446 }, { 225,-5446 }, { 226,-5446 }, { 227,-5446 },
 { 228,-5446 }, { 229,-5446 }, { 230,-5446 }, { 231,-5446 }, { 232,-5446 },
 { 233,-5446 }, { 234,-5446 }, { 235,-5446 }, { 236,-5446 }, { 237,-5446 },
 { 238,-5446 }, { 239,-5446 }, { 240,-5446 }, { 241,-5446 }, { 242,-5446 },
 { 243,-5446 }, { 244,-5446 }, { 245,-5446 }, { 246,-5446 }, { 247,-5446 },
 { 248,-5446 }, { 249,-5446 }, { 250,-5446 }, { 251,-5446 }, { 252,-5446 },
 { 253,-5446 }, { 254,-5446 }, { 255,-5446 }, {   0,  33 }, {   0,12216 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,-6066 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,4639 }, {  49,4639 }, {  50,4639 },
 {  51,4639 }, {  52,4639 }, {  53,4639 }, {  54,4639 }, {  55,4639 },
 {  56,4639 }, {  57,4639 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4639 },

 {  66,4639 }, {  67,4639 }, {  68,4639 }, {  69,4639 }, {  70,4639 },
 {  71,4639 }, {  72,4639 }, {  73,4639 }, {  74,4639 }, {  75,4639 },
 {  76,4639 }, {  77,4639 }, {  78,4639 }, {  79,4639 }, {  80,4639 },
 {  81,4639 }, {  82,4639 }, {  83,4639 }, {  84,4639 }, {  85,4639 },
 {  86,4639 }, {  87,4639 }, {  88,4639 }, {  89,4639 }, {  90,4639 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,4639 },
 {   0,   0 }, {  97,4639 }, {  98,4639 }, {  99,4639 }, { 100,4639 },
 { 101,4639 }, { 102,4639 }, { 103,4639 }, { 104,4639 }, { 105,4639 },
 { 106,4639 }, { 107,4639 }, { 108,4639 }, { 109,4639 }, { 110,4639 },
 { 111,4639 }, { 112,4639 }, { 113,4639 }, { 114,4639 }, { 115,4639 },

 { 116,4639 }, { 117,4639 }, { 118,4639 }, { 119,4639 }, { 120,4639 },
 { 121,4639 }, { 122,4639 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,4639 }, { 129,4639 }, { 130,4639 },
 { 131,4639 }, { 132,4639 }, { 133,4639 }, { 134,4639 }, { 135,4639 },
 { 136,4639 }, { 137,4639 }, { 138,4639 }, { 139,4639 }, { 140,4639 },
 { 141,4639 }, { 142,4639 }, { 143,4639 }, { 144,4639 }, { 145,4639 },
 { 146,4639 }, { 147,4639 }, { 148,4639 }, { 149,4639 }, { 150,4639 },
 { 151,4639 }, { 152,4639 }, { 153,4639 }, { 154,4639 }, { 155,4639 },
 { 156,4639 }, { 157,4639 }, { 158,4639 }, { 159,4639 }, { 160,4639 },
 { 161,4639 }, { 162,4639 }, { 163,4639 }, { 164,4639 }, { 165,4639 },

 { 166,4639 }, { 167,4639 }, { 168,4639 }, { 169,4639 }, { 170,4639 },
 { 171,4639 }, { 172,4639 }, { 173,4639 }, { 174,4639 }, { 175,4639 },
 { 176,4639 }, { 177,4639 }, { 178,4639 }, { 179,4639 }, { 180,4639 },
 { 181,4639 }, { 182,4639 }, { 183,4639 }, { 184,4639 }, { 185,4639 },
 { 186,4639 }, { 187,4639 }, { 188,4639 }, { 189,4639 }, { 190,4639 },
 { 191,4639 }, { 192,4639 }, { 193,4639 }, { 194,4639 }, { 195,4639 },
 { 196,4639 }, { 197,4639 }, { 198,4639 }, { 199,4639 }, { 200,4639 },
 { 201,4639 }, { 202,4639 }, { 203,4639 }, { 204,4639 }, { 205,4639 },
 { 206,4639 }, { 207,4639 }, { 208,4639 }, { 209,4639 }, { 210,4639 },
 { 211,4639 }, { 212,4639 }, { 213,4639 }, { 214,4639 }, { 215,4639 },

 { 216,4639 }, { 217,4639 }, { 218,4639 }, { 219,4639 }, { 220,4639 },
 { 221,4639 }, { 222,4639 }, { 223,4639 }, { 224,4639 }, { 225,4639 },
 { 226,4639 }, { 227,4639 }, { 228,4639 }, { 229,4639 }, { 230,4639 },
 { 231,4639 }, { 232,4639 }, { 233,4639 }, { 234,4639 }, { 235,4639 },
 { 236,4639 }, { 237,4639 }, { 238,4639 }, { 239,4639 }, { 240,4639 },
 { 241,4639 }, { 242,4639 }, { 243,4639 }, { 244,4639 }, { 245,4639 },
 { 246,4639 }, { 247,4639 }, { 248,4639 }, { 249,4639 }, { 250,4639 },
 { 251,4639 }, { 252,4639 }, { 253,4639 }, { 254,4639 }, { 255,4639 },
 {   0,   1 }, {   0,11959 }, {   1,4639 }, {   2,4639 }, {   3,4639 },
 {   4,4639 }, {   5,4639 }, {   6,4639 }, {   7,4639 }, {   8,4639 },

 {   9,4639 }, {   0,   0 }, {  11,4639 }, {  12,4639 }, {   0,   0 },
 {  14,4639 }, {  15,4639 }, {  16,4639 }, {  17,4639 }, {  18,4639 },
 {  19,4639 }, {  20,4639 }, {  21,4639 }, {  22,4639 }, {  23,4639 },
 {  24,4639 }, {  25,4639 }, {  26,4639 }, {  27,4639 }, {  28,4639 },
 {  29,4639 }, {  30,4639 }, {  31,4639 }, {  32,4639 }, {  33,4897 },
 {  34,4639 }, {  35,4897 }, {  36,4639 }, {  37,4897 }, {  38,4897 },
 {  39,4639 }, {  40,4639 }, {  41,4639 }, {  42,4897 }, {  43,4897 },
 {  44,4639 }, {  45,4897 }, {  46,4639 }, {  47,4897 }, {  48,4639 },
 {  49,4639 }, {  50,4639 }, {  51,4639 }, {  52,4639 }, {  53,4639 },
 {  54,4639 }, {  55,4639 }, {  56,4639 }, {  57,4639 }, {  58,4639 },

 {  59,4639 }, {  60,4897 }, {  61,4897 }, {  62,4897 }, {  63,4897 },
 {  64,4897 }, {  65,4639 }, {  66,4639 }, {  67,4639 }, {  68,4639 },
 {  69,4639 }, {  70,4639 }, {  71,4639 }, {  72,4639 }, {  73,4639 },
 {  74,4639 }, {  75,4639 }, {  76,4639 }, {  77,4639 }, {  78,4639 },
 {  79,4639 }, {  80,4639 }, {  81,4639 }, {  82,4639 }, {  83,4639 },
 {  84,4639 }, {  85,4639 }, {  86,4639 }, {  87,4639 }, {  88,4639 },
 {  89,4639 }, {  90,4639 }, {  91,4639 }, {  92,4639 }, {  93,4639 },
 {  94,4897 }, {  95,4639 }, {  96,4897 }, {  97,4639 }, {  98,4639 },
 {  99,4639 }, { 100,4639 }, { 101,4639 }, { 102,4639 }, { 103,4639 },
 { 104,4639 }, { 105,4639 }, { 106,4639 }, { 107,4639 }, { 108,4639 },

 { 109,4639 }, { 110,4639 }, { 111,4639 }, { 112,4639 }, { 113,4639 },
 { 114,4639 }, { 115,4639 }, { 116,4639 }, { 117,4639 }, { 118,4639 },
 { 119,4639 }, { 120,4639 }, { 121,4639 }, { 122,4639 }, { 123,4639 },
 { 124,4897 }, { 125,4639 }, { 126,4897 }, { 127,4639 }, { 128,4639 },
 { 129,4639 }, { 130,4639 }, { 131,4639 }, { 132,4639 }, { 133,4639 },
 { 134,4639 }, { 135,4639 }, { 136,4639 }, { 137,4639 }, { 138,4639 },
 { 139,4639 }, { 140,4639 }, { 141,4639 }, { 142,4639 }, { 143,4639 },
 { 144,4639 }, { 145,4639 }, { 146,4639 }, { 147,4639 }, { 148,4639 },
 { 149,4639 }, { 150,4639 }, { 151,4639 }, { 152,4639 }, { 153,4639 },
 { 154,4639 }, { 155,4639 }, { 156,4639 }, { 157,4639 }, { 158,4639 },

 { 159,4639 }, { 160,4639 }, { 161,4639 }, { 162,4639 }, { 163,4639 },
 { 164,4639 }, { 165,4639 }, { 166,4639 }, { 167,4639 }, { 168,4639 },
 { 169,4639 }, { 170,4639 }, { 171,4639 }, { 172,4639 }, { 173,4639 },
 { 174,4639 }, { 175,4639 }, { 176,4639 }, { 177,4639 }, { 178,4639 },
 { 179,4639 }, { 180,4639 }, { 181,4639 }, { 182,4639 }, { 183,4639 },
 { 184,4639 }, { 185,4639 }, { 186,4639 }, { 187,4639 }, { 188,4639 },
 { 189,4639 }, { 190,4639 }, { 191,4639 }, { 192,4639 }, { 193,4639 },
 { 194,4639 }, { 195,4639 }, { 196,4639 }, { 197,4639 }, { 198,4639 },
 { 199,4639 }, { 200,4639 }, { 201,4639 }, { 202,4639 }, { 203,4639 },
 { 204,4639 }, { 205,4639 }, { 206,4639 }, { 207,4639 }, { 208,4639 },

 { 209,4639 }, { 210,4639 }, { 211,4639 }, { 212,4639 }, { 213,4639 },
 { 214,4639 }, { 215,4639 }, { 216,4639 }, { 217,4639 }, { 218,4639 },
 { 219,4639 }, { 220,4639 }, { 221,4639 }, { 222,4639 }, { 223,4639 },
 { 224,4639 }, { 225,4639 }, { 226,4639 }, { 227,4639 }, { 228,4639 },
 { 229,4639 }, { 230,4639 }, { 231,4639 }, { 232,4639 }, { 233,4639 },
 { 234,4639 }, { 235,4639 }, { 236,4639 }, { 237,4639 }, { 238,4639 },
 { 239,4639 }, { 240,4639 }, { 241,4639 }, { 242,4639 }, { 243,4639 },
 { 244,4639 }, { 245,4639 }, { 246,4639 }, { 247,4639 }, { 248,4639 },
 { 249,4639 }, { 250,4639 }, { 251,4639 }, { 252,4639 }, { 253,4639 },
 { 254,4639 }, { 255,4639 }, { 256,4639 }, {   0,  64 }, {   0,11701 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,4897 }, {  49,4897 }, {  50,4897 },

 {  51,4897 }, {  52,4897 }, {  53,4897 }, {  54,4897 }, {  55,4897 },
 {  56,4897 }, {  57,4897 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-6216 },
 {  66,-6216 }, {  67,-6216 }, {  68,-6216 }, {  69,5154 }, {  70,-6216 },
 {  71,-6216 }, {  72,-6216 }, {  73,-6216 }, {  74,-6216 }, {  75,-6216 },
 {  76,-6216 }, {  77,-6216 }, {  78,-6216 }, {  79,-6216 }, {  80,-6216 },
 {  81,-6216 }, {  82,-6216 }, {  83,-6216 }, {  84,-6216 }, {  85,-6216 },
 {  86,-6216 }, {  87,-6216 }, {  88,-6216 }, {  89,-6216 }, {  90,-6216 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,5164 },
 {   0,   0 }, {  97,-6216 }, {  98,-6216 }, {  99,-6216 }, { 100,-6216 },

 { 101,5154 }, { 102,-6216 }, { 103,-6216 }, { 104,-6216 }, { 105,-6216 },
 { 106,-6216 }, { 107,-6216 }, { 108,-6216 }, { 109,-6216 }, { 110,-6216 },
 { 111,-6216 }, { 112,-6216 }, { 113,-6216 }, { 114,-6216 }, { 115,-6216 },
 { 116,-6216 }, { 117,-6216 }, { 118,-6216 }, { 119,-6216 }, { 120,-6216 },
 { 121,-6216 }, { 122,-6216 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,-6216 }, { 129,-6216 }, { 130,-6216 },
 { 131,-6216 }, { 132,-6216 }, { 133,-6216 }, { 134,-6216 }, { 135,-6216 },
 { 136,-6216 }, { 137,-6216 }, { 138,-6216 }, { 139,-6216 }, { 140,-6216 },
 { 141,-6216 }, { 142,-6216 }, { 143,-6216 }, { 144,-6216 }, { 145,-6216 },
 { 146,-6216 }, { 147,-6216 }, { 148,-6216 }, { 149,-6216 }, { 150,-6216 },

 { 151,-6216 }, { 152,-6216 }, { 153,-6216 }, { 154,-6216 }, { 155,-6216 },
 { 156,-6216 }, { 157,-6216 }, { 158,-6216 }, { 159,-6216 }, { 160,-6216 },
 { 161,-6216 }, { 162,-6216 }, { 163,-6216 }, { 164,-6216 }, { 165,-6216 },
 { 166,-6216 }, { 167,-6216 }, { 168,-6216 }, { 169,-6216 }, { 170,-6216 },
 { 171,-6216 }, { 172,-6216 }, { 173,-6216 }, { 174,-6216 }, { 175,-6216 },
 { 176,-6216 }, { 177,-6216 }, { 178,-6216 }, { 179,-6216 }, { 180,-6216 },
 { 181,-6216 }, { 182,-6216 }, { 183,-6216 }, { 184,-6216 }, { 185,-6216 },
 { 186,-6216 }, { 187,-6216 }, { 188,-6216 }, { 189,-6216 }, { 190,-6216 },
 { 191,-6216 }, { 192,-6216 }, { 193,-6216 }, { 194,-6216 }, { 195,-6216 },
 { 196,-6216 }, { 197,-6216 }, { 198,-6216 }, { 199,-6216 }, { 200,-6216 },

 { 201,-6216 }, { 202,-6216 }, { 203,-6216 }, { 204,-6216 }, { 205,-6216 },
 { 206,-6216 }, { 207,-6216 }, { 208,-6216 }, { 209,-6216 }, { 210,-6216 },
 { 211,-6216 }, { 212,-6216 }, { 213,-6216 }, { 214,-6216 }, { 215,-6216 },
 { 216,-6216 }, { 217,-6216 }, { 218,-6216 }, { 219,-6216 }, { 220,-6216 },
 { 221,-6216 }, { 222,-6216 }, { 223,-6216 }, { 224,-6216 }, { 225,-6216 },
 { 226,-6216 }, { 227,-6216 }, { 228,-6216 }, { 229,-6216 }, { 230,-6216 },
 { 231,-6216 }, { 232,-6216 }, { 233,-6216 }, { 234,-6216 }, { 235,-6216 },
 { 236,-6216 }, { 237,-6216 }, { 238,-6216 }, { 239,-6216 }, { 240,-6216 },
 { 241,-6216 }, { 242,-6216 }, { 243,-6216 }, { 244,-6216 }, { 245,-6216 },
 { 246,-6216 }, { 247,-6216 }, { 248,-6216 }, { 249,-6216 }, { 250,-6216 },

 { 251,-6216 }, { 252,-6216 }, { 253,-6216 }, { 254,-6216 }, { 255,-6216 },
 {   0,   2 }, {   0,11444 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  64 }, {   0,11412 }, {  33,4932 },
 {   0,   0 }, {  35,4932 }, {   0,   0 }, {  37,4932 }, {  38,4932 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,4932 }, {  43,4932 },

 {   0,   0 }, {  45,4932 }, {   0,   0 }, {  47,4932 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  60,4932 }, {  61,4932 }, {  62,4932 }, {  63,4932 },
 {  64,4932 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,-6503 },
 {   0,   0 }, {  48,4966 }, {  49,4966 }, {  50,4966 }, {  51,4966 },
 {  52,4966 }, {  53,4966 }, {  54,4966 }, {  55,4966 }, {  56,4966 },
 {  57,4966 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  94,4932 }, {   0,   0 }, {  96,4932 }, {  65,-6505 }, {  66,-6505 },
 {  67,-6505 }, {  68,-6505 }, {  69,4865 }, {  70,-6505 }, {  71,-6505 },
 {  72,-6505 }, {  73,-6505 }, {  74,-6505 }, {  75,-6505 }, {  76,-6505 },
 {  77,-6505 }, {  78,-6505 }, {  79,-6505 }, {  80,-6505 }, {  81,-6505 },
 {  82,-6505 }, {  83,-6505 }, {  84,-6505 }, {  85,-6505 }, {  86,-6505 },
 {  87,-6505 }, {  88,-6505 }, {  89,-6505 }, {  90,-6505 }, {   0,   0 },
 { 124,4932 }, {   0,   0 }, { 126,4932 }, {  95,-6505 }, {   0,   0 },
 {  97,-6505 }, {  98,-6505 }, {  99,-6505 }, { 100,-6505 }, { 101,4865 },
 { 102,-6505 }, { 103,-6505 }, { 104,-6505 }, { 105,-6505 }, { 106,-6505 },
 { 107,-6505 }, { 108,-6505 }, { 109,-6505 }, { 110,-6505 }, { 111,-6505 },

 { 112,-6505 }, { 113,-6505 }, { 114,-6505 }, { 115,-6505 }, { 116,-6505 },
 { 117,-6505 }, { 118,-6505 }, { 119,-6505 }, { 120,-6505 }, { 121,-6505 },
 { 122,-6505 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,-6505 }, { 129,-6505 }, { 130,-6505 }, { 131,-6505 },
 { 132,-6505 }, { 133,-6505 }, { 134,-6505 }, { 135,-6505 }, { 136,-6505 },
 { 137,-6505 }, { 138,-6505 }, { 139,-6505 }, { 140,-6505 }, { 141,-6505 },
 { 142,-6505 }, { 143,-6505 }, { 144,-6505 }, { 145,-6505 }, { 146,-6505 },
 { 147,-6505 }, { 148,-6505 }, { 149,-6505 }, { 150,-6505 }, { 151,-6505 },
 { 152,-6505 }, { 153,-6505 }, { 154,-6505 }, { 155,-6505 }, { 156,-6505 },
 { 157,-6505 }, { 158,-6505 }, { 159,-6505 }, { 160,-6505 }, { 161,-6505 },

 { 162,-6505 }, { 163,-6505 }, { 164,-6505 }, { 165,-6505 }, { 166,-6505 },
 { 167,-6505 }, { 168,-6505 }, { 169,-6505 }, { 170,-6505 }, { 171,-6505 },
 { 172,-6505 }, { 173,-6505 }, { 174,-6505 }, { 175,-6505 }, { 176,-6505 },
 { 177,-6505 }, { 178,-6505 }, { 179,-6505 }, { 180,-6505 }, { 181,-6505 },
 { 182,-6505 }, { 183,-6505 }, { 184,-6505 }, { 185,-6505 }, { 186,-6505 },
 { 187,-6505 }, { 188,-6505 }, { 189,-6505 }, { 190,-6505 }, { 191,-6505 },
 { 192,-6505 }, { 193,-6505 }, { 194,-6505 }, { 195,-6505 }, { 196,-6505 },
 { 197,-6505 }, { 198,-6505 }, { 199,-6505 }, { 200,-6505 }, { 201,-6505 },
 { 202,-6505 }, { 203,-6505 }, { 204,-6505 }, { 205,-6505 }, { 206,-6505 },
 { 207,-6505 }, { 208,-6505 }, { 209,-6505 }, { 210,-6505 }, { 211,-6505 },

 { 212,-6505 }, { 213,-6505 }, { 214,-6505 }, { 215,-6505 }, { 216,-6505 },
 { 217,-6505 }, { 218,-6505 }, { 219,-6505 }, { 220,-6505 }, { 221,-6505 },
 { 222,-6505 }, { 223,-6505 }, { 224,-6505 }, { 225,-6505 }, { 226,-6505 },
 { 227,-6505 }, { 228,-6505 }, { 229,-6505 }, { 230,-6505 }, { 231,-6505 },
 { 232,-6505 }, { 233,-6505 }, { 234,-6505 }, { 235,-6505 }, { 236,-6505 },
 { 237,-6505 }, { 238,-6505 }, { 239,-6505 }, { 240,-6505 }, { 241,-6505 },
 { 242,-6505 }, { 243,-6505 }, { 244,-6505 }, { 245,-6505 }, { 246,-6505 },
 { 247,-6505 }, { 248,-6505 }, { 249,-6505 }, { 250,-6505 }, { 251,-6505 },
 { 252,-6505 }, { 253,-6505 }, { 254,-6505 }, { 255,-6505 }, {   0,  57 },
 {   0,11155 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  46,-257 }, {   0,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,-7123 }, {  66,-7123 }, {  67,-7123 }, {  68,-7123 }, {  69, 257 },
 {  70,-7123 }, {  71,-7123 }, {  72,-7123 }, {  73,-7123 }, {  74,-7123 },
 {  75,-7123 }, {  76,-7123 }, {  77,-7123 }, {  78,-7123 }, {  79,-7123 },
 {  80,-7123 }, {  81,-7123 }, {  82,-7123 }, {  83,-7123 }, {  84,-7123 },
 {  85,-7123 }, {  86,-7123 }, {  87,-7123 }, {  88,-7123 }, {  89,-7123 },
 {  90,-7123 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95, 298 }, {   0,   0 }, {  97,-7123 }, {  98,-7123 }, {  99,-7123 },
 { 100,-7123 }, { 101, 257 }, { 102,-7123 }, { 103,-7123 }, { 104,-7123 },

 { 105,-7123 }, { 106,-7123 }, { 107,-7123 }, { 108,-7123 }, { 109,-7123 },
 { 110,-7123 }, { 111,-7123 }, { 112,-7123 }, { 113,-7123 }, { 114,-7123 },
 { 115,-7123 }, { 116,-7123 }, { 117,-7123 }, { 118,-7123 }, { 119,-7123 },
 { 120,-7123 }, { 121,-7123 }, { 122,-7123 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-7123 }, { 129,-7123 },
 { 130,-7123 }, { 131,-7123 }, { 132,-7123 }, { 133,-7123 }, { 134,-7123 },
 { 135,-7123 }, { 136,-7123 }, { 137,-7123 }, { 138,-7123 }, { 139,-7123 },
 { 140,-7123 }, { 141,-7123 }, { 142,-7123 }, { 143,-7123 }, { 144,-7123 },
 { 145,-7123 }, { 146,-7123 }, { 147,-7123 }, { 148,-7123 }, { 149,-7123 },
 { 150,-7123 }, { 151,-7123 }, { 152,-7123 }, { 153,-7123 }, { 154,-7123 },

 { 155,-7123 }, { 156,-7123 }, { 157,-7123 }, { 158,-7123 }, { 159,-7123 },
 { 160,-7123 }, { 161,-7123 }, { 162,-7123 }, { 163,-7123 }, { 164,-7123 },
 { 165,-7123 }, { 166,-7123 }, { 167,-7123 }, { 168,-7123 }, { 169,-7123 },
 { 170,-7123 }, { 171,-7123 }, { 172,-7123 }, { 173,-7123 }, { 174,-7123 },
 { 175,-7123 }, { 176,-7123 }, { 177,-7123 }, { 178,-7123 }, { 179,-7123 },
 { 180,-7123 }, { 181,-7123 }, { 182,-7123 }, { 183,-7123 }, { 184,-7123 },
 { 185,-7123 }, { 186,-7123 }, { 187,-7123 }, { 188,-7123 }, { 189,-7123 },
 { 190,-7123 }, { 191,-7123 }, { 192,-7123 }, { 193,-7123 }, { 194,-7123 },
 { 195,-7123 }, { 196,-7123 }, { 197,-7123 }, { 198,-7123 }, { 199,-7123 },
 { 200,-7123 }, { 201,-7123 }, { 202,-7123 }, { 203,-7123 }, { 204,-7123 },

 { 205,-7123 }, { 206,-7123 }, { 207,-7123 }, { 208,-7123 }, { 209,-7123 },
 { 210,-7123 }, { 211,-7123 }, { 212,-7123 }, { 213,-7123 }, { 214,-7123 },
 { 215,-7123 }, { 216,-7123 }, { 217,-7123 }, { 218,-7123 }, { 219,-7123 },
 { 220,-7123 }, { 221,-7123 }, { 222,-7123 }, { 223,-7123 }, { 224,-7123 },
 { 225,-7123 }, { 226,-7123 }, { 227,-7123 }, { 228,-7123 }, { 229,-7123 },
 { 230,-7123 }, { 231,-7123 }, { 232,-7123 }, { 233,-7123 }, { 234,-7123 },
 { 235,-7123 }, { 236,-7123 }, { 237,-7123 }, { 238,-7123 }, { 239,-7123 },
 { 240,-7123 }, { 241,-7123 }, { 242,-7123 }, { 243,-7123 }, { 244,-7123 },
 { 245,-7123 }, { 246,-7123 }, { 247,-7123 }, { 248,-7123 }, { 249,-7123 },
 { 250,-7123 }, { 251,-7123 }, { 252,-7123 }, { 253,-7123 }, { 254,-7123 },

 { 255,-7123 }, {   0,  68 }, {   0,10898 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  62 }, {   0,10888 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  61 },
 {   0,10880 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  68 }, {   0,10857 }, {   0,   0 },
 {  43,4711 }, {   0,   0 }, {  45,4711 }, {   0,   0 }, {   0,   0 },

 {  48,4966 }, {  49,4966 }, {  50,4966 }, {  51,4966 }, {  52,4966 },
 {  53,4966 }, {  54,4966 }, {  55,4966 }, {  56,4966 }, {  57,4966 },
 {  48,5213 }, {  49,5213 }, {  50,5213 }, {  51,5213 }, {  52,5213 },
 {  53,5213 }, {  54,5213 }, {  55,5213 }, {  48,5462 }, {  49,5462 },
 {  50,5462 }, {  51,5462 }, {  52,5462 }, {  53,5462 }, {  54,5462 },
 {  55,5462 }, {  56,5462 }, {  57,5462 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,5462 }, {  66,5462 }, {  67,5462 }, {  68,5462 }, {  69,5462 },
 {  70,5462 }, {  48,5734 }, {  49,5734 }, {  50,5734 }, {  51,5734 },
 {  52,5734 }, {  53,5734 }, {  54,5734 }, {  55,5734 }, {  56,5734 },

 {  57,5734 }, {   0,  49 }, {   0,10798 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,5221 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  51 }, {   0,10787 }, {   0,   0 },
 {  95,5719 }, {   0,   0 }, {  97,5462 }, {  98,5462 }, {  99,5462 },
 { 100,5462 }, { 101,5462 }, { 102,5462 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  33,-1765 }, {   0,   0 }, {  35,-1765 }, {   0,   0 }, {  37,-1765 },
 {  38,-1765 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,-1765 },
 {  43,-1765 }, {  33,-1776 }, {  45,-1765 }, {  35,-1776 }, {  47,-1765 },

 {  37,-1776 }, {  38,-1776 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42,-1776 }, {  43,-1776 }, {   0,   0 }, {  45,-1776 }, {   0,   0 },
 {  47,-1776 }, {   0,   0 }, {  60,-1765 }, {  61,-1765 }, {  62,-1765 },
 {  63,-1765 }, {  64,-1765 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,-1776 }, {  61,-1776 },
 {  62,-1776 }, {  63,-1776 }, {  64,-1776 }, {   0,   0 }, {   0,  48 },
 {   0,10720 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,-1765 }, {   0,   0 }, {  96,-1765 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94,-1776 }, {   0,   0 }, {  96,-1776 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  33,-1843 }, {   0,   0 },
 {  35,-1843 }, {   0,   0 }, {  37,-1843 }, {  38,-1843 }, {   0,  50 },
 {   0,10680 }, {   0,   0 }, {  42,-1843 }, {  43,-1843 }, {   0,   0 },
 {  45,-1843 }, { 124,-1765 }, {  47,-1843 }, { 126,-1765 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 124,-1776 }, {   0,   0 }, { 126,-1776 },
 {  60,-1843 }, {  61,-1843 }, {  62,-1843 }, {  63,-1843 }, {  64,-1843 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  33,-1883 }, {   0,   0 },
 {  35,-1883 }, {   0,   0 }, {  37,-1883 }, {  38,-1883 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  42,-1883 }, {  43,-1883 }, {   0,   0 },
 {  45,-1883 }, {   0,   0 }, {  47,-1883 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,-1843 },
 {   0,   0 }, {  96,-1843 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  60,-1883 }, {  61,-1883 }, {  62,-1883 }, {  63,-1883 }, {  64,-1883 },
 {   0,  74 }, {   0,10614 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,-1843 },
 {   0,   0 }, { 126,-1843 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,-1883 },
 {   0,   0 }, {  96,-1883 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  36,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, { 124,-1883 },
 {   0,   0 }, { 126,-1883 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,   0 }, {   0,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },

 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },

 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },

 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, {   0,  10 }, {   0,10357 }, {   1,   0 },
 {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 },

 {   7,   0 }, {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 },
 {  12,   0 }, {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 },
 {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 },
 {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 },
 {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 },
 {  32,   0 }, {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 },
 {  37,   0 }, {  38,   0 }, {   0,   0 }, {  40,   0 }, {  41,   0 },
 {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 },
 {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },

 {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 },
 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },
 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 },
 {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 },
 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },

 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 },
 { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },
 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },

 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },
 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },
 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },

 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },
 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },
 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 },

 {   0,   5 }, {   0,10099 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },
 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 },
 {  34,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {   0,   0 }, {  43,   0 },
 {  44,   0 }, {  45,   0 }, {  46,   0 }, {   0,   0 }, {  48,   0 },

 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },

 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },
 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },

 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },

 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },

 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,   3 }, {   0,9841 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  33,4975 }, {   0,   0 }, {  35,4975 },
 {   0,   0 }, {  37,4975 }, {  38,4975 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  42,4975 }, {  43,4975 }, {   0,   0 }, {  45,4975 },
 {   0,   0 }, {  47,4975 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,4975 },
 {  61,4975 }, {  62,4975 }, {  63,4975 }, {  64,4975 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,4975 }, {   0,   0 },
 {  96,4975 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,4975 }, {   0,   0 },
 { 126,4975 }, {   0,  43 }, {   0,9713 }, {   1,   0 }, {   2,   0 },
 {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 },
 {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 },

 {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 },
 {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 },
 {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 },
 {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 },
 {  33,   0 }, {   0,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 },
 {  38,   0 }, {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 },
 {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 }, {  47,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 },

 {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 },
 {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 },
 {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 },
 {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 },
 {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 },
 {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 },
 {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 },
 {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 },
 { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 },
 { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 },

 { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 },
 { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 },
 { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 },
 { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 },
 { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 },
 { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 },
 { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 },
 { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 },
 { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 },
 { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 },

 { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 },
 { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 },
 { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 },
 { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 },
 { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 },
 { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 },
 { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 },
 { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 },
 { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 },
 { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 },

 { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 },
 { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 },
 { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 },
 { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 },
 { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 },
 { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 },
 { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 },
 { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 },
 { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,   9 },
 {   0,9455 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },

 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 },
 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },
 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },
 {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },

 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },

 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },

 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },

 { 255,   0 }, { 256,   0 }, {   0,  21 }, {   0,9197 }, {   1,   0 },
 {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 },
 {   7,   0 }, {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 },
 {  12,   0 }, {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 },
 {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 },
 {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 },
 {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 },
 {  32,   0 }, {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 },
 {  37,   0 }, {  38,   0 }, {   0,   0 }, {  40,   0 }, {  41,   0 },
 {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 },

 {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 },
 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },
 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 },
 {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 },

 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },
 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 },
 { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },

 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },
 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },
 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },

 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },
 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },
 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },

 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 },
 {   0,  18 }, {   0,8939 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  18 }, {   0,8934 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   9,   0 }, {  10,   5 }, {  11,   0 }, {  12,   0 }, {  13,   5 },
 {   9,  24 }, {  10,  24 }, {  11,  24 }, {  12,  24 }, {  13,  24 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  18 },
 {   0,8910 }, {   0,   0 }, {   0,   0 }, {  32,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  32,  24 }, {   9,   0 },

 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {   0,   0 },
 {  39,-9030 }, {  45,-9027 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  45,-8995 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  32,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  39,-9054 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  45,-9019 }, {   0,  18 }, {   0,8863 }, {   1,4383 }, {   2,4383 },
 {   3,4383 }, {   4,4383 }, {   5,4383 }, {   6,4383 }, {   7,4383 },
 {   8,4383 }, {   9,4641 }, {  10, -71 }, {  11,4641 }, {  12,4641 },

 {  13, -71 }, {  14,4383 }, {  15,4383 }, {  16,4383 }, {  17,4383 },
 {  18,4383 }, {  19,4383 }, {  20,4383 }, {  21,4383 }, {  22,4383 },
 {  23,4383 }, {  24,4383 }, {  25,4383 }, {  26,4383 }, {  27,4383 },
 {  28,4383 }, {  29,4383 }, {  30,4383 }, {  31,4383 }, {  32,4641 },
 {  33,4383 }, {  34,4383 }, {  35,4383 }, {  36,4383 }, {  37,4383 },
 {  38,4383 }, {  39,4383 }, {  40,4383 }, {  41,4383 }, {  42,4383 },
 {  43,4383 }, {  44,4383 }, {  45,4899 }, {  46,4383 }, {  47,4383 },
 {  48,4383 }, {  49,4383 }, {  50,4383 }, {  51,4383 }, {  52,4383 },
 {  53,4383 }, {  54,4383 }, {  55,4383 }, {  56,4383 }, {  57,4383 },
 {  58,4383 }, {  59,4383 }, {  60,4383 }, {  61,4383 }, {  62,4383 },

 {  63,4383 }, {  64,4383 }, {  65,4383 }, {  66,4383 }, {  67,4383 },
 {  68,4383 }, {  69,4383 }, {  70,4383 }, {  71,4383 }, {  72,4383 },
 {  73,4383 }, {  74,4383 }, {  75,4383 }, {  76,4383 }, {  77,4383 },
 {  78,4383 }, {  79,4383 }, {  80,4383 }, {  81,4383 }, {  82,4383 },
 {  83,4383 }, {  84,4383 }, {  85,4383 }, {  86,4383 }, {  87,4383 },
 {  88,4383 }, {  89,4383 }, {  90,4383 }, {  91,4383 }, {  92,4383 },
 {  93,4383 }, {  94,4383 }, {  95,4383 }, {  96,4383 }, {  97,4383 },
 {  98,4383 }, {  99,4383 }, { 100,4383 }, { 101,4383 }, { 102,4383 },
 { 103,4383 }, { 104,4383 }, { 105,4383 }, { 106,4383 }, { 107,4383 },
 { 108,4383 }, { 109,4383 }, { 110,4383 }, { 111,4383 }, { 112,4383 },

 { 113,4383 }, { 114,4383 }, { 115,4383 }, { 116,4383 }, { 117,4383 },
 { 118,4383 }, { 119,4383 }, { 120,4383 }, { 121,4383 }, { 122,4383 },
 { 123,4383 }, { 124,4383 }, { 125,4383 }, { 126,4383 }, { 127,4383 },
 { 128,4383 }, { 129,4383 }, { 130,4383 }, { 131,4383 }, { 132,4383 },
 { 133,4383 }, { 134,4383 }, { 135,4383 }, { 136,4383 }, { 137,4383 },
 { 138,4383 }, { 139,4383 }, { 140,4383 }, { 141,4383 }, { 142,4383 },
 { 143,4383 }, { 144,4383 }, { 145,4383 }, { 146,4383 }, { 147,4383 },
 { 148,4383 }, { 149,4383 }, { 150,4383 }, { 151,4383 }, { 152,4383 },
 { 153,4383 }, { 154,4383 }, { 155,4383 }, { 156,4383 }, { 157,4383 },
 { 158,4383 }, { 159,4383 }, { 160,4383 }, { 161,4383 }, { 162,4383 },

 { 163,4383 }, { 164,4383 }, { 165,4383 }, { 166,4383 }, { 167,4383 },
 { 168,4383 }, { 169,4383 }, { 170,4383 }, { 171,4383 }, { 172,4383 },
 { 173,4383 }, { 174,4383 }, { 175,4383 }, { 176,4383 }, { 177,4383 },
 { 178,4383 }, { 179,4383 }, { 180,4383 }, { 181,4383 }, { 182,4383 },
 { 183,4383 }, { 184,4383 }, { 185,4383 }, { 186,4383 }, { 187,4383 },
 { 188,4383 }, { 189,4383 }, { 190,4383 }, { 191,4383 }, { 192,4383 },
 { 193,4383 }, { 194,4383 }, { 195,4383 }, { 196,4383 }, { 197,4383 },
 { 198,4383 }, { 199,4383 }, { 200,4383 }, { 201,4383 }, { 202,4383 },
 { 203,4383 }, { 204,4383 }, { 205,4383 }, { 206,4383 }, { 207,4383 },
 { 208,4383 }, { 209,4383 }, { 210,4383 }, { 211,4383 }, { 212,4383 },

 { 213,4383 }, { 214,4383 }, { 215,4383 }, { 216,4383 }, { 217,4383 },
 { 218,4383 }, { 219,4383 }, { 220,4383 }, { 221,4383 }, { 222,4383 },
 { 223,4383 }, { 224,4383 }, { 225,4383 }, { 226,4383 }, { 227,4383 },
 { 228,4383 }, { 229,4383 }, { 230,4383 }, { 231,4383 }, { 232,4383 },
 { 233,4383 }, { 234,4383 }, { 235,4383 }, { 236,4383 }, { 237,4383 },
 { 238,4383 }, { 239,4383 }, { 240,4383 }, { 241,4383 }, { 242,4383 },
 { 243,4383 }, { 244,4383 }, { 245,4383 }, { 246,4383 }, { 247,4383 },
 { 248,4383 }, { 249,4383 }, { 250,4383 }, { 251,4383 }, { 252,4383 },
 { 253,4383 }, { 254,4383 }, { 255,4383 }, { 256,4383 }, {   0,  22 },
 {   0,8605 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },

 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 },
 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },
 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },
 {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {   0,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },

 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },

 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },

 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },

 { 255,   0 }, { 256,   0 }, {   0,  29 }, {   0,8347 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0,8339 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,8316 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  48,4641 }, {  49,4641 }, {  50,4641 }, {  51,4641 },
 {  52,4641 }, {  53,4641 }, {  54,4641 }, {  55,4641 }, {  48,4641 },
 {  49,4641 }, {  50,4641 }, {  51,4641 }, {  52,4641 }, {  53,4641 },
 {  54,4641 }, {  55,4641 }, {  56,4641 }, {  57,4641 }, {   0,   0 },
 {   0,   0 }, {   0,  28 }, {   0,8278 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,4641 }, {  66,4641 }, {  67,4641 }, {  68,4641 },
 {  69,4641 }, {  70,4641 }, {  48,4641 }, {  49,4641 }, {  50,4641 },
 {  51,4641 }, {  52,4641 }, {  53,4641 }, {  54,4641 }, {  55,4641 },
 {  56,4641 }, {  57,4641 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4641 },

 {  66,4641 }, {  67,4641 }, {  68,4641 }, {  69,4641 }, {  70,4641 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4641 }, {  98,4641 },
 {  99,4641 }, { 100,4641 }, { 101,4641 }, { 102,4641 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,4641 }, {  49,4641 }, {  50,4641 }, {  51,4641 }, {  52,4641 },
 {  53,4641 }, {  54,4641 }, {  55,4641 }, {  56,4641 }, {  57,4641 },
 {   0,   0 }, {  97,4641 }, {  98,4641 }, {  99,4641 }, { 100,4641 },
 { 101,4641 }, { 102,4641 }, {  65,4641 }, {  66,4641 }, {  67,4641 },
 {  68,4641 }, {  69,4641 }, {  70,4641 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4641 },
 {  98,4641 }, {  99,4641 }, { 100,4641 }, { 101,4641 }, { 102,4641 },
 {   0,  35 }, {   0,8174 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },

 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 },
 {  34,   0 }, {  35,   0 }, {   0,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 },
 {  44,   0 }, {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },

 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },

 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },

 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },

 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,  36 }, {   0,7916 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,-10006 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,4351 }, {  49,4351 }, {  50,4351 },
 {  51,4351 }, {  52,4351 }, {  53,4351 }, {  54,4351 }, {  55,4351 },
 {  56,4351 }, {  57,4351 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4351 },

 {  66,4351 }, {  67,4351 }, {  68,4351 }, {  69,4351 }, {  70,4351 },
 {  71,4351 }, {  72,4351 }, {  73,4351 }, {  74,4351 }, {  75,4351 },
 {  76,4351 }, {  77,4351 }, {  78,4351 }, {  79,4351 }, {  80,4351 },
 {  81,4351 }, {  82,4351 }, {  83,4351 }, {  84,4351 }, {  85,4351 },
 {  86,4351 }, {  87,4351 }, {  88,4351 }, {  89,4351 }, {  90,4351 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,4351 },
 {   0,   0 }, {  97,4351 }, {  98,4351 }, {  99,4351 }, { 100,4351 },
 { 101,4351 }, { 102,4351 }, { 103,4351 }, { 104,4351 }, { 105,4351 },
 { 106,4351 }, { 107,4351 }, { 108,4351 }, { 109,4351 }, { 110,4351 },
 { 111,4351 }, { 112,4351 }, { 113,4351 }, { 114,4351 }, { 115,4351 },

 { 116,4351 }, { 117,4351 }, { 118,4351 }, { 119,4351 }, { 120,4351 },
 { 121,4351 }, { 122,4351 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,4351 }, { 129,4351 }, { 130,4351 },
 { 131,4351 }, { 132,4351 }, { 133,4351 }, { 134,4351 }, { 135,4351 },
 { 136,4351 }, { 137,4351 }, { 138,4351 }, { 139,4351 }, { 140,4351 },
 { 141,4351 }, { 142,4351 }, { 143,4351 }, { 144,4351 }, { 145,4351 },
 { 146,4351 }, { 147,4351 }, { 148,4351 }, { 149,4351 }, { 150,4351 },
 { 151,4351 }, { 152,4351 }, { 153,4351 }, { 154,4351 }, { 155,4351 },
 { 156,4351 }, { 157,4351 }, { 158,4351 }, { 159,4351 }, { 160,4351 },
 { 161,4351 }, { 162,4351 }, { 163,4351 }, { 164,4351 }, { 165,4351 },

 { 166,4351 }, { 167,4351 }, { 168,4351 }, { 169,4351 }, { 170,4351 },
 { 171,4351 }, { 172,4351 }, { 173,4351 }, { 174,4351 }, { 175,4351 },
 { 176,4351 }, { 177,4351 }, { 178,4351 }, { 179,4351 }, { 180,4351 },
 { 181,4351 }, { 182,4351 }, { 183,4351 }, { 184,4351 }, { 185,4351 },
 { 186,4351 }, { 187,4351 }, { 188,4351 }, { 189,4351 }, { 190,4351 },
 { 191,4351 }, { 192,4351 }, { 193,4351 }, { 194,4351 }, { 195,4351 },
 { 196,4351 }, { 197,4351 }, { 198,4351 }, { 199,4351 }, { 200,4351 },
 { 201,4351 }, { 202,4351 }, { 203,4351 }, { 204,4351 }, { 205,4351 },
 { 206,4351 }, { 207,4351 }, { 208,4351 }, { 209,4351 }, { 210,4351 },
 { 211,4351 }, { 212,4351 }, { 213,4351 }, { 214,4351 }, { 215,4351 },

 { 216,4351 }, { 217,4351 }, { 218,4351 }, { 219,4351 }, { 220,4351 },
 { 221,4351 }, { 222,4351 }, { 223,4351 }, { 224,4351 }, { 225,4351 },
 { 226,4351 }, { 227,4351 }, { 228,4351 }, { 229,4351 }, { 230,4351 },
 { 231,4351 }, { 232,4351 }, { 233,4351 }, { 234,4351 }, { 235,4351 },
 { 236,4351 }, { 237,4351 }, { 238,4351 }, { 239,4351 }, { 240,4351 },
 { 241,4351 }, { 242,4351 }, { 243,4351 }, { 244,4351 }, { 245,4351 },
 { 246,4351 }, { 247,4351 }, { 248,4351 }, { 249,4351 }, { 250,4351 },
 { 251,4351 }, { 252,4351 }, { 253,4351 }, { 254,4351 }, { 255,4351 },
 {   0,  27 }, {   0,7659 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,7636 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,4351 },
 {  49,4351 }, {  50,4351 }, {  51,4351 }, {  52,4351 }, {  53,4351 },
 {  54,4351 }, {  55,4351 }, {  56,4351 }, {  57,4351 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,4351 }, {  66,4351 }, {  67,4351 }, {  68,4351 },
 {  69,4351 }, {  70,4351 }, {  48,4351 }, {  49,4351 }, {  50,4351 },
 {  51,4351 }, {  52,4351 }, {  53,4351 }, {  54,4351 }, {  55,4351 },
 {  56,4351 }, {  57,4351 }, {   0,  33 }, {   0,7577 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4351 },
 {  66,4351 }, {  67,4351 }, {  68,4351 }, {  69,4351 }, {  70,4351 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4351 }, {  98,4351 },
 {  99,4351 }, { 100,4351 }, { 101,4351 }, { 102,4351 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36,-10705 },
 {   0,   0 }, {  97,4351 }, {  98,4351 }, {  99,4351 }, { 100,4351 },
 { 101,4351 }, { 102,4351 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },

 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,   0 }, {   0,   0 },
 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },
 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },
 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },
 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },

 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },
 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },
 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },

 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },
 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, {   0,   1 },
 {   0,7320 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },
 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 },
 {   0,   0 }, {  11,   0 }, {  12,   0 }, {   0,   0 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },

 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },
 {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {  39,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },

 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },
 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },

 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },
 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },

 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },
 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },

 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },
 { 255,   0 }, { 256,   0 }, {   0,   1 }, {   0,7062 }, {   1,-258 },
 {   2,-258 }, {   3,-258 }, {   4,-258 }, {   5,-258 }, {   6,-258 },
 {   7,-258 }, {   8,-258 }, {   9,-258 }, {   0,   0 }, {  11,-258 },

 {  12,-258 }, {   0,   0 }, {  14,-258 }, {  15,-258 }, {  16,-258 },
 {  17,-258 }, {  18,-258 }, {  19,-258 }, {  20,-258 }, {  21,-258 },
 {  22,-258 }, {  23,-258 }, {  24,-258 }, {  25,-258 }, {  26,-258 },
 {  27,-258 }, {  28,-258 }, {  29,-258 }, {  30,-258 }, {  31,-258 },
 {  32,-258 }, {  33,   0 }, {  34,-258 }, {  35,   0 }, {  36,-258 },
 {  37,   0 }, {  38,   0 }, {  39,-258 }, {  40,-258 }, {  41,-258 },
 {  42,   0 }, {  43,   0 }, {  44,-258 }, {  45,   0 }, {  46,-258 },
 {  47,   0 }, {  48,-258 }, {  49,-258 }, {  50,-258 }, {  51,-258 },
 {  52,-258 }, {  53,-258 }, {  54,-258 }, {  55,-258 }, {  56,-258 },
 {  57,-258 }, {  58,-258 }, {  59,-258 }, {  60,   0 }, {  61,   0 },

 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,-258 }, {  66,-258 },
 {  67,-258 }, {  68,-258 }, {  69,-258 }, {  70,-258 }, {  71,-258 },
 {  72,-258 }, {  73,-258 }, {  74,-258 }, {  75,-258 }, {  76,-258 },
 {  77,-258 }, {  78,-258 }, {  79,-258 }, {  80,-258 }, {  81,-258 },
 {  82,-258 }, {  83,-258 }, {  84,-258 }, {  85,-258 }, {  86,-258 },
 {  87,-258 }, {  88,-258 }, {  89,-258 }, {  90,-258 }, {  91,-258 },
 {  92,-258 }, {  93,-258 }, {  94,   0 }, {  95,-258 }, {  96,   0 },
 {  97,-258 }, {  98,-258 }, {  99,-258 }, { 100,-258 }, { 101,-258 },
 { 102,-258 }, { 103,-258 }, { 104,-258 }, { 105,-258 }, { 106,-258 },
 { 107,-258 }, { 108,-258 }, { 109,-258 }, { 110,-258 }, { 111,-258 },

 { 112,-258 }, { 113,-258 }, { 114,-258 }, { 115,-258 }, { 116,-258 },
 { 117,-258 }, { 118,-258 }, { 119,-258 }, { 120,-258 }, { 121,-258 },
 { 122,-258 }, { 123,-258 }, { 124,   0 }, { 125,-258 }, { 126,   0 },
 { 127,-258 }, { 128,-258 }, { 129,-258 }, { 130,-258 }, { 131,-258 },
 { 132,-258 }, { 133,-258 }, { 134,-258 }, { 135,-258 }, { 136,-258 },
 { 137,-258 }, { 138,-258 }, { 139,-258 }, { 140,-258 }, { 141,-258 },
 { 142,-258 }, { 143,-258 }, { 144,-258 }, { 145,-258 }, { 146,-258 },
 { 147,-258 }, { 148,-258 }, { 149,-258 }, { 150,-258 }, { 151,-258 },
 { 152,-258 }, { 153,-258 }, { 154,-258 }, { 155,-258 }, { 156,-258 },
 { 157,-258 }, { 158,-258 }, { 159,-258 }, { 160,-258 }, { 161,-258 },

 { 162,-258 }, { 163,-258 }, { 164,-258 }, { 165,-258 }, { 166,-258 },
 { 167,-258 }, { 168,-258 }, { 169,-258 }, { 170,-258 }, { 171,-258 },
 { 172,-258 }, { 173,-258 }, { 174,-258 }, { 175,-258 }, { 176,-258 },
 { 177,-258 }, { 178,-258 }, { 179,-258 }, { 180,-258 }, { 181,-258 },
 { 182,-258 }, { 183,-258 }, { 184,-258 }, { 185,-258 }, { 186,-258 },
 { 187,-258 }, { 188,-258 }, { 189,-258 }, { 190,-258 }, { 191,-258 },
 { 192,-258 }, { 193,-258 }, { 194,-258 }, { 195,-258 }, { 196,-258 },
 { 197,-258 }, { 198,-258 }, { 199,-258 }, { 200,-258 }, { 201,-258 },
 { 202,-258 }, { 203,-258 }, { 204,-258 }, { 205,-258 }, { 206,-258 },
 { 207,-258 }, { 208,-258 }, { 209,-258 }, { 210,-258 }, { 211,-258 },

 { 212,-258 }, { 213,-258 }, { 214,-258 }, { 215,-258 }, { 216,-258 },
 { 217,-258 }, { 218,-258 }, { 219,-258 }, { 220,-258 }, { 221,-258 },
 { 222,-258 }, { 223,-258 }, { 224,-258 }, { 225,-258 }, { 226,-258 },
 { 227,-258 }, { 228,-258 }, { 229,-258 }, { 230,-258 }, { 231,-258 },
 { 232,-258 }, { 233,-258 }, { 234,-258 }, { 235,-258 }, { 236,-258 },
 { 237,-258 }, { 238,-258 }, { 239,-258 }, { 240,-258 }, { 241,-258 },
 { 242,-258 }, { 243,-258 }, { 244,-258 }, { 245,-258 }, { 246,-258 },
 { 247,-258 }, { 248,-258 }, { 249,-258 }, { 250,-258 }, { 251,-258 },
 { 252,-258 }, { 253,-258 }, { 254,-258 }, { 255,-258 }, { 256,-258 },
 {   0,  64 }, {   0,6804 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },

 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,-11113 }, {  66,-11113 }, {  67,-11113 }, {  68,-11113 },
 {  69, 257 }, {  70,-11113 }, {  71,-11113 }, {  72,-11113 }, {  73,-11113 },
 {  74,-11113 }, {  75,-11113 }, {  76,-11113 }, {  77,-11113 }, {  78,-11113 },
 {  79,-11113 }, {  80,-11113 }, {  81,-11113 }, {  82,-11113 }, {  83,-11113 },
 {  84,-11113 }, {  85,-11113 }, {  86,-11113 }, {  87,-11113 }, {  88,-11113 },
 {  89,-11113 }, {  90,-11113 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95, 267 }, {   0,   0 }, {  97,-11113 }, {  98,-11113 },
 {  99,-11113 }, { 100,-11113 }, { 101, 257 }, { 102,-11113 }, { 103,-11113 },

 { 104,-11113 }, { 105,-11113 }, { 106,-11113 }, { 107,-11113 }, { 108,-11113 },
 { 109,-11113 }, { 110,-11113 }, { 111,-11113 }, { 112,-11113 }, { 113,-11113 },
 { 114,-11113 }, { 115,-11113 }, { 116,-11113 }, { 117,-11113 }, { 118,-11113 },
 { 119,-11113 }, { 120,-11113 }, { 121,-11113 }, { 122,-11113 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-11113 },
 { 129,-11113 }, { 130,-11113 }, { 131,-11113 }, { 132,-11113 }, { 133,-11113 },
 { 134,-11113 }, { 135,-11113 }, { 136,-11113 }, { 137,-11113 }, { 138,-11113 },
 { 139,-11113 }, { 140,-11113 }, { 141,-11113 }, { 142,-11113 }, { 143,-11113 },
 { 144,-11113 }, { 145,-11113 }, { 146,-11113 }, { 147,-11113 }, { 148,-11113 },
 { 149,-11113 }, { 150,-11113 }, { 151,-11113 }, { 152,-11113 }, { 153,-11113 },

 { 154,-11113 }, { 155,-11113 }, { 156,-11113 }, { 157,-11113 }, { 158,-11113 },
 { 159,-11113 }, { 160,-11113 }, { 161,-11113 }, { 162,-11113 }, { 163,-11113 },
 { 164,-11113 }, { 165,-11113 }, { 166,-11113 }, { 167,-11113 }, { 168,-11113 },
 { 169,-11113 }, { 170,-11113 }, { 171,-11113 }, { 172,-11113 }, { 173,-11113 },
 { 174,-11113 }, { 175,-11113 }, { 176,-11113 }, { 177,-11113 }, { 178,-11113 },
 { 179,-11113 }, { 180,-11113 }, { 181,-11113 }, { 182,-11113 }, { 183,-11113 },
 { 184,-11113 }, { 185,-11113 }, { 186,-11113 }, { 187,-11113 }, { 188,-11113 },
 { 189,-11113 }, { 190,-11113 }, { 191,-11113 }, { 192,-11113 }, { 193,-11113 },
 { 194,-11113 }, { 195,-11113 }, { 196,-11113 }, { 197,-11113 }, { 198,-11113 },
 { 199,-11113 }, { 200,-11113 }, { 201,-11113 }, { 202,-11113 }, { 203,-11113 },

 { 204,-11113 }, { 205,-11113 }, { 206,-11113 }, { 207,-11113 }, { 208,-11113 },
 { 209,-11113 }, { 210,-11113 }, { 211,-11113 }, { 212,-11113 }, { 213,-11113 },
 { 214,-11113 }, { 215,-11113 }, { 216,-11113 }, { 217,-11113 }, { 218,-11113 },
 { 219,-11113 }, { 220,-11113 }, { 221,-11113 }, { 222,-11113 }, { 223,-11113 },
 { 224,-11113 }, { 225,-11113 }, { 226,-11113 }, { 227,-11113 }, { 228,-11113 },
 { 229,-11113 }, { 230,-11113 }, { 231,-11113 }, { 232,-11113 }, { 233,-11113 },
 { 234,-11113 }, { 235,-11113 }, { 236,-11113 }, { 237,-11113 }, { 238,-11113 },
 { 239,-11113 }, { 240,-11113 }, { 241,-11113 }, { 242,-11113 }, { 243,-11113 },
 { 244,-11113 }, { 245,-11113 }, { 246,-11113 }, { 247,-11113 }, { 248,-11113 },
 { 249,-11113 }, { 250,-11113 }, { 251,-11113 }, { 252,-11113 }, { 253,-11113 },

 { 254,-11113 }, { 255,-11113 }, {   0,  72 }, {   0,6547 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  72 }, {   0,6537 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   2 }, {   0,6512 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  43, 360 }, {   0,   0 }, {  45, 360 }, {   0,   0 },

 {   0,   0 }, {  48, 615 }, {  49, 615 }, {  50, 615 }, {  51, 615 },
 {  52, 615 }, {  53, 615 }, {  54, 615 }, {  55, 615 }, {  56, 615 },
 {  57, 615 }, {  48,-267 }, {  49,-267 }, {  50,-267 }, {  51,-267 },
 {  52,-267 }, {  53,-267 }, {  54,-267 }, {  55,-267 }, {  56,-267 },
 {  57,-267 }, {  33,   0 }, {   0,   0 }, {  35,   0 }, {   0,   0 },
 {  37,   0 }, {  38,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42,   0 }, {  43,   0 }, {   0,   0 }, {  45,   0 }, {   0,   0 },
 {  47,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,   0 }, {  61,   0 },

 {  62,   0 }, {  63,   0 }, {  64,   0 }, {   0,  64 }, {   0,6446 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94,   0 }, {   0,   0 }, {  96,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  48,3199 }, {  49,3199 }, {  50,3199 },
 {  51,3199 }, {  52,3199 }, {  53,3199 }, {  54,3199 }, {  55,3199 },
 {  56,3199 }, {  57,3199 }, { 124,   0 }, {   0,   0 }, { 126,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-11471 },
 {  66,-11471 }, {  67,-11471 }, {  68,-11471 }, {  69,-101 }, {  70,-11471 },
 {  71,-11471 }, {  72,-11471 }, {  73,-11471 }, {  74,-11471 }, {  75,-11471 },
 {  76,-11471 }, {  77,-11471 }, {  78,-11471 }, {  79,-11471 }, {  80,-11471 },
 {  81,-11471 }, {  82,-11471 }, {  83,-11471 }, {  84,-11471 }, {  85,-11471 },
 {  86,-11471 }, {  87,-11471 }, {  88,-11471 }, {  89,-11471 }, {  90,-11471 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,3456 },

 {   0,   0 }, {  97,-11471 }, {  98,-11471 }, {  99,-11471 }, { 100,-11471 },
 { 101,-101 }, { 102,-11471 }, { 103,-11471 }, { 104,-11471 }, { 105,-11471 },
 { 106,-11471 }, { 107,-11471 }, { 108,-11471 }, { 109,-11471 }, { 110,-11471 },
 { 111,-11471 }, { 112,-11471 }, { 113,-11471 }, { 114,-11471 }, { 115,-11471 },
 { 116,-11471 }, { 117,-11471 }, { 118,-11471 }, { 119,-11471 }, { 120,-11471 },
 { 121,-11471 }, { 122,-11471 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,-11471 }, { 129,-11471 }, { 130,-11471 },
 { 131,-11471 }, { 132,-11471 }, { 133,-11471 }, { 134,-11471 }, { 135,-11471 },
 { 136,-11471 }, { 137,-11471 }, { 138,-11471 }, { 139,-11471 }, { 140,-11471 },
 { 141,-11471 }, { 142,-11471 }, { 143,-11471 }, { 144,-11471 }, { 145,-11471 },

 { 146,-11471 }, { 147,-11471 }, { 148,-11471 }, { 149,-11471 }, { 150,-11471 },
 { 151,-11471 }, { 152,-11471 }, { 153,-11471 }, { 154,-11471 }, { 155,-11471 },
 { 156,-11471 }, { 157,-11471 }, { 158,-11471 }, { 159,-11471 }, { 160,-11471 },
 { 161,-11471 }, { 162,-11471 }, { 163,-11471 }, { 164,-11471 }, { 165,-11471 },
 { 166,-11471 }, { 167,-11471 }, { 168,-11471 }, { 169,-11471 }, { 170,-11471 },
 { 171,-11471 }, { 172,-11471 }, { 173,-11471 }, { 174,-11471 }, { 175,-11471 },
 { 176,-11471 }, { 177,-11471 }, { 178,-11471 }, { 179,-11471 }, { 180,-11471 },
 { 181,-11471 }, { 182,-11471 }, { 183,-11471 }, { 184,-11471 }, { 185,-11471 },
 { 186,-11471 }, { 187,-11471 }, { 188,-11471 }, { 189,-11471 }, { 190,-11471 },
 { 191,-11471 }, { 192,-11471 }, { 193,-11471 }, { 194,-11471 }, { 195,-11471 },

 { 196,-11471 }, { 197,-11471 }, { 198,-11471 }, { 199,-11471 }, { 200,-11471 },
 { 201,-11471 }, { 202,-11471 }, { 203,-11471 }, { 204,-11471 }, { 205,-11471 },
 { 206,-11471 }, { 207,-11471 }, { 208,-11471 }, { 209,-11471 }, { 210,-11471 },
 { 211,-11471 }, { 212,-11471 }, { 213,-11471 }, { 214,-11471 }, { 215,-11471 },
 { 216,-11471 }, { 217,-11471 }, { 218,-11471 }, { 219,-11471 }, { 220,-11471 },
 { 221,-11471 }, { 222,-11471 }, { 223,-11471 }, { 224,-11471 }, { 225,-11471 },
 { 226,-11471 }, { 227,-11471 }, { 228,-11471 }, { 229,-11471 }, { 230,-11471 },
 { 231,-11471 }, { 232,-11471 }, { 233,-11471 }, { 234,-11471 }, { 235,-11471 },
 { 236,-11471 }, { 237,-11471 }, { 238,-11471 }, { 239,-11471 }, { 240,-11471 },
 { 241,-11471 }, { 242,-11471 }, { 243,-11471 }, { 244,-11471 }, { 245,-11471 },

 { 246,-11471 }, { 247,-11471 }, { 248,-11471 }, { 249,-11471 }, { 250,-11471 },
 { 251,-11471 }, { 252,-11471 }, { 253,-11471 }, { 254,-11471 }, { 255,-11471 },
 {   0,  60 }, {   0,6189 }, {   0,  67 }, {   0,6187 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  48, 255 }, {  49, 255 }, {  50, 255 }, {  51, 255 },
 {  52, 255 }, {  53, 255 }, {  54, 255 }, {  55, 255 }, {  56, 255 },
 {  57, 255 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,-11714 }, {  66,-11714 }, {  67,-11714 }, {  68,-11714 },
 {  69,-11714 }, {  70,-11714 }, {  71,-11714 }, {  72,-11714 }, {  73,-11714 },
 {  74,-11714 }, {  75,-11714 }, {  76,-11714 }, {  77,-11714 }, {  78,-11714 },
 {  79,-11714 }, {  80,-11714 }, {  81,-11714 }, {  82,-11714 }, {  83,-11714 },
 {  84,-11714 }, {  85,-11714 }, {  86,-11714 }, {  87,-11714 }, {  88,-11714 },

 {  89,-11714 }, {  90,-11714 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,-11444 }, {   0,   0 }, {  97,-11714 }, {  98,-11714 },
 {  99,-11714 }, { 100,-11714 }, { 101,-11714 }, { 102,-11714 }, { 103,-11714 },
 { 104,-11714 }, { 105,-11714 }, { 106,-11714 }, { 107,-11714 }, { 108,-11714 },
 { 109,-11714 }, { 110,-11714 }, { 111,-11714 }, { 112,-11714 }, { 113,-11714 },
 { 114,-11714 }, { 115,-11714 }, { 116,-11714 }, { 117,-11714 }, { 118,-11714 },
 { 119,-11714 }, { 120,-11714 }, { 121,-11714 }, { 122,-11714 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-11714 },
 { 129,-11714 }, { 130,-11714 }, { 131,-11714 }, { 132,-11714 }, { 133,-11714 },
 { 134,-11714 }, { 135,-11714 }, { 136,-11714 }, { 137,-11714 }, { 138,-11714 },

 { 139,-11714 }, { 140,-11714 }, { 141,-11714 }, { 142,-11714 }, { 143,-11714 },
 { 144,-11714 }, { 145,-11714 }, { 146,-11714 }, { 147,-11714 }, { 148,-11714 },
 { 149,-11714 }, { 150,-11714 }, { 151,-11714 }, { 152,-11714 }, { 153,-11714 },
 { 154,-11714 }, { 155,-11714 }, { 156,-11714 }, { 157,-11714 }, { 158,-11714 },
 { 159,-11714 }, { 160,-11714 }, { 161,-11714 }, { 162,-11714 }, { 163,-11714 },
 { 164,-11714 }, { 165,-11714 }, { 166,-11714 }, { 167,-11714 }, { 168,-11714 },
 { 169,-11714 }, { 170,-11714 }, { 171,-11714 }, { 172,-11714 }, { 173,-11714 },
 { 174,-11714 }, { 175,-11714 }, { 176,-11714 }, { 177,-11714 }, { 178,-11714 },
 { 179,-11714 }, { 180,-11714 }, { 181,-11714 }, { 182,-11714 }, { 183,-11714 },
 { 184,-11714 }, { 185,-11714 }, { 186,-11714 }, { 187,-11714 }, { 188,-11714 },

 { 189,-11714 }, { 190,-11714 }, { 191,-11714 }, { 192,-11714 }, { 193,-11714 },
 { 194,-11714 }, { 195,-11714 }, { 196,-11714 }, { 197,-11714 }, { 198,-11714 },
 { 199,-11714 }, { 200,-11714 }, { 201,-11714 }, { 202,-11714 }, { 203,-11714 },
 { 204,-11714 }, { 205,-11714 }, { 206,-11714 }, { 207,-11714 }, { 208,-11714 },
 { 209,-11714 }, { 210,-11714 }, { 211,-11714 }, { 212,-11714 }, { 213,-11714 },
 { 214,-11714 }, { 215,-11714 }, { 216,-11714 }, { 217,-11714 }, { 218,-11714 },
 { 219,-11714 }, { 220,-11714 }, { 221,-11714 }, { 222,-11714 }, { 223,-11714 },
 { 224,-11714 }, { 225,-11714 }, { 226,-11714 }, { 227,-11714 }, { 228,-11714 },
 { 229,-11714 }, { 230,-11714 }, { 231,-11714 }, { 232,-11714 }, { 233,-11714 },
 { 234,-11714 }, { 235,-11714 }, { 236,-11714 }, { 237,-11714 }, { 238,-11714 },

 { 239,-11714 }, { 240,-11714 }, { 241,-11714 }, { 242,-11714 }, { 243,-11714 },
 { 244,-11714 }, { 245,-11714 }, { 246,-11714 }, { 247,-11714 }, { 248,-11714 },
 { 249,-11714 }, { 250,-11714 }, { 251,-11714 }, { 252,-11714 }, { 253,-11714 },
 { 254,-11714 }, { 255,-11714 }, {   0,  66 }, {   0,5932 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,2952 }, {  49,2952 }, {  50,2952 }, {  51,2952 },
 {  52,2952 }, {  53,2952 }, {  54,2952 }, {  55,2952 }, {  56,2952 },
 {  57,2952 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-11699 }, {  66,-11699 },
 {  67,-11699 }, {  68,-11699 }, {  69,-11699 }, {  70,-11699 }, {  71,-11699 },
 {  72,-11699 }, {  73,-11699 }, {  74,-11699 }, {  75,-11699 }, {  76,-11699 },
 {  77,-11699 }, {  78,-11699 }, {  79,-11699 }, {  80,-11699 }, {  81,-11699 },

 {  82,-11699 }, {  83,-11699 }, {  84,-11699 }, {  85,-11699 }, {  86,-11699 },
 {  87,-11699 }, {  88,-11699 }, {  89,-11699 }, {  90,-11699 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,3209 }, {   0,   0 },
 {  97,-11699 }, {  98,-11699 }, {  99,-11699 }, { 100,-11699 }, { 101,-11699 },
 { 102,-11699 }, { 103,-11699 }, { 104,-11699 }, { 105,-11699 }, { 106,-11699 },
 { 107,-11699 }, { 108,-11699 }, { 109,-11699 }, { 110,-11699 }, { 111,-11699 },
 { 112,-11699 }, { 113,-11699 }, { 114,-11699 }, { 115,-11699 }, { 116,-11699 },
 { 117,-11699 }, { 118,-11699 }, { 119,-11699 }, { 120,-11699 }, { 121,-11699 },
 { 122,-11699 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,-11699 }, { 129,-11699 }, { 130,-11699 }, { 131,-11699 },

 { 132,-11699 }, { 133,-11699 }, { 134,-11699 }, { 135,-11699 }, { 136,-11699 },
 { 137,-11699 }, { 138,-11699 }, { 139,-11699 }, { 140,-11699 }, { 141,-11699 },
 { 142,-11699 }, { 143,-11699 }, { 144,-11699 }, { 145,-11699 }, { 146,-11699 },
 { 147,-11699 }, { 148,-11699 }, { 149,-11699 }, { 150,-11699 }, { 151,-11699 },
 { 152,-11699 }, { 153,-11699 }, { 154,-11699 }, { 155,-11699 }, { 156,-11699 },
 { 157,-11699 }, { 158,-11699 }, { 159,-11699 }, { 160,-11699 }, { 161,-11699 },
 { 162,-11699 }, { 163,-11699 }, { 164,-11699 }, { 165,-11699 }, { 166,-11699 },
 { 167,-11699 }, { 168,-11699 }, { 169,-11699 }, { 170,-11699 }, { 171,-11699 },
 { 172,-11699 }, { 173,-11699 }, { 174,-11699 }, { 175,-11699 }, { 176,-11699 },
 { 177,-11699 }, { 178,-11699 }, { 179,-11699 }, { 180,-11699 }, { 181,-11699 },

 { 182,-11699 }, { 183,-11699 }, { 184,-11699 }, { 185,-11699 }, { 186,-11699 },
 { 187,-11699 }, { 188,-11699 }, { 189,-11699 }, { 190,-11699 }, { 191,-11699 },
 { 192,-11699 }, { 193,-11699 }, { 194,-11699 }, { 195,-11699 }, { 196,-11699 },
 { 197,-11699 }, { 198,-11699 }, { 199,-11699 }, { 200,-11699 }, { 201,-11699 },
 { 202,-11699 }, { 203,-11699 }, { 204,-11699 }, { 205,-11699 }, { 206,-11699 },
 { 207,-11699 }, { 208,-11699 }, { 209,-11699 }, { 210,-11699 }, { 211,-11699 },
 { 212,-11699 }, { 213,-11699 }, { 214,-11699 }, { 215,-11699 }, { 216,-11699 },
 { 217,-11699 }, { 218,-11699 }, { 219,-11699 }, { 220,-11699 }, { 221,-11699 },
 { 222,-11699 }, { 223,-11699 }, { 224,-11699 }, { 225,-11699 }, { 226,-11699 },
 { 227,-11699 }, { 228,-11699 }, { 229,-11699 }, { 230,-11699 }, { 231,-11699 },

 { 232,-11699 }, { 233,-11699 }, { 234,-11699 }, { 235,-11699 }, { 236,-11699 },
 { 237,-11699 }, { 238,-11699 }, { 239,-11699 }, { 240,-11699 }, { 241,-11699 },
 { 242,-11699 }, { 243,-11699 }, { 244,-11699 }, { 245,-11699 }, { 246,-11699 },
 { 247,-11699 }, { 248,-11699 }, { 249,-11699 }, { 250,-11699 }, { 251,-11699 },
 { 252,-11699 }, { 253,-11699 }, { 254,-11699 }, { 255,-11699 }, {   0,  59 },
 {   0,5675 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  62 }, {   0,5667 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  48,  -8 }, {  49,  -8 }, {  50,  -8 }, {  51,  -8 },
 {  52,  -8 }, {  53,  -8 }, {  54,  -8 }, {  55,  -8 }, {   0,   0 },
 {  65,-11954 }, {  66,-11954 }, {  67,-11954 }, {  68,-11954 }, {  69,-11954 },
 {  70,-11954 }, {  71,-11954 }, {  72,-11954 }, {  73,-11954 }, {  74,-11954 },

 {  75,-11954 }, {  76,-11954 }, {  77,-11954 }, {  78,-11954 }, {  79,-11954 },
 {  80,-11954 }, {  81,-11954 }, {  82,-11954 }, {  83,-11954 }, {  84,-11954 },
 {  85,-11954 }, {  86,-11954 }, {  87,-11954 }, {  88,-11954 }, {  89,-11954 },
 {  90,-11954 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,2962 }, {   0,   0 }, {  97,-11954 }, {  98,-11954 }, {  99,-11954 },
 { 100,-11954 }, { 101,-11954 }, { 102,-11954 }, { 103,-11954 }, { 104,-11954 },
 { 105,-11954 }, { 106,-11954 }, { 107,-11954 }, { 108,-11954 }, { 109,-11954 },
 { 110,-11954 }, { 111,-11954 }, { 112,-11954 }, { 113,-11954 }, { 114,-11954 },
 { 115,-11954 }, { 116,-11954 }, { 117,-11954 }, { 118,-11954 }, { 119,-11954 },
 { 120,-11954 }, { 121,-11954 }, { 122,-11954 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-11954 }, { 129,-11954 },
 { 130,-11954 }, { 131,-11954 }, { 132,-11954 }, { 133,-11954 }, { 134,-11954 },
 { 135,-11954 }, { 136,-11954 }, { 137,-11954 }, { 138,-11954 }, { 139,-11954 },
 { 140,-11954 }, { 141,-11954 }, { 142,-11954 }, { 143,-11954 }, { 144,-11954 },
 { 145,-11954 }, { 146,-11954 }, { 147,-11954 }, { 148,-11954 }, { 149,-11954 },
 { 150,-11954 }, { 151,-11954 }, { 152,-11954 }, { 153,-11954 }, { 154,-11954 },
 { 155,-11954 }, { 156,-11954 }, { 157,-11954 }, { 158,-11954 }, { 159,-11954 },
 { 160,-11954 }, { 161,-11954 }, { 162,-11954 }, { 163,-11954 }, { 164,-11954 },
 { 165,-11954 }, { 166,-11954 }, { 167,-11954 }, { 168,-11954 }, { 169,-11954 },
 { 170,-11954 }, { 171,-11954 }, { 172,-11954 }, { 173,-11954 }, { 174,-11954 },

 { 175,-11954 }, { 176,-11954 }, { 177,-11954 }, { 178,-11954 }, { 179,-11954 },
 { 180,-11954 }, { 181,-11954 }, { 182,-11954 }, { 183,-11954 }, { 184,-11954 },
 { 185,-11954 }, { 186,-11954 }, { 187,-11954 }, { 188,-11954 }, { 189,-11954 },
 { 190,-11954 }, { 191,-11954 }, { 192,-11954 }, { 193,-11954 }, { 194,-11954 },
 { 195,-11954 }, { 196,-11954 }, { 197,-11954 }, { 198,-11954 }, { 199,-11954 },
 { 200,-11954 }, { 201,-11954 }, { 202,-11954 }, { 203,-11954 }, { 204,-11954 },
 { 205,-11954 }, { 206,-11954 }, { 207,-11954 }, { 208,-11954 }, { 209,-11954 },
 { 210,-11954 }, { 211,-11954 }, { 212,-11954 }, { 213,-11954 }, { 214,-11954 },
 { 215,-11954 }, { 216,-11954 }, { 217,-11954 }, { 218,-11954 }, { 219,-11954 },
 { 220,-11954 }, { 221,-11954 }, { 222,-11954 }, { 223,-11954 }, { 224,-11954 },

 { 225,-11954 }, { 226,-11954 }, { 227,-11954 }, { 228,-11954 }, { 229,-11954 },
 { 230,-11954 }, { 231,-11954 }, { 232,-11954 }, { 233,-11954 }, { 234,-11954 },
 { 235,-11954 }, { 236,-11954 }, { 237,-11954 }, { 238,-11954 }, { 239,-11954 },
 { 240,-11954 }, { 241,-11954 }, { 242,-11954 }, { 243,-11954 }, { 244,-11954 },
 { 245,-11954 }, { 246,-11954 }, { 247,-11954 }, { 248,-11954 }, { 249,-11954 },
 { 250,-11954 }, { 251,-11954 }, { 252,-11954 }, { 253,-11954 }, { 254,-11954 },
 { 255,-11954 }, {   0,  58 }, {   0,5418 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,2713 }, {  66,2713 }, {  67,2713 },

 {  68,2713 }, {  69,2713 }, {  70,2713 }, {  71,-12209 }, {  72,-12209 },
 {  73,-12209 }, {  74,-12209 }, {  75,-12209 }, {  76,-12209 }, {  77,-12209 },
 {  78,-12209 }, {  79,-12209 }, {  80,-12209 }, {  81,-12209 }, {  82,-12209 },
 {  83,-12209 }, {  84,-12209 }, {  85,-12209 }, {  86,-12209 }, {  87,-12209 },
 {  88,-12209 }, {  89,-12209 }, {  90,-12209 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,2970 }, {   0,   0 }, {  97,2713 },
 {  98,2713 }, {  99,2713 }, { 100,2713 }, { 101,2713 }, { 102,2713 },
 { 103,-12209 }, { 104,-12209 }, { 105,-12209 }, { 106,-12209 }, { 107,-12209 },
 { 108,-12209 }, { 109,-12209 }, { 110,-12209 }, { 111,-12209 }, { 112,-12209 },
 { 113,-12209 }, { 114,-12209 }, { 115,-12209 }, { 116,-12209 }, { 117,-12209 },

 { 118,-12209 }, { 119,-12209 }, { 120,-12209 }, { 121,-12209 }, { 122,-12209 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-12209 }, { 129,-12209 }, { 130,-12209 }, { 131,-12209 }, { 132,-12209 },
 { 133,-12209 }, { 134,-12209 }, { 135,-12209 }, { 136,-12209 }, { 137,-12209 },
 { 138,-12209 }, { 139,-12209 }, { 140,-12209 }, { 141,-12209 }, { 142,-12209 },
 { 143,-12209 }, { 144,-12209 }, { 145,-12209 }, { 146,-12209 }, { 147,-12209 },
 { 148,-12209 }, { 149,-12209 }, { 150,-12209 }, { 151,-12209 }, { 152,-12209 },
 { 153,-12209 }, { 154,-12209 }, { 155,-12209 }, { 156,-12209 }, { 157,-12209 },
 { 158,-12209 }, { 159,-12209 }, { 160,-12209 }, { 161,-12209 }, { 162,-12209 },
 { 163,-12209 }, { 164,-12209 }, { 165,-12209 }, { 166,-12209 }, { 167,-12209 },

 { 168,-12209 }, { 169,-12209 }, { 170,-12209 }, { 171,-12209 }, { 172,-12209 },
 { 173,-12209 }, { 174,-12209 }, { 175,-12209 }, { 176,-12209 }, { 177,-12209 },
 { 178,-12209 }, { 179,-12209 }, { 180,-12209 }, { 181,-12209 }, { 182,-12209 },
 { 183,-12209 }, { 184,-12209 }, { 185,-12209 }, { 186,-12209 }, { 187,-12209 },
 { 188,-12209 }, { 189,-12209 }, { 190,-12209 }, { 191,-12209 }, { 192,-12209 },
 { 193,-12209 }, { 194,-12209 }, { 195,-12209 }, { 196,-12209 }, { 197,-12209 },
 { 198,-12209 }, { 199,-12209 }, { 200,-12209 }, { 201,-12209 }, { 202,-12209 },
 { 203,-12209 }, { 204,-12209 }, { 205,-12209 }, { 206,-12209 }, { 207,-12209 },
 { 208,-12209 }, { 209,-12209 }, { 210,-12209 }, { 211,-12209 }, { 212,-12209 },
 { 213,-12209 }, { 214,-12209 }, { 215,-12209 }, { 216,-12209 }, { 217,-12209 },

 { 218,-12209 }, { 219,-12209 }, { 220,-12209 }, { 221,-12209 }, { 222,-12209 },
 { 223,-12209 }, { 224,-12209 }, { 225,-12209 }, { 226,-12209 }, { 227,-12209 },
 { 228,-12209 }, { 229,-12209 }, { 230,-12209 }, { 231,-12209 }, { 232,-12209 },
 { 233,-12209 }, { 234,-12209 }, { 235,-12209 }, { 236,-12209 }, { 237,-12209 },
 { 238,-12209 }, { 239,-12209 }, { 240,-12209 }, { 241,-12209 }, { 242,-12209 },
 { 243,-12209 }, { 244,-12209 }, { 245,-12209 }, { 246,-12209 }, { 247,-12209 },
 { 248,-12209 }, { 249,-12209 }, { 250,-12209 }, { 251,-12209 }, { 252,-12209 },
 { 253,-12209 }, { 254,-12209 }, { 255,-12209 }, {   0,  61 }, {   0,5161 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  57 }, {   0,5123 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,-257 }, {  49,-257 }, {  50,-257 },
 {  51,-257 }, {  52,-257 }, {  53,-257 }, {  54,-257 }, {  55,-257 },
 {  56,-257 }, {  57,-257 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-257 },
 {  66,-257 }, {  67,-257 }, {  68,-257 }, {  69,-257 }, {  70,-257 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,2713 }, {   0,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {   0,   0 }, {  97,-257 }, {  98,-257 }, {  99,-257 }, { 100,-257 },
 { 101,-257 }, { 102,-257 }, {  65,-13155 }, {  66,-13155 }, {  67,-13155 },
 {  68,-13155 }, {  69,-5775 }, {  70,-13155 }, {  71,-13155 }, {  72,-13155 },

 {  73,-13155 }, {  74,-13155 }, {  75,-13155 }, {  76,-13155 }, {  77,-13155 },
 {  78,-13155 }, {  79,-13155 }, {  80,-13155 }, {  81,-13155 }, {  82,-13155 },
 {  83,-13155 }, {  84,-13155 }, {  85,-13155 }, {  86,-13155 }, {  87,-13155 },
 {  88,-13155 }, {  89,-13155 }, {  90,-13155 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,-5734 }, {   0,   0 }, {  97,-13155 },
 {  98,-13155 }, {  99,-13155 }, { 100,-13155 }, { 101,-5775 }, { 102,-13155 },
 { 103,-13155 }, { 104,-13155 }, { 105,-13155 }, { 106,-13155 }, { 107,-13155 },
 { 108,-13155 }, { 109,-13155 }, { 110,-13155 }, { 111,-13155 }, { 112,-13155 },
 { 113,-13155 }, { 114,-13155 }, { 115,-13155 }, { 116,-13155 }, { 117,-13155 },
 { 118,-13155 }, { 119,-13155 }, { 120,-13155 }, { 121,-13155 }, { 122,-13155 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-13155 }, { 129,-13155 }, { 130,-13155 }, { 131,-13155 }, { 132,-13155 },
 { 133,-13155 }, { 134,-13155 }, { 135,-13155 }, { 136,-13155 }, { 137,-13155 },
 { 138,-13155 }, { 139,-13155 }, { 140,-13155 }, { 141,-13155 }, { 142,-13155 },
 { 143,-13155 }, { 144,-13155 }, { 145,-13155 }, { 146,-13155 }, { 147,-13155 },
 { 148,-13155 }, { 149,-13155 }, { 150,-13155 }, { 151,-13155 }, { 152,-13155 },
 { 153,-13155 }, { 154,-13155 }, { 155,-13155 }, { 156,-13155 }, { 157,-13155 },
 { 158,-13155 }, { 159,-13155 }, { 160,-13155 }, { 161,-13155 }, { 162,-13155 },
 { 163,-13155 }, { 164,-13155 }, { 165,-13155 }, { 166,-13155 }, { 167,-13155 },
 { 168,-13155 }, { 169,-13155 }, { 170,-13155 }, { 171,-13155 }, { 172,-13155 },

 { 173,-13155 }, { 174,-13155 }, { 175,-13155 }, { 176,-13155 }, { 177,-13155 },
 { 178,-13155 }, { 179,-13155 }, { 180,-13155 }, { 181,-13155 }, { 182,-13155 },
 { 183,-13155 }, { 184,-13155 }, { 185,-13155 }, { 186,-13155 }, { 187,-13155 },
 { 188,-13155 }, { 189,-13155 }, { 190,-13155 }, { 191,-13155 }, { 192,-13155 },
 { 193,-13155 }, { 194,-13155 }, { 195,-13155 }, { 196,-13155 }, { 197,-13155 },
 { 198,-13155 }, { 199,-13155 }, { 200,-13155 }, { 201,-13155 }, { 202,-13155 },
 { 203,-13155 }, { 204,-13155 }, { 205,-13155 }, { 206,-13155 }, { 207,-13155 },
 { 208,-13155 }, { 209,-13155 }, { 210,-13155 }, { 211,-13155 }, { 212,-13155 },
 { 213,-13155 }, { 214,-13155 }, { 215,-13155 }, { 216,-13155 }, { 217,-13155 },
 { 218,-13155 }, { 219,-13155 }, { 220,-13155 }, { 221,-13155 }, { 222,-13155 },

 { 223,-13155 }, { 224,-13155 }, { 225,-13155 }, { 226,-13155 }, { 227,-13155 },
 { 228,-13155 }, { 229,-13155 }, { 230,-13155 }, { 231,-13155 }, { 232,-13155 },
 { 233,-13155 }, { 234,-13155 }, { 235,-13155 }, { 236,-13155 }, { 237,-13155 },
 { 238,-13155 }, { 239,-13155 }, { 240,-13155 }, { 241,-13155 }, { 242,-13155 },
 { 243,-13155 }, { 244,-13155 }, { 245,-13155 }, { 246,-13155 }, { 247,-13155 },
 { 248,-13155 }, { 249,-13155 }, { 250,-13155 }, { 251,-13155 }, { 252,-13155 },
 { 253,-13155 }, { 254,-13155 }, { 255,-13155 }, {   0,   3 }, {   0,4866 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  33,   0 }, {   0,   0 }, {  35,   0 },
 {   0,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  42,   0 }, {  43,   0 }, {   0,   0 }, {  45,   0 },
 {   0,   0 }, {  47,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,   0 },
 {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,   0 }, {   0,   0 },
 {  96,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,   0 }, {   0,   0 },
 { 126,   0 }, {   0,  18 }, {   0,4738 }, {   1,2585 }, {   2,2585 },
 {   3,2585 }, {   4,2585 }, {   5,2585 }, {   6,2585 }, {   7,2585 },
 {   8,2585 }, {   9,2843 }, {  10,3101 }, {  11,2843 }, {  12,2843 },
 {  13,3101 }, {  14,2585 }, {  15,2585 }, {  16,2585 }, {  17,2585 },
 {  18,2585 }, {  19,2585 }, {  20,2585 }, {  21,2585 }, {  22,2585 },
 {  23,2585 }, {  24,2585 }, {  25,2585 }, {  26,2585 }, {  27,2585 },
 {  28,2585 }, {  29,2585 }, {  30,2585 }, {  31,2585 }, {  32,2843 },
 {  33,2585 }, {  34,2585 }, {  35,2585 }, {  36,2585 }, {  37,2585 },

 {  38,2585 }, {  39,2585 }, {  40,2585 }, {  41,2585 }, {  42,2585 },
 {  43,2585 }, {  44,2585 }, {  45,3148 }, {  46,2585 }, {  47,2585 },
 {  48,2585 }, {  49,2585 }, {  50,2585 }, {  51,2585 }, {  52,2585 },
 {  53,2585 }, {  54,2585 }, {  55,2585 }, {  56,2585 }, {  57,2585 },
 {  58,2585 }, {  59,2585 }, {  60,2585 }, {  61,2585 }, {  62,2585 },
 {  63,2585 }, {  64,2585 }, {  65,2585 }, {  66,2585 }, {  67,2585 },
 {  68,2585 }, {  69,2585 }, {  70,2585 }, {  71,2585 }, {  72,2585 },
 {  73,2585 }, {  74,2585 }, {  75,2585 }, {  76,2585 }, {  77,2585 },
 {  78,2585 }, {  79,2585 }, {  80,2585 }, {  81,2585 }, {  82,2585 },
 {  83,2585 }, {  84,2585 }, {  85,2585 }, {  86,2585 }, {  87,2585 },

 {  88,2585 }, {  89,2585 }, {  90,2585 }, {  91,2585 }, {  92,2585 },
 {  93,2585 }, {  94,2585 }, {  95,2585 }, {  96,2585 }, {  97,2585 },
 {  98,2585 }, {  99,2585 }, { 100,2585 }, { 101,2585 }, { 102,2585 },
 { 103,2585 }, { 104,2585 }, { 105,2585 }, { 106,2585 }, { 107,2585 },
 { 108,2585 }, { 109,2585 }, { 110,2585 }, { 111,2585 }, { 112,2585 },
 { 113,2585 }, { 114,2585 }, { 115,2585 }, { 116,2585 }, { 117,2585 },
 { 118,2585 }, { 119,2585 }, { 120,2585 }, { 121,2585 }, { 122,2585 },
 { 123,2585 }, { 124,2585 }, { 125,2585 }, { 126,2585 }, { 127,2585 },
 { 128,2585 }, { 129,2585 }, { 130,2585 }, { 131,2585 }, { 132,2585 },
 { 133,2585 }, { 134,2585 }, { 135,2585 }, { 136,2585 }, { 137,2585 },

 { 138,2585 }, { 139,2585 }, { 140,2585 }, { 141,2585 }, { 142,2585 },
 { 143,2585 }, { 144,2585 }, { 145,2585 }, { 146,2585 }, { 147,2585 },
 { 148,2585 }, { 149,2585 }, { 150,2585 }, { 151,2585 }, { 152,2585 },
 { 153,2585 }, { 154,2585 }, { 155,2585 }, { 156,2585 }, { 157,2585 },
 { 158,2585 }, { 159,2585 }, { 160,2585 }, { 161,2585 }, { 162,2585 },
 { 163,2585 }, { 164,2585 }, { 165,2585 }, { 166,2585 }, { 167,2585 },
 { 168,2585 }, { 169,2585 }, { 170,2585 }, { 171,2585 }, { 172,2585 },
 { 173,2585 }, { 174,2585 }, { 175,2585 }, { 176,2585 }, { 177,2585 },
 { 178,2585 }, { 179,2585 }, { 180,2585 }, { 181,2585 }, { 182,2585 },
 { 183,2585 }, { 184,2585 }, { 185,2585 }, { 186,2585 }, { 187,2585 },

 { 188,2585 }, { 189,2585 }, { 190,2585 }, { 191,2585 }, { 192,2585 },
 { 193,2585 }, { 194,2585 }, { 195,2585 }, { 196,2585 }, { 197,2585 },
 { 198,2585 }, { 199,2585 }, { 200,2585 }, { 201,2585 }, { 202,2585 },
 { 203,2585 }, { 204,2585 }, { 205,2585 }, { 206,2585 }, { 207,2585 },
 { 208,2585 }, { 209,2585 }, { 210,2585 }, { 211,2585 }, { 212,2585 },
 { 213,2585 }, { 214,2585 }, { 215,2585 }, { 216,2585 }, { 217,2585 },
 { 218,2585 }, { 219,2585 }, { 220,2585 }, { 221,2585 }, { 222,2585 },
 { 223,2585 }, { 224,2585 }, { 225,2585 }, { 226,2585 }, { 227,2585 },
 { 228,2585 }, { 229,2585 }, { 230,2585 }, { 231,2585 }, { 232,2585 },
 { 233,2585 }, { 234,2585 }, { 235,2585 }, { 236,2585 }, { 237,2585 },

 { 238,2585 }, { 239,2585 }, { 240,2585 }, { 241,2585 }, { 242,2585 },
 { 243,2585 }, { 244,2585 }, { 245,2585 }, { 246,2585 }, { 247,2585 },
 { 248,2585 }, { 249,2585 }, { 250,2585 }, { 251,2585 }, { 252,2585 },
 { 253,2585 }, { 254,2585 }, { 255,2585 }, { 256,2585 }, {   0,  18 },
 {   0,4480 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },
 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9, 258 },
 {  10,-4454 }, {  11, 258 }, {  12, 258 }, {  13,-4454 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },
 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },

 {  30,   0 }, {  31,   0 }, {  32, 258 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {  39,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45, 516 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },

 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },
 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },

 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },
 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },

 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },
 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },

 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },
 { 255,   0 }, { 256,   0 }, {   0,  18 }, {   0,4222 }, {   1,-258 },
 {   2,-258 }, {   3,-258 }, {   4,-258 }, {   5,-258 }, {   6,-258 },
 {   7,-258 }, {   8,-258 }, {   9,   0 }, {  10,-4712 }, {  11,   0 },
 {  12,   0 }, {  13,-4712 }, {  14,-258 }, {  15,-258 }, {  16,-258 },
 {  17,-258 }, {  18,-258 }, {  19,-258 }, {  20,-258 }, {  21,-258 },

 {  22,-258 }, {  23,-258 }, {  24,-258 }, {  25,-258 }, {  26,-258 },
 {  27,-258 }, {  28,-258 }, {  29,-258 }, {  30,-258 }, {  31,-258 },
 {  32,   0 }, {  33,-258 }, {  34,-258 }, {  35,-258 }, {  36,-258 },
 {  37,-258 }, {  38,-258 }, {  39,-258 }, {  40,-258 }, {  41,-258 },
 {  42,-258 }, {  43,-258 }, {  44,-258 }, {  45, 258 }, {  46,-258 },
 {  47,-258 }, {  48,-258 }, {  49,-258 }, {  50,-258 }, {  51,-258 },
 {  52,-258 }, {  53,-258 }, {  54,-258 }, {  55,-258 }, {  56,-258 },
 {  57,-258 }, {  58,-258 }, {  59,-258 }, {  60,-258 }, {  61,-258 },
 {  62,-258 }, {  63,-258 }, {  64,-258 }, {  65,-258 }, {  66,-258 },
 {  67,-258 }, {  68,-258 }, {  69,-258 }, {  70,-258 }, {  71,-258 },

 {  72,-258 }, {  73,-258 }, {  74,-258 }, {  75,-258 }, {  76,-258 },
 {  77,-258 }, {  78,-258 }, {  79,-258 }, {  80,-258 }, {  81,-258 },
 {  82,-258 }, {  83,-258 }, {  84,-258 }, {  85,-258 }, {  86,-258 },
 {  87,-258 }, {  88,-258 }, {  89,-258 }, {  90,-258 }, {  91,-258 },
 {  92,-258 }, {  93,-258 }, {  94,-258 }, {  95,-258 }, {  96,-258 },
 {  97,-258 }, {  98,-258 }, {  99,-258 }, { 100,-258 }, { 101,-258 },
 { 102,-258 }, { 103,-258 }, { 104,-258 }, { 105,-258 }, { 106,-258 },
 { 107,-258 }, { 108,-258 }, { 109,-258 }, { 110,-258 }, { 111,-258 },
 { 112,-258 }, { 113,-258 }, { 114,-258 }, { 115,-258 }, { 116,-258 },
 { 117,-258 }, { 118,-258 }, { 119,-258 }, { 120,-258 }, { 121,-258 },

 { 122,-258 }, { 123,-258 }, { 124,-258 }, { 125,-258 }, { 126,-258 },
 { 127,-258 }, { 128,-258 }, { 129,-258 }, { 130,-258 }, { 131,-258 },
 { 132,-258 }, { 133,-258 }, { 134,-258 }, { 135,-258 }, { 136,-258 },
 { 137,-258 }, { 138,-258 }, { 139,-258 }, { 140,-258 }, { 141,-258 },
 { 142,-258 }, { 143,-258 }, { 144,-258 }, { 145,-258 }, { 146,-258 },
 { 147,-258 }, { 148,-258 }, { 149,-258 }, { 150,-258 }, { 151,-258 },
 { 152,-258 }, { 153,-258 }, { 154,-258 }, { 155,-258 }, { 156,-258 },
 { 157,-258 }, { 158,-258 }, { 159,-258 }, { 160,-258 }, { 161,-258 },
 { 162,-258 }, { 163,-258 }, { 164,-258 }, { 165,-258 }, { 166,-258 },
 { 167,-258 }, { 168,-258 }, { 169,-258 }, { 170,-258 }, { 171,-258 },

 { 172,-258 }, { 173,-258 }, { 174,-258 }, { 175,-258 }, { 176,-258 },
 { 177,-258 }, { 178,-258 }, { 179,-258 }, { 180,-258 }, { 181,-258 },
 { 182,-258 }, { 183,-258 }, { 184,-258 }, { 185,-258 }, { 186,-258 },
 { 187,-258 }, { 188,-258 }, { 189,-258 }, { 190,-258 }, { 191,-258 },
 { 192,-258 }, { 193,-258 }, { 194,-258 }, { 195,-258 }, { 196,-258 },
 { 197,-258 }, { 198,-258 }, { 199,-258 }, { 200,-258 }, { 201,-258 },
 { 202,-258 }, { 203,-258 }, { 204,-258 }, { 205,-258 }, { 206,-258 },
 { 207,-258 }, { 208,-258 }, { 209,-258 }, { 210,-258 }, { 211,-258 },
 { 212,-258 }, { 213,-258 }, { 214,-258 }, { 215,-258 }, { 216,-258 },
 { 217,-258 }, { 218,-258 }, { 219,-258 }, { 220,-258 }, { 221,-258 },

 { 222,-258 }, { 223,-258 }, { 224,-258 }, { 225,-258 }, { 226,-258 },
 { 227,-258 }, { 228,-258 }, { 229,-258 }, { 230,-258 }, { 231,-258 },
 { 232,-258 }, { 233,-258 }, { 234,-258 }, { 235,-258 }, { 236,-258 },
 { 237,-258 }, { 238,-258 }, { 239,-258 }, { 240,-258 }, { 241,-258 },
 { 242,-258 }, { 243,-258 }, { 244,-258 }, { 245,-258 }, { 246,-258 },
 { 247,-258 }, { 248,-258 }, { 249,-258 }, { 250,-258 }, { 251,-258 },
 { 252,-258 }, { 253,-258 }, { 254,-258 }, { 255,-258 }, { 256,-258 },
 {   0,  18 }, {   0,3964 }, {   1,-516 }, {   2,-516 }, {   3,-516 },
 {   4,-516 }, {   5,-516 }, {   6,-516 }, {   7,-516 }, {   8,-516 },
 {   9,-258 }, {  10,-4970 }, {  11,-258 }, {  12,-258 }, {  13,-4970 },

 {  14,-516 }, {  15,-516 }, {  16,-516 }, {  17,-516 }, {  18,-516 },
 {  19,-516 }, {  20,-516 }, {  21,-516 }, {  22,-516 }, {  23,-516 },
 {  24,-516 }, {  25,-516 }, {  26,-516 }, {  27,-516 }, {  28,-516 },
 {  29,-516 }, {  30,-516 }, {  31,-516 }, {  32,-258 }, {  33,-516 },
 {  34,-516 }, {  35,-516 }, {  36,-516 }, {  37,-516 }, {  38,-516 },
 {  39,-516 }, {  40,-516 }, {  41,-516 }, {  42,-516 }, {  43,-516 },
 {  44,-516 }, {  45,2632 }, {  46,-516 }, {  47,-516 }, {  48,-516 },
 {  49,-516 }, {  50,-516 }, {  51,-516 }, {  52,-516 }, {  53,-516 },
 {  54,-516 }, {  55,-516 }, {  56,-516 }, {  57,-516 }, {  58,-516 },
 {  59,-516 }, {  60,-516 }, {  61,-516 }, {  62,-516 }, {  63,-516 },

 {  64,-516 }, {  65,-516 }, {  66,-516 }, {  67,-516 }, {  68,-516 },
 {  69,-516 }, {  70,-516 }, {  71,-516 }, {  72,-516 }, {  73,-516 },
 {  74,-516 }, {  75,-516 }, {  76,-516 }, {  77,-516 }, {  78,-516 },
 {  79,-516 }, {  80,-516 }, {  81,-516 }, {  82,-516 }, {  83,-516 },
 {  84,-516 }, {  85,-516 }, {  86,-516 }, {  87,-516 }, {  88,-516 },
 {  89,-516 }, {  90,-516 }, {  91,-516 }, {  92,-516 }, {  93,-516 },
 {  94,-516 }, {  95,-516 }, {  96,-516 }, {  97,-516 }, {  98,-516 },
 {  99,-516 }, { 100,-516 }, { 101,-516 }, { 102,-516 }, { 103,-516 },
 { 104,-516 }, { 105,-516 }, { 106,-516 }, { 107,-516 }, { 108,-516 },
 { 109,-516 }, { 110,-516 }, { 111,-516 }, { 112,-516 }, { 113,-516 },

 { 114,-516 }, { 115,-516 }, { 116,-516 }, { 117,-516 }, { 118,-516 },
 { 119,-516 }, { 120,-516 }, { 121,-516 }, { 122,-516 }, { 123,-516 },
 { 124,-516 }, { 125,-516 }, { 126,-516 }, { 127,-516 }, { 128,-516 },
 { 129,-516 }, { 130,-516 }, { 131,-516 }, { 132,-516 }, { 133,-516 },
 { 134,-516 }, { 135,-516 }, { 136,-516 }, { 137,-516 }, { 138,-516 },
 { 139,-516 }, { 140,-516 }, { 141,-516 }, { 142,-516 }, { 143,-516 },
 { 144,-516 }, { 145,-516 }, { 146,-516 }, { 147,-516 }, { 148,-516 },
 { 149,-516 }, { 150,-516 }, { 151,-516 }, { 152,-516 }, { 153,-516 },
 { 154,-516 }, { 155,-516 }, { 156,-516 }, { 157,-516 }, { 158,-516 },
 { 159,-516 }, { 160,-516 }, { 161,-516 }, { 162,-516 }, { 163,-516 },

 { 164,-516 }, { 165,-516 }, { 166,-516 }, { 167,-516 }, { 168,-516 },
 { 169,-516 }, { 170,-516 }, { 171,-516 }, { 172,-516 }, { 173,-516 },
 { 174,-516 }, { 175,-516 }, { 176,-516 }, { 177,-516 }, { 178,-516 },
 { 179,-516 }, { 180,-516 }, { 181,-516 }, { 182,-516 }, { 183,-516 },
 { 184,-516 }, { 185,-516 }, { 186,-516 }, { 187,-516 }, { 188,-516 },
 { 189,-516 }, { 190,-516 }, { 191,-516 }, { 192,-516 }, { 193,-516 },
 { 194,-516 }, { 195,-516 }, { 196,-516 }, { 197,-516 }, { 198,-516 },
 { 199,-516 }, { 200,-516 }, { 201,-516 }, { 202,-516 }, { 203,-516 },
 { 204,-516 }, { 205,-516 }, { 206,-516 }, { 207,-516 }, { 208,-516 },
 { 209,-516 }, { 210,-516 }, { 211,-516 }, { 212,-516 }, { 213,-516 },

 { 214,-516 }, { 215,-516 }, { 216,-516 }, { 217,-516 }, { 218,-516 },
 { 219,-516 }, { 220,-516 }, { 221,-516 }, { 222,-516 }, { 223,-516 },
 { 224,-516 }, { 225,-516 }, { 226,-516 }, { 227,-516 }, { 228,-516 },
 { 229,-516 }, { 230,-516 }, { 231,-516 }, { 232,-516 }, { 233,-516 },
 { 234,-516 }, { 235,-516 }, { 236,-516 }, { 237,-516 }, { 238,-516 },
 { 239,-516 }, { 240,-516 }, { 241,-516 }, { 242,-516 }, { 243,-516 },
 { 244,-516 }, { 245,-516 }, { 246,-516 }, { 247,-516 }, { 248,-516 },
 { 249,-516 }, { 250,-516 }, { 251,-516 }, { 252,-516 }, { 253,-516 },
 { 254,-516 }, { 255,-516 }, { 256,-516 }, {   0,  29 }, {   0,3706 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,  27 }, {   0,3698 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0,3675 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,-13919 }, {  49,-13919 }, {  50,-13919 },
 {  51,-13919 }, {  52,-13919 }, {  53,-13919 }, {  54,-13919 }, {  55,-13919 },

 {  48,2624 }, {  49,2624 }, {  50,2624 }, {  51,2624 }, {  52,2624 },
 {  53,2624 }, {  54,2624 }, {  55,2624 }, {  56,2624 }, {  57,2624 },
 {   0,   0 }, {   0,   0 }, {   0,  30 }, {   0,3637 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,2624 }, {  66,2624 }, {  67,2624 },
 {  68,2624 }, {  69,2624 }, {  70,2624 }, {  48,2624 }, {  49,2624 },
 {  50,2624 }, {  51,2624 }, {  52,2624 }, {  53,2624 }, {  54,2624 },
 {  55,2624 }, {  56,2624 }, {  57,2624 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,2624 }, {  66,2624 }, {  67,2624 }, {  68,2624 }, {  69,2624 },
 {  70,2624 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,2624 },

 {  98,2624 }, {  99,2624 }, { 100,2624 }, { 101,2624 }, { 102,2624 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,-13986 }, {  49,-13986 }, {  50,-13986 }, {  51,-13986 },
 {  52,-13986 }, {  53,-13986 }, {  54,-13986 }, {  55,-13986 }, {  56,-13986 },
 {  57,-13986 }, {   0,   0 }, {  97,2624 }, {  98,2624 }, {  99,2624 },
 { 100,2624 }, { 101,2624 }, { 102,2624 }, {  65,-13986 }, {  66,-13986 },
 {  67,-13986 }, {  68,-13986 }, {  69,-13986 }, {  70,-13986 }, {   0,  36 },
 {   0,3565 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97,-13986 }, {  98,-13986 }, {  99,-13986 }, { 100,-13986 }, { 101,-13986 },
 { 102,-13986 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  36,-14357 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,   0 }, {   0,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },
 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },

 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },
 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },

 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },
 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },

 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },
 { 255,   0 }, {   0,  27 }, {   0,3308 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0,3285 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,2295 }, {  49,2295 }, {  50,2295 }, {  51,2295 }, {  52,2295 },
 {  53,2295 }, {  54,2295 }, {  55,2295 }, {  56,2295 }, {  57,2295 },

 {   0,   0 }, {   0,   0 }, {   0,  64 }, {   0,3247 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,2295 }, {  66,2295 }, {  67,2295 },
 {  68,2295 }, {  69,2295 }, {  70,2295 }, {  48,2295 }, {  49,2295 },
 {  50,2295 }, {  51,2295 }, {  52,2295 }, {  53,2295 }, {  54,2295 },
 {  55,2295 }, {  56,2295 }, {  57,2295 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,2295 }, {  66,2295 }, {  67,2295 }, {  68,2295 }, {  69,2295 },
 {  70,2295 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,2295 },
 {  98,2295 }, {  99,2295 }, { 100,2295 }, { 101,2295 }, { 102,2295 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {   0,   0 }, {  97,2295 }, {  98,2295 }, {  99,2295 },
 { 100,2295 }, { 101,2295 }, { 102,2295 }, {  65,-14670 }, {  66,-14670 },
 {  67,-14670 }, {  68,-14670 }, {  69,-3300 }, {  70,-14670 }, {  71,-14670 },
 {  72,-14670 }, {  73,-14670 }, {  74,-14670 }, {  75,-14670 }, {  76,-14670 },
 {  77,-14670 }, {  78,-14670 }, {  79,-14670 }, {  80,-14670 }, {  81,-14670 },
 {  82,-14670 }, {  83,-14670 }, {  84,-14670 }, {  85,-14670 }, {  86,-14670 },
 {  87,-14670 }, {  88,-14670 }, {  89,-14670 }, {  90,-14670 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95, 257 }, {   0,   0 },

 {  97,-14670 }, {  98,-14670 }, {  99,-14670 }, { 100,-14670 }, { 101,-3300 },
 { 102,-14670 }, { 103,-14670 }, { 104,-14670 }, { 105,-14670 }, { 106,-14670 },
 { 107,-14670 }, { 108,-14670 }, { 109,-14670 }, { 110,-14670 }, { 111,-14670 },
 { 112,-14670 }, { 113,-14670 }, { 114,-14670 }, { 115,-14670 }, { 116,-14670 },
 { 117,-14670 }, { 118,-14670 }, { 119,-14670 }, { 120,-14670 }, { 121,-14670 },
 { 122,-14670 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,-14670 }, { 129,-14670 }, { 130,-14670 }, { 131,-14670 },
 { 132,-14670 }, { 133,-14670 }, { 134,-14670 }, { 135,-14670 }, { 136,-14670 },
 { 137,-14670 }, { 138,-14670 }, { 139,-14670 }, { 140,-14670 }, { 141,-14670 },
 { 142,-14670 }, { 143,-14670 }, { 144,-14670 }, { 145,-14670 }, { 146,-14670 },

 { 147,-14670 }, { 148,-14670 }, { 149,-14670 }, { 150,-14670 }, { 151,-14670 },
 { 152,-14670 }, { 153,-14670 }, { 154,-14670 }, { 155,-14670 }, { 156,-14670 },
 { 157,-14670 }, { 158,-14670 }, { 159,-14670 }, { 160,-14670 }, { 161,-14670 },
 { 162,-14670 }, { 163,-14670 }, { 164,-14670 }, { 165,-14670 }, { 166,-14670 },
 { 167,-14670 }, { 168,-14670 }, { 169,-14670 }, { 170,-14670 }, { 171,-14670 },
 { 172,-14670 }, { 173,-14670 }, { 174,-14670 }, { 175,-14670 }, { 176,-14670 },
 { 177,-14670 }, { 178,-14670 }, { 179,-14670 }, { 180,-14670 }, { 181,-14670 },
 { 182,-14670 }, { 183,-14670 }, { 184,-14670 }, { 185,-14670 }, { 186,-14670 },
 { 187,-14670 }, { 188,-14670 }, { 189,-14670 }, { 190,-14670 }, { 191,-14670 },
 { 192,-14670 }, { 193,-14670 }, { 194,-14670 }, { 195,-14670 }, { 196,-14670 },

 { 197,-14670 }, { 198,-14670 }, { 199,-14670 }, { 200,-14670 }, { 201,-14670 },
 { 202,-14670 }, { 203,-14670 }, { 204,-14670 }, { 205,-14670 }, { 206,-14670 },
 { 207,-14670 }, { 208,-14670 }, { 209,-14670 }, { 210,-14670 }, { 211,-14670 },
 { 212,-14670 }, { 213,-14670 }, { 214,-14670 }, { 215,-14670 }, { 216,-14670 },
 { 217,-14670 }, { 218,-14670 }, { 219,-14670 }, { 220,-14670 }, { 221,-14670 },
 { 222,-14670 }, { 223,-14670 }, { 224,-14670 }, { 225,-14670 }, { 226,-14670 },
 { 227,-14670 }, { 228,-14670 }, { 229,-14670 }, { 230,-14670 }, { 231,-14670 },
 { 232,-14670 }, { 233,-14670 }, { 234,-14670 }, { 235,-14670 }, { 236,-14670 },
 { 237,-14670 }, { 238,-14670 }, { 239,-14670 }, { 240,-14670 }, { 241,-14670 },
 { 242,-14670 }, { 243,-14670 }, { 244,-14670 }, { 245,-14670 }, { 246,-14670 },

 { 247,-14670 }, { 248,-14670 }, { 249,-14670 }, { 250,-14670 }, { 251,-14670 },
 { 252,-14670 }, { 253,-14670 }, { 254,-14670 }, { 255,-14670 }, {   0,  72 },
 {   0,2990 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  66 },
 {   0,2980 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-257 }, {  49,-257 },
 {  50,-257 }, {  51,-257 }, {  52,-257 }, {  53,-257 }, {  54,-257 },
 {  55,-257 }, {  56,-257 }, {  57,-257 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,-14651 }, {  66,-14651 }, {  67,-14651 }, {  68,-14651 }, {  69,-14651 },
 {  70,-14651 }, {  71,-14651 }, {  72,-14651 }, {  73,-14651 }, {  74,-14651 },
 {  75,-14651 }, {  76,-14651 }, {  77,-14651 }, {  78,-14651 }, {  79,-14651 },

 {  80,-14651 }, {  81,-14651 }, {  82,-14651 }, {  83,-14651 }, {  84,-14651 },
 {  85,-14651 }, {  86,-14651 }, {  87,-14651 }, {  88,-14651 }, {  89,-14651 },
 {  90,-14651 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95, 257 }, {   0,   0 }, {  97,-14651 }, {  98,-14651 }, {  99,-14651 },
 { 100,-14651 }, { 101,-14651 }, { 102,-14651 }, { 103,-14651 }, { 104,-14651 },
 { 105,-14651 }, { 106,-14651 }, { 107,-14651 }, { 108,-14651 }, { 109,-14651 },
 { 110,-14651 }, { 111,-14651 }, { 112,-14651 }, { 113,-14651 }, { 114,-14651 },
 { 115,-14651 }, { 116,-14651 }, { 117,-14651 }, { 118,-14651 }, { 119,-14651 },
 { 120,-14651 }, { 121,-14651 }, { 122,-14651 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-14651 }, { 129,-14651 },

 { 130,-14651 }, { 131,-14651 }, { 132,-14651 }, { 133,-14651 }, { 134,-14651 },
 { 135,-14651 }, { 136,-14651 }, { 137,-14651 }, { 138,-14651 }, { 139,-14651 },
 { 140,-14651 }, { 141,-14651 }, { 142,-14651 }, { 143,-14651 }, { 144,-14651 },
 { 145,-14651 }, { 146,-14651 }, { 147,-14651 }, { 148,-14651 }, { 149,-14651 },
 { 150,-14651 }, { 151,-14651 }, { 152,-14651 }, { 153,-14651 }, { 154,-14651 },
 { 155,-14651 }, { 156,-14651 }, { 157,-14651 }, { 158,-14651 }, { 159,-14651 },
 { 160,-14651 }, { 161,-14651 }, { 162,-14651 }, { 163,-14651 }, { 164,-14651 },
 { 165,-14651 }, { 166,-14651 }, { 167,-14651 }, { 168,-14651 }, { 169,-14651 },
 { 170,-14651 }, { 171,-14651 }, { 172,-14651 }, { 173,-14651 }, { 174,-14651 },
 { 175,-14651 }, { 176,-14651 }, { 177,-14651 }, { 178,-14651 }, { 179,-14651 },

 { 180,-14651 }, { 181,-14651 }, { 182,-14651 }, { 183,-14651 }, { 184,-14651 },
 { 185,-14651 }, { 186,-14651 }, { 187,-14651 }, { 188,-14651 }, { 189,-14651 },
 { 190,-14651 }, { 191,-14651 }, { 192,-14651 }, { 193,-14651 }, { 194,-14651 },
 { 195,-14651 }, { 196,-14651 }, { 197,-14651 }, { 198,-14651 }, { 199,-14651 },
 { 200,-14651 }, { 201,-14651 }, { 202,-14651 }, { 203,-14651 }, { 204,-14651 },
 { 205,-14651 }, { 206,-14651 }, { 207,-14651 }, { 208,-14651 }, { 209,-14651 },
 { 210,-14651 }, { 211,-14651 }, { 212,-14651 }, { 213,-14651 }, { 214,-14651 },
 { 215,-14651 }, { 216,-14651 }, { 217,-14651 }, { 218,-14651 }, { 219,-14651 },
 { 220,-14651 }, { 221,-14651 }, { 222,-14651 }, { 223,-14651 }, { 224,-14651 },
 { 225,-14651 }, { 226,-14651 }, { 227,-14651 }, { 228,-14651 }, { 229,-14651 },

 { 230,-14651 }, { 231,-14651 }, { 232,-14651 }, { 233,-14651 }, { 234,-14651 },
 { 235,-14651 }, { 236,-14651 }, { 237,-14651 }, { 238,-14651 }, { 239,-14651 },
 { 240,-14651 }, { 241,-14651 }, { 242,-14651 }, { 243,-14651 }, { 244,-14651 },
 { 245,-14651 }, { 246,-14651 }, { 247,-14651 }, { 248,-14651 }, { 249,-14651 },
 { 250,-14651 }, { 251,-14651 }, { 252,-14651 }, { 253,-14651 }, { 254,-14651 },
 { 255,-14651 }, {   0,  73 }, {   0,2723 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  70 }, {   0,2713 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  58 },
 {   0,2705 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,-257 }, {  49,-257 }, {  50,-257 }, {  51,-257 }, {  52,-257 },
 {  53,-257 }, {  54,-257 }, {  55,-257 }, {  56,-257 }, {  57,-257 },
 {  48,-2962 }, {  49,-2962 }, {  50,-2962 }, {  51,-2962 }, {  52,-2962 },
 {  53,-2962 }, {  54,-2962 }, {  55,-2962 }, {  48,-2713 }, {  49,-2713 },
 {  50,-2713 }, {  51,-2713 }, {  52,-2713 }, {  53,-2713 }, {  54,-2713 },

 {  55,-2713 }, {  56,-2713 }, {  57,-2713 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,-14922 }, {  72,-14922 }, {  73,-14922 }, {  74,-14922 },
 {  75,-14922 }, {  76,-14922 }, {  77,-14922 }, {  78,-14922 }, {  79,-14922 },
 {  80,-14922 }, {  81,-14922 }, {  82,-14922 }, {  83,-14922 }, {  84,-14922 },
 {  85,-14922 }, {  86,-14922 }, {  87,-14922 }, {  88,-14922 }, {  89,-14922 },
 {  90,-14922 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95, 257 }, {   0,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,-14922 }, { 104,-14922 },

 { 105,-14922 }, { 106,-14922 }, { 107,-14922 }, { 108,-14922 }, { 109,-14922 },
 { 110,-14922 }, { 111,-14922 }, { 112,-14922 }, { 113,-14922 }, { 114,-14922 },
 { 115,-14922 }, { 116,-14922 }, { 117,-14922 }, { 118,-14922 }, { 119,-14922 },
 { 120,-14922 }, { 121,-14922 }, { 122,-14922 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-14922 }, { 129,-14922 },
 { 130,-14922 }, { 131,-14922 }, { 132,-14922 }, { 133,-14922 }, { 134,-14922 },
 { 135,-14922 }, { 136,-14922 }, { 137,-14922 }, { 138,-14922 }, { 139,-14922 },
 { 140,-14922 }, { 141,-14922 }, { 142,-14922 }, { 143,-14922 }, { 144,-14922 },
 { 145,-14922 }, { 146,-14922 }, { 147,-14922 }, { 148,-14922 }, { 149,-14922 },
 { 150,-14922 }, { 151,-14922 }, { 152,-14922 }, { 153,-14922 }, { 154,-14922 },

 { 155,-14922 }, { 156,-14922 }, { 157,-14922 }, { 158,-14922 }, { 159,-14922 },
 { 160,-14922 }, { 161,-14922 }, { 162,-14922 }, { 163,-14922 }, { 164,-14922 },
 { 165,-14922 }, { 166,-14922 }, { 167,-14922 }, { 168,-14922 }, { 169,-14922 },
 { 170,-14922 }, { 171,-14922 }, { 172,-14922 }, { 173,-14922 }, { 174,-14922 },
 { 175,-14922 }, { 176,-14922 }, { 177,-14922 }, { 178,-14922 }, { 179,-14922 },
 { 180,-14922 }, { 181,-14922 }, { 182,-14922 }, { 183,-14922 }, { 184,-14922 },
 { 185,-14922 }, { 186,-14922 }, { 187,-14922 }, { 188,-14922 }, { 189,-14922 },
 { 190,-14922 }, { 191,-14922 }, { 192,-14922 }, { 193,-14922 }, { 194,-14922 },
 { 195,-14922 }, { 196,-14922 }, { 197,-14922 }, { 198,-14922 }, { 199,-14922 },
 { 200,-14922 }, { 201,-14922 }, { 202,-14922 }, { 203,-14922 }, { 204,-14922 },

 { 205,-14922 }, { 206,-14922 }, { 207,-14922 }, { 208,-14922 }, { 209,-14922 },
 { 210,-14922 }, { 211,-14922 }, { 212,-14922 }, { 213,-14922 }, { 214,-14922 },
 { 215,-14922 }, { 216,-14922 }, { 217,-14922 }, { 218,-14922 }, { 219,-14922 },
 { 220,-14922 }, { 221,-14922 }, { 222,-14922 }, { 223,-14922 }, { 224,-14922 },
 { 225,-14922 }, { 226,-14922 }, { 227,-14922 }, { 228,-14922 }, { 229,-14922 },
 { 230,-14922 }, { 231,-14922 }, { 232,-14922 }, { 233,-14922 }, { 234,-14922 },
 { 235,-14922 }, { 236,-14922 }, { 237,-14922 }, { 238,-14922 }, { 239,-14922 },
 { 240,-14922 }, { 241,-14922 }, { 242,-14922 }, { 243,-14922 }, { 244,-14922 },
 { 245,-14922 }, { 246,-14922 }, { 247,-14922 }, { 248,-14922 }, { 249,-14922 },
 { 250,-14922 }, { 251,-14922 }, { 252,-14922 }, { 253,-14922 }, { 254,-14922 },

 { 255,-14922 }, {   0,  69 }, {   0,2448 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  64 },
 {   0,2410 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  48,-2970 }, {  49,-2970 }, {  50,-2970 }, {  51,-2970 }, {  52,-2970 },
 {  53,-2970 }, {  54,-2970 }, {  55,-2970 }, {  56,-2970 }, {  57,-2970 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-2970 }, {  66,-2970 }, {  67,-2970 },
 {  68,-2970 }, {  69,-2970 }, {  70,-2970 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-4036 }, {  49,-4036 },
 {  50,-4036 }, {  51,-4036 }, {  52,-4036 }, {  53,-4036 }, {  54,-4036 },
 {  55,-4036 }, {  56,-4036 }, {  57,-4036 }, {   0,   0 }, {  97,-2970 },

 {  98,-2970 }, {  99,-2970 }, { 100,-2970 }, { 101,-2970 }, { 102,-2970 },
 {  65,-15507 }, {  66,-15507 }, {  67,-15507 }, {  68,-15507 }, {  69,-4137 },
 {  70,-15507 }, {  71,-15507 }, {  72,-15507 }, {  73,-15507 }, {  74,-15507 },
 {  75,-15507 }, {  76,-15507 }, {  77,-15507 }, {  78,-15507 }, {  79,-15507 },
 {  80,-15507 }, {  81,-15507 }, {  82,-15507 }, {  83,-15507 }, {  84,-15507 },
 {  85,-15507 }, {  86,-15507 }, {  87,-15507 }, {  88,-15507 }, {  89,-15507 },
 {  90,-15507 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,-15507 }, {   0,   0 }, {  97,-15507 }, {  98,-15507 }, {  99,-15507 },
 { 100,-15507 }, { 101,-4137 }, { 102,-15507 }, { 103,-15507 }, { 104,-15507 },
 { 105,-15507 }, { 106,-15507 }, { 107,-15507 }, { 108,-15507 }, { 109,-15507 },

 { 110,-15507 }, { 111,-15507 }, { 112,-15507 }, { 113,-15507 }, { 114,-15507 },
 { 115,-15507 }, { 116,-15507 }, { 117,-15507 }, { 118,-15507 }, { 119,-15507 },
 { 120,-15507 }, { 121,-15507 }, { 122,-15507 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-15507 }, { 129,-15507 },
 { 130,-15507 }, { 131,-15507 }, { 132,-15507 }, { 133,-15507 }, { 134,-15507 },
 { 135,-15507 }, { 136,-15507 }, { 137,-15507 }, { 138,-15507 }, { 139,-15507 },
 { 140,-15507 }, { 141,-15507 }, { 142,-15507 }, { 143,-15507 }, { 144,-15507 },
 { 145,-15507 }, { 146,-15507 }, { 147,-15507 }, { 148,-15507 }, { 149,-15507 },
 { 150,-15507 }, { 151,-15507 }, { 152,-15507 }, { 153,-15507 }, { 154,-15507 },
 { 155,-15507 }, { 156,-15507 }, { 157,-15507 }, { 158,-15507 }, { 159,-15507 },

 { 160,-15507 }, { 161,-15507 }, { 162,-15507 }, { 163,-15507 }, { 164,-15507 },
 { 165,-15507 }, { 166,-15507 }, { 167,-15507 }, { 168,-15507 }, { 169,-15507 },
 { 170,-15507 }, { 171,-15507 }, { 172,-15507 }, { 173,-15507 }, { 174,-15507 },
 { 175,-15507 }, { 176,-15507 }, { 177,-15507 }, { 178,-15507 }, { 179,-15507 },
 { 180,-15507 }, { 181,-15507 }, { 182,-15507 }, { 183,-15507 }, { 184,-15507 },
 { 185,-15507 }, { 186,-15507 }, { 187,-15507 }, { 188,-15507 }, { 189,-15507 },
 { 190,-15507 }, { 191,-15507 }, { 192,-15507 }, { 193,-15507 }, { 194,-15507 },
 { 195,-15507 }, { 196,-15507 }, { 197,-15507 }, { 198,-15507 }, { 199,-15507 },
 { 200,-15507 }, { 201,-15507 }, { 202,-15507 }, { 203,-15507 }, { 204,-15507 },
 { 205,-15507 }, { 206,-15507 }, { 207,-15507 }, { 208,-15507 }, { 209,-15507 },

 { 210,-15507 }, { 211,-15507 }, { 212,-15507 }, { 213,-15507 }, { 214,-15507 },
 { 215,-15507 }, { 216,-15507 }, { 217,-15507 }, { 218,-15507 }, { 219,-15507 },
 { 220,-15507 }, { 221,-15507 }, { 222,-15507 }, { 223,-15507 }, { 224,-15507 },
 { 225,-15507 }, { 226,-15507 }, { 227,-15507 }, { 228,-15507 }, { 229,-15507 },
 { 230,-15507 }, { 231,-15507 }, { 232,-15507 }, { 233,-15507 }, { 234,-15507 },
 { 235,-15507 }, { 236,-15507 }, { 237,-15507 }, { 238,-15507 }, { 239,-15507 },
 { 240,-15507 }, { 241,-15507 }, { 242,-15507 }, { 243,-15507 }, { 244,-15507 },
 { 245,-15507 }, { 246,-15507 }, { 247,-15507 }, { 248,-15507 }, { 249,-15507 },
 { 250,-15507 }, { 251,-15507 }, { 252,-15507 }, { 253,-15507 }, { 254,-15507 },
 { 255,-15507 }, {   0,  18 }, {   0,2153 }, {   1,   0 }, {   2,   0 },

 {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 },
 {   8,   0 }, {   9, 258 }, {  10, 516 }, {  11, 258 }, {  12, 258 },
 {  13, 516 }, {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 },
 {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 },
 {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 },
 {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32, 258 },
 {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 },
 {  38,   0 }, {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 },
 {  43,   0 }, {  44,   0 }, {  45, 563 }, {  46,   0 }, {  47,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },

 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 },
 {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 },
 {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 },
 {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 },
 {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 },
 {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 },
 {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 },
 {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 },
 {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 },

 { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 },
 { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 },
 { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 },
 { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 },
 { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 },
 { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 },
 { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 },
 { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 },
 { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 },
 { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 },

 { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 },
 { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 },
 { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 },
 { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 },
 { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 },
 { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 },
 { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 },
 { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 },
 { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 },
 { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 },

 { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 },
 { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 },
 { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 },
 { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 },
 { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 },
 { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 },
 { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 },
 { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 },
 { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 },
 { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 },

 { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,  18 },
 {   0,1895 }, {   1,-258 }, {   2,-258 }, {   3,-258 }, {   4,-258 },
 {   5,-258 }, {   6,-258 }, {   7,-258 }, {   8,-258 }, {   9,   0 },
 {  10, 258 }, {  11,   0 }, {  12,   0 }, {  13, 258 }, {  14,-258 },
 {  15,-258 }, {  16,-258 }, {  17,-258 }, {  18,-258 }, {  19,-258 },
 {  20,-258 }, {  21,-258 }, {  22,-258 }, {  23,-258 }, {  24,-258 },
 {  25,-258 }, {  26,-258 }, {  27,-258 }, {  28,-258 }, {  29,-258 },
 {  30,-258 }, {  31,-258 }, {  32,   0 }, {  33,-258 }, {  34,-258 },
 {  35,-258 }, {  36,-258 }, {  37,-258 }, {  38,-258 }, {  39,-258 },
 {  40,-258 }, {  41,-258 }, {  42,-258 }, {  43,-258 }, {  44,-258 },

 {  45, 305 }, {  46,-258 }, {  47,-258 }, {  48,-258 }, {  49,-258 },
 {  50,-258 }, {  51,-258 }, {  52,-258 }, {  53,-258 }, {  54,-258 },
 {  55,-258 }, {  56,-258 }, {  57,-258 }, {  58,-258 }, {  59,-258 },
 {  60,-258 }, {  61,-258 }, {  62,-258 }, {  63,-258 }, {  64,-258 },
 {  65,-258 }, {  66,-258 }, {  67,-258 }, {  68,-258 }, {  69,-258 },
 {  70,-258 }, {  71,-258 }, {  72,-258 }, {  73,-258 }, {  74,-258 },
 {  75,-258 }, {  76,-258 }, {  77,-258 }, {  78,-258 }, {  79,-258 },
 {  80,-258 }, {  81,-258 }, {  82,-258 }, {  83,-258 }, {  84,-258 },
 {  85,-258 }, {  86,-258 }, {  87,-258 }, {  88,-258 }, {  89,-258 },
 {  90,-258 }, {  91,-258 }, {  92,-258 }, {  93,-258 }, {  94,-258 },

 {  95,-258 }, {  96,-258 }, {  97,-258 }, {  98,-258 }, {  99,-258 },
 { 100,-258 }, { 101,-258 }, { 102,-258 }, { 103,-258 }, { 104,-258 },
 { 105,-258 }, { 106,-258 }, { 107,-258 }, { 108,-258 }, { 109,-258 },
 { 110,-258 }, { 111,-258 }, { 112,-258 }, { 113,-258 }, { 114,-258 },
 { 115,-258 }, { 116,-258 }, { 117,-258 }, { 118,-258 }, { 119,-258 },
 { 120,-258 }, { 121,-258 }, { 122,-258 }, { 123,-258 }, { 124,-258 },
 { 125,-258 }, { 126,-258 }, { 127,-258 }, { 128,-258 }, { 129,-258 },
 { 130,-258 }, { 131,-258 }, { 132,-258 }, { 133,-258 }, { 134,-258 },
 { 135,-258 }, { 136,-258 }, { 137,-258 }, { 138,-258 }, { 139,-258 },
 { 140,-258 }, { 141,-258 }, { 142,-258 }, { 143,-258 }, { 144,-258 },

 { 145,-258 }, { 146,-258 }, { 147,-258 }, { 148,-258 }, { 149,-258 },
 { 150,-258 }, { 151,-258 }, { 152,-258 }, { 153,-258 }, { 154,-258 },
 { 155,-258 }, { 156,-258 }, { 157,-258 }, { 158,-258 }, { 159,-258 },
 { 160,-258 }, { 161,-258 }, { 162,-258 }, { 163,-258 }, { 164,-258 },
 { 165,-258 }, { 166,-258 }, { 167,-258 }, { 168,-258 }, { 169,-258 },
 { 170,-258 }, { 171,-258 }, { 172,-258 }, { 173,-258 }, { 174,-258 },
 { 175,-258 }, { 176,-258 }, { 177,-258 }, { 178,-258 }, { 179,-258 },
 { 180,-258 }, { 181,-258 }, { 182,-258 }, { 183,-258 }, { 184,-258 },
 { 185,-258 }, { 186,-258 }, { 187,-258 }, { 188,-258 }, { 189,-258 },
 { 190,-258 }, { 191,-258 }, { 192,-258 }, { 193,-258 }, { 194,-258 },

 { 195,-258 }, { 196,-258 }, { 197,-258 }, { 198,-258 }, { 199,-258 },
 { 200,-258 }, { 201,-258 }, { 202,-258 }, { 203,-258 }, { 204,-258 },
 { 205,-258 }, { 206,-258 }, { 207,-258 }, { 208,-258 }, { 209,-258 },
 { 210,-258 }, { 211,-258 }, { 212,-258 }, { 213,-258 }, { 214,-258 },
 { 215,-258 }, { 216,-258 }, { 217,-258 }, { 218,-258 }, { 219,-258 },
 { 220,-258 }, { 221,-258 }, { 222,-258 }, { 223,-258 }, { 224,-258 },
 { 225,-258 }, { 226,-258 }, { 227,-258 }, { 228,-258 }, { 229,-258 },
 { 230,-258 }, { 231,-258 }, { 232,-258 }, { 233,-258 }, { 234,-258 },
 { 235,-258 }, { 236,-258 }, { 237,-258 }, { 238,-258 }, { 239,-258 },
 { 240,-258 }, { 241,-258 }, { 242,-258 }, { 243,-258 }, { 244,-258 },

 { 245,-258 }, { 246,-258 }, { 247,-258 }, { 248,-258 }, { 249,-258 },
 { 250,-258 }, { 251,-258 }, { 252,-258 }, { 253,-258 }, { 254,-258 },
 { 255,-258 }, { 256,-258 }, {   0,  18 }, {   0,1637 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   9,-7273 }, {  10,-7273 }, {  11,-7273 },
 {  12,-7273 }, {  13,-7273 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  32,-7273 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  39,-16327 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-16292 }, {   0,  18 },
 {   0,1590 }, {   1,-563 }, {   2,-563 }, {   3,-563 }, {   4,-563 },
 {   5,-563 }, {   6,-563 }, {   7,-563 }, {   8,-563 }, {   9,-305 },
 {  10, -47 }, {  11,-305 }, {  12,-305 }, {  13, -47 }, {  14,-563 },
 {  15,-563 }, {  16,-563 }, {  17,-563 }, {  18,-563 }, {  19,-563 },
 {  20,-563 }, {  21,-563 }, {  22,-563 }, {  23,-563 }, {  24,-563 },
 {  25,-563 }, {  26,-563 }, {  27,-563 }, {  28,-563 }, {  29,-563 },
 {  30,-563 }, {  31,-563 }, {  32,-305 }, {  33,-563 }, {  34,-563 },
 {  35,-563 }, {  36,-563 }, {  37,-563 }, {  38,-563 }, {  39,-563 },

 {  40,-563 }, {  41,-563 }, {  42,-563 }, {  43,-563 }, {  44,-563 },
 {  45, 704 }, {  46,-563 }, {  47,-563 }, {  48,-563 }, {  49,-563 },
 {  50,-563 }, {  51,-563 }, {  52,-563 }, {  53,-563 }, {  54,-563 },
 {  55,-563 }, {  56,-563 }, {  57,-563 }, {  58,-563 }, {  59,-563 },
 {  60,-563 }, {  61,-563 }, {  62,-563 }, {  63,-563 }, {  64,-563 },
 {  65,-563 }, {  66,-563 }, {  67,-563 }, {  68,-563 }, {  69,-563 },
 {  70,-563 }, {  71,-563 }, {  72,-563 }, {  73,-563 }, {  74,-563 },
 {  75,-563 }, {  76,-563 }, {  77,-563 }, {  78,-563 }, {  79,-563 },
 {  80,-563 }, {  81,-563 }, {  82,-563 }, {  83,-563 }, {  84,-563 },
 {  85,-563 }, {  86,-563 }, {  87,-563 }, {  88,-563 }, {  89,-563 },

 {  90,-563 }, {  91,-563 }, {  92,-563 }, {  93,-563 }, {  94,-563 },
 {  95,-563 }, {  96,-563 }, {  97,-563 }, {  98,-563 }, {  99,-563 },
 { 100,-563 }, { 101,-563 }, { 102,-563 }, { 103,-563 }, { 104,-563 },
 { 105,-563 }, { 106,-563 }, { 107,-563 }, { 108,-563 }, { 109,-563 },
 { 110,-563 }, { 111,-563 }, { 112,-563 }, { 113,-563 }, { 114,-563 },
 { 115,-563 }, { 116,-563 }, { 117,-563 }, { 118,-563 }, { 119,-563 },
 { 120,-563 }, { 121,-563 }, { 122,-563 }, { 123,-563 }, { 124,-563 },
 { 125,-563 }, { 126,-563 }, { 127,-563 }, { 128,-563 }, { 129,-563 },
 { 130,-563 }, { 131,-563 }, { 132,-563 }, { 133,-563 }, { 134,-563 },
 { 135,-563 }, { 136,-563 }, { 137,-563 }, { 138,-563 }, { 139,-563 },

 { 140,-563 }, { 141,-563 }, { 142,-563 }, { 143,-563 }, { 144,-563 },
 { 145,-563 }, { 146,-563 }, { 147,-563 }, { 148,-563 }, { 149,-563 },
 { 150,-563 }, { 151,-563 }, { 152,-563 }, { 153,-563 }, { 154,-563 },
 { 155,-563 }, { 156,-563 }, { 157,-563 }, { 158,-563 }, { 159,-563 },
 { 160,-563 }, { 161,-563 }, { 162,-563 }, { 163,-563 }, { 164,-563 },
 { 165,-563 }, { 166,-563 }, { 167,-563 }, { 168,-563 }, { 169,-563 },
 { 170,-563 }, { 171,-563 }, { 172,-563 }, { 173,-563 }, { 174,-563 },
 { 175,-563 }, { 176,-563 }, { 177,-563 }, { 178,-563 }, { 179,-563 },
 { 180,-563 }, { 181,-563 }, { 182,-563 }, { 183,-563 }, { 184,-563 },
 { 185,-563 }, { 186,-563 }, { 187,-563 }, { 188,-563 }, { 189,-563 },

 { 190,-563 }, { 191,-563 }, { 192,-563 }, { 193,-563 }, { 194,-563 },
 { 195,-563 }, { 196,-563 }, { 197,-563 }, { 198,-563 }, { 199,-563 },
 { 200,-563 }, { 201,-563 }, { 202,-563 }, { 203,-563 }, { 204,-563 },
 { 205,-563 }, { 206,-563 }, { 207,-563 }, { 208,-563 }, { 209,-563 },
 { 210,-563 }, { 211,-563 }, { 212,-563 }, { 213,-563 }, { 214,-563 },
 { 215,-563 }, { 216,-563 }, { 217,-563 }, { 218,-563 }, { 219,-563 },
 { 220,-563 }, { 221,-563 }, { 222,-563 }, { 223,-563 }, { 224,-563 },
 { 225,-563 }, { 226,-563 }, { 227,-563 }, { 228,-563 }, { 229,-563 },
 { 230,-563 }, { 231,-563 }, { 232,-563 }, { 233,-563 }, { 234,-563 },
 { 235,-563 }, { 236,-563 }, { 237,-563 }, { 238,-563 }, { 239,-563 },

 { 240,-563 }, { 241,-563 }, { 242,-563 }, { 243,-563 }, { 244,-563 },
 { 245,-563 }, { 246,-563 }, { 247,-563 }, { 248,-563 }, { 249,-563 },
 { 250,-563 }, { 251,-563 }, { 252,-563 }, { 253,-563 }, { 254,-563 },
 { 255,-563 }, { 256,-563 }, {   0,  18 }, {   0,1332 }, {   1,-3148 },
 {   2,-3148 }, {   3,-3148 }, {   4,-3148 }, {   5,-3148 }, {   6,-3148 },
 {   7,-3148 }, {   8,-3148 }, {   9,-2890 }, {  10,-7602 }, {  11,-2890 },
 {  12,-2890 }, {  13,-7602 }, {  14,-3148 }, {  15,-3148 }, {  16,-3148 },
 {  17,-3148 }, {  18,-3148 }, {  19,-3148 }, {  20,-3148 }, {  21,-3148 },
 {  22,-3148 }, {  23,-3148 }, {  24,-3148 }, {  25,-3148 }, {  26,-3148 },
 {  27,-3148 }, {  28,-3148 }, {  29,-3148 }, {  30,-3148 }, {  31,-3148 },

 {  32,-2890 }, {  33,-3148 }, {  34,-3148 }, {  35,-3148 }, {  36,-3148 },
 {  37,-3148 }, {  38,-3148 }, {  39,-3148 }, {  40,-3148 }, {  41,-3148 },
 {  42,-3148 }, {  43,-3148 }, {  44,-3148 }, {  45,   0 }, {  46,-3148 },
 {  47,-3148 }, {  48,-3148 }, {  49,-3148 }, {  50,-3148 }, {  51,-3148 },
 {  52,-3148 }, {  53,-3148 }, {  54,-3148 }, {  55,-3148 }, {  56,-3148 },
 {  57,-3148 }, {  58,-3148 }, {  59,-3148 }, {  60,-3148 }, {  61,-3148 },
 {  62,-3148 }, {  63,-3148 }, {  64,-3148 }, {  65,-3148 }, {  66,-3148 },
 {  67,-3148 }, {  68,-3148 }, {  69,-3148 }, {  70,-3148 }, {  71,-3148 },
 {  72,-3148 }, {  73,-3148 }, {  74,-3148 }, {  75,-3148 }, {  76,-3148 },
 {  77,-3148 }, {  78,-3148 }, {  79,-3148 }, {  80,-3148 }, {  81,-3148 },

 {  82,-3148 }, {  83,-3148 }, {  84,-3148 }, {  85,-3148 }, {  86,-3148 },
 {  87,-3148 }, {  88,-3148 }, {  89,-3148 }, {  90,-3148 }, {  91,-3148 },
 {  92,-3148 }, {  93,-3148 }, {  94,-3148 }, {  95,-3148 }, {  96,-3148 },
 {  97,-3148 }, {  98,-3148 }, {  99,-3148 }, { 100,-3148 }, { 101,-3148 },
 { 102,-3148 }, { 103,-3148 }, { 104,-3148 }, { 105,-3148 }, { 106,-3148 },
 { 107,-3148 }, { 108,-3148 }, { 109,-3148 }, { 110,-3148 }, { 111,-3148 },
 { 112,-3148 }, { 113,-3148 }, { 114,-3148 }, { 115,-3148 }, { 116,-3148 },
 { 117,-3148 }, { 118,-3148 }, { 119,-3148 }, { 120,-3148 }, { 121,-3148 },
 { 122,-3148 }, { 123,-3148 }, { 124,-3148 }, { 125,-3148 }, { 126,-3148 },
 { 127,-3148 }, { 128,-3148 }, { 129,-3148 }, { 130,-3148 }, { 131,-3148 },

 { 132,-3148 }, { 133,-3148 }, { 134,-3148 }, { 135,-3148 }, { 136,-3148 },
 { 137,-3148 }, { 138,-3148 }, { 139,-3148 }, { 140,-3148 }, { 141,-3148 },
 { 142,-3148 }, { 143,-3148 }, { 144,-3148 }, { 145,-3148 }, { 146,-3148 },
 { 147,-3148 }, { 148,-3148 }, { 149,-3148 }, { 150,-3148 }, { 151,-3148 },
 { 152,-3148 }, { 153,-3148 }, { 154,-3148 }, { 155,-3148 }, { 156,-3148 },
 { 157,-3148 }, { 158,-3148 }, { 159,-3148 }, { 160,-3148 }, { 161,-3148 },
 { 162,-3148 }, { 163,-3148 }, { 164,-3148 }, { 165,-3148 }, { 166,-3148 },
 { 167,-3148 }, { 168,-3148 }, { 169,-3148 }, { 170,-3148 }, { 171,-3148 },
 { 172,-3148 }, { 173,-3148 }, { 174,-3148 }, { 175,-3148 }, { 176,-3148 },
 { 177,-3148 }, { 178,-3148 }, { 179,-3148 }, { 180,-3148 }, { 181,-3148 },

 { 182,-3148 }, { 183,-3148 }, { 184,-3148 }, { 185,-3148 }, { 186,-3148 },
 { 187,-3148 }, { 188,-3148 }, { 189,-3148 }, { 190,-3148 }, { 191,-3148 },
 { 192,-3148 }, { 193,-3148 }, { 194,-3148 }, { 195,-3148 }, { 196,-3148 },
 { 197,-3148 }, { 198,-3148 }, { 199,-3148 }, { 200,-3148 }, { 201,-3148 },
 { 202,-3148 }, { 203,-3148 }, { 204,-3148 }, { 205,-3148 }, { 206,-3148 },
 { 207,-3148 }, { 208,-3148 }, { 209,-3148 }, { 210,-3148 }, { 211,-3148 },
 { 212,-3148 }, { 213,-3148 }, { 214,-3148 }, { 215,-3148 }, { 216,-3148 },
 { 217,-3148 }, { 218,-3148 }, { 219,-3148 }, { 220,-3148 }, { 221,-3148 },
 { 222,-3148 }, { 223,-3148 }, { 224,-3148 }, { 225,-3148 }, { 226,-3148 },
 { 227,-3148 }, { 228,-3148 }, { 229,-3148 }, { 230,-3148 }, { 231,-3148 },

 { 232,-3148 }, { 233,-3148 }, { 234,-3148 }, { 235,-3148 }, { 236,-3148 },
 { 237,-3148 }, { 238,-3148 }, { 239,-3148 }, { 240,-3148 }, { 241,-3148 },
 { 242,-3148 }, { 243,-3148 }, { 244,-3148 }, { 245,-3148 }, { 246,-3148 },
 { 247,-3148 }, { 248,-3148 }, { 249,-3148 }, { 250,-3148 }, { 251,-3148 },
 { 252,-3148 }, { 253,-3148 }, { 254,-3148 }, { 255,-3148 }, { 256,-3148 },
 {   0,  27 }, {   0,1074 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,1051 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48, 446 },
 {  49, 446 }, {  50, 446 }, {  51, 446 }, {  52, 446 }, {  53, 446 },
 {  54, 446 }, {  55, 446 }, {  56, 446 }, {  57, 446 }, {   0,   0 },
 {   0,   0 }, {   0,  27 }, {   0,1013 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65, 446 }, {  66, 446 }, {  67, 446 }, {  68, 446 },
 {  69, 446 }, {  70, 446 }, {  48, 446 }, {  49, 446 }, {  50, 446 },

 {  51, 446 }, {  52, 446 }, {  53, 446 }, {  54, 446 }, {  55, 446 },
 {  56, 446 }, {  57, 446 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0, 990 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65, 446 },
 {  66, 446 }, {  67, 446 }, {  68, 446 }, {  69, 446 }, {  70, 446 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97, 446 }, {  98, 446 },
 {  99, 446 }, { 100, 446 }, { 101, 446 }, { 102, 446 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48, 446 }, {  49, 446 }, {  50, 446 }, {  51, 446 }, {  52, 446 },
 {  53, 446 }, {  54, 446 }, {  55, 446 }, {  56, 446 }, {  57, 446 },
 {   0,   0 }, {  97, 446 }, {  98, 446 }, {  99, 446 }, { 100, 446 },

 { 101, 446 }, { 102, 446 }, {  65, 446 }, {  66, 446 }, {  67, 446 },
 {  68, 446 }, {  69, 446 }, {  70, 446 }, {  48, 446 }, {  49, 446 },
 {  50, 446 }, {  51, 446 }, {  52, 446 }, {  53, 446 }, {  54, 446 },
 {  55, 446 }, {  56, 446 }, {  57, 446 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65, 446 }, {  66, 446 }, {  67, 446 }, {  68, 446 }, {  69, 446 },
 {  70, 446 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97, 446 },
 {  98, 446 }, {  99, 446 }, { 100, 446 }, { 101, 446 }, { 102, 446 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  97, 446 }, {  98, 446 }, {  99, 446 },
 { 100, 446 }, { 101, 446 }, { 102, 446 }, {   0,  18 }, {   0, 886 },
 {   1,-1267 }, {   2,-1267 }, {   3,-1267 }, {   4,-1267 }, {   5,-1267 },
 {   6,-1267 }, {   7,-1267 }, {   8,-1267 }, {   9,-1009 }, {  10,-751 },
 {  11,-1009 }, {  12,-1009 }, {  13,-751 }, {  14,-1267 }, {  15,-1267 },
 {  16,-1267 }, {  17,-1267 }, {  18,-1267 }, {  19,-1267 }, {  20,-1267 },
 {  21,-1267 }, {  22,-1267 }, {  23,-1267 }, {  24,-1267 }, {  25,-1267 },
 {  26,-1267 }, {  27,-1267 }, {  28,-1267 }, {  29,-1267 }, {  30,-1267 },
 {  31,-1267 }, {  32,-1009 }, {  33,-1267 }, {  34,-1267 }, {  35,-1267 },

 {  36,-1267 }, {  37,-1267 }, {  38,-1267 }, {  39,-1267 }, {  40,-1267 },
 {  41,-1267 }, {  42,-1267 }, {  43,-1267 }, {  44,-1267 }, {  45,   0 },
 {  46,-1267 }, {  47,-1267 }, {  48,-1267 }, {  49,-1267 }, {  50,-1267 },
 {  51,-1267 }, {  52,-1267 }, {  53,-1267 }, {  54,-1267 }, {  55,-1267 },
 {  56,-1267 }, {  57,-1267 }, {  58,-1267 }, {  59,-1267 }, {  60,-1267 },
 {  61,-1267 }, {  62,-1267 }, {  63,-1267 }, {  64,-1267 }, {  65,-1267 },
 {  66,-1267 }, {  67,-1267 }, {  68,-1267 }, {  69,-1267 }, {  70,-1267 },
 {  71,-1267 }, {  72,-1267 }, {  73,-1267 }, {  74,-1267 }, {  75,-1267 },
 {  76,-1267 }, {  77,-1267 }, {  78,-1267 }, {  79,-1267 }, {  80,-1267 },
 {  81,-1267 }, {  82,-1267 }, {  83,-1267 }, {  84,-1267 }, {  85,-1267 },

 {  86,-1267 }, {  87,-1267 }, {  88,-1267 }, {  89,-1267 }, {  90,-1267 },
 {  91,-1267 }, {  92,-1267 }, {  93,-1267 }, {  94,-1267 }, {  95,-1267 },
 {  96,-1267 }, {  97,-1267 }, {  98,-1267 }, {  99,-1267 }, { 100,-1267 },
 { 101,-1267 }, { 102,-1267 }, { 103,-1267 }, { 104,-1267 }, { 105,-1267 },
 { 106,-1267 }, { 107,-1267 }, { 108,-1267 }, { 109,-1267 }, { 110,-1267 },
 { 111,-1267 }, { 112,-1267 }, { 113,-1267 }, { 114,-1267 }, { 115,-1267 },
 { 116,-1267 }, { 117,-1267 }, { 118,-1267 }, { 119,-1267 }, { 120,-1267 },
 { 121,-1267 }, { 122,-1267 }, { 123,-1267 }, { 124,-1267 }, { 125,-1267 },
 { 126,-1267 }, { 127,-1267 }, { 128,-1267 }, { 129,-1267 }, { 130,-1267 },
 { 131,-1267 }, { 132,-1267 }, { 133,-1267 }, { 134,-1267 }, { 135,-1267 },

 { 136,-1267 }, { 137,-1267 }, { 138,-1267 }, { 139,-1267 }, { 140,-1267 },
 { 141,-1267 }, { 142,-1267 }, { 143,-1267 }, { 144,-1267 }, { 145,-1267 },
 { 146,-1267 }, { 147,-1267 }, { 148,-1267 }, { 149,-1267 }, { 150,-1267 },
 { 151,-1267 }, { 152,-1267 }, { 153,-1267 }, { 154,-1267 }, { 155,-1267 },
 { 156,-1267 }, { 157,-1267 }, { 158,-1267 }, { 159,-1267 }, { 160,-1267 },
 { 161,-1267 }, { 162,-1267 }, { 163,-1267 }, { 164,-1267 }, { 165,-1267 },
 { 166,-1267 }, { 167,-1267 }, { 168,-1267 }, { 169,-1267 }, { 170,-1267 },
 { 171,-1267 }, { 172,-1267 }, { 173,-1267 }, { 174,-1267 }, { 175,-1267 },
 { 176,-1267 }, { 177,-1267 }, { 178,-1267 }, { 179,-1267 }, { 180,-1267 },
 { 181,-1267 }, { 182,-1267 }, { 183,-1267 }, { 184,-1267 }, { 185,-1267 },

 { 186,-1267 }, { 187,-1267 }, { 188,-1267 }, { 189,-1267 }, { 190,-1267 },
 { 191,-1267 }, { 192,-1267 }, { 193,-1267 }, { 194,-1267 }, { 195,-1267 },
 { 196,-1267 }, { 197,-1267 }, { 198,-1267 }, { 199,-1267 }, { 200,-1267 },
 { 201,-1267 }, { 202,-1267 }, { 203,-1267 }, { 204,-1267 }, { 205,-1267 },
 { 206,-1267 }, { 207,-1267 }, { 208,-1267 }, { 209,-1267 }, { 210,-1267 },
 { 211,-1267 }, { 212,-1267 }, { 213,-1267 }, { 214,-1267 }, { 215,-1267 },
 { 216,-1267 }, { 217,-1267 }, { 218,-1267 }, { 219,-1267 }, { 220,-1267 },
 { 221,-1267 }, { 222,-1267 }, { 223,-1267 }, { 224,-1267 }, { 225,-1267 },
 { 226,-1267 }, { 227,-1267 }, { 228,-1267 }, { 229,-1267 }, { 230,-1267 },
 { 231,-1267 }, { 232,-1267 }, { 233,-1267 }, { 234,-1267 }, { 235,-1267 },

 { 236,-1267 }, { 237,-1267 }, { 238,-1267 }, { 239,-1267 }, { 240,-1267 },
 { 241,-1267 }, { 242,-1267 }, { 243,-1267 }, { 244,-1267 }, { 245,-1267 },
 { 246,-1267 }, { 247,-1267 }, { 248,-1267 }, { 249,-1267 }, { 250,-1267 },
 { 251,-1267 }, { 252,-1267 }, { 253,-1267 }, { 254,-1267 }, { 255,-1267 },
 { 256,-1267 }, {   0,  27 }, {   0, 628 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0, 605 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48, 143 }, {  49, 143 }, {  50, 143 }, {  51, 143 }, {  52, 143 },
 {  53, 143 }, {  54, 143 }, {  55, 143 }, {  56, 143 }, {  57, 143 },
 {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0, 567 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65, 143 }, {  66, 143 }, {  67, 143 },
 {  68, 143 }, {  69, 143 }, {  70, 143 }, {  48,-17016 }, {  49,-17016 },
 {  50,-17016 }, {  51,-17016 }, {  52,-17016 }, {  53,-17016 }, {  54,-17016 },

 {  55,-17016 }, {  56,-17016 }, {  57,-17016 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0, 544 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,-17016 }, {  66,-17016 }, {  67,-17016 }, {  68,-17016 }, {  69,-17016 },
 {  70,-17016 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97, 143 },
 {  98, 143 }, {  99, 143 }, { 100, 143 }, { 101, 143 }, { 102, 143 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48, 105 }, {  49, 105 }, {  50, 105 }, {  51, 105 },
 {  52, 105 }, {  53, 105 }, {  54, 105 }, {  55, 105 }, {  56, 105 },
 {  57, 105 }, {   0,   0 }, {  97,-17016 }, {  98,-17016 }, {  99,-17016 },
 { 100,-17016 }, { 101,-17016 }, { 102,-17016 }, {  65, 105 }, {  66, 105 },

 {  67, 105 }, {  68, 105 }, {  69, 105 }, {  70, 105 }, {  48,-17075 },
 {  49,-17075 }, {  50,-17075 }, {  51,-17075 }, {  52,-17075 }, {  53,-17075 },
 {  54,-17075 }, {  55,-17075 }, {  56,-17075 }, {  57,-17075 }, {   0,  27 },
 {   0, 485 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,-17075 }, {  66,-17075 }, {  67,-17075 }, {  68,-17075 },
 {  69,-17075 }, {  70,-17075 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97, 105 }, {  98, 105 }, {  99, 105 }, { 100, 105 }, { 101, 105 },
 { 102, 105 }, {   0,   0 }, {   0,  27 }, {   0, 462 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,-17075 }, {  98,-17075 },
 {  99,-17075 }, { 100,-17075 }, { 101,-17075 }, { 102,-17075 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,  61 }, {  49,  61 },
 {  50,  61 }, {  51,  61 }, {  52,  61 }, {  53,  61 }, {  54,  61 },
 {  55,  61 }, {  56,  61 }, {  57,  61 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0, 424 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,  61 }, {  66,  61 }, {  67,  61 }, {  68,  61 }, {  69,  61 },
 {  70,  61 }, {  48,  61 }, {  49,  61 }, {  50,  61 }, {  51,  61 },
 {  52,  61 }, {  53,  61 }, {  54,  61 }, {  55,  61 }, {  56,  61 },
 {  57,  61 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0, 401 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,  61 }, {  66,  61 },
 {  67,  61 }, {  68,  61 }, {  69,  61 }, {  70,  61 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  97,  61 }, {  98,  61 }, {  99,  61 },
 { 100,  61 }, { 101,  61 }, { 102,  61 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,  82 },
 {  49,  82 }, {  50,  82 }, {  51,  82 }, {  52,  82 }, {  53,  82 },
 {  54,  82 }, {  55,  82 }, {  56,  82 }, {  57,  82 }, {   0,   0 },
 {  97,  61 }, {  98,  61 }, {  99,  61 }, { 100,  61 }, { 101,  61 },
 { 102,  61 }, {  65,  82 }, {  66,  82 }, {  67,  82 }, {  68,  82 },
 {  69,  82 }, {  70,  82 }, {  48,  82 }, {  49,  82 }, {  50,  82 },

 {  51,  82 }, {  52,  82 }, {  53,  82 }, {  54,  82 }, {  55,  82 },
 {  56,  82 }, {  57,  82 }, {   0,  27 }, {   0, 342 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,  82 },
 {  66,  82 }, {  67,  82 }, {  68,  82 }, {  69,  82 }, {  70,  82 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,  82 }, {  98,  82 },
 {  99,  82 }, { 100,  82 }, { 101,  82 }, { 102,  82 }, {   0,   0 },
 {   0,  27 }, {   0, 319 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  97,  82 }, {  98,  82 }, {  99,  82 }, { 100,  82 },

 { 101,  82 }, { 102,  82 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,  61 }, {  49,  61 }, {  50,  61 }, {  51,  61 },
 {  52,  61 }, {  53,  61 }, {  54,  61 }, {  55,  61 }, {  56,  61 },
 {  57,  61 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0, 281 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,  61 }, {  66,  61 },
 {  67,  61 }, {  68,  61 }, {  69,  61 }, {  70,  61 }, {  48,  61 },
 {  49,  61 }, {  50,  61 }, {  51,  61 }, {  52,  61 }, {  53,  61 },
 {  54,  61 }, {  55,  61 }, {  56,  61 }, {  57,  61 }, {   0,   0 },
 {   0,   0 }, {   0,  27 }, {   0, 258 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,  61 }, {  66,  61 }, {  67,  61 }, {  68,  61 },

 {  69,  61 }, {  70,  61 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97,  61 }, {  98,  61 }, {  99,  61 }, { 100,  61 }, { 101,  61 },
 { 102,  61 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,-17340 }, {  49,-17340 }, {  50,-17340 },
 {  51,-17340 }, {  52,-17340 }, {  53,-17340 }, {  54,-17340 }, {  55,-17340 },
 {  56,-17340 }, {  57,-17340 }, {   0,   0 }, {  97,  61 }, {  98,  61 },
 {  99,  61 }, { 100,  61 }, { 101,  61 }, { 102,  61 }, {  65,-17340 },
 {  66,-17340 }, {  67,-17340 }, {  68,-17340 }, {  69,-17340 }, {  70,-17340 },
 {  48,-17361 }, {  49,-17361 }, {  50,-17361 }, {  51,-17361 }, {  52,-17361 },
 {  53,-17361 }, {  54,-17361 }, {  55,-17361 }, {  56,-17361 }, {  57,-17361 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-17361 }, {  66,-17361 }, {  67,-17361 },
 {  68,-17361 }, {  69,-17361 }, {  70,-17361 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  97,-17340 }, {  98,-17340 }, {  99,-17340 }, { 100,-17340 },
 { 101,-17340 }, { 102,-17340 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,-17361 },
 {  98,-17361 }, {  99,-17361 }, { 100,-17361 }, { 101,-17361 }, { 102,-17361 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 257,  77 },

 {   1,   0 },    };

static const struct yy_trans_info *yy_start_state_list[25] =
    {
    &yy_transition[1],
    &yy_transition[3],
    &yy_transition[261],
    &yy_transition[519],
    &yy_transition[777],
    &yy_transition[1035],
    &yy_transition[1293],
    &yy_transition[1551],
    &yy_transition[1809],
    &yy_transition[2067],
    &yy_transition[2325],
    &yy_transition[2583],
    &yy_transition[2841],
    &yy_transition[3099],
    &yy_transition[3357],
    &yy_transition[3615],
    &yy_transition[3873],
    &yy_transition[4131],
    &yy_transition[4389],
    &yy_transition[4647],
    &yy_transition[4905],
    &yy_transition[5163],
    &yy_transition[5421],
    &yy_transition[5679],
    &yy_transition[5937],

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scan.l"

#line 49 "scan.l"

/* LCOV_EXCL_START */

/* Avoid exit() on fatal scanner errors (a bit ugly -- see yy_fatal_error) */
#undef fprintf
#define fprintf(file, fmt, msg)  fprintf_to_ereport(fmt, msg)

static void
fprintf_to_ereport(const char *fmt, const char *msg)
{
	ereport(ERROR, (errmsg_internal("%s", msg)));
}

/*
 * GUC variables.  This is a DIRECT violation of the warning given at the
 * head of gram.y, ie flex/bison code must not depend on any GUC variables;
 * as such, changing their values can induce very unintuitive behavior.
 * But we shall have to live with it until we can remove these variables.
 */
int			backslash_quote = BACKSLASH_QUOTE_SAFE_ENCODING;
bool		escape_string_warning = true;
bool		standard_conforming_strings = true;

/*
 * Constant data exported from this file.  This array maps from the
 * zero-based keyword numbers returned by ScanKeywordLookup to the
 * Bison token numbers needed by gram.y.  This is exported because
 * callers need to pass it to scanner_init, if they are using the
 * standard keyword list ScanKeywords.
 */
#define PG_KEYWORD(kwname, value, category, collabel) value,

const uint16 ScanKeywordTokens[] = {
#include "parser/kwlist.h"
};

#undef PG_KEYWORD

/*
 * Set the type of YYSTYPE.
 */
#define YYSTYPE core_YYSTYPE

/*
 * Set the type of yyextra.  All state variables used by the scanner should
 * be in yyextra, *not* statically allocated.
 */
#define YY_EXTRA_TYPE core_yy_extra_type *

/*
 * Each call to yylex must set yylloc to the location of the found token
 * (expressed as a byte offset from the start of the input text).
 * When we parse a token that requires multiple lexer rules to process,
 * this should be done in the first such rule, else yylloc will point
 * into the middle of the token.
 */
#define SET_YYLLOC()  (*(yylloc) = yytext - yyextra->scanbuf)

/*
 * Advance yylloc by the given number of bytes.
 */
#define ADVANCE_YYLLOC(delta)  ( *(yylloc) += (delta) )

/*
 * Sometimes, we do want yylloc to point into the middle of a token; this is
 * useful for instance to throw an error about an escape sequence within a
 * string literal.  But if we find no error there, we want to revert yylloc
 * to the token start, so that that's the location reported to the parser.
 * Use PUSH_YYLLOC/POP_YYLLOC to save/restore yylloc around such code.
 * (Currently the implied "stack" is just one location, but someday we might
 * need to nest these.)
 */
#define PUSH_YYLLOC()	(yyextra->save_yylloc = *(yylloc))
#define POP_YYLLOC()	(*(yylloc) = yyextra->save_yylloc)

#define startlit()	( yyextra->literallen = 0 )
static void addlit(char *ytext, int yleng, core_yyscan_t yyscanner);
static void addlitchar(unsigned char ychar, core_yyscan_t yyscanner);
static char *litbufdup(core_yyscan_t yyscanner);
static unsigned char unescape_single_char(unsigned char c, core_yyscan_t yyscanner);
static int	process_integer_literal(const char *token, YYSTYPE *lval, int base);
static void addunicode(pg_wchar c, yyscan_t yyscanner);

#define yyerror(msg)  scanner_yyerror(msg, yyscanner)

#define lexer_errposition()  scanner_errposition(*(yylloc), yyscanner)

static void check_string_escape_warning(unsigned char ychar, core_yyscan_t yyscanner);
static void check_escape_warning(core_yyscan_t yyscanner);

/*
 * Work around a bug in flex 2.5.35: it emits a couple of functions that
 * it forgets to emit declarations for.  Since we use -Wmissing-prototypes,
 * this would cause warnings.  Providing our own declarations should be
 * harmless even when the bug gets fixed.
 */
extern int	core_yyget_column(yyscan_t yyscanner);
extern void core_yyset_column(int column_no, yyscan_t yyscanner);

#line 6182 "scan.c"
#define YY_NO_INPUT 1
/*
 * OK, here is a short description of lex/flex rules behavior.
 * The longest pattern which matches an input string is always chosen.
 * For equal-length patterns, the first occurring in the rules list is chosen.
 * INITIAL is the starting state, to which all non-conditional rules apply.
 * Exclusive states change parsing rules while the state is active.  When in
 * an exclusive state, only those rules defined for that state apply.
 *
 * We use exclusive states for quoted strings, extended comments,
 * and to eliminate parsing troubles for numeric strings.
 * Exclusive states:
 *  <xb> bit string literal
 *  <xc> extended C-style comments
 *  <xd> delimited identifiers (double-quoted identifiers)
 *  <xh> hexadecimal byte string
 *  <xq> standard quoted strings
 *  <xqs> quote stop (detect continued strings)
 *  <xe> extended quoted strings (support backslash escape sequences)
 *  <xdolq> $foo$ quoted strings
 *  <xui> quoted identifier with Unicode escapes
 *  <xus> quoted string with Unicode escapes
 *  <xeu> Unicode surrogate pair in extended quoted string
 *
 * Remember to add an <<EOF>> case whenever you add a new exclusive state!
 * The default one is probably not the right thing.
 */

/*
 * In order to make the world safe for Windows and Mac clients as well as
 * Unix ones, we accept either \n or \r as a newline.  A DOS-style \r\n
 * sequence will be seen as two successive newlines, but that doesn't cause
 * any problems.  Comments that start with -- and extend to the next
 * newline are treated as equivalent to a single whitespace character.
 *
 * NOTE a fine point: if there is no newline following --, we will absorb
 * everything to the end of the input as a comment.  This is correct.  Older
 * versions of Postgres failed to recognize -- as a comment if the input
 * did not end with a newline.
 *
 * non_newline_space tracks all the other space characters except newlines.
 *
 * XXX if you change the set of whitespace characters, fix scanner_isspace()
 * to agree.
 */
/*
 * SQL requires at least one newline in the whitespace separating
 * string literals that are to be concatenated.  Silly, but who are we
 * to argue?  Note that {whitespace_with_newline} should not have * after
 * it, whereas {whitespace} should generally have a * after it...
 */
/* If we see {quote} then {quotecontinue}, the quoted string continues */
/*
 * {quotecontinuefail} is needed to avoid lexer backup when we fail to match
 * {quotecontinue}.  It might seem that this could just be {whitespace}*,
 * but if there's a dash after {whitespace_with_newline}, it must be consumed
 * to see if there's another dash --- which would start a {comment} and thus
 * allow continuation of the {quotecontinue} token.
 */
/* Bit string
 * It is tempting to scan the string for only those characters
 * which are allowed. However, this leads to silently swallowed
 * characters if illegal characters are included in the string.
 * For example, if xbinside is [01] then B'ABCD' is interpreted
 * as a zero-length string, and the ABCD' is lost!
 * Better to pass the string forward and let the input routines
 * validate the contents.
 */
/* Hexadecimal byte string */
/* National character */
/* Quoted string that allows backslash escapes */
/* Extended quote
 * xqdouble implements embedded quote, ''''
 */
/* $foo$ style quotes ("dollar quoting")
 * The quoted string starts with $foo$ where "foo" is an optional string
 * in the form of an identifier, except that it may not contain "$",
 * and extends to the first occurrence of an identical string.
 * There is *no* processing of the quoted text.
 *
 * {dolqfailed} is an error rule to avoid scanner backup when {dolqdelim}
 * fails to match its trailing "$".
 */
/* Double quote
 * Allows embedded spaces and other special characters into identifiers.
 */
/* Quoted identifier with Unicode escapes */
/* Quoted string with Unicode escapes */
/* error rule to avoid backup */
/* C-style comments
 *
 * The "extended comment" syntax closely resembles allowable operator syntax.
 * The tricky part here is to get lex to recognize a string starting with
 * slash-star as a comment, when interpreting it as an operator would produce
 * a longer match --- remember lex will prefer a longer match!  Also, if we
 * have something like plus-slash-star, lex will think this is a 3-character
 * operator whereas we want to see it as a + operator and a comment start.
 * The solution is two-fold:
 * 1. append {op_chars}* to xcstart so that it matches as much text as
 *    {operator} would. Then the tie-breaker (first matching rule of same
 *    length) ensures xcstart wins.  We put back the extra stuff with yyless()
 *    in case it contains a star-slash that should terminate the comment.
 * 2. In the operator rule, check for slash-star within the operator, and
 *    if found throw it back with yyless().  This handles the plus-slash-star
 *    problem.
 * Dash-dash comments have similar interactions with the operator rule.
 */
/* Assorted special-case operators and operator-like tokens */
/*
 * These operator-like tokens (unlike the above ones) also match the {operator}
 * rule, which means that they might be overridden by a longer match if they
 * are followed by a comment start or a + or - character. Accordingly, if you
 * add to this list, you must also add corresponding code to the {operator}
 * block to return the correct token in such cases. (This is not needed in
 * psqlscan.l since the token value is ignored there.)
 */
/*
 * "self" is the set of chars that should be returned as single-character
 * tokens.  "op_chars" is the set of chars that can make up "Op" tokens,
 * which can be one or more characters long (but if a single-char token
 * appears in the "self" set, it is not to be returned as an Op).  Note
 * that the sets overlap, but each has some chars that are not in the other.
 *
 * If you change either set, adjust the character lists appearing in the
 * rule for "operator"!
 */
/*
 * Numbers
 *
 * Unary minus is not part of a number here.  Instead we pass it separately to
 * the parser, and there it gets coerced via doNegate().
 *
 * {numericfail} is used because we would like "1..10" to lex as 1, dot_dot, 10.
 *
 * {realfail} is added to prevent the need for scanner
 * backup when the {real} rule fails to match completely.
 */
/* Positional parameters don't accept underscores. */
/*
 * Dollar quoted strings are totally opaque, and no escaping is done on them.
 * Other quoted strings must allow some special characters such as single-quote
 *  and newline.
 * Embedded single-quotes are implemented both in the SQL standard
 *  style of two adjacent single quotes "''" and in the Postgres/Java style
 *  of escaped-quote "\'".
 * Other embedded escaped characters are matched explicitly and the leading
 *  backslash is dropped from the string.
 * Note that xcstart must appear before operator, as explained above!
 *  Also whitespace (comment) must appear before operator.
 */
#line 6333 "scan.c"

#define INITIAL 0
#define xb 1
#define xc 2
#define xd 3
#define xh 4
#define xq 5
#define xqs 6
#define xe 7
#define xdolq 8
#define xui 9
#define xus 10
#define xeu 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 441 "scan.l"


#line 6629 "scan.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yy_start_state_list[yyg->yy_start];
yy_match:
		{
		const struct yy_trans_info *yy_trans_info;

		YY_CHAR yy_c;

		for ( yy_c = YY_SC_TO_UI(*yy_cp);
		      (yy_trans_info = &yy_current_state[yy_c])->
		yy_verify == yy_c;
		      yy_c = YY_SC_TO_UI(*++yy_cp) )
			yy_current_state += yy_trans_info->yy_nxt;
		}

yy_find_action:
		yy_act = yy_current_state[-1].yy_nxt;

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 443 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 447 "scan.l"
{
					/* Set location in case of syntax error in comment */
					SET_YYLLOC();
					yyextra->xcdepth = 0;
					BEGIN(xc);
					/* Put back any characters past slash-star; see above */
					yyless(2);
				}
	YY_BREAK

case 3:
YY_RULE_SETUP
#line 457 "scan.l"
{
					(yyextra->xcdepth)++;
					/* Put back any characters past slash-star; see above */
					yyless(2);
				}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 463 "scan.l"
{
					if (yyextra->xcdepth <= 0)
						BEGIN(INITIAL);
					else
						(yyextra->xcdepth)--;
				}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 470 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 474 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 478 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case YY_STATE_EOF(xc):
#line 482 "scan.l"
{
					yyerror("unterminated /* comment");
				}
	YY_BREAK
/* <xc> */
case 8:
YY_RULE_SETUP
#line 487 "scan.l"
{
					/* Binary bit type.
					 * At some point we should simply pass the string
					 * forward to the parser and label it there.
					 * In the meantime, place a leading "b" on the string
					 * to mark it for the input routine as a binary string.
					 */
					SET_YYLLOC();
					BEGIN(xb);
					startlit();
					addlitchar('b', yyscanner);
				}
	YY_BREAK
case 9:
/* rule 9 can match eol */
#line 500 "scan.l"
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 500 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xb):
#line 503 "scan.l"
{ yyerror("unterminated bit string literal"); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 505 "scan.l"
{
					/* Hexadecimal bit type.
					 * At some point we should simply pass the string
					 * forward to the parser and label it there.
					 * In the meantime, place a leading "x" on the string
					 * to mark it for the input routine as a hex string.
					 */
					SET_YYLLOC();
					BEGIN(xh);
					startlit();
					addlitchar('x', yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xh):
#line 517 "scan.l"
{ yyerror("unterminated hexadecimal string literal"); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 519 "scan.l"
{
					/* National character.
					 * We will pass this along as a normal character string,
					 * but preceded with an internally-generated "NCHAR".
					 */
					int		kwnum;

					SET_YYLLOC();
					yyless(1);	/* eat only 'n' this time */

					kwnum = ScanKeywordLookup("nchar",
											  yyextra->keywordlist);
					if (kwnum >= 0)
					{
						yylval->keyword = GetScanKeyword(kwnum,
														 yyextra->keywordlist);
						return yyextra->keyword_tokens[kwnum];
					}
					else
					{
						/* If NCHAR isn't a keyword, just return "n" */
						yylval->str = pstrdup("n");
						return IDENT;
					}
				}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 545 "scan.l"
{
					yyextra->warn_on_first_escape = true;
					yyextra->saw_non_ascii = false;
					SET_YYLLOC();
					if (yyextra->standard_conforming_strings)
						BEGIN(xq);
					else
						BEGIN(xe);
					startlit();
				}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 555 "scan.l"
{
					yyextra->warn_on_first_escape = false;
					yyextra->saw_non_ascii = false;
					SET_YYLLOC();
					BEGIN(xe);
					startlit();
				}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 562 "scan.l"
{
					SET_YYLLOC();
					if (!yyextra->standard_conforming_strings)
						ereport(ERROR,
								(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
								 errmsg("unsafe use of string constant with Unicode escapes"),
								 errdetail("String constants with Unicode escapes cannot be used when \"standard_conforming_strings\" is off."),
								 lexer_errposition()));
					BEGIN(xus);
					startlit();
				}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 574 "scan.l"
{
					/*
					 * When we are scanning a quoted string and see an end
					 * quote, we must look ahead for a possible continuation.
					 * If we don't see one, we know the end quote was in fact
					 * the end of the string.  To reduce the lexer table size,
					 * we use a single "xqs" state to do the lookahead for all
					 * types of strings.
					 */
					yyextra->state_before_str_stop = YYSTATE;
					BEGIN(xqs);
				}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 586 "scan.l"
{
					/*
					 * Found a quote continuation, so return to the in-quote
					 * state and continue scanning the literal.  Nothing is
					 * added to the literal's contents.
					 */
					BEGIN(yyextra->state_before_str_stop);
				}
	YY_BREAK
case 18:
/* rule 18 can match eol */
#line 595 "scan.l"
case 19:
/* rule 19 can match eol */
#line 596 "scan.l"
YY_RULE_SETUP
case YY_STATE_EOF(xqs):
#line 596 "scan.l"
{
					/*
					 * Failed to see a quote continuation.  Throw back
					 * everything after the end quote, and handle the string
					 * according to the state we were in previously.
					 */
					yyless(0);
					BEGIN(INITIAL);

					switch (yyextra->state_before_str_stop)
					{
						case xb:
							yylval->str = litbufdup(yyscanner);
							return BCONST;
						case xh:
							yylval->str = litbufdup(yyscanner);
							return XCONST;
						case xq:
						case xe:
							/*
							 * Check that the data remains valid, if it might
							 * have been made invalid by unescaping any chars.
							 */
							if (yyextra->saw_non_ascii)
								pg_verifymbstr(yyextra->literalbuf,
											   yyextra->literallen,
											   false);
							yylval->str = litbufdup(yyscanner);
							return SCONST;
						case xus:
							yylval->str = litbufdup(yyscanner);
							return USCONST;
						default:
							yyerror("unhandled previous state in xqs");
					}
				}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 633 "scan.l"
{
					addlitchar('\'', yyscanner);
				}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 636 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 639 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 642 "scan.l"
{
					pg_wchar	c = strtoul(yytext + 2, NULL, 16);

					/*
					 * For consistency with other productions, issue any
					 * escape warning with cursor pointing to start of string.
					 * We might want to change that, someday.
					 */
					check_escape_warning(yyscanner);

					/* Remember start of overall string token ... */
					PUSH_YYLLOC();
					/* ... and set the error cursor to point at this esc seq */
					SET_YYLLOC();

					if (is_utf16_surrogate_first(c))
					{
						yyextra->utf16_first_part = c;
						BEGIN(xeu);
					}
					else if (is_utf16_surrogate_second(c))
						yyerror("invalid Unicode surrogate pair");
					else
						addunicode(c, yyscanner);

					/* Restore yylloc to be start of string token */
					POP_YYLLOC();
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 670 "scan.l"
{
					pg_wchar	c = strtoul(yytext + 2, NULL, 16);

					/* Remember start of overall string token ... */
					PUSH_YYLLOC();
					/* ... and set the error cursor to point at this esc seq */
					SET_YYLLOC();

					if (!is_utf16_surrogate_second(c))
						yyerror("invalid Unicode surrogate pair");

					c = surrogate_pair_to_codepoint(yyextra->utf16_first_part, c);

					addunicode(c, yyscanner);

					/* Restore yylloc to be start of string token */
					POP_YYLLOC();

					BEGIN(xe);
				}
	YY_BREAK
case 25:
#line 691 "scan.l"
case 26:
/* rule 26 can match eol */
#line 692 "scan.l"
YY_RULE_SETUP
case YY_STATE_EOF(xeu):
#line 692 "scan.l"
{
					/* Set the error cursor to point at missing esc seq */
					SET_YYLLOC();
					yyerror("invalid Unicode surrogate pair");
				}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 697 "scan.l"
{
					/* Set the error cursor to point at malformed esc seq */
					SET_YYLLOC();
					ereport(ERROR,
							(errcode(ERRCODE_INVALID_ESCAPE_SEQUENCE),
							 errmsg("invalid Unicode escape"),
							 errhint("Unicode escapes must be \\uXXXX or \\UXXXXXXXX."),
							 lexer_errposition()));
				}
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 706 "scan.l"
{
					if (yytext[1] == '\'')
					{
						if (yyextra->backslash_quote == BACKSLASH_QUOTE_OFF ||
							(yyextra->backslash_quote == BACKSLASH_QUOTE_SAFE_ENCODING &&
							 PG_ENCODING_IS_CLIENT_ONLY(pg_get_client_encoding())))
							ereport(ERROR,
									(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
									 errmsg("unsafe use of \\' in a string literal"),
									 errhint("Use '' to write quotes in strings. \\' is insecure in client-only encodings."),
									 lexer_errposition()));
					}
					check_string_escape_warning(yytext[1], yyscanner);
					addlitchar(unescape_single_char(yytext[1], yyscanner),
							   yyscanner);
				}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 722 "scan.l"
{
					unsigned char c = strtoul(yytext + 1, NULL, 8);

					check_escape_warning(yyscanner);
					addlitchar(c, yyscanner);
					if (c == '\0' || IS_HIGHBIT_SET(c))
						yyextra->saw_non_ascii = true;
				}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 730 "scan.l"
{
					unsigned char c = strtoul(yytext + 2, NULL, 16);

					check_escape_warning(yyscanner);
					addlitchar(c, yyscanner);
					if (c == '\0' || IS_HIGHBIT_SET(c))
						yyextra->saw_non_ascii = true;
				}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 738 "scan.l"
{
					/* This is only needed for \ just before EOF */
					addlitchar(yytext[0], yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xq):
case YY_STATE_EOF(xe):
case YY_STATE_EOF(xus):
#line 742 "scan.l"
{ yyerror("unterminated quoted string"); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 744 "scan.l"
{
					SET_YYLLOC();
					yyextra->dolqstart = pstrdup(yytext);
					BEGIN(xdolq);
					startlit();
				}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 750 "scan.l"
{
					SET_YYLLOC();
					/* throw back all but the initial "$" */
					yyless(1);
					/* and treat it as {other} */
					return yytext[0];
				}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 757 "scan.l"
{
					if (strcmp(yytext, yyextra->dolqstart) == 0)
					{
						pfree(yyextra->dolqstart);
						yyextra->dolqstart = NULL;
						BEGIN(INITIAL);
						yylval->str = litbufdup(yyscanner);
						return SCONST;
					}
					else
					{
						/*
						 * When we fail to match $...$ to dolqstart, transfer
						 * the $... part to the output, but put back the final
						 * $ for rescanning.  Consider $delim$...$junk$delim$
						 */
						addlit(yytext, yyleng - 1, yyscanner);
						yyless(yyleng - 1);
					}
				}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 777 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 780 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 783 "scan.l"
{
					/* This is only needed for $ inside the quoted text */
					addlitchar(yytext[0], yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xdolq):
#line 787 "scan.l"
{ yyerror("unterminated dollar-quoted string"); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 789 "scan.l"
{
					SET_YYLLOC();
					BEGIN(xd);
					startlit();
				}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 794 "scan.l"
{
					SET_YYLLOC();
					BEGIN(xui);
					startlit();
				}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 799 "scan.l"
{
					char	   *ident;

					BEGIN(INITIAL);
					if (yyextra->literallen == 0)
						yyerror("zero-length delimited identifier");
					ident = litbufdup(yyscanner);
					if (yyextra->literallen >= NAMEDATALEN)
						truncate_identifier(ident, yyextra->literallen, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 811 "scan.l"
{
					BEGIN(INITIAL);
					if (yyextra->literallen == 0)
						yyerror("zero-length delimited identifier");
					/* can't truncate till after we de-escape the ident */
					yylval->str = litbufdup(yyscanner);
					return UIDENT;
				}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 819 "scan.l"
{
					addlitchar('"', yyscanner);
				}
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 822 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xd):
case YY_STATE_EOF(xui):
#line 825 "scan.l"
{ yyerror("unterminated quoted identifier"); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 827 "scan.l"
{
					char	   *ident;

					SET_YYLLOC();
					/* throw back all but the initial u/U */
					yyless(1);
					/* and treat it as {identifier} */
					ident = downcase_truncate_identifier(yytext, yyleng, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 839 "scan.l"
{
					SET_YYLLOC();
					return TYPECAST;
				}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 844 "scan.l"
{
					SET_YYLLOC();
					return DOT_DOT;
				}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 849 "scan.l"
{
					SET_YYLLOC();
					return COLON_EQUALS;
				}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 854 "scan.l"
{
					SET_YYLLOC();
					return EQUALS_GREATER;
				}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 859 "scan.l"
{
					SET_YYLLOC();
					return LESS_EQUALS;
				}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 864 "scan.l"
{
					SET_YYLLOC();
					return GREATER_EQUALS;
				}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 869 "scan.l"
{
					/* We accept both "<>" and "!=" as meaning NOT_EQUALS */
					SET_YYLLOC();
					return NOT_EQUALS;
				}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 875 "scan.l"
{
					/* We accept both "<>" and "!=" as meaning NOT_EQUALS */
					SET_YYLLOC();
					return NOT_EQUALS;
				}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 881 "scan.l"
{
					SET_YYLLOC();
					return yytext[0];
				}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 886 "scan.l"
{
					/*
					 * Check for embedded slash-star or dash-dash; those
					 * are comment starts, so operator must stop there.
					 * Note that slash-star or dash-dash at the first
					 * character will match a prior rule, not this one.
					 */
					int			nchars = yyleng;
					char	   *slashstar = strstr(yytext, "/*");
					char	   *dashdash = strstr(yytext, "--");

					if (slashstar && dashdash)
					{
						/* if both appear, take the first one */
						if (slashstar > dashdash)
							slashstar = dashdash;
					}
					else if (!slashstar)
						slashstar = dashdash;
					if (slashstar)
						nchars = slashstar - yytext;

					/*
					 * For SQL compatibility, '+' and '-' cannot be the
					 * last char of a multi-char operator unless the operator
					 * contains chars that are not in SQL operators.
					 * The idea is to lex '=-' as two operators, but not
					 * to forbid operator names like '?-' that could not be
					 * sequences of SQL operators.
					 */
					if (nchars > 1 &&
						(yytext[nchars - 1] == '+' ||
						 yytext[nchars - 1] == '-'))
					{
						int			ic;

						for (ic = nchars - 2; ic >= 0; ic--)
						{
							char c = yytext[ic];
							if (c == '~' || c == '!' || c == '@' ||
								c == '#' || c == '^' || c == '&' ||
								c == '|' || c == '`' || c == '?' ||
								c == '%')
								break;
						}
						if (ic < 0)
						{
							/*
							 * didn't find a qualifying character, so remove
							 * all trailing [+-]
							 */
							do {
								nchars--;
							} while (nchars > 1 &&
								 (yytext[nchars - 1] == '+' ||
								  yytext[nchars - 1] == '-'));
						}
					}

					SET_YYLLOC();

					if (nchars < yyleng)
					{
						/* Strip the unwanted chars from the token */
						yyless(nchars);
						/*
						 * If what we have left is only one char, and it's
						 * one of the characters matching "self", then
						 * return it as a character token the same way
						 * that the "self" rule would have.
						 */
						if (nchars == 1 &&
							strchr(",()[].;:+-*/%^<>=", yytext[0]))
							return yytext[0];
						/*
						 * Likewise, if what we have left is two chars, and
						 * those match the tokens ">=", "<=", "=>", "<>" or
						 * "!=", then we must return the appropriate token
						 * rather than the generic Op.
						 */
						if (nchars == 2)
						{
							if (yytext[0] == '=' && yytext[1] == '>')
								return EQUALS_GREATER;
							if (yytext[0] == '>' && yytext[1] == '=')
								return GREATER_EQUALS;
							if (yytext[0] == '<' && yytext[1] == '=')
								return LESS_EQUALS;
							if (yytext[0] == '<' && yytext[1] == '>')
								return NOT_EQUALS;
							if (yytext[0] == '!' && yytext[1] == '=')
								return NOT_EQUALS;
						}
					}

					/*
					 * Complain if operator is too long.  Unlike the case
					 * for identifiers, we make this an error not a notice-
					 * and-truncate, because the odds are we are looking at
					 * a syntactic mistake anyway.
					 */
					if (nchars >= NAMEDATALEN)
						yyerror("operator too long");

					yylval->str = pstrdup(yytext);
					return Op;
				}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 994 "scan.l"
{
					SET_YYLLOC();
					yylval->ival = atol(yytext + 1);
					return PARAM;
				}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 999 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after parameter");
				}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 1004 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 10);
				}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 1008 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 16);
				}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 1012 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 8);
				}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 1016 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 2);
				}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 1020 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid hexadecimal integer");
				}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 1024 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid octal integer");
				}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 1028 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid binary integer");
				}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 1032 "scan.l"
{
					SET_YYLLOC();
					yylval->str = pstrdup(yytext);
					return FCONST;
				}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 1037 "scan.l"
{
					/* throw back the .., and treat as integer */
					yyless(yyleng - 2);
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 10);
				}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 1043 "scan.l"
{
					SET_YYLLOC();
					yylval->str = pstrdup(yytext);
					return FCONST;
				}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 1048 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 1052 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 1056 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 1060 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 1064 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 1068 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 1072 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 1078 "scan.l"
{
					int			kwnum;
					char	   *ident;

					SET_YYLLOC();

					/* Is it a keyword? */
					kwnum = ScanKeywordLookup(yytext,
											  yyextra->keywordlist);
					if (kwnum >= 0)
					{
						yylval->keyword = GetScanKeyword(kwnum,
														 yyextra->keywordlist);
						return yyextra->keyword_tokens[kwnum];
					}

					/*
					 * No.  Convert the identifier to lower case, and truncate
					 * if necessary.
					 */
					ident = downcase_truncate_identifier(yytext, yyleng, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 1103 "scan.l"
{
					SET_YYLLOC();
					return yytext[0];
				}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 1108 "scan.l"
{
					SET_YYLLOC();
					yyterminate();
				}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 1113 "scan.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 7638 "scan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yy_start_state_list[yyg->yy_start];

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		yy_current_state += yy_current_state[(*yy_cp ? YY_SC_TO_UI(*yy_cp) : 256)].yy_nxt;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	int yy_c = 256;
	const struct yy_trans_info *yy_trans_info;

	yy_trans_info = &yy_current_state[(unsigned int) yy_c];
	yy_current_state += yy_trans_info->yy_nxt;
	yy_is_jam = (yy_trans_info->yy_verify != yy_c);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 1113 "scan.l"


/* LCOV_EXCL_STOP */

/*
 * Arrange access to yyextra for subroutines of the main yylex() function.
 * We expect each subroutine to have a yyscanner parameter.  Rather than
 * use the yyget_xxx functions, which might or might not get inlined by the
 * compiler, we cheat just a bit and cast yyscanner to the right type.
 */
#undef yyextra
#define yyextra  (((struct yyguts_t *) yyscanner)->yyextra_r)

/* Likewise for a couple of other things we need. */
#undef yylloc
#define yylloc	(((struct yyguts_t *) yyscanner)->yylloc_r)
#undef yyleng
#define yyleng	(((struct yyguts_t *) yyscanner)->yyleng_r)


/*
 * scanner_errposition
 *		Report a lexer or grammar error cursor position, if possible.
 *
 * This is expected to be used within an ereport() call, or via an error
 * callback such as setup_scanner_errposition_callback().  The return value
 * is a dummy (always 0, in fact).
 *
 * Note that this can only be used for messages emitted during raw parsing
 * (essentially, scan.l, parser.c, and gram.y), since it requires the
 * yyscanner struct to still be available.
 */
int
scanner_errposition(int location, core_yyscan_t yyscanner)
{
	int			pos;

	if (location < 0)
		return 0;				/* no-op if location is unknown */

	/* Convert byte offset to character number */
	pos = pg_mbstrlen_with_len(yyextra->scanbuf, location) + 1;
	/* And pass it to the ereport mechanism */
	return errposition(pos);
}

/*
 * Error context callback for inserting scanner error location.
 *
 * Note that this will be called for *any* error occurring while the
 * callback is installed.  We avoid inserting an irrelevant error location
 * if the error is a query cancel --- are there any other important cases?
 */
static void
scb_error_callback(void *arg)
{
	ScannerCallbackState *scbstate = (ScannerCallbackState *) arg;

	if (geterrcode() != ERRCODE_QUERY_CANCELED)
		(void) scanner_errposition(scbstate->location, scbstate->yyscanner);
}

/*
 * setup_scanner_errposition_callback
 *		Arrange for non-scanner errors to report an error position
 *
 * Sometimes the scanner calls functions that aren't part of the scanner
 * subsystem and can't reasonably be passed the yyscanner pointer; yet
 * we would like any errors thrown in those functions to be tagged with an
 * error location.  Use this function to set up an error context stack
 * entry that will accomplish that.  Usage pattern:
 *
 *		declare a local variable "ScannerCallbackState scbstate"
 *		...
 *		setup_scanner_errposition_callback(&scbstate, yyscanner, location);
 *		call function that might throw error;
 *		cancel_scanner_errposition_callback(&scbstate);
 */
void
setup_scanner_errposition_callback(ScannerCallbackState *scbstate,
								   core_yyscan_t yyscanner,
								   int location)
{
	/* Setup error traceback support for ereport() */
	scbstate->yyscanner = yyscanner;
	scbstate->location = location;
	scbstate->errcallback.callback = scb_error_callback;
	scbstate->errcallback.arg = (void *) scbstate;
	scbstate->errcallback.previous = error_context_stack;
	error_context_stack = &scbstate->errcallback;
}

/*
 * Cancel a previously-set-up errposition callback.
 */
void
cancel_scanner_errposition_callback(ScannerCallbackState *scbstate)
{
	/* Pop the error context stack */
	error_context_stack = scbstate->errcallback.previous;
}

/*
 * scanner_yyerror
 *		Report a lexer or grammar error.
 *
 * The message's cursor position is whatever YYLLOC was last set to,
 * ie, the start of the current token if called within yylex(), or the
 * most recently lexed token if called from the grammar.
 * This is OK for syntax error messages from the Bison parser, because Bison
 * parsers report error as soon as the first unparsable token is reached.
 * Beware of using yyerror for other purposes, as the cursor position might
 * be misleading!
 */
void
scanner_yyerror(const char *message, core_yyscan_t yyscanner)
{
	const char *loc = yyextra->scanbuf + *yylloc;

	if (*loc == YY_END_OF_BUFFER_CHAR)
	{
		ereport(ERROR,
				(errcode(ERRCODE_SYNTAX_ERROR),
		/* translator: %s is typically the translation of "syntax error" */
				 errmsg("%s at end of input", _(message)),
				 lexer_errposition()));
	}
	else
	{
		ereport(ERROR,
				(errcode(ERRCODE_SYNTAX_ERROR),
		/* translator: first %s is typically the translation of "syntax error" */
				 errmsg("%s at or near \"%s\"", _(message), loc),
				 lexer_errposition()));
	}
}


/*
 * Called before any actual parsing is done
 */
core_yyscan_t
scanner_init(const char *str,
			 core_yy_extra_type *yyext,
			 const ScanKeywordList *keywordlist,
			 const uint16 *keyword_tokens)
{
	Size		slen = strlen(str);
	yyscan_t	scanner;

	if (yylex_init(&scanner) != 0)
		elog(ERROR, "yylex_init() failed: %m");

	core_yyset_extra(yyext, scanner);

	yyext->keywordlist = keywordlist;
	yyext->keyword_tokens = keyword_tokens;

	yyext->backslash_quote = backslash_quote;
	yyext->escape_string_warning = escape_string_warning;
	yyext->standard_conforming_strings = standard_conforming_strings;

	/*
	 * Make a scan buffer with special termination needed by flex.
	 */
	yyext->scanbuf = (char *) palloc(slen + 2);
	yyext->scanbuflen = slen;
	memcpy(yyext->scanbuf, str, slen);
	yyext->scanbuf[slen] = yyext->scanbuf[slen + 1] = YY_END_OF_BUFFER_CHAR;
	yy_scan_buffer(yyext->scanbuf, slen + 2, scanner);

	/* initialize literal buffer to a reasonable but expansible size */
	yyext->literalalloc = 1024;
	yyext->literalbuf = (char *) palloc(yyext->literalalloc);
	yyext->literallen = 0;

	return scanner;
}


/*
 * Called after parsing is done to clean up after scanner_init()
 */
void
scanner_finish(core_yyscan_t yyscanner)
{
	/*
	 * We don't bother to call yylex_destroy(), because all it would do is
	 * pfree a small amount of control storage.  It's cheaper to leak the
	 * storage until the parsing context is destroyed.  The amount of space
	 * involved is usually negligible compared to the output parse tree
	 * anyway.
	 *
	 * We do bother to pfree the scanbuf and literal buffer, but only if they
	 * represent a nontrivial amount of space.  The 8K cutoff is arbitrary.
	 */
	if (yyextra->scanbuflen >= 8192)
		pfree(yyextra->scanbuf);
	if (yyextra->literalalloc >= 8192)
		pfree(yyextra->literalbuf);
}


static void
addlit(char *ytext, int yleng, core_yyscan_t yyscanner)
{
	/* enlarge buffer if needed */
	if ((yyextra->literallen + yleng) >= yyextra->literalalloc)
	{
		yyextra->literalalloc = pg_nextpower2_32(yyextra->literallen + yleng + 1);
		yyextra->literalbuf = (char *) repalloc(yyextra->literalbuf,
												yyextra->literalalloc);
	}
	/* append new data */
	memcpy(yyextra->literalbuf + yyextra->literallen, ytext, yleng);
	yyextra->literallen += yleng;
}


static void
addlitchar(unsigned char ychar, core_yyscan_t yyscanner)
{
	/* enlarge buffer if needed */
	if ((yyextra->literallen + 1) >= yyextra->literalalloc)
	{
		yyextra->literalalloc *= 2;
		yyextra->literalbuf = (char *) repalloc(yyextra->literalbuf,
												yyextra->literalalloc);
	}
	/* append new data */
	yyextra->literalbuf[yyextra->literallen] = ychar;
	yyextra->literallen += 1;
}


/*
 * Create a palloc'd copy of literalbuf, adding a trailing null.
 */
static char *
litbufdup(core_yyscan_t yyscanner)
{
	int			llen = yyextra->literallen;
	char	   *new;

	new = palloc(llen + 1);
	memcpy(new, yyextra->literalbuf, llen);
	new[llen] = '\0';
	return new;
}

/*
 * Process {decinteger}, {hexinteger}, etc.  Note this will also do the right
 * thing with {numeric}, ie digits and a decimal point.
 */
static int
process_integer_literal(const char *token, YYSTYPE *lval, int base)
{
	ErrorSaveContext escontext = {T_ErrorSaveContext};
	int32		val;

	val = pg_strtoint32_safe(token, (Node *) &escontext);
	if (escontext.error_occurred)
	{
		/* integer too large (or contains decimal pt), treat it as a float */
		lval->str = pstrdup(token);
		return FCONST;
	}
	lval->ival = val;
	return ICONST;
}

static void
addunicode(pg_wchar c, core_yyscan_t yyscanner)
{
	ScannerCallbackState scbstate;
	char		buf[MAX_UNICODE_EQUIVALENT_STRING + 1];

	if (!is_valid_unicode_codepoint(c))
		yyerror("invalid Unicode escape value");

	/*
	 * We expect that pg_unicode_to_server() will complain about any
	 * unconvertible code point, so we don't have to set saw_non_ascii.
	 */
	setup_scanner_errposition_callback(&scbstate, yyscanner, *(yylloc));
	pg_unicode_to_server(c, (unsigned char *) buf);
	cancel_scanner_errposition_callback(&scbstate);
	addlit(buf, strlen(buf), yyscanner);
}

static unsigned char
unescape_single_char(unsigned char c, core_yyscan_t yyscanner)
{
	switch (c)
	{
		case 'b':
			return '\b';
		case 'f':
			return '\f';
		case 'n':
			return '\n';
		case 'r':
			return '\r';
		case 't':
			return '\t';
		case 'v':
			return '\v';
		default:
			/* check for backslash followed by non-7-bit-ASCII */
			if (c == '\0' || IS_HIGHBIT_SET(c))
				yyextra->saw_non_ascii = true;

			return c;
	}
}

static void
check_string_escape_warning(unsigned char ychar, core_yyscan_t yyscanner)
{
	if (ychar == '\'')
	{
		if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
			ereport(WARNING,
					(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
					 errmsg("nonstandard use of \\' in a string literal"),
					 errhint("Use '' to write quotes in strings, or use the escape string syntax (E'...')."),
					 lexer_errposition()));
		yyextra->warn_on_first_escape = false;	/* warn only once per string */
	}
	else if (ychar == '\\')
	{
		if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
			ereport(WARNING,
					(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
					 errmsg("nonstandard use of \\\\ in a string literal"),
					 errhint("Use the escape string syntax for backslashes, e.g., E'\\\\'."),
					 lexer_errposition()));
		yyextra->warn_on_first_escape = false;	/* warn only once per string */
	}
	else
		check_escape_warning(yyscanner);
}

static void
check_escape_warning(core_yyscan_t yyscanner)
{
	if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
		ereport(WARNING,
				(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
				 errmsg("nonstandard use of escape in a string literal"),
		errhint("Use the escape string syntax for escapes, e.g., E'\\r\\n'."),
				 lexer_errposition()));
	yyextra->warn_on_first_escape = false;		/* warn only once per string */
}

/*
 * Interface functions to make flex use palloc() instead of malloc().
 * It'd be better to make these static, but flex insists otherwise.
 */

void *
core_yyalloc(yy_size_t bytes, core_yyscan_t yyscanner)
{
	return palloc(bytes);
}

void *
core_yyrealloc(void *ptr, yy_size_t bytes, core_yyscan_t yyscanner)
{
	if (ptr)
		return repalloc(ptr, bytes);
	else
		return palloc(bytes);
}

void
core_yyfree(void *ptr, core_yyscan_t yyscanner)
{
	if (ptr)
		pfree(ptr);
}

